@@ -116,7 +116,7 @@ tools = [
 ['grid_analysis', 18, 'Accumulation Functions'],
 ['grid_analysis', 19, 'IMCORR - Feature Tracking'],
 ['grid_analysis', 20, 'Soil Texture Classification for Tables'],
-['grid_calculus', 0, 'Grid Normalisation'],
+['grid_calculus', 0, 'Grid Normalization'],
 ['grid_calculus', 1, 'Grid Calculator'],
 ['grid_calculus', 2, 'Grid Volume'],
 ['grid_calculus', 3, 'Grid Difference'],
@@ -126,7 +126,7 @@ tools = [
 ['grid_calculus', 7, 'Random Field'],
 ['grid_calculus', 8, 'Grids Sum'],
 ['grid_calculus', 9, 'Grids Product'],
-['grid_calculus', 10, 'Grid Standardisation'],
+['grid_calculus', 10, 'Grid Standardization'],
 ['grid_calculus', 11, 'Fuzzify'],
 ['grid_calculus', 12, 'Fuzzy Intersection (AND)'],
 ['grid_calculus', 13, 'Fuzzy Union (OR)'],
@@ -347,7 +347,7 @@ tools = [
 ['pointcloud_tools', 6, 'Point Cloud Reclassifier / Subset Extractor'],
 ['pointcloud_tools', 7, 'Drop Point Cloud Attributes'],
 ['pointcloud_tools', 8, 'Transform Point Cloud'],
-['pointcloud_tools', 9, 'Point Cloud Thinning (simple)'],
+['pointcloud_tools', 9, 'Point Cloud Thinning (Simple)'],
 ['pointcloud_tools', 10, 'Point Cloud Attribute Calculator'],
 ['pointcloud_tools', 11, 'Cluster Analysis for Point Clouds'],
 ['pointcloud_tools', 12, 'Merge Point Clouds'],
@@ -379,7 +379,7 @@ tools = [
 ['shapes_points', 1, 'Count Points in Polygons'],
 ['shapes_points', 2, 'Create Point Grid'],
 ['shapes_points', 3, 'Point Distances'],
-['shapes_points', 4, 'Fit N Points to shape'],
+['shapes_points', 4, 'Populate Polygons with Points'],
 ['shapes_points', 5, 'Convert Lines to Points'],
 ['shapes_points', 6, 'Add Coordinates to Points'],
 ['shapes_points', 7, 'Remove Duplicate Points'],
@@ -545,7 +545,7 @@ tools = [
 ['ta_morphometry', 9, 'Downslope Distance Gradient'],
 ['ta_morphometry', 10, 'Mass Balance Index'],
 ['ta_morphometry', 11, 'Effective Air Flow Heights'],
-['ta_morphometry', 12, 'Diurnal Anisotropic Heating'],
+['ta_morphometry', 12, 'Diurnal Anisotropic Heat'],
 ['ta_morphometry', 13, 'Land Surface Temperature'],
 ['ta_morphometry', 14, 'Relative Heights and Slope Positions'],
 ['ta_morphometry', 15, 'Wind Effect (Windward / Leeward Index)'],
@@ -582,7 +582,7 @@ tools = [
 ['table_calculus', 5, 'Running Average'],
 ['table_calculus', 6, 'Cluster Analysis'],
 ['table_calculus', 7, 'Principle Components Analysis'],
-['table_calculus', 8, 'Fill Gaps in Records'],
+['table_calculus', 8, 'Fill Gaps in Ordered Records'],
 ['table_calculus', 11, 'Find Field of Extreme Value'],
 ['table_calculus', 12, 'Minimum Redundancy Feature Selection'],
 ['table_calculus', 14, 'Cluster Analysis (Shapes)'],
@@ -713,5 +713,17 @@ tools = [
 ['db_pgsql', 34, 'Export Grid Collection to PostGIS'],
 ['grid_gridding', 9, 'Polygons to Grid'],
 ['grid_gridding', 10, 'Polygon Categories to Grid'],
-['ta_lighting', 7, 'Potential Annual Insolation']
+['ta_lighting', 7, 'Potential Annual Insolation'],
+['climate_tools', 19, 'Climate Classification'],
+['climate_tools', 20, 'Soil Water Balance'],
+['grid_tools', 39, 'Change Grid Values - Flood Fill'],
+['io_gdal', 11, 'Import ASTER Scene'],
+['shapes_tools', 29, 'Focal Mechanism (Beachball Plots)'],
+['grids_tools', 3, 'Extract a Grid from a Grid Collection'],
+['grids_tools', 4, 'Add a Grid to a Grid Collection'],
+['grid_calculus', 20, 'Grid Collection Calculator'],
+['statistics_grid', 16, 'Statistics for Grids from Files'],
+['statistics_grid', 17, 'Build Statistics for Grids'],
+['statistics_grid', 18, 'Evaluate Statistics for Grids'],
+['table_calculus', 9, 'Fill Gaps in Records']
 ]
