@@ -449,7 +449,7 @@ SAGA_API_DLL_EXPORT int				SG_Get_Significant_Decimals		(double Value, int maxDe
 
 SAGA_API_DLL_EXPORT void			SG_Flip_Decimal_Separators		(CSG_String &String);
 
-SAGA_API_DLL_EXPORT CSG_String		SG_Get_String					(double Value, int Precision = 0, bool bScientific = false);
+SAGA_API_DLL_EXPORT CSG_String		SG_Get_String					(double Value, int Precision = -99);
 SAGA_API_DLL_EXPORT CSG_String		SG_Get_String					(int    Value, int Precision = 0);
 
 
@@ -622,7 +622,10 @@ public:
 	int &				Get				(int    Index)							{	return( *((int *)m_Array.Get_Entry(Index)) );	}
 	int	 				Get				(int    Index)	const					{	return( *((int *)m_Array.Get_Entry(Index)) );	}
 
+	bool				Assign			(int Value);
+
 	CSG_Array_Int &		operator =		(const CSG_Array_Int &Array)			{	Create(Array);	return( *this );	}
+	CSG_Array_Int &		operator =		(int Value)								{	Assign(Value);	return( *this );	}
 
 	int &				operator []		(size_t Index)							{	return( Get(Index) );	}
 	int  				operator []		(size_t Index)	const					{	return( Get(Index) );	}
