@@ -26,7 +26,8 @@
 // This library is free software; you can redistribute   //
 // it and/or modify it under the terms of the GNU Lesser //
 // General Public License as published by the Free       //
-// Software Foundation, version 2.1 of the License.      //
+// Software Foundation, either version 2.1 of the        //
+// License, or (at your option) any later version.       //
 //                                                       //
 // This library is distributed in the hope that it will  //
 // be useful, but WITHOUT ANY WARRANTY; without even the //
@@ -36,9 +37,7 @@
 //                                                       //
 // You should have received a copy of the GNU Lesser     //
 // General Public License along with this program; if    //
-// not, write to the Free Software Foundation, Inc.,     //
-// 51 Franklin Street, 5th Floor, Boston, MA 02110-1301, //
-// USA.                                                  //
+// not, see <http://www.gnu.org/licenses/>.              //
 //                                                       //
 //-------------------------------------------------------//
 //                                                       //
@@ -67,18 +66,26 @@
 #include <wx/filename.h>
 #include <wx/dir.h>
 #include <wx/wxcrtvararg.h>
+#include <wx/wfstream.h>
+#include <wx/zipstrm.h>
+#include <wx/log.h>
+#include <wx/version.h>
 
 #include "api_core.h"
 
-#if defined(_SAGA_VC)
-	#define SG_FILE_TELL	_ftelli64
-	#define SG_FILE_SEEK	_fseeki64
-	#define SG_FILE_SIZE	__int64
-#else
-	#define SG_FILE_TELL	ftell
-	#define SG_FILE_SEEK	fseek
-	#define SG_FILE_SIZE	long
-#endif
+
+///////////////////////////////////////////////////////////
+//														 //
+//														 //
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+#define m_pStream_Base	((wxStreamBase   *)m_pStream)
+#define m_pStream_In	((wxInputStream  *)m_pStream)
+#define m_pStream_Out	((wxOutputStream *)m_pStream)
+#define m_pStream_File	((wxFFileStream  *)m_pStream)
+
 
 ///////////////////////////////////////////////////////////
 //														 //
@@ -108,56 +115,51 @@ CSG_File::~CSG_File(void)
 }
 
 //---------------------------------------------------------
-bool CSG_File::Attach(FILE *Stream)
-{
-	Close();
-
-	m_pStream	= Stream;
-
-	return( true );
-}
-
-//---------------------------------------------------------
-bool CSG_File::Detach(void)
-{
-	m_pStream	= NULL;
-
-	return( true );
-}
-
-//---------------------------------------------------------
-bool CSG_File::Open(const CSG_String &File_Name, int Mode, bool bBinary, int Encoding)
+bool CSG_File::Open(const CSG_String &FileName, int Mode, bool bBinary, int Encoding)
 {
 	Close();
 
+	m_Mode		= Mode;
 	m_Encoding	= Encoding;
+	m_FileName	= FileName;
 
-	CSG_String	sMode;
-
-	switch( Mode )
-	{
-	default:	return( false );
-	case SG_FILE_R:		sMode	= bBinary ? SG_T("rb" ) : SG_T("r" );	break;
-	case SG_FILE_W:		sMode	= bBinary ? SG_T("wb" ) : SG_T("w" );	break;
-	case SG_FILE_RW:	sMode	= bBinary ? SG_T("wb+") : SG_T("w+");	break;
-	case SG_FILE_WA:	sMode	= bBinary ? SG_T("ab" ) : SG_T("a" );	break;
-	case SG_FILE_RWA:	sMode	= bBinary ? SG_T("rb+") : SG_T("r+");	break;
-	}
+	wxString	sEncoding;
 
 	switch( Encoding )
 	{
-	case SG_FILE_ENCODING_CHAR:		default:	break;
-	case SG_FILE_ENCODING_UNICODE:	sMode	+= SG_T(", ccs=UNICODE");	break;
-	case SG_FILE_ENCODING_UTF8:		sMode	+= SG_T(", ccs=UTF-8"  );	break;
-	case SG_FILE_ENCODING_UTF16:	sMode	+= SG_T(", ccs=UTF-16" );	break;
+	default                      :	sEncoding	= ""             ;	break;
+	case SG_FILE_ENCODING_UNICODE:	sEncoding	= ", ccs=UNICODE";	break;
+	case SG_FILE_ENCODING_UTF8   :	sEncoding	= ", ccs=UTF-8"  ;	break;
+	case SG_FILE_ENCODING_UTF16  :	sEncoding	= ", ccs=UTF-16" ;	break;
 	}
 
-	if( File_Name.Length() > 0 )
+	if( Mode == SG_FILE_W )
 	{
-		m_pStream	= fopen(File_Name, sMode);
+		wxString	sMode	= bBinary ? "wb" : "w";
+
+		m_pStream	= new wxFFileOutputStream(FileName.c_str(), sMode + sEncoding);
+	}
+	else if( Mode == SG_FILE_R && SG_File_Exists(FileName) )
+	{
+		wxString	sMode	= bBinary ? "rb" : "r";
+
+		m_pStream	= new wxFFileInputStream (FileName.c_str(), sMode + sEncoding);
+	}
+	else if( Mode == SG_FILE_RW )
+	{
+		wxString	sMode	= SG_File_Exists(FileName) ? (bBinary ? "r+b" : "r+") : (bBinary ? "w+b" : "w+");
+
+		m_pStream	= new wxFFileStream      (FileName.c_str(), sMode + sEncoding);
 	}
 
-	return( m_pStream != NULL );
+	if( !m_pStream || !m_pStream_Base->IsOk() )
+	{
+		Close();
+
+		return( false );
+	}
+
+	return( true );
 }
 
 //---------------------------------------------------------
@@ -165,7 +167,7 @@ bool CSG_File::Close(void)
 {
 	if( m_pStream )
 	{
-		fclose(m_pStream);
+		delete(m_pStream_Base);
 
 		m_pStream	= NULL;
 
@@ -176,134 +178,146 @@ bool CSG_File::Close(void)
 }
 
 //---------------------------------------------------------
-sLong CSG_File::Length(void)	const
+sLong CSG_File::Length(void) const
+{
+	return( m_pStream ? m_pStream_Base->GetLength() : -1 );
+}
+
+//---------------------------------------------------------
+bool CSG_File::is_EOF(void)	const
+{
+	return( is_Reading() && m_pStream_In->Eof() );
+}
+
+//---------------------------------------------------------
+bool CSG_File::Seek(sLong Offset, int Origin) const
 {
 	if( m_pStream )
 	{
-		SG_FILE_SIZE	pos	= SG_FILE_TELL(m_pStream);	SG_FILE_SEEK(m_pStream,   0, SEEK_END);
-		SG_FILE_SIZE	len	= SG_FILE_TELL(m_pStream);	SG_FILE_SEEK(m_pStream, pos, SEEK_SET);
+		wxSeekMode	Seek = Origin == SG_FILE_CURRENT ? wxFromCurrent : Origin == SG_FILE_END ? wxFromEnd : wxFromStart;
 
-		return( len );
+		switch( m_Mode )
+		{
+		case SG_FILE_R : return( m_pStream_In  ->SeekI(Offset, Seek) != wxInvalidOffset );
+		case SG_FILE_W : return( m_pStream_Out ->SeekO(Offset, Seek) != wxInvalidOffset );
+		case SG_FILE_RW: return( m_pStream_File->SeekI(Offset, Seek) != wxInvalidOffset
+							&&   m_pStream_File->SeekO(Offset, Seek) != wxInvalidOffset );
+		}
+	}
+
+	return( false );
+}
+
+//---------------------------------------------------------
+bool CSG_File::Seek_Start(void) const	{	return( Seek(0, SEEK_SET) );	}
+bool CSG_File::Seek_End  (void) const	{	return( Seek(0, SEEK_END) );	}
+
+//---------------------------------------------------------
+sLong CSG_File::Tell(void) const
+{
+	if( m_pStream )
+	{
+		switch( m_Mode )
+		{
+		case SG_FILE_R : return( m_pStream_In  ->TellI() );
+		case SG_FILE_W : return( m_pStream_Out ->TellO() );
+		case SG_FILE_RW: return( m_pStream_File->TellI() );
+		}
 	}
 
 	return( -1 );
 }
 
-//---------------------------------------------------------
-bool CSG_File::is_EOF(void)	const
-{
-	return( m_pStream == NULL || feof(m_pStream) != 0 );
-}
-
-//---------------------------------------------------------
-bool CSG_File::Seek(sLong Offset, int Origin) const
-{
-	switch( Origin )
-	{
-	default:
-	case SG_FILE_START:		Origin	= SEEK_SET;	break;
-	case SG_FILE_CURRENT:	Origin	= SEEK_CUR;	break;
-	case SG_FILE_END:		Origin	= SEEK_END;	break;
-	}
-
-	return( m_pStream ? !SG_FILE_SEEK(m_pStream, Offset, Origin) : false );
-}
-
-//---------------------------------------------------------
-bool CSG_File::Seek_Start(void) const
-{
-	return( m_pStream && SG_FILE_SEEK(m_pStream, 0, SEEK_SET) == 0 );
-}
-
-//---------------------------------------------------------
-bool CSG_File::Seek_End(void) const
-{
-	return( m_pStream && SG_FILE_SEEK(m_pStream, 0, SEEK_END) == 0 );
-}
-
-//---------------------------------------------------------
-sLong CSG_File::Tell(void) const
-{
-	return( m_pStream ? SG_FILE_TELL(m_pStream) : -1 );
-}
-
-//---------------------------------------------------------
-bool CSG_File::Flush(void) const
-{
-	return( m_pStream ? !fflush(m_pStream) : false );
-}
-
 //---------------------------------------------------------
 int CSG_File::Printf(const char *Format, ...)
 {
-	if( !m_pStream )
+	if( !is_Writing() )
 	{
 		return( 0 );
 	}
 
+	wxString	String;
+
 #ifdef _SAGA_LINUX
-	wxString	_Format(Format);	_Format.Replace("%s", "%ls");	// workaround as we only use wide characters since wx 2.9.4 so interpret strings as multibyte
+	wxString _Format(Format); _Format.Replace("%s", "%ls");	// workaround as we only use wide characters since wx 2.9.4 so interpret strings as multibyte
 	va_list	argptr; va_start(argptr, _Format);
-	int	result	= wxVfprintf(m_pStream, _Format, argptr);
+	int	Result	= String.PrintfV(_Format, argptr);
 #else
-	va_list	argptr;	va_start(argptr, Format);
-
-	int	result	= wxVfprintf(m_pStream, Format, argptr);
+	va_list	argptr; va_start(argptr, Format);
+	int	Result	= String.PrintfV(Format, argptr);
 #endif
-
 	va_end(argptr);
 
-	return( result );
+	Write(&String);
+
+	return( Result );
 }
 
 //---------------------------------------------------------
 int CSG_File::Printf(const wchar_t *Format, ...)
 {
-	if( !m_pStream )
+	if( !is_Writing() )
 	{
 		return( 0 );
 	}
 
-#ifdef _SAGA_LINUX
-	wxString	_Format(Format);	_Format.Replace("%s", "%ls");	// workaround as we only use wide characters since wx 2.9.4 so interpret strings as multibyte
-	va_list	argptr; va_start(argptr, _Format);
-	int	result	= wxVfprintf(m_pStream, _Format, argptr);
-#else
-	va_list	argptr;	va_start(argptr, Format);
+	wxString	String;
 
-	int	result	= wxVfprintf(m_pStream, Format, argptr);
+#ifdef _SAGA_LINUX
+	wxString _Format(Format); _Format.Replace("%s", "%ls");	// workaround as we only use wide characters since wx 2.9.4 so interpret strings as multibyte
+	va_list	argptr; va_start(argptr, _Format);
+	int	Result	= String.PrintfV(_Format, argptr);
+#else
+	va_list	argptr; va_start(argptr, Format);
+	int	Result	= String.PrintfV(Format, argptr);
 #endif
 
 	va_end(argptr);
 
-	return( result );
+	Write(&String);
+
+	return( Result );
 }
 
 //---------------------------------------------------------
 size_t CSG_File::Read(void *Buffer, size_t Size, size_t Count) const
 {
-	return( m_pStream ? fread(Buffer, Size, Count, m_pStream) : 0 );
+	return( !is_Reading() || Size == 0 || Count == 0 ? 0 : m_Mode == SG_FILE_RW
+		? m_pStream_File->Read(Buffer, Size * Count).LastRead() / Size
+		: m_pStream_In  ->Read(Buffer, Size * Count).LastRead() / Size
+	);
 }
 
 size_t CSG_File::Read(CSG_String &Buffer, size_t Size) const
 {
-	if( m_pStream )
+	if( is_Reading() && Size > 0 )
 	{
-		char	*b	= (char *)SG_Calloc(Size + 1, sizeof(char));
-		size_t	 i	= fread(b, sizeof(char), Size, m_pStream);
-		Buffer		= b;
-		SG_Free(b);
+		CSG_Array	b(sizeof(char), Size + 1);
 
-		return( i );
+		size_t	 i	= Read(b.Get_Array(), b.Get_Value_Size(), Size);
+
+		if( i > 0 )
+		{
+			char	*s	= (char *)b.Get_Array(); s[Size] = '\0';
+
+			Buffer	= s;
+
+			return( i );
+		}
 	}
 
+	Buffer.Clear();
+
 	return( 0 );
 }
 
 //---------------------------------------------------------
 size_t CSG_File::Write(void *Buffer, size_t Size, size_t Count) const
 {
-	return( m_pStream && Size > 0 && Count > 0 ? fwrite(Buffer, Size, Count, m_pStream) : 0 );
+	return( !is_Writing() || Size == 0 || Count == 0 ? 0 : m_Mode == SG_FILE_RW
+		? m_pStream_File->Write(Buffer, Size * Count).LastWrite()
+		: m_pStream_Out ->Write(Buffer, Size * Count).LastWrite()
+	);
 }
 
 size_t CSG_File::Write(const CSG_String &Buffer) const
@@ -314,13 +328,13 @@ size_t CSG_File::Write(const CSG_String &Buffer) const
 //---------------------------------------------------------
 bool CSG_File::Read_Line(CSG_String &sLine)	const
 {
-	int		c;
-
-	if( m_pStream && !feof(m_pStream) )
+	if( is_Reading() && !is_EOF() )
 	{
 		sLine.Clear();
 
-		while( !feof(m_pStream) && (c = fgetc(m_pStream)) != 0x0A && c != EOF )
+		int		c;
+
+		while( !is_EOF() && (c = Read_Char()) != 0x0A && c != EOF )
 		{
 			if( c != 0x0D )
 			{
@@ -337,12 +351,7 @@ bool CSG_File::Read_Line(CSG_String &sLine)	const
 //---------------------------------------------------------
 int CSG_File::Read_Char(void) const
 {
-	if( m_pStream )
-	{
-		return( getc(m_pStream) );
-	}
-
-	return( 0 );
+	return( !is_Reading() ? 0 : m_Mode == SG_FILE_RW ? m_pStream_File->GetC() : m_pStream_In->GetC() );
 }
 
 //---------------------------------------------------------
@@ -400,23 +409,61 @@ bool CSG_File::Write_Double(double Value, bool bByteOrderBig)
 //---------------------------------------------------------
 bool CSG_File::Scan(int &Value) const
 {
-	return( m_pStream && fscanf(m_pStream, "%d" , &Value) == 1 );
+	if( is_Reading() )
+	{
+		int		c;
+
+		while( !is_EOF() && isspace(c = Read_Char()) );	// remove leading white space
+
+		if( isdigit(c) || strchr("-+", c) )
+		{
+			CSG_String	s	= (char)c;
+
+			while( !is_EOF() && isdigit(c = Read_Char()) )
+			{
+				s	+= (char)c;
+			}
+
+			return( s.asInt(Value) );
+		}
+	}
+
+	return( false );
 }
 
 bool CSG_File::Scan(double &Value) const
 {
-	return( m_pStream && fscanf(m_pStream, "%lf", &Value) == 1 );
+	if( is_Reading() )
+	{
+		int		c;
+
+		while( !is_EOF() && isspace(c = Read_Char()) );	// remove leading white space
+
+		if( isdigit(c) || strchr("-+.,eE", c) )
+		{
+			CSG_String	s	= (char)c;
+
+			while( !is_EOF() && (isdigit(c = Read_Char()) || strchr(".,eE", c) || strchr("", c)) )
+			{
+				s	+= (char)c;
+			}
+
+			return( s.asDouble(Value) );
+		}
+	}
+
+	return( false );
 }
 
 bool CSG_File::Scan(CSG_String &Value, SG_Char Separator) const
 {
-	if( m_pStream && !feof(m_pStream) )
+	if( is_Reading() && !is_EOF() )
 	{
-		int		c;
-
 		Value.Clear();
 
-		while( !feof(m_pStream) && (c = fgetc(m_pStream)) != Separator && c != EOF )
+		int		c;
+
+		while( !is_EOF() && (c = Read_Char()) != Separator && c != EOF )
 		{
 			Value	+= (char)c;
 		}
@@ -459,20 +506,182 @@ CSG_String CSG_File::Scan_String(SG_Char Separator) const
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-bool			SG_Dir_Exists(const SG_Char *Directory)
+CSG_File_Zip::CSG_File_Zip(void)
 {
-	return( Directory && *Directory && wxFileName::DirExists(Directory) );
 }
 
 //---------------------------------------------------------
-bool			SG_Dir_Create(const SG_Char *Directory)
+CSG_File_Zip::~CSG_File_Zip(void)
+{
+	Close();
+}
+
+//---------------------------------------------------------
+CSG_File_Zip::CSG_File_Zip(const CSG_String &FileName, int Mode)
+{
+	Open(FileName, Mode);
+}
+
+//---------------------------------------------------------
+bool CSG_File_Zip::Open(const CSG_String &FileName, int Mode)
+{
+	wxLogNull	logNo;	// suppress user notification dialog for invalid zip files
+
+	Close();
+
+	m_Mode	= Mode;
+
+	if( Mode == SG_FILE_W )
+	{
+		m_pStream	= new wxZipOutputStream(new wxFileOutputStream(FileName.c_str()));
+	}
+	else if( Mode == SG_FILE_R && SG_File_Exists(FileName) )
+	{
+		m_pStream	= new wxZipInputStream (new wxFileInputStream (FileName.c_str()));
+	}
+
+	if( !m_pStream || !m_pStream_Base->IsOk() )
+	{
+		Close();
+
+		return( false );
+	}
+
+	if( is_Reading() )
+	{
+		wxZipEntry	*pEntry;
+
+		while( (pEntry = ((wxZipInputStream *)m_pStream)->GetNextEntry()) != NULL )
+		{
+			m_Files	+= pEntry;
+		}
+	}
+
+	return( true );
+}
+
+//---------------------------------------------------------
+bool CSG_File_Zip::Close(void)
+{
+	for(size_t i=0; i<m_Files.Get_Size(); i++)
+	{
+		delete((wxZipEntry *)m_Files[i]);
+	}
+
+	m_Files.Set_Array(0);
+
+	return( CSG_File::Close() );
+}
+
+//---------------------------------------------------------
+bool CSG_File_Zip::Add_Directory(const CSG_String &Name)
+{
+	return( is_Writing() && ((wxZipOutputStream *)m_pStream)->PutNextDirEntry(Name.c_str()) );
+}
+
+//---------------------------------------------------------
+bool CSG_File_Zip::Add_File(const CSG_String &Name, bool bBinary)
+{
+	if( is_Writing() )
+	{
+		wxZipEntry	*pEntry	= new wxZipEntry(Name.c_str());
+
+		pEntry->SetIsText(bBinary == false);
+
+		#if wxCHECK_VERSION(3, 1, 1)
+		((wxZipOutputStream *)m_pStream)->SetFormat(wxZIP_FORMAT_ZIP64);
+		#endif
+
+		if( ((wxZipOutputStream *)m_pStream)->PutNextEntry(pEntry) )
+		{
+			m_FileName	= Name;
+
+			return( true );
+		}
+	}
+
+	return( false );
+}
+
+//---------------------------------------------------------
+bool CSG_File_Zip::is_Directory(size_t Index)
+{
+	if( is_Reading() && m_Files[Index] )
+	{
+		return( ((wxZipEntry *)m_Files[Index])->IsDir() );
+	}
+
+	return( false );
+}
+
+//---------------------------------------------------------
+bool CSG_File_Zip::Get_File(size_t Index)
+{
+	if( is_Reading() && m_Files[Index] )
+	{
+		if( ((wxZipInputStream *)m_pStream)->OpenEntry(*(wxZipEntry *)m_Files[Index]) )
+		{
+			m_FileName	= Get_File_Name(Index);
+
+			return( true );
+		}
+	}
+
+	return( false );
+}
+
+//---------------------------------------------------------
+bool CSG_File_Zip::Get_File(const CSG_String &Name)
+{
+	if( is_Reading() )
+	{
+		for(size_t i=0; i<m_Files.Get_Size(); i++)
+		{
+			if( !((wxZipEntry *)m_Files[i])->GetName().Cmp(Name.c_str()) )
+			{
+				return( Get_File(i) );
+			}
+		}
+	}
+
+	return( false );
+}
+
+//---------------------------------------------------------
+CSG_String CSG_File_Zip::Get_File_Name(size_t Index)
+{
+	CSG_String	s;
+
+	if( is_Reading() && m_Files[Index] )
+	{
+		wxString Name(((wxZipEntry *)m_Files[Index])->GetName()); s	= &Name;
+	}
+
+	return( s );
+}
+
+
+///////////////////////////////////////////////////////////
+//														 //
+//														 //
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+bool			SG_Dir_Exists(const CSG_String &Directory)
+{
+	return( wxFileName::DirExists(Directory.c_str()) );
+}
+
+//---------------------------------------------------------
+bool			SG_Dir_Create(const CSG_String &Directory)
 {
 	if( SG_Dir_Exists(Directory) )
 	{
 		return( true );
 	}
 
-	return( wxFileName::Mkdir(Directory) );
+	return( wxFileName::Mkdir(Directory.c_str()) );
 }
 
 //---------------------------------------------------------
@@ -506,7 +715,7 @@ bool			SG_Dir_List_Subdirectories	(CSG_Strings &List, const CSG_String &Director
 		{
 			do
 			{
-				List	+= SG_File_Make_Path(Directory, FileName);
+				List	+= SG_File_Make_Path(Directory, &FileName);
 			}
 			while( Dir.GetNext(&FileName) );
 		}
@@ -516,7 +725,12 @@ bool			SG_Dir_List_Subdirectories	(CSG_Strings &List, const CSG_String &Director
 }
 
 //---------------------------------------------------------
-bool			SG_Dir_List_Files			(CSG_Strings &List, const CSG_String &Directory, const SG_Char *Extension)
+bool			SG_Dir_List_Files			(CSG_Strings &List, const CSG_String &Directory)
+{
+	return( SG_Dir_List_Files(List, Directory, "") );
+}
+
+bool			SG_Dir_List_Files			(CSG_Strings &List, const CSG_String &Directory, const CSG_String &Extension)
 {
 	List.Clear();
 
@@ -530,9 +744,9 @@ bool			SG_Dir_List_Files			(CSG_Strings &List, const CSG_String &Directory, cons
 		{
 			do
 			{
-				if( !Extension || !*Extension || SG_File_Cmp_Extension(FileName, Extension) )
+				if( Extension.is_Empty() || SG_File_Cmp_Extension(&FileName, Extension) )
 				{
-					List	+= SG_File_Make_Path(Directory, FileName);
+					List	+= SG_File_Make_Path(Directory, &FileName);
 				}
 			}
 			while( Dir.GetNext(&FileName) );
@@ -550,115 +764,117 @@ bool			SG_Dir_List_Files			(CSG_Strings &List, const CSG_String &Directory, cons
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-bool			SG_File_Exists(const SG_Char *FileName)
+bool			SG_File_Exists(const CSG_String &FileName)
 {
-	return( FileName && *FileName && wxFileExists(FileName) );
+	return( wxFileExists(FileName.c_str()) );
 }
 
 //---------------------------------------------------------
-bool			SG_File_Delete(const SG_Char *FileName)
+bool			SG_File_Delete(const CSG_String &FileName)
 {
-	return( SG_File_Exists(FileName) && wxRemoveFile(FileName) );
+	return( SG_File_Exists(FileName) && wxRemoveFile(FileName.c_str()) );
 }
 
 //---------------------------------------------------------
-CSG_String		SG_File_Get_Name_Temp(const SG_Char *Prefix, const SG_Char *Directory)
+CSG_String		SG_File_Get_Name_Temp(const CSG_String &Prefix)
+{
+	return( SG_File_Get_Name_Temp(Prefix, "") );
+}
+
+CSG_String		SG_File_Get_Name_Temp(const CSG_String &Prefix, const CSG_String &Directory)
 {
 	if( !SG_Dir_Exists(Directory) )
 	{
-		return( CSG_String(wxFileName::CreateTempFileName(Prefix).wc_str()) );
+		return( CSG_String(wxFileName::CreateTempFileName(Prefix.c_str()).wc_str()) );
 	}
 
 	return( CSG_String(wxFileName::CreateTempFileName(SG_File_Make_Path(Directory, Prefix).w_str()).wc_str()) );
 }
 
 //---------------------------------------------------------
-CSG_String		SG_File_Get_Name(const SG_Char *full_Path, bool bExtension)
+CSG_String		SG_File_Get_Name(const CSG_String &full_Path, bool bExtension)
 {
-	wxFileName	fn(full_Path);
-	CSG_String	s(fn.GetFullName().wc_str());
+	wxFileName	fn(full_Path.c_str());
 
-	return( !bExtension && s.Find(SG_T(".")) >= 0 ? s.BeforeLast(SG_T('.')) : s );
-}
-
-//---------------------------------------------------------
-CSG_String		SG_File_Get_Path(const SG_Char *full_Path)
-{
-	if( full_Path && *full_Path )
+	if( bExtension )
 	{
-		wxFileName	fn(full_Path);
-
-		return( CSG_String(fn.GetPath(wxPATH_GET_VOLUME|wxPATH_GET_SEPARATOR).wc_str()) );
+		wxString s(fn.GetFullName()); return( CSG_String(&s) );
 	}
 
-	return( SG_T("") );
+	wxString s(fn.GetName()); return( &s );
 }
 
 //---------------------------------------------------------
-CSG_String		SG_File_Get_Path_Absolute	(const SG_Char *full_Path)
+CSG_String		SG_File_Get_Path(const CSG_String &full_Path)
 {
-	wxString	Path;
+	wxString	s(wxFileName(full_Path.c_str()).GetPath(wxPATH_GET_VOLUME|wxPATH_GET_SEPARATOR));
 
-	if( full_Path && *full_Path )
-	{
-		wxFileName	fn(full_Path);
-
-		fn.MakeAbsolute();
-
-		Path	= fn.GetFullPath();
-	}
-
-	return( &Path );
+	return( CSG_String(&s) );
 }
 
 //---------------------------------------------------------
-CSG_String		SG_File_Get_Path_Relative	(const SG_Char *Directory, const SG_Char *full_Path)
+CSG_String		SG_File_Get_Path_Absolute(const CSG_String &full_Path)
 {
-	wxFileName	fn(full_Path);
+	wxFileName	fn(full_Path.c_str());
 
-	fn.MakeRelativeTo(Directory);
+	fn.MakeAbsolute();
 
-	return( CSG_String(fn.GetFullPath().wc_str()) );
+	wxString s(fn.GetFullPath()); return( &s );
 }
 
 //---------------------------------------------------------
-CSG_String		SG_File_Make_Path(const SG_Char *Directory, const SG_Char *Name, const SG_Char *Extension)
+CSG_String		SG_File_Get_Path_Relative(const CSG_String &Directory, const CSG_String &full_Path)
+{
+	wxFileName	fn(full_Path.c_str());
+
+	fn.MakeRelativeTo(Directory.c_str());
+
+	wxString s(fn.GetFullPath()); return( &s );
+}
+
+//---------------------------------------------------------
+CSG_String		SG_File_Make_Path(const CSG_String &Directory, const CSG_String &Name)
+{
+	return( SG_File_Make_Path(Directory, Name, "") );
+}
+
+CSG_String		SG_File_Make_Path(const CSG_String &Directory, const CSG_String &Name, const CSG_String &Extension)
 {
 	wxFileName	fn;
 
-	fn.AssignDir(Directory && *Directory ? Directory : SG_File_Get_Path(Name).c_str());
+	fn.AssignDir(!Directory.is_Empty() ? Directory.c_str() : SG_File_Get_Path(Name).c_str());
 
-	if( Extension && *Extension )
+	if( !Extension.is_Empty() )
 	{
 		fn.SetName		(SG_File_Get_Name(Name, false).c_str());
-		fn.SetExt		(Extension);
+		fn.SetExt		(Extension.c_str());
 	}
 	else
 	{
 		fn.SetFullName	(SG_File_Get_Name(Name,  true).c_str());
 	}
 
-	return( CSG_String(fn.GetFullPath().wc_str()) );
+	wxString s(fn.GetFullPath()); return( &s );
 }
 
 //---------------------------------------------------------
-bool			SG_File_Cmp_Extension(const SG_Char *File_Name, const SG_Char *Extension)
+bool			SG_File_Cmp_Extension(const CSG_String &FileName, const CSG_String &Extension)
 {
-	wxFileName	fn(File_Name);
-
-	return( fn.GetExt().CmpNoCase(Extension) == 0 );
+	return( SG_File_Get_Extension(FileName).CmpNoCase(Extension) == 0 );
 }
 
 //---------------------------------------------------------
-bool			SG_File_Set_Extension(CSG_String &File_Name, const CSG_String &Extension)
+bool			SG_File_Set_Extension(CSG_String &FileName, const CSG_String &Extension)
 {
-	if( File_Name.Length() > 0 && Extension.Length() > 0 )
+	if( FileName.Length() > 0 && Extension.Length() > 0 )
 	{
-		wxFileName	fn(File_Name.w_str());
+		wxFileName	fn(FileName.c_str());
 
-		fn.SetExt(Extension.w_str());
+		fn.SetExt(Extension.c_str());
 
-		File_Name	= fn.GetFullPath().wc_str();
+		wxString s(fn.GetFullPath());
+		
+		FileName	= &s;
 
 		return( true );
 	}
@@ -667,38 +883,11 @@ bool			SG_File_Set_Extension(CSG_String &File_Name, const CSG_String &Extension)
 }
 
 //---------------------------------------------------------
-CSG_String		SG_File_Get_Extension(const SG_Char *File_Name)
+CSG_String		SG_File_Get_Extension(const CSG_String &FileName)
 {
-	wxFileName	fn(File_Name);
+	wxFileName	fn(FileName.c_str());
 
-	return( CSG_String(fn.GetExt().wc_str()) );
-}
-
-
-///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
-///////////////////////////////////////////////////////////
-
-//---------------------------------------------------------
-bool			SG_Read_Line(FILE *Stream, CSG_String &Line)
-{
-	char	c;
-
-	if( Stream && !feof(Stream) )
-	{
-		Line.Clear();
-
-		while( !feof(Stream) && (c = fgetc(Stream)) != 0x0A && c != 0x0D )
-		{
-			Line.Append(c);
-		}
-
-		return( true );
-	}
-
-	return( false );
+	wxString s(fn.GetExt()); return( &s );
 }
 
 
@@ -711,7 +900,7 @@ bool			SG_Read_Line(FILE *Stream, CSG_String &Line)
 //---------------------------------------------------------
 bool			SG_Get_Environment(const CSG_String &Variable, CSG_String *Value)
 {
-	if( Value == NULL)
+	if( Value == NULL )
 	{
 		return( wxGetEnv(Variable.w_str(), NULL) );
 	}
