@@ -26,7 +26,8 @@
 // This library is free software; you can redistribute   //
 // it and/or modify it under the terms of the GNU Lesser //
 // General Public License as published by the Free       //
-// Software Foundation, version 2.1 of the License.      //
+// Software Foundation, either version 2.1 of the        //
+// License, or (at your option) any later version.       //
 //                                                       //
 // This library is distributed in the hope that it will  //
 // be useful, but WITHOUT ANY WARRANTY; without even the //
@@ -36,9 +37,7 @@
 //                                                       //
 // You should have received a copy of the GNU Lesser     //
 // General Public License along with this program; if    //
-// not, write to the Free Software Foundation, Inc.,     //
-// 51 Franklin Street, 5th Floor, Boston, MA 02110-1301, //
-// USA.                                                  //
+// not, see <http://www.gnu.org/licenses/>.              //
 //                                                       //
 //-------------------------------------------------------//
 //                                                       //
@@ -160,7 +159,7 @@ void CSG_Translator::Destroy(void)
 bool CSG_Translator::Create(const CSG_String &File_Name, bool bSetExtension, int iText, int iTranslation, bool bCmpNoCase)
 {
 	CSG_Table	Translations;
-	CSG_String	fName(bSetExtension ? SG_File_Make_Path(NULL, File_Name, SG_T("lng")) : File_Name);
+	CSG_String	fName(bSetExtension ? SG_File_Make_Path("", File_Name, "lng") : File_Name);
 
 	SG_UI_Msg_Lock(true);
 
@@ -183,7 +182,7 @@ bool CSG_Translator::Create(class CSG_Table *pTranslations, int iText, int iTran
 
 	Destroy();
 
-	if( iText != iTranslation && pTranslations && pTranslations->Get_Field_Count() > iText && pTranslations->Get_Field_Count() > iTranslation && pTranslations->Get_Record_Count() > 0 )
+	if( iText != iTranslation && pTranslations && pTranslations->Get_Field_Count() > iText && pTranslations->Get_Field_Count() > iTranslation && pTranslations->Get_Count() > 0 )
 	{
 		int		i;
 
@@ -191,31 +190,34 @@ bool CSG_Translator::Create(class CSG_Table *pTranslations, int iText, int iTran
 
 		if( m_bCmpNoCase )
 		{
-			for(i=0; i<pTranslations->Get_Record_Count(); i++)
+			for(i=0; i<pTranslations->Get_Count(); i++)
 			{
 				CSG_Table_Record	*pRecord	= pTranslations->Get_Record(i);
 
-				CSG_String	s	= pRecord->asString(iText);
+				if( !pRecord->is_NoData(iText) )
+				{
+					CSG_String	s	= pRecord->asString(iText);
 
-				pRecord->Set_Value(iText, s.Make_Lower().c_str());
+					pRecord->Set_Value(iText, s.Make_Lower().c_str());
+				}
 			}
 		}
 
 		pTranslations->Set_Index(iText, TABLE_INDEX_Ascending);
 
-		m_Translations	= (CSG_Translation **)SG_Malloc(pTranslations->Get_Record_Count() * sizeof(CSG_Translation *));
+		m_Translations	= (CSG_Translation **)SG_Malloc(pTranslations->Get_Count() * sizeof(CSG_Translation *));
 
-		for(i=0; i<pTranslations->Get_Record_Count(); i++)
+		for(i=0; i<pTranslations->Get_Count(); i++)
 		{
 			CSG_Table_Record	*pRecord	= pTranslations->Get_Record_byIndex(i);
 
-			if( *pRecord->asString(iText) && *pRecord->asString(iTranslation) )
+			if( !pRecord->is_NoData(iText) && !pRecord->is_NoData(iTranslation) )
 			{
 				m_Translations[m_nTranslations++]	= new CSG_Translation(pRecord->asString(iText), pRecord->asString(iTranslation));
 			}
 		}
 
-		if( m_nTranslations < pTranslations->Get_Record_Count() )
+		if( m_nTranslations < pTranslations->Get_Count() )
 		{
 			m_Translations	= (CSG_Translation **)SG_Realloc(m_Translations, m_nTranslations * sizeof(CSG_Translation *));
 		}
