@@ -59,10 +59,12 @@
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-#include "datetime.h"
+#include <time.h>
 
 #include <wx/datetime.h>
 
+#include "datetime.h"
+
 
 ///////////////////////////////////////////////////////////
 //														 //
@@ -196,13 +198,12 @@ CSG_DateTime & CSG_DateTime::Set_Hour(double Value)
 {
 	m_pDateTime->ResetTime();
 
-	if( Value >= 0.0 && Value <= 24.0 )
-	{
-		m_pDateTime->SetHour       ((wxDateTime::wxDateTime_t)Value);	Value	= (Value - (wxDateTime::wxDateTime_t)Value) *   60.0;
-		m_pDateTime->SetMinute     ((wxDateTime::wxDateTime_t)Value);	Value	= (Value - (wxDateTime::wxDateTime_t)Value) *   60.0;
-		m_pDateTime->SetSecond     ((wxDateTime::wxDateTime_t)Value);	Value	= (Value - (wxDateTime::wxDateTime_t)Value) * 1000.0;
-		m_pDateTime->SetMillisecond((wxDateTime::wxDateTime_t)Value);
-	}
+	Value	= fmod(Value, 24.0); if( Value < 0.0 ) Value += 24.0;
+
+	m_pDateTime->SetHour       ((wxDateTime::wxDateTime_t)Value);	Value	= (Value - (wxDateTime::wxDateTime_t)Value) *   60.0;
+	m_pDateTime->SetMinute     ((wxDateTime::wxDateTime_t)Value);	Value	= (Value - (wxDateTime::wxDateTime_t)Value) *   60.0;
+	m_pDateTime->SetSecond     ((wxDateTime::wxDateTime_t)Value);	Value	= (Value - (wxDateTime::wxDateTime_t)Value) * 1000.0;
+	m_pDateTime->SetMillisecond((wxDateTime::wxDateTime_t)Value);
 
 	return( *this );
 }
@@ -216,7 +217,7 @@ CSG_DateTime & CSG_DateTime::Set_Day(unsigned short Value)
 }
 
 //---------------------------------------------------------
-CSG_DateTime & CSG_DateTime::Set_Month(Month Value)
+CSG_DateTime & CSG_DateTime::Set_Month(unsigned short Value)
 {
 	m_pDateTime->SetMonth((wxDateTime::Month)Value);
 
@@ -548,6 +549,68 @@ CSG_DateTime CSG_DateTime::Now(void)
 }
 
 
+///////////////////////////////////////////////////////////
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+CSG_DateTime & CSG_DateTime::Set_Unix_Time(sLong Seconds)
+{
+	time_t		tUnix	= Seconds;
+	struct tm	t;
+
+	#ifdef _SAGA_LINUX
+		t	= *gmtime(&tUnix);
+	#else
+		gmtime_s(&t, &tUnix);
+	#endif
+
+	Set(t.tm_mday, (CSG_DateTime::Month)(t.tm_mon), t.tm_year + 1900, t.tm_hour, t.tm_min, t.tm_sec);
+
+	return( *this );
+}
+
+//---------------------------------------------------------
+CSG_DateTime & CSG_DateTime::Set_Hours_AD(int Hours)
+{
+	long	d, n;
+	double	h;
+
+	h		= 1721424.0 + (Hours - 12.0) / 24.0;
+	d		= (long)h;		// Truncate to integral day
+	h		= h - d + 0.5;	// Fractional part of calendar day
+	if( h >= 1.0 )			// Is it really the next calendar day?
+	{
+		h--;
+		d++;
+	}
+
+	int	day, mon, year, hour, min, sec;
+
+	h		= 24.0 * (h);
+	hour	= (int)h;
+	h		= 60.0 * (h - hour);
+	min		= (int)h;
+	h		= 60.0 * (h - min);
+	sec		= (int)h;
+
+	d		= d + 68569;
+	n		= 4 * d / 146097;
+	d		= d - (146097 * n + 3) / 4;
+	year	= 4000 * (d + 1) / 1461001;
+	d		= d - 1461 * year / 4 + 31;	// 1461 = 365.25 * 4
+	mon		= 80 * d / 2447;
+	day		= d - 2447 * mon / 80;
+	d		= mon / 11;
+	mon		= mon + 2 - 12 * d;
+	year	= 100 * (n - 49) + year + d;
+
+	Set(day, (CSG_DateTime::Month)(mon - 1), year, hour, min, sec);
+
+	return( *this );
+}
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 ///////////////////////////////////////////////////////////
@@ -671,6 +734,50 @@ double			SG_Date_To_JulianDayNumber(const CSG_String &Date)
 }
 
 
+///////////////////////////////////////////////////////////
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+/**
+  * Returns the day number (starting with zero for the first
+  * of January) for the mid of the requested month (January = 0).
+*/
+//---------------------------------------------------------
+int SG_Get_Day_MidOfMonth(int Month, bool bLeapYear)
+{
+	static const int	MidOfMonth[12]	=
+	// JAN  FEB  MAR  APR  MAY  JUN  JUL  AUG  SEP  OCT  NOV  DEC
+	//	31,  28,  31,  30,  31,  30,  31,  31,  30,  31,  30,  31
+	//	 0,  31,  59,  90, 120, 151, 181, 212, 243, 273, 304, 334
+	{	15,  45,  74, 105, 135, 166, 196, 227, 258, 288, 319, 349	};
+
+	int	Day;
+
+	if( Month < 0 )
+	{
+		Month	= (Month % 12) + 12;
+		Day		= MidOfMonth[Month] - 365;
+	}
+	else if( Month >= 12 )
+	{
+		Month	= (Month % 12);
+		Day		= MidOfMonth[Month] + 365;
+	}
+	else
+	{
+		Day		= MidOfMonth[Month];
+	}
+
+	if( bLeapYear && Month > 1 )
+	{
+		Day++;
+	}
+
+	return( Day );
+}
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 //														 //
@@ -763,119 +870,26 @@ bool SG_Get_Sun_Position(const CSG_DateTime &Time, double Longitude, double Lati
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-#include <time.h>
-
-//---------------------------------------------------------
-CSG_Time_Converter::CSG_Time_Converter(void)
+double SG_Get_Day_Length(int DayOfYear, double Latitude)
 {
-	m_sec		= 0;
-	m_min		= 0;
-	m_hour		= 0;
-	m_day		= 0;
-	m_mon		= 0;
-	m_year		= 0;
+	double	tanLat	= tan(Latitude * M_DEG_TO_RAD);
 
-	m_StrFmt	= SG_TIME_STRFMT_YMD_hms;
+	double	JD		= DayOfYear * M_PI * 2. / 365.;
+
+	double	SunDec	= 0.4093 * sin(JD - 1.405);	// solar declination
+
+	double	d		= -tanLat * tan(SunDec);	// sunset hour angle
+
+	return( acos(d < -1 ? -1 : d < 1 ? d : 1) * 24. / M_PI );
 }
 
 //---------------------------------------------------------
-CSG_Time_Converter::CSG_Time_Converter(int Time, TSG_Time_Format Format)
+double SG_Get_Day_Length(const CSG_DateTime &Date, double Latitude)
 {
-	Set_Time(Time, Format);
-}
-
-//---------------------------------------------------------
-bool CSG_Time_Converter::Set_Time(int Time, TSG_Time_Format Format)
-{
-	switch( Format )
-	{
-	default:
-		{
-			return( false );
-		}
-
-	//-----------------------------------------------------
-	case SG_TIME_FMT_Seconds_Unix:
-		{
-			time_t		tUnix	= Time;
-			struct tm	t;
-
-			#ifdef _SAGA_LINUX
-				t	= *gmtime(&tUnix);
-			#else
-				gmtime_s(&t, &tUnix);
-			#endif
-			
-			m_sec	= t.tm_sec;
-			m_min	= t.tm_min;
-			m_hour	= t.tm_hour;
-			m_day	= t.tm_mday;
-			m_mon	= t.tm_mon;
-			m_year	= t.tm_year + 1900;
-		}
-		break;
-
-	//-----------------------------------------------------
-	case SG_TIME_FMT_Hours_AD:
-		{
-			long	d, n;
-			double	h;
-
-			h		= 1721424.0 + (Time - 12.0) / 24.0;
-			d		= (long)h;		// Truncate to integral day
-			h		= h - d + 0.5;	// Fractional part of calendar day
-			if( h >= 1.0 )			// Is it really the next calendar day?
-			{
-				h--;
-				d++;
-			}
-
-			h		= 24.0 * (h);
-			m_hour	= (int)h;
-			h		= 60.0 * (h - m_hour);
-			m_min	= (int)h;
-			h		= 60.0 * (h - m_min);
-			m_sec	= (int)h;
-
-			d		= d + 68569;
-			n		= 4 * d / 146097;
-			d		= d - (146097 * n + 3) / 4;
-			m_year	= 4000 * (d + 1) / 1461001;
-			d		= d - 1461 * m_year / 4 + 31;	// 1461 = 365.25 * 4
-			m_mon	= 80 * d / 2447;
-			m_day	= d - 2447 * m_mon / 80;
-			d		= m_mon / 11;
-			m_mon	= m_mon + 2 - 12 * d;
-			m_year	= 100 * (n - 49) + m_year + d;
-		}
-		break;
-	}
-
-	//-----------------------------------------------------
-	return( true );
-}
-
-//---------------------------------------------------------
-CSG_String CSG_Time_Converter::Get_String(void) const
-{
-	CSG_String	s;
-
-	s.Printf(SG_T("%04d.%02d.%02d %02d:%02d:%02d"), m_year, m_mon, m_day, m_hour, m_min, m_sec);
-
-	return( s );
-}
-
-//---------------------------------------------------------
-CSG_String CSG_Time_Converter::Get_String(int Time, TSG_Time_Format Format)
-{
-	CSG_Time_Converter	tc(Time, Format);
-
-	return( tc.Get_String() );
+	return( SG_Get_Day_Length(Date.Get_DayOfYear(), Latitude) );
 }
 
 
