@@ -85,6 +85,7 @@
 typedef enum ESG_Grid_File_Format
 {
 	GRID_FILE_FORMAT_Undefined			= 0,
+	GRID_FILE_FORMAT_Binary_old,
 	GRID_FILE_FORMAT_Binary,
 	GRID_FILE_FORMAT_ASCII,
 	GRID_FILE_FORMAT_Compressed
@@ -195,13 +196,28 @@ class SAGA_API_DLL_EXPORT CSG_Grid_System
 {
 public:
 	CSG_Grid_System(void);
-	CSG_Grid_System(const CSG_Grid_System &System);
-	CSG_Grid_System(double Cellsize, const CSG_Rect &Extent);
-	CSG_Grid_System(double Cellsize, double xMin, double yMin, double xMax, double yMax);
-	CSG_Grid_System(double Cellsize, double xMin, double yMin, int NX, int NY);
+
+								CSG_Grid_System		(const CSG_Grid_System &System);
+	bool						Create				(const CSG_Grid_System &System);
+
+								CSG_Grid_System		(double Cellsize, const CSG_Rect &Extent);
+	bool						Create				(double Cellsize, const CSG_Rect &Extent);
+
+								CSG_Grid_System		(double Cellsize, double xMin, double yMin, double xMax, double yMax);
+	bool						Create				(double Cellsize, double xMin, double yMin, double xMax, double yMax);
+
+								CSG_Grid_System		(double Cellsize, double xMin, double yMin, int NX, int NY);
+	bool						Create				(double Cellsize, double xMin, double yMin, int NX, int NY);
 
 	~CSG_Grid_System(void);
 
+	bool						Destroy				(void);
+
+	//-----------------------------------------------------
+	bool						Assign				(const CSG_Grid_System &System);
+	bool						Assign				(double Cellsize, const CSG_Rect &Extent);
+	bool						Assign				(double Cellsize, double xMin, double yMin, double xMax, double yMax);
+	bool						Assign				(double Cellsize, double xMin, double yMin, int NX, int NY);
 
 	//-----------------------------------------------------
 	bool						is_Valid			(void)	const;
@@ -230,11 +246,6 @@ public:
 	bool						operator ==			(const CSG_Grid_System &System) const;
 	void						operator =			(const CSG_Grid_System &System);
 
-	bool						Assign				(const CSG_Grid_System &System);
-	bool						Assign				(double Cellsize, const CSG_Rect &Extent);
-	bool						Assign				(double Cellsize, double xMin, double yMin, double xMax, double yMax);
-	bool						Assign				(double Cellsize, double xMin, double yMin, int NX, int NY);
-
 	bool						is_Equal			(const CSG_Grid_System &System) const;
 	bool						is_Equal			(double Cellsize, const TSG_Rect &Extent) const;
 
@@ -462,7 +473,9 @@ public:		///////////////////////////////////////////////
 
 
 	//-----------------------------------------------------
-	virtual bool					Save			(const CSG_String &FileName, int Format = GRID_FILE_FORMAT_Binary);
+	virtual bool					Save			(const CSG_String &File, int Format = 0);
+	virtual bool					Save			(const char       *File, int Format = 0)	{	return( Save(CSG_String(File), Format) );	}
+	virtual bool					Save			(const wchar_t    *File, int Format = 0)	{	return( Save(CSG_String(File), Format) );	}
 
 	//-----------------------------------------------------
 	/** Data object type information.
@@ -874,7 +887,7 @@ private:	///////////////////////////////////////////////
 	bool						_Load_PGSQL				(const CSG_String &FileName, bool bCached, bool bLoadData);
 
 	bool						_Load_Native			(const CSG_String &FileName, bool bCached, bool bLoadData);
-	bool						_Save_Native			(const CSG_String &FileName, bool bBinary);
+	bool						_Save_Native			(const CSG_String &FileName, TSG_Grid_File_Format Format);
 
 	bool						_Load_Compressed		(const CSG_String &FileName, bool bCached, bool bLoadData);
 	bool						_Save_Compressed		(const CSG_String &FileName);
@@ -959,6 +972,11 @@ SAGA_API_DLL_EXPORT void			SG_Grid_Cache_Set_Threshold_MB	(double nMegabytes);
 SAGA_API_DLL_EXPORT sLong			SG_Grid_Cache_Get_Threshold		(void);
 SAGA_API_DLL_EXPORT double			SG_Grid_Cache_Get_Threshold_MB	(void);
 
+//---------------------------------------------------------
+SAGA_API_DLL_EXPORT bool					SG_Grid_Set_File_Format_Default		(int Format);
+SAGA_API_DLL_EXPORT TSG_Grid_File_Format	SG_Grid_Get_File_Format_Default		(void);
+SAGA_API_DLL_EXPORT CSG_String				SG_Grid_Get_File_Extension_Default	(void);
+
 
 ///////////////////////////////////////////////////////////
 //														 //
@@ -1036,7 +1054,7 @@ public:
 	bool						Set_Circle			(class CSG_Parameters &Parameters);
 	bool						Set_Annulus			(class CSG_Parameters &Parameters);
 	bool						Set_Sector			(class CSG_Parameters &Parameters);
-	static bool					On_Parameters_Enable(class CSG_Parameters &pParameters);
+	static bool					Enable_Parameters	(class CSG_Parameters &Parameters);
 
 	CSG_Distance_Weighting &	Get_Weighting		(void)			{	return( m_Weighting );		}
 
