@@ -327,6 +327,8 @@ bool CSG_Grids::Create(const CSG_Grid_System &System, int NZ, double zMin, TSG_D
 
 	if( m_pGrids[0]->Create(System, Type) )
 	{
+		Set_NoData_Value_Range(m_pGrids[0]->Get_NoData_Value(), m_pGrids[0]->Get_NoData_hiValue());
+
 		for(int i=0; i<NZ; i++, zMin+=System.Get_Cellsize())
 		{
 			if( !Add_Grid(zMin) )
@@ -694,7 +696,7 @@ bool CSG_Grids::Add_Grid(CSG_Table_Record &Attributes)
 	//-----------------------------------------------------
 	m_Attributes.Add_Record(&Attributes);
 
-	m_pGrids[n]->Set_Name(CSG_String::Format("%s [%s]", Get_Name(), SG_Get_String(Get_Z(n), -10).c_str()));
+	m_pGrids[n]->Set_Name("%s [%s]", Get_Name(), SG_Get_String(Get_Z(n), -10).c_str());
 
 	SG_FREE_SAFE(m_Index);	// invalidate index
 
@@ -2195,7 +2197,7 @@ bool CSG_Grids::_Load_Attributes(CSG_File &Stream)
 
 	while( Stream.Read_Line(sLine) && !sLine.is_Empty() )
 	{
-		CSG_String_Tokenizer	Values(sLine, "\t");
+		CSG_String_Tokenizer	Values(sLine, "\t", SG_TOKEN_RET_EMPTY_ALL);
 
 		if( Values.Get_Tokens_Count() == (size_t)Attributes.Get_Field_Count() )
 		{
