@@ -231,8 +231,6 @@ bool CSG_Vector::Del_Row(int iRow)
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -272,8 +270,6 @@ bool CSG_Vector::from_String(const CSG_String &String)
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -430,8 +426,6 @@ bool CSG_Vector::Multiply(const class CSG_Matrix &Matrix)
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -568,8 +562,6 @@ CSG_Vector operator * (double Scalar, const CSG_Vector &Vector)
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -599,8 +591,6 @@ bool CSG_Vector::Set_Unity(void)
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -619,8 +609,6 @@ bool CSG_Vector::Sort(void)
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -681,6 +669,79 @@ CSG_Vector CSG_Vector::Get_Unity(void) const
 }
 
 
+///////////////////////////////////////////////////////////
+//														 //
+//														 //
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+bool	SG_VectorR2_Rotate(double &x, double &y, double Angle)
+{
+	double	sin_a	= sin(Angle);
+	double	cos_a	= cos(Angle);
+
+	double	t	= x;
+
+	x	= t * cos_a - y * sin_a;
+	y	= t * sin_a + y * cos_a;
+
+	return( true );
+}
+
+//---------------------------------------------------------
+bool	SG_VectorR2_Rotate(double     Vector[2], double Angle)
+{
+	return( SG_VectorR2_Rotate(Vector[0], Vector[1], Angle) );
+}
+
+//---------------------------------------------------------
+bool	SG_VectorR2_Rotate(CSG_Vector &Vector  , double Angle)
+{
+	return( Vector.Get_N() >= 2 && SG_VectorR2_Rotate(Vector[0], Vector[1], Angle) );
+}
+
+//---------------------------------------------------------
+bool	SG_VectorR3_Rotate(double     Vector[3], size_t Axis, double Angle)
+{
+	if( Axis <= 3 )
+	{
+		CSG_Vector	v(3, Vector);
+
+		double	sin_a	= sin(Angle);
+		double	cos_a	= cos(Angle);
+
+		switch( Axis )
+		{
+		case 0:
+			Vector[1] = v[1] * cos_a - v[2] * sin_a;
+			Vector[2] = v[1] * sin_a + v[2] * cos_a;
+			break;
+
+		case 1:
+			Vector[0] = v[0] * cos_a + v[2] * sin_a;
+			Vector[2] =-v[0] * sin_a + v[2] * cos_a;
+			break;
+
+		case 2:
+			Vector[0] = v[0] * cos_a - v[1] * sin_a;
+			Vector[1] = v[0] * sin_a + v[1] * cos_a;
+			break;
+		}
+
+		return( true );
+	}
+
+	return( false );
+}
+
+//---------------------------------------------------------
+bool	SG_VectorR3_Rotate(CSG_Vector &Vector  , size_t Axis, double Angle)
+{
+	return( Vector.Get_N() >= 3 && SG_VectorR3_Rotate(Vector.Get_Data(), Axis, Angle) );
+}
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 //														 //
@@ -797,8 +858,6 @@ void CSG_Matrix::_On_Construction(void)
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1169,8 +1228,6 @@ CSG_Vector CSG_Matrix::Get_Row(int iRow)	const
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1226,8 +1283,6 @@ bool CSG_Matrix::from_String(const CSG_String &String)
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1410,8 +1465,6 @@ CSG_Matrix CSG_Matrix::Multiply(const CSG_Matrix &Matrix) const
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1546,8 +1599,6 @@ CSG_Matrix	operator * (double Scalar, const CSG_Matrix &Matrix)
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1647,8 +1698,6 @@ bool CSG_Matrix::Set_Inverse(bool bSilent, int nSubSquare)
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1747,8 +1796,6 @@ bool		SG_Matrix_Eigen_Reduction(const CSG_Matrix &Matrix, CSG_Matrix &Eigen_Vect
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
