@@ -306,6 +306,14 @@ private:
 //---------------------------------------------------------
 SAGA_API_DLL_EXPORT CSG_Vector	operator *			(double Scalar, const CSG_Vector &Vector);
 
+//---------------------------------------------------------
+SAGA_API_DLL_EXPORT bool	SG_VectorR2_Rotate		(double &x, double &y, double Angle);
+SAGA_API_DLL_EXPORT bool	SG_VectorR2_Rotate		(double     Vector[2], double Angle);
+SAGA_API_DLL_EXPORT bool	SG_VectorR2_Rotate		(CSG_Vector &Vector  , double Angle);
+
+SAGA_API_DLL_EXPORT bool	SG_VectorR3_Rotate		(double     Vector[3], size_t Axis, double Angle);
+SAGA_API_DLL_EXPORT bool	SG_VectorR3_Rotate		(CSG_Vector &Vector  , size_t Axis, double Angle);
+
 
 ///////////////////////////////////////////////////////////
 //														 //
@@ -587,12 +595,19 @@ public:
 	double						Get_Quantile		(double Quantile);
 	double						Get_Gini			(void);
 
+	sLong						Get_IndexOfMinimum	(void);
+	sLong						Get_IndexOfMaximum	(void);
+
+	sLong						Get_nValues_Above	(double Threshold, bool bEquals = false);
+	sLong						Get_nValues_Below	(double Threshold, bool bEquals = false);
+
 	void						Add					(const CSG_Simple_Statistics &Statistics);
 
 	void						Add_Value			(double Value, double Weight = 1.0);
 
-	double						Get_Value			(sLong i)	const	{	return( i >= 0 && i < (sLong)m_Values.Get_Size() ? Get_Values()[i] : m_Mean );	}
 	double *					Get_Values			(void)		const	{	return( (double *)m_Values.Get_Array() );	}
+	double						Get_Value			(sLong i)	const	{	return( i >= 0 && i < (sLong)m_Values.Get_Size() ? Get_Values()[i] : m_Mean );	}
+	double						operator []			(sLong i)	const	{	return( i >= 0 && i < (sLong)m_Values.Get_Size() ? Get_Values()[i] : m_Mean );	}
 
 
 	CSG_Simple_Statistics &		operator  =			(const CSG_Simple_Statistics &Statistics)	{	Create(Statistics);	return( *this );	}
@@ -966,13 +981,13 @@ public:
 	bool					Add_Element			(void);
 	bool					Set_Feature			(int iElement, int iFeature, double Value);
 
-	int						Get_Cluster			(int iElement)	const	{	return( iElement >= 0 && iElement < Get_nElements() ? m_Cluster[iElement] : -1 );	}
+	int						Get_Cluster			(int iElement)	const	{	return( iElement >= 0 && iElement < Get_nElements() ? m_Clusters[iElement] : -1 );	}
 
-	bool					Execute				(int Method, int nClusters, int nMaxIterations = 0);
+	bool					Execute				(int Method, int nClusters, int nMaxIterations = 0, int Initialization = 0);
 
 	int						Get_nElements		(void)	const	{	return( (int)m_Features.Get_Size() );	}
-	int						Get_nFeatures		(void)	const	{	return( m_nFeatures );	}
-	int						Get_nClusters		(void)	const	{	return( m_nClusters );	}
+	int						Get_nFeatures		(void)	const	{	return(      m_nFeatures           );	}
+	int						Get_nClusters		(void)	const	{	return( (int)m_nMembers.Get_Size() );	}
 
 	int						Get_Iteration		(void)	const	{	return( m_Iteration );	}
 
@@ -985,15 +1000,22 @@ public:
 
 private:
 
-	int						*m_Cluster, m_Iteration, m_nFeatures, m_nClusters, *m_nMembers;
+	int						m_Iteration, m_nFeatures;
 
-	double					*m_Variance, **m_Centroid, m_SP;
+	double					m_SP;
+
+	CSG_Array_Int			m_Clusters, m_nMembers;
 
 	CSG_Array				m_Features;
 
+	CSG_Vector				m_Variance;
 
-	bool					Minimum_Distance	(bool bInitialize, int nMaxIterations);
-	bool					Hill_Climbing		(bool bInitialize, int nMaxIterations);
+	CSG_Matrix				m_Centroid;
+
+
+	bool					_Minimum_Distance	(bool bInitialize, int nMaxIterations);
+
+	bool					_Hill_Climbing		(bool bInitialize, int nMaxIterations);
 
 };
 
@@ -1676,7 +1698,7 @@ public:
 	typedef struct SSG_Formula_Item
 	{
 		const SG_Char		*name;
-		TSG_PFNC_Formula_1	f;			
+		TSG_PFNC_Formula_1	f;
 		int					n_pars;		
 		int					varying;	// Does the result of the function vary even when the parameters stay the same? varying = 1 for e.g. random - number generators.
 	}
@@ -1701,6 +1723,9 @@ private:
 
 	TMAT_Formula				m_Formula;
 
+	TSG_Formula_Item			*m_Functions;
+
+
 	CSG_String					m_sFormula, m_sError;
 
 	const SG_Char				*i_error;
