@@ -139,21 +139,11 @@ bool CSG_Parameters::Create(const CSG_Parameters &Parameters)
 	Set_Description	(Parameters.Get_Description());
 
 	//-----------------------------------------------------
-	int		i;
-
-	for(i=0; i<Parameters.m_nParameters; i++)
+	for(int i=0; i<Parameters.m_nParameters; i++)
 	{
 		_Add(Parameters.m_Parameters[i]);
 	}
 
-	for(i=0; i<Parameters.m_nParameters; i++)
-	{
-		if( Get_Parameter(i) && Parameters.m_Parameters[i]->m_pParent )
-		{
-			Get_Parameter(i)->m_pParent	= Get_Parameter(Parameters.m_Parameters[i]->m_pParent->Get_Identifier());
-		}
-	}
-
 	if( Parameters.m_pGrid_System )
 	{
 		m_pGrid_System	= Get_Parameter(Parameters.m_pGrid_System->Get_Identifier());
@@ -225,9 +215,19 @@ void CSG_Parameters::Set_Manager(CSG_Data_Manager *pManager)
   * Change the identifier of this parameter list after construction.
 */
 //---------------------------------------------------------
-void CSG_Parameters::Set_Identifier(const CSG_String &String)
+void CSG_Parameters::Set_Identifier(const CSG_String &Identifier)
 {
-	m_Identifier	= String;
+	m_Identifier	= Identifier;
+}
+
+//---------------------------------------------------------
+/**
+  * Change the identifier of this parameter list after construction.
+*/
+//---------------------------------------------------------
+bool CSG_Parameters::Cmp_Identifier(const CSG_String &Identifier)	const
+{
+	return( m_Identifier.Cmp(Identifier) == 0 );
 }
 
 //---------------------------------------------------------
@@ -235,9 +235,9 @@ void CSG_Parameters::Set_Identifier(const CSG_String &String)
   * Change the name of this parameter list after construction.
 */
 //---------------------------------------------------------
-void CSG_Parameters::Set_Name(const CSG_String &String)
+void CSG_Parameters::Set_Name(const CSG_String &Name)
 {
-	m_Name			= String;
+	m_Name			= Name;
 }
 
 //---------------------------------------------------------
@@ -245,9 +245,9 @@ void CSG_Parameters::Set_Name(const CSG_String &String)
   * Change the description for this parameter list after construction.
 */
 //---------------------------------------------------------
-void CSG_Parameters::Set_Description(const CSG_String &String)
+void CSG_Parameters::Set_Description(const CSG_String &Description)
 {
-	m_Description	= String;
+	m_Description	= Description;
 }
 
 //---------------------------------------------------------
@@ -393,13 +393,9 @@ CSG_Parameter * CSG_Parameters::Add_Info_Range(const CSG_String &ParentID, const
 //---------------------------------------------------------
 CSG_Parameter * CSG_Parameters::Add_Choice(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, const CSG_String &Items, int Default)
 {
-	CSG_Parameter			*pParameter;
-	CSG_Parameter_Choice	*m_pData;
+	CSG_Parameter	*pParameter	= _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_Choice, 0);
 
-	pParameter	= _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_Choice, 0);
-
-	m_pData		= (CSG_Parameter_Choice *)pParameter->m_pData;
-	m_pData->Set_Items(Items);
+	pParameter->asChoice()->Set_Items(Items);
 
 	bool	bCallback	= Set_Callback(false);
 	pParameter->Set_Value  (Default);
@@ -412,13 +408,9 @@ CSG_Parameter * CSG_Parameters::Add_Choice(const CSG_String &ParentID, const CSG
 //---------------------------------------------------------
 CSG_Parameter * CSG_Parameters::Add_Choices(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, const CSG_String &Items)
 {
-	CSG_Parameter			*pParameter;
-	CSG_Parameter_Choices	*m_pData;
+	CSG_Parameter	*pParameter	= _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_Choices, 0);
 
-	pParameter	= _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_Choices, 0);
-
-	m_pData		= (CSG_Parameter_Choices *)pParameter->m_pData;
-	m_pData->Set_Items(Items);
+	pParameter->asChoices()->Set_Items(Items);
 
 	return( pParameter );
 }
@@ -437,16 +429,12 @@ CSG_Parameter * CSG_Parameters::Add_Info_String(const CSG_String &ParentID, cons
 //---------------------------------------------------------
 CSG_Parameter * CSG_Parameters::Add_FilePath(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, const SG_Char *Filter, const SG_Char *Default, bool bSave, bool bDirectory, bool bMultiple)
 {
-	CSG_Parameter			*pParameter;
-	CSG_Parameter_File_Name	*m_pData;
+	CSG_Parameter	*pParameter	= _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_FilePath, 0);
 
-	pParameter	= _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_FilePath, 0);
-
-	m_pData		= (CSG_Parameter_File_Name *)pParameter->m_pData;
-	m_pData->Set_Filter			(Filter);
-	m_pData->Set_Flag_Save		(bSave);
-	m_pData->Set_Flag_Multiple	(bMultiple);
-	m_pData->Set_Flag_Directory	(bDirectory);
+	pParameter->asFilePath()->Set_Filter        (Filter    );
+	pParameter->asFilePath()->Set_Flag_Save     (bSave     );
+	pParameter->asFilePath()->Set_Flag_Multiple (bMultiple );
+	pParameter->asFilePath()->Set_Flag_Directory(bDirectory);
 
 	bool	bCallback	= Set_Callback(false);
 	pParameter->Set_Value  (Default);
@@ -509,8 +497,6 @@ CSG_Parameter * CSG_Parameters::Add_FixedTable(const CSG_String &ParentID, const
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -551,7 +537,7 @@ CSG_Parameter * CSG_Parameters::Add_Grid(const CSG_String &ParentID, const CSG_S
 
 	pParameter	= _Add(SystemID, ID, Name, Description, PARAMETER_TYPE_Grid, Constraint);
 
-	((CSG_Parameter_Grid *)pParameter->m_pData)->Set_Preferred_Type(Preferred_Type);
+	((CSG_Parameter_Grid *)pParameter)->Set_Preferred_Type(Preferred_Type);
 
 	return( pParameter );
 }
@@ -561,7 +547,7 @@ CSG_Parameter * CSG_Parameters::Add_Grid_or_Const(const CSG_String &ParentID, co
 {
 	CSG_Parameter	*pParameter	= Add_Grid(ParentID, ID, Name, Description, PARAMETER_INPUT_OPTIONAL, bSystem_Dependent);
 
-	((CSG_Parameter_Grid *)pParameter->m_pData)->Add_Default(Value, Minimum, bMinimum, Maximum, bMaximum);
+	((CSG_Parameter_Grid *)pParameter)->Add_Default(Value, Minimum, bMinimum, Maximum, bMaximum);
 
 	return( pParameter );
 }
@@ -573,7 +559,7 @@ CSG_Parameter * CSG_Parameters::Add_Grid_Output(const CSG_String &ParentID, cons
 
 	pParameter	= _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_DataObject_Output, PARAMETER_OUTPUT_OPTIONAL);
 
-	((CSG_Parameter_Data_Object_Output *)pParameter->Get_Data())->Set_DataObject_Type(SG_DATAOBJECT_TYPE_Grid);
+	((CSG_Parameter_Data_Object_Output *)pParameter)->Set_DataObject_Type(SG_DATAOBJECT_TYPE_Grid);
 
 	return( pParameter );
 }
@@ -602,8 +588,6 @@ CSG_Parameter * CSG_Parameters::Add_Grid_List(const CSG_String &ParentID, const
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -629,7 +613,7 @@ CSG_Parameter * CSG_Parameters::Add_Grids(const CSG_String &ParentID, const CSG_
 
 	pParameter	= _Add(SystemID, ID, Name, Description, PARAMETER_TYPE_Grids, Constraint);
 
-	((CSG_Parameter_Grids *)pParameter->m_pData)->Set_Preferred_Type(Preferred_Type);
+	((CSG_Parameter_Grids *)pParameter)->Set_Preferred_Type(Preferred_Type);
 
 	return( pParameter );
 }
@@ -641,7 +625,7 @@ CSG_Parameter * CSG_Parameters::Add_Grids_Output(const CSG_String &ParentID, con
 
 	pParameter	= _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_DataObject_Output, PARAMETER_OUTPUT_OPTIONAL);
 
-	((CSG_Parameter_Data_Object_Output *)pParameter->Get_Data())->Set_DataObject_Type(SG_DATAOBJECT_TYPE_Grids);
+	((CSG_Parameter_Data_Object_Output *)pParameter)->Set_DataObject_Type(SG_DATAOBJECT_TYPE_Grids);
 
 	return( pParameter );
 }
@@ -670,8 +654,6 @@ CSG_Parameter * CSG_Parameters::Add_Grids_List(const CSG_String &ParentID, const
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -698,7 +680,7 @@ CSG_Parameter * CSG_Parameters::Add_Table_Field_or_Const(const CSG_String &Paren
 
 	if( pParameter )
 	{
-		((CSG_Parameter_Table_Field *)pParameter->m_pData)->Add_Default(Value, Minimum, bMinimum, Maximum, bMaximum);
+		((CSG_Parameter_Table_Field *)pParameter)->Add_Default(Value, Minimum, bMinimum, Maximum, bMaximum);
 	}
 
 	return( pParameter );
@@ -738,7 +720,7 @@ CSG_Parameter * CSG_Parameters::Add_Table_Output(const CSG_String &ParentID, con
 
 	pParameter	= _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_DataObject_Output, PARAMETER_OUTPUT_OPTIONAL);
 
-	((CSG_Parameter_Data_Object_Output *)pParameter->Get_Data())->Set_DataObject_Type(SG_DATAOBJECT_TYPE_Table);
+	((CSG_Parameter_Data_Object_Output *)pParameter)->Set_DataObject_Type(SG_DATAOBJECT_TYPE_Table);
 
 	return( pParameter );
 }
@@ -756,8 +738,6 @@ CSG_Parameter * CSG_Parameters::Add_Table_List(const CSG_String &ParentID, const
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -767,7 +747,7 @@ CSG_Parameter * CSG_Parameters::Add_Shapes(const CSG_String &ParentID, const CSG
 
 	pParameter	= _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_Shapes, Constraint);
 
-	((CSG_Parameter_Shapes *)pParameter->m_pData)->Set_Shape_Type(Shape_Type);
+	((CSG_Parameter_Shapes *)pParameter)->Set_Shape_Type(Shape_Type);
 
 	return( pParameter );
 }
@@ -779,7 +759,7 @@ CSG_Parameter * CSG_Parameters::Add_Shapes_Output(const CSG_String &ParentID, co
 
 	pParameter	= _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_DataObject_Output, PARAMETER_OUTPUT_OPTIONAL);
 
-	((CSG_Parameter_Data_Object_Output *)pParameter->Get_Data())->Set_DataObject_Type(SG_DATAOBJECT_TYPE_Shapes);
+	((CSG_Parameter_Data_Object_Output *)pParameter)->Set_DataObject_Type(SG_DATAOBJECT_TYPE_Shapes);
 
 	return( pParameter );
 }
@@ -791,7 +771,7 @@ CSG_Parameter * CSG_Parameters::Add_Shapes_List(const CSG_String &ParentID, cons
 
 	pParameter	= _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_Shapes_List, Constraint);
 
-	((CSG_Parameter_Shapes_List *)pParameter->m_pData)->Set_Shape_Type(Type);
+	((CSG_Parameter_Shapes_List *)pParameter)->Set_Shape_Type(Type);
 
 	return( pParameter );
 }
@@ -799,8 +779,6 @@ CSG_Parameter * CSG_Parameters::Add_Shapes_List(const CSG_String &ParentID, cons
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -820,7 +798,7 @@ CSG_Parameter * CSG_Parameters::Add_TIN_Output(const CSG_String &ParentID, const
 
 	pParameter	= _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_DataObject_Output, PARAMETER_OUTPUT_OPTIONAL);
 
-	((CSG_Parameter_Data_Object_Output *)pParameter->Get_Data())->Set_DataObject_Type(SG_DATAOBJECT_TYPE_TIN);
+	((CSG_Parameter_Data_Object_Output *)pParameter)->Set_DataObject_Type(SG_DATAOBJECT_TYPE_TIN);
 
 	return( pParameter );
 }
@@ -838,8 +816,6 @@ CSG_Parameter * CSG_Parameters::Add_TIN_List(const CSG_String &ParentID, const C
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -859,7 +835,7 @@ CSG_Parameter * CSG_Parameters::Add_PointCloud_Output(const CSG_String &ParentID
 
 	pParameter	= _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_DataObject_Output, PARAMETER_OUTPUT_OPTIONAL);
 
-	((CSG_Parameter_Data_Object_Output *)pParameter->Get_Data())->Set_DataObject_Type(SG_DATAOBJECT_TYPE_PointCloud);
+	((CSG_Parameter_Data_Object_Output *)pParameter)->Set_DataObject_Type(SG_DATAOBJECT_TYPE_PointCloud);
 
 	return( pParameter );
 }
@@ -877,8 +853,6 @@ CSG_Parameter * CSG_Parameters::Add_PointCloud_List(const CSG_String &ParentID,
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -896,8 +870,6 @@ CSG_Parameter * CSG_Parameters::Add_Parameters(const CSG_String &ParentID, const
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -925,8 +897,8 @@ CSG_Parameter * CSG_Parameters::_Add_Value(const CSG_String &ParentID, const CSG
 		||  Type == PARAMETER_TYPE_Double
 		||  Type == PARAMETER_TYPE_Degree )
 		{
-			((CSG_Parameter_Value *)pParameter->m_pData)->Set_Minimum(Minimum, bMinimum);
-			((CSG_Parameter_Value *)pParameter->m_pData)->Set_Maximum(Maximum, bMaximum);
+			pParameter->asValue()->Set_Minimum(Minimum, bMinimum);
+			pParameter->asValue()->Set_Maximum(Maximum, bMaximum);
 		}
 	}
 
@@ -959,33 +931,26 @@ CSG_Parameter * CSG_Parameters::_Add_Value(const CSG_String &ParentID, const CSG
 //---------------------------------------------------------
 CSG_Parameter * CSG_Parameters::_Add_Range(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, bool bInformation, double Default_Min, double Default_Max, double Minimum, bool bMinimum, double Maximum, bool bMaximum)
 {
-	double				d;
-	CSG_Parameter		*pParameter;
-	CSG_Parameter_Range	*pData;
-
 	//-----------------------------------------------------
 	if( Default_Min > Default_Max )
 	{
-		d			= Default_Min;
+		double	d	= Default_Min;
 		Default_Min	= Default_Max;
 		Default_Max	= d;
 	}
 
 	//-----------------------------------------------------
-	pParameter	= _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_Range, bInformation ? PARAMETER_INFORMATION : 0);
+	CSG_Parameter	*pParameter	= _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_Range, bInformation ? PARAMETER_INFORMATION : 0);
 
-	pData		= pParameter->asRange();
+	pParameter->asRange()->Get_Min_Parameter()->Set_Minimum(Minimum, bMinimum);
+	pParameter->asRange()->Get_Min_Parameter()->Set_Maximum(Maximum, bMaximum);
+	pParameter->asRange()->Get_Min_Parameter()->Set_Default(Default_Min);
+	pParameter->asRange()->Set_Min(Default_Min);
 
-	((CSG_Parameter_Value *)pData->Get_LoParm()->Get_Data())->Set_Minimum(Minimum, bMinimum);
-	((CSG_Parameter_Value *)pData->Get_LoParm()->Get_Data())->Set_Maximum(Maximum, bMaximum);
-	((CSG_Parameter_Value *)pData->Get_HiParm()->Get_Data())->Set_Minimum(Minimum, bMinimum);
-	((CSG_Parameter_Value *)pData->Get_HiParm()->Get_Data())->Set_Maximum(Maximum, bMaximum);
-
-	pData->Set_LoVal(Default_Min);
-	pData->Set_HiVal(Default_Max);
-
-	((CSG_Parameter_Value *)pData->Get_LoParm()->Get_Data())->Set_Default(Default_Min);
-	((CSG_Parameter_Value *)pData->Get_HiParm()->Get_Data())->Set_Default(Default_Max);
+	pParameter->asRange()->Get_Max_Parameter()->Set_Minimum(Minimum, bMinimum);
+	pParameter->asRange()->Get_Max_Parameter()->Set_Maximum(Maximum, bMaximum);
+	pParameter->asRange()->Get_Max_Parameter()->Set_Default(Default_Max);
+	pParameter->asRange()->Set_Max(Default_Max);
 
 	return( pParameter );
 }
@@ -1002,7 +967,7 @@ CSG_Parameter * CSG_Parameters::_Add_String(const CSG_String &ParentID, const CS
 	pParameter->Set_Default(String);
 	Set_Callback(bCallback);
 
-	((CSG_Parameter_String *)pParameter->Get_Data())->Set_Password(bPassword);
+	((CSG_Parameter_String *)pParameter)->Set_Password(bPassword);
 
 	return( pParameter );
 }
@@ -1010,8 +975,6 @@ CSG_Parameter * CSG_Parameters::_Add_String(const CSG_String &ParentID, const CS
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1022,11 +985,59 @@ CSG_Parameter * CSG_Parameters::_Add(const CSG_String &ParentID, const CSG_Strin
 {
 	wxASSERT_MSG(!ID.is_Empty(), "CSG_Parameter::Add: ID is empty");
 
-	CSG_Parameter	*pParameter	= new CSG_Parameter(this, Get_Parameter(ParentID), ID, Name, Description, Type, Constraint);
+	CSG_Parameter	*pParameter;
+
+	switch( Type )
+	{
+	default:
+		return( NULL );
+
+	case PARAMETER_TYPE_Node             : pParameter	= new CSG_Parameter_Node              (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
+
+	case PARAMETER_TYPE_Bool             : pParameter	= new CSG_Parameter_Bool              (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
+	case PARAMETER_TYPE_Int              : pParameter	= new CSG_Parameter_Int               (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
+	case PARAMETER_TYPE_Double           : pParameter	= new CSG_Parameter_Double            (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
+	case PARAMETER_TYPE_Degree           : pParameter	= new CSG_Parameter_Degree            (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
+	case PARAMETER_TYPE_Date             : pParameter	= new CSG_Parameter_Date              (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
+	case PARAMETER_TYPE_Range            : pParameter	= new CSG_Parameter_Range             (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
+	case PARAMETER_TYPE_Choice           : pParameter	= new CSG_Parameter_Choice            (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
+	case PARAMETER_TYPE_Choices          : pParameter	= new CSG_Parameter_Choices           (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
+
+	case PARAMETER_TYPE_String           : pParameter	= new CSG_Parameter_String            (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
+	case PARAMETER_TYPE_Text             : pParameter	= new CSG_Parameter_Text              (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
+	case PARAMETER_TYPE_FilePath         : pParameter	= new CSG_Parameter_File_Name         (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
+
+	case PARAMETER_TYPE_Font             : pParameter	= new CSG_Parameter_Font              (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
+	case PARAMETER_TYPE_Color            : pParameter	= new CSG_Parameter_Color             (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
+	case PARAMETER_TYPE_Colors           : pParameter	= new CSG_Parameter_Colors            (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
+	case PARAMETER_TYPE_FixedTable       : pParameter	= new CSG_Parameter_Fixed_Table       (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
+	case PARAMETER_TYPE_Grid_System      : pParameter	= new CSG_Parameter_Grid_System       (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
+	case PARAMETER_TYPE_Table_Field      : pParameter	= new CSG_Parameter_Table_Field       (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
+	case PARAMETER_TYPE_Table_Fields     : pParameter	= new CSG_Parameter_Table_Fields      (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
+
+	case PARAMETER_TYPE_DataObject_Output: pParameter	= new CSG_Parameter_Data_Object_Output(this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
+	case PARAMETER_TYPE_Grid             : pParameter	= new CSG_Parameter_Grid              (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
+	case PARAMETER_TYPE_Grids            : pParameter	= new CSG_Parameter_Grids             (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
+	case PARAMETER_TYPE_Table            : pParameter	= new CSG_Parameter_Table             (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
+	case PARAMETER_TYPE_Shapes           : pParameter	= new CSG_Parameter_Shapes            (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
+	case PARAMETER_TYPE_TIN              : pParameter	= new CSG_Parameter_TIN               (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
+	case PARAMETER_TYPE_PointCloud       : pParameter	= new CSG_Parameter_PointCloud        (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
+
+	case PARAMETER_TYPE_Grid_List        : pParameter	= new CSG_Parameter_Grid_List         (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
+	case PARAMETER_TYPE_Grids_List       : pParameter	= new CSG_Parameter_Grids_List        (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
+	case PARAMETER_TYPE_Table_List       : pParameter	= new CSG_Parameter_Table_List        (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
+	case PARAMETER_TYPE_Shapes_List      : pParameter	= new CSG_Parameter_Shapes_List       (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
+	case PARAMETER_TYPE_TIN_List         : pParameter	= new CSG_Parameter_TIN_List          (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
+	case PARAMETER_TYPE_PointCloud_List  : pParameter	= new CSG_Parameter_PointCloud_List   (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
+
+	case PARAMETER_TYPE_Parameters       : pParameter	= new CSG_Parameter_Parameters        (this, Get_Parameter(ParentID), ID, Name, Description, Constraint);	break;
+	}
 
 	m_Parameters	= (CSG_Parameter **)SG_Realloc(m_Parameters, (m_nParameters + 1) * sizeof(CSG_Parameter *));
 	m_Parameters[m_nParameters++]	= pParameter;
 
+	pParameter->_Set_String();
+
 	return( pParameter );
 }
 
@@ -1035,11 +1046,11 @@ CSG_Parameter * CSG_Parameters::_Add(CSG_Parameter *pSource)
 {
 	CSG_Parameter	*pParameter	= !pSource ? NULL : _Add(
 		pSource->Get_Parent() ? pSource->Get_Parent()->Get_Identifier() : SG_T(""),
-		pSource->Get_Identifier(),
-		pSource->Get_Name(),
+		pSource->Get_Identifier (),
+		pSource->Get_Name       (),
 		pSource->Get_Description(),
-		pSource->Get_Type(),
-		pSource->m_pData->Get_Constraint()
+		pSource->Get_Type       (),
+		pSource->m_Constraint
 	);
 
 	if( pParameter )
@@ -1053,22 +1064,50 @@ CSG_Parameter * CSG_Parameters::_Add(CSG_Parameter *pSource)
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-CSG_Parameter * CSG_Parameters::Get_Parameter(const CSG_String &Identifier)
+CSG_Parameter * CSG_Parameters::Get_Parameter(const CSG_String &ID)
 {
-	if( m_Parameters && Identifier.Length() )
+	if( m_Parameters && !ID.is_Empty() )
 	{
 		for(int i=0; i<m_nParameters; i++)
 		{
-			if( !m_Parameters[i]->m_Identifier.Cmp(Identifier) )
+			if( m_Parameters[i]->Cmp_Identifier(ID) )
 			{
 				return( m_Parameters[i] );
 			}
 		}
+
+		//-------------------------------------------------
+		if( ID.Find('.') > 0 )	// id not found? check for sub-parameter ('id.id')!
+		{
+			CSG_Parameter	*pParameter	= Get_Parameter(ID.BeforeFirst('.'));
+
+			if( pParameter )
+			{
+				switch( pParameter->Get_Type()  )
+				{
+				case PARAMETER_TYPE_Parameters:
+					return( pParameter->asParameters()->Get_Parameter(ID.AfterFirst('.')) );
+
+				case PARAMETER_TYPE_Range     :
+					if( !ID.AfterFirst('.').CmpNoCase("min") || !ID.AfterFirst('.').CmpNoCase("minimum") )
+					{
+						return( pParameter->asRange()->Get_Min_Parameter() );
+					}
+
+					if( !ID.AfterFirst('.').CmpNoCase("max") || !ID.AfterFirst('.').CmpNoCase("maximum") )
+					{
+						return( pParameter->asRange()->Get_Max_Parameter() );
+					}
+					break;
+
+				default:
+					break;
+				}
+			}
+		}
 	}
 
 	return( NULL );
@@ -1228,78 +1267,75 @@ bool CSG_Parameters::_On_Parameter_Changed(CSG_Parameter *pParameter, int Flags)
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-bool CSG_Parameters::Set_Parameter(const CSG_String &Identifier, CSG_Parameter *pSource)
+bool CSG_Parameters::Set_Parameter(const char       *ID, CSG_Parameter *pValue)	{	return( Set_Parameter(CSG_String(ID), pValue) );	}
+bool CSG_Parameters::Set_Parameter(const wchar_t    *ID, CSG_Parameter *pValue)	{	return( Set_Parameter(CSG_String(ID), pValue) );	}
+bool CSG_Parameters::Set_Parameter(const CSG_String &ID, CSG_Parameter *pValue)
 {
-	CSG_Parameter	*pTarget;
+	CSG_Parameter	*pTarget	= Get_Parameter(ID);
 
-	if( pSource != NULL && (pTarget = Get_Parameter(Identifier)) != NULL && pSource->Get_Type() == pTarget->Get_Type() )
-	{
-		return( pTarget->Assign(pSource) );
-	}
-
-	return( false );
+	return( pTarget && pValue && pTarget->Get_Type() == pValue->Get_Type() && pTarget->Assign(pValue) );
 }
 
 //---------------------------------------------------------
-bool CSG_Parameters::Set_Parameter(const CSG_String &Identifier, int Value, int Type)
+bool CSG_Parameters::Set_Parameter(const char       *ID, void *Value, int Type)	{	return( Set_Parameter(CSG_String(ID), Value, Type) );	}
+bool CSG_Parameters::Set_Parameter(const wchar_t    *ID, void *Value, int Type)	{	return( Set_Parameter(CSG_String(ID), Value, Type) );	}
+bool CSG_Parameters::Set_Parameter(const CSG_String &ID, void *Value, int Type)
 {
-	CSG_Parameter	*pTarget	= Get_Parameter(Identifier);
+	CSG_Parameter	*pTarget	= Get_Parameter(ID);
 
-	if( pTarget && (Type == PARAMETER_TYPE_Undefined || Type == pTarget->Get_Type()) )
-	{
-		pTarget->Set_Value(Value);
-
-		return( true );
-	}
-
-	return( false );
+	return( pTarget && (Type == PARAMETER_TYPE_Undefined || Type == pTarget->Get_Type()) && pTarget->Set_Value(Value) );
 }
 
 //---------------------------------------------------------
-bool CSG_Parameters::Set_Parameter(const CSG_String &Identifier, double Value, int Type)
+bool CSG_Parameters::Set_Parameter(const char       *ID, CSG_Data_Object *Value, int Type)	{	return( Set_Parameter(CSG_String(ID), Value, Type) );	}
+bool CSG_Parameters::Set_Parameter(const wchar_t    *ID, CSG_Data_Object *Value, int Type)	{	return( Set_Parameter(CSG_String(ID), Value, Type) );	}
+bool CSG_Parameters::Set_Parameter(const CSG_String &ID, CSG_Data_Object *Value, int Type)
 {
-	CSG_Parameter	*pTarget	= Get_Parameter(Identifier);
+	CSG_Parameter	*pTarget	= Get_Parameter(ID);
 
-	if( pTarget && (Type == PARAMETER_TYPE_Undefined || Type == pTarget->Get_Type()) )
-	{
-		pTarget->Set_Value(Value);
-
-		return( true );
-	}
-
-	return( false );
+	return( pTarget && (Type == PARAMETER_TYPE_Undefined || Type == pTarget->Get_Type()) && pTarget->Set_Value(Value) );
 }
 
 //---------------------------------------------------------
-bool CSG_Parameters::Set_Parameter(const CSG_String &Identifier, void *Value, int Type)
+bool CSG_Parameters::Set_Parameter(const char       *ID, int Value, int Type)	{	return( Set_Parameter(CSG_String(ID), Value, Type) );	}
+bool CSG_Parameters::Set_Parameter(const wchar_t    *ID, int Value, int Type)	{	return( Set_Parameter(CSG_String(ID), Value, Type) );	}
+bool CSG_Parameters::Set_Parameter(const CSG_String &ID, int Value, int Type)
 {
-	CSG_Parameter	*pTarget	= Get_Parameter(Identifier);
+	CSG_Parameter	*pTarget	= Get_Parameter(ID);
 
-	if( pTarget && (Type == PARAMETER_TYPE_Undefined || Type == pTarget->Get_Type()) )
-	{
-		pTarget->Set_Value(Value);
-
-		return( true );
-	}
-
-	return( false );
+	return( pTarget && (Type == PARAMETER_TYPE_Undefined || Type == pTarget->Get_Type()) && pTarget->Set_Value(Value) );
 }
 
 //---------------------------------------------------------
-bool CSG_Parameters::Set_Parameter(const CSG_String &Identifier, const SG_Char *Value, int Type)
+bool CSG_Parameters::Set_Parameter(const char       *ID, double Value, int Type)	{	return( Set_Parameter(CSG_String(ID), Value, Type) );	}
+bool CSG_Parameters::Set_Parameter(const wchar_t    *ID, double Value, int Type)	{	return( Set_Parameter(CSG_String(ID), Value, Type) );	}
+bool CSG_Parameters::Set_Parameter(const CSG_String &ID, double Value, int Type)
 {
-	CSG_Parameter	*pTarget	= Get_Parameter(Identifier);
+	CSG_Parameter	*pTarget	= Get_Parameter(ID);
 
-	if( pTarget && (Type == PARAMETER_TYPE_Undefined || Type == pTarget->Get_Type()) )
-	{
-		pTarget->Set_Value(Value);
-
-		return( true );
-	}
-
-	return( false );
+	return( pTarget && (Type == PARAMETER_TYPE_Undefined || Type == pTarget->Get_Type()) && pTarget->Set_Value(Value) );
 }
 
+//---------------------------------------------------------
+bool CSG_Parameters::Set_Parameter(const char       *ID, const CSG_String &Value, int Type)	{	return( Set_Parameter(CSG_String(ID), Value, Type) );	}
+bool CSG_Parameters::Set_Parameter(const wchar_t    *ID, const CSG_String &Value, int Type)	{	return( Set_Parameter(CSG_String(ID), Value, Type) );	}
+bool CSG_Parameters::Set_Parameter(const CSG_String &ID, const CSG_String &Value, int Type)
+{
+	CSG_Parameter	*pTarget	= Get_Parameter(ID);
+
+	return( pTarget && (Type == PARAMETER_TYPE_Undefined || Type == pTarget->Get_Type()) && pTarget->Set_Value(Value) );
+}
+
+//---------------------------------------------------------
+bool CSG_Parameters::Set_Parameter(const CSG_String &ID, const char    *Value, int Type)	{	return( Set_Parameter(ID, CSG_String(Value)) );	}
+bool CSG_Parameters::Set_Parameter(const char       *ID, const char    *Value, int Type)	{	return( Set_Parameter(ID, CSG_String(Value)) );	}
+bool CSG_Parameters::Set_Parameter(const wchar_t    *ID, const char    *Value, int Type)	{	return( Set_Parameter(ID, CSG_String(Value)) );	}
+
+//---------------------------------------------------------
+bool CSG_Parameters::Set_Parameter(const CSG_String &ID, const wchar_t *Value, int Type)	{	return( Set_Parameter(ID, CSG_String(Value)) );	}
+bool CSG_Parameters::Set_Parameter(const char       *ID, const wchar_t *Value, int Type)	{	return( Set_Parameter(ID, CSG_String(Value)) );	}
+bool CSG_Parameters::Set_Parameter(const wchar_t    *ID, const wchar_t *Value, int Type)	{	return( Set_Parameter(ID, CSG_String(Value)) );	}
+
 
 ///////////////////////////////////////////////////////////
 //														 //
@@ -1499,7 +1535,7 @@ bool CSG_Parameters::DataObjects_Create(void)
 				case PARAMETER_TYPE_TIN       :	pDataObject	= SG_Create_TIN       ();	break;
 				case PARAMETER_TYPE_PointCloud:	pDataObject	= SG_Create_PointCloud();	break;
 				case PARAMETER_TYPE_Shapes    :	pDataObject	= SG_Create_Shapes(
-						((CSG_Parameter_Shapes *)p->Get_Data())->Get_Shape_Type()
+						((CSG_Parameter_Shapes *)p)->Get_Shape_Type()
 					);
 					break;
 
@@ -1510,11 +1546,11 @@ bool CSG_Parameters::DataObjects_Create(void)
 					{
 						if( p->Get_Type() == PARAMETER_TYPE_Grid )
 						{
-							pDataObject	= SG_Create_Grid(*p->Get_Parent()->asGrid_System(), ((CSG_Parameter_Grid *)p->Get_Data())->Get_Preferred_Type());
+							pDataObject	= SG_Create_Grid(*p->Get_Parent()->asGrid_System(), ((CSG_Parameter_Grid *)p)->Get_Preferred_Type());
 						}
 						else
 						{
-							pDataObject	= SG_Create_Grids(*p->Get_Parent()->asGrid_System(), 0, 0.0, ((CSG_Parameter_Grids *)p->Get_Data())->Get_Preferred_Type());
+							pDataObject	= SG_Create_Grids(*p->Get_Parent()->asGrid_System(), 0, 0.0, ((CSG_Parameter_Grids *)p)->Get_Preferred_Type());
 						}
 					}
 					break;
@@ -1525,10 +1561,10 @@ bool CSG_Parameters::DataObjects_Create(void)
 			}
 			else if( p->Get_Type() == PARAMETER_TYPE_Shapes && p->asShapes() )
 			{
-				if( ((CSG_Parameter_Shapes *)p->Get_Data())->Get_Shape_Type() != SHAPE_TYPE_Undefined
-				&&	((CSG_Parameter_Shapes *)p->Get_Data())->Get_Shape_Type() != p->asShapes()->Get_Type() )
+				if( ((CSG_Parameter_Shapes *)p)->Get_Shape_Type() != SHAPE_TYPE_Undefined
+				&&	((CSG_Parameter_Shapes *)p)->Get_Shape_Type() != p->asShapes()->Get_Type() )
 				{
-					pDataObject	= SG_Create_Shapes(((CSG_Parameter_Shapes *)p->Get_Data())->Get_Shape_Type());
+					pDataObject	= SG_Create_Shapes(((CSG_Parameter_Shapes *)p)->Get_Shape_Type());
 				}
 			}
 
@@ -1719,7 +1755,7 @@ bool CSG_Parameters::Get_String(CSG_String &String, bool bOptionsOnly)
 		{
 			CSG_Parameter	*p	= m_Parameters[i];
 
-			if( (!bOptionsOnly || p->is_Option()) && p->is_Enabled() && !p->is_Information() && !(p->Get_Type() == PARAMETER_TYPE_String && ((CSG_Parameter_String *)p->Get_Data())->is_Password()) )
+			if( (!bOptionsOnly || p->is_Option()) && p->is_Enabled() && !p->is_Information() && !(p->Get_Type() == PARAMETER_TYPE_String && ((CSG_Parameter_String *)p)->is_Password()) )
 			{
 				bResult	= true;
 
@@ -1771,7 +1807,7 @@ bool CSG_Parameters::Set_History(CSG_MetaData &MetaData, bool bOptions, bool bDa
 			CSG_Parameter	*p	= m_Parameters[i];
 
 			if(	p->is_Option() && p->is_Enabled() && !p->is_Information()
-			&&	!(p->Get_Type() == PARAMETER_TYPE_String && ((CSG_Parameter_String *)p->Get_Data())->is_Password()) )
+			&&	!(p->Get_Type() == PARAMETER_TYPE_String && ((CSG_Parameter_String *)p)->is_Password()) )
 			{
 				p->Serialize(MetaData, true);
 			}
@@ -1893,40 +1929,34 @@ bool CSG_Parameters::Serialize(CSG_MetaData &MetaData, bool bSave)
 	{
 		MetaData.Destroy();
 
-		MetaData.Set_Name    (SG_T("PARAMETERS"));
-		MetaData.Set_Property(SG_T("name"), Get_Name());
+		MetaData.Set_Name("parameters");
+		MetaData.Set_Property("name", m_Name);
 
 		for(int i=0; i<Get_Count(); i++)
 		{
 			m_Parameters[i]->Serialize(MetaData, true);
 		}
-	}
-	else
-	{
-		if( MetaData.Get_Name().Cmp(SG_T("PARAMETERS")) )
-		{
-			return( false );
-		}
 
-		MetaData.Get_Property(SG_T("name"), m_Name);
+		return( true );
+	}
+	else if( MetaData.Cmp_Name("parameters") )
+	{
+		MetaData.Get_Property("name", m_Name);
 
 		for(int i=0; i<MetaData.Get_Children_Count(); i++)
 		{
-			CSG_String		Identifier;
-			CSG_Parameter	*pParameter = NULL;
+			CSG_Parameter	*pParameter = Get_Parameter(MetaData.Get_Child(i)->Get_Property("id"));
 
-			if(	MetaData.Get_Child(i)->Get_Property(SG_T("id"), Identifier)
-			&&	(pParameter	= Get_Parameter(Identifier)) != NULL )
+			if(	pParameter && pParameter->Serialize(*MetaData.Get_Child(i), false) )
 			{
-				if( pParameter->Serialize(*MetaData.Get_Child(i), false) )
-				{
-					pParameter->has_Changed();
-				}
+				pParameter->has_Changed();
 			}
 		}
+
+		return( true );
 	}
 
-	return( true );
+	return( false );
 }
 
 //---------------------------------------------------------
@@ -1942,17 +1972,17 @@ bool CSG_Parameters::Serialize_Compatibility(CSG_File &Stream)
 	}
 
 	//-----------------------------------------------------
-	while( Stream.Read_Line(sLine) && sLine.Cmp(SG_T("[PARAMETER_ENTRIES_BEGIN]")) );
+	while( Stream.Read_Line(sLine) && sLine.Cmp("[PARAMETER_ENTRIES_BEGIN]") );
 
-	if( sLine.Cmp(SG_T("[PARAMETER_ENTRIES_BEGIN]")) )
+	if( sLine.Cmp("[PARAMETER_ENTRIES_BEGIN]") )
 	{
 		return( false );
 	}
 
 	//-----------------------------------------------------
-	while( Stream.Read_Line(sLine) && sLine.Cmp(SG_T("[PARAMETER_ENTRIES_END]")) )
+	while( Stream.Read_Line(sLine) && sLine.Cmp("[PARAMETER_ENTRIES_END]") )
 	{
-		if( !sLine.Cmp(SG_T("[PARAMETER_ENTRY_BEGIN]"))
+		if( !sLine.Cmp("[PARAMETER_ENTRY_BEGIN]")
 		&&	Stream.Read_Line(sLine) && (pParameter = Get_Parameter(sLine)) != NULL
 		&&	Stream.Read_Line(sLine) )
 		{
@@ -2040,7 +2070,7 @@ bool CSG_Parameters::Serialize_Compatibility(CSG_File &Stream)
 			case 21: // PARAMETER_TYPE_Table_List:
 			case 22: // PARAMETER_TYPE_Shapes_List:
 			case 23: // PARAMETER_TYPE_TIN_List:
-				while( Stream.Read_Line(sLine) && sLine.Cmp(SG_T("[ENTRY_DATAOBJECTLIST_END]")) )
+				while( Stream.Read_Line(sLine) && sLine.Cmp("[ENTRY_DATAOBJECTLIST_END]") )
 				{
 					CSG_Data_Object	*pObject	= m_pManager ? m_pManager->Find(sLine) : NULL;
 
