@@ -275,7 +275,22 @@ bool CSG_PointCloud::_Load(const CSG_String &FileName)
 
 		CSG_String	_FileName(SG_File_Get_Name(FileName, false) + ".");
 
-		if( (bResult = Stream.Get_File(_FileName + "sg-pts")) == true && _Load(Stream) )
+		if( (bResult = Stream.Get_File(_FileName + "sg-pts")) == false )
+		{
+			for(size_t i=0; i<Stream.Get_File_Count(); i++)
+			{
+				if( SG_File_Cmp_Extension(Stream.Get_File_Name(i), "sg-pts") )
+				{
+					_FileName	= SG_File_Get_Name(Stream.Get_File_Name(i), false) + ".";
+
+					break;
+				}
+			}
+
+			bResult	= Stream.Get_File(_FileName + "sg-pts");
+		}
+
+		if( bResult && _Load(Stream) )
 		{
 			if( Stream.Get_File(_FileName + "sg-info") )
 			{
@@ -1202,7 +1217,7 @@ CSG_Table_Record * CSG_PointCloud::Ins_Record(int iRecord, CSG_Table_Record *pCo
 //---------------------------------------------------------
 CSG_Table_Record * CSG_PointCloud::Add_Record(CSG_Table_Record *pCopy)
 {
-	return( NULL );
+	return( Add_Shape(pCopy, SHAPE_COPY) );
 }
 
 //---------------------------------------------------------
@@ -1216,7 +1231,14 @@ CSG_Shape * CSG_PointCloud::Add_Shape(CSG_Table_Record *pCopy, TSG_ADD_Shape_Cop
 		{
 			if( Get_Field_Type(iField) == pCopy->Get_Table()->Get_Field_Type(iField) )
 			{
-				Set_Value(iField, pCopy->asDouble(iField));
+				if( SG_Data_Type_is_Numeric(Get_Field_Type(iField)) )
+				{
+					Set_Value(iField, pCopy->asDouble(iField));
+				}
+				else
+				{
+					Set_Value(iField, pCopy->asString(iField));
+				}
 			}
 		}
 	}
