@@ -105,6 +105,16 @@ TSG_Shape_Type;
 //---------------------------------------------------------
 SAGA_API_DLL_EXPORT CSG_String	SG_Get_ShapeType_Name	(TSG_Shape_Type Type);
 
+//---------------------------------------------------------
+typedef enum ESG_Shape_File_Format
+{
+	SHAPE_FILE_FORMAT_Undefined	= 0,
+	SHAPE_FILE_FORMAT_ESRI,
+	SHAPE_FILE_FORMAT_GeoPackage,
+	SHAPE_FILE_FORMAT_GeoJSON
+}
+TSG_Shape_File_Format;
+
 
 ///////////////////////////////////////////////////////////
 //														 //
@@ -145,9 +155,10 @@ public:
 	virtual int					Del_Parts			(void)											= 0;
 
 	virtual int					Get_Part_Count		(void)											= 0;
-	virtual int					Get_Point_Count		(void);
+	virtual int					Get_Point_Count		(void)											= 0;
 	virtual int					Get_Point_Count		(int iPart)										= 0;
-	virtual TSG_Point			Get_Point			(int iPoint, int iPart = 0, bool bAscending = true)	= 0;
+	virtual TSG_Point			Get_Point			(int iPoint)									= 0;
+	virtual TSG_Point			Get_Point			(int iPoint, int iPart, bool bAscending = true)	= 0;
 
 	virtual void				Set_Z				(double z, int iPoint, int iPart = 0)				{		}
 	virtual double				Get_Z				(int iPoint, int iPart = 0, bool bAscending = true)	{	return( 0.0 );	}
@@ -215,8 +226,11 @@ public:
 	virtual int					Del_Parts			(void)												{	return( -1 );				}
 
 	virtual int					Get_Part_Count		(void)												{	return( 1 );				}
+	virtual int					Get_Point_Count		(void)												{	return( 1 );				}
 	virtual int					Get_Point_Count		(int iPart)											{	return( 1 );				}
-	virtual TSG_Point			Get_Point			(int iPoint, int iPart = 0, bool bAscending = true)	{	return( m_Point );			}
+	virtual TSG_Point			Get_Point			(void)												{	return( m_Point );			}
+	virtual TSG_Point			Get_Point			(int iPoint)										{	return( m_Point );			}
+	virtual TSG_Point			Get_Point			(int iPoint, int iPart, bool bAscending = true)		{	return( m_Point );			}
 
 	virtual const CSG_Rect &	Get_Extent			(void);
 
@@ -401,9 +415,12 @@ public:
 
 	virtual int					Get_Part_Count		(void)		{	return( m_nParts );		}
 	virtual CSG_Shape_Part *	Get_Part			(int iPart)	{	return( iPart >= 0 && iPart < m_nParts ? m_pParts[iPart] : NULL );	}
+
+	virtual int					Get_Point_Count		(void)		{	_Update_Extent();	return( m_nPoints );	}
 	virtual int					Get_Point_Count		(int iPart)	{	return( iPart >= 0 && iPart < m_nParts ? m_pParts[iPart]->Get_Count() : 0 );	}
 
-	virtual TSG_Point			Get_Point			(int iPoint, int iPart = 0, bool bAscending = true)
+	virtual TSG_Point			Get_Point			(int iPoint);
+	virtual TSG_Point			Get_Point			(int iPoint, int iPart, bool bAscending = true)
 	{
 		if( iPart >= 0 && iPart < m_nParts )
 		{
@@ -443,7 +460,7 @@ protected:
 
 	bool						m_bUpdate;
 
-	int							m_nParts;
+	int							m_nParts, m_nPoints;
 
 	double						m_ZMin, m_ZMax, m_MMin, m_MMax;
 
@@ -516,7 +533,7 @@ protected:
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-typedef enum
+typedef enum ESG_Polygon_Point_Relation
 {
 	SG_POLYGON_POINT_Outside,
 	SG_POLYGON_POINT_Vertex,
@@ -549,6 +566,8 @@ public:
 	bool						Contains			(const TSG_Point &p);
 	bool						Contains			(double x, double y);
 
+	bool						is_Neighbour		(CSG_Shape_Polygon_Part *pPart, bool bSimpleCheck = true);
+
 	double						Get_Distance		(TSG_Point Point, TSG_Point &Next);
 
 
@@ -612,6 +631,8 @@ public:
 	bool						Contains			(const TSG_Point &p);
 	bool						Contains			(double x, double y);
 
+	bool						is_Neighbour		(CSG_Shape_Polygon *pPolygon, bool bSimpleCheck = true);
+
 	virtual double				Get_Distance		(TSG_Point Point, TSG_Point &Next, int iPart);
 
 
@@ -676,7 +697,9 @@ public:
 
 	virtual bool					Assign					(CSG_Data_Object *pObject);
 
-	virtual bool					Save					(const CSG_String &File_Name, int Format = 0);
+	virtual bool					Save					(const CSG_String &File, int Format = 0);
+	virtual bool					Save					(const char       *File, int Format = 0)	{	return( Save(CSG_String(File), Format) );	}
+	virtual bool					Save					(const wchar_t    *File, int Format = 0)	{	return( Save(CSG_String(File), Format) );	}
 
 	virtual bool					is_Valid				(void)	const			{	return( m_Type != SHAPE_TYPE_Undefined && Get_Count() >= 0 );		}
 
@@ -736,6 +759,9 @@ protected:
 
 private:
 
+	bool							_Load_GDAL				(const CSG_String &File_Name);
+	bool							_Save_GDAL				(const CSG_String &File_Name, const CSG_String &Driver);
+
 	bool							_Load_ESRI				(const CSG_String &File_Name);
 	bool							_Save_ESRI				(const CSG_String &File_Name);
 
@@ -765,6 +791,12 @@ SAGA_API_DLL_EXPORT CSG_Shapes *	SG_Create_Shapes	(TSG_Shape_Type Type, const SG
 SAGA_API_DLL_EXPORT CSG_Shapes *	SG_Create_Shapes	(CSG_Shapes *pTemplate);
 
 
+//---------------------------------------------------------
+SAGA_API_DLL_EXPORT bool					SG_Shapes_Set_File_Format_Default		(int Format);
+SAGA_API_DLL_EXPORT TSG_Shape_File_Format	SG_Shapes_Get_File_Format_Default		(void);
+SAGA_API_DLL_EXPORT CSG_String				SG_Shapes_Get_File_Extension_Default	(void);
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 //				Point Region QuadTree					 //
