@@ -147,8 +147,8 @@ public:
 	bool						is_NoData		(int              iField)	const;
 	bool						is_NoData		(const CSG_String &Field)	const;
 
-	const SG_Char *				asString		(int              iField, int Decimals = 0)	const;
-	const SG_Char *				asString		(const CSG_String &Field, int Decimals = 0)	const;
+	const SG_Char *				asString		(int              iField, int Decimals = -99)	const;
+	const SG_Char *				asString		(const CSG_String &Field, int Decimals = -99)	const;
 
 	SG_Char						asChar			(int              iField)	const	{	return( (SG_Char)asInt   (iField) );	}
 	SG_Char						asChar			(const CSG_String &Field)	const	{	return( (SG_Char)asInt   ( Field) );	}
@@ -239,9 +239,16 @@ public:
 	virtual bool					Assign				(CSG_Data_Object *pSource);
 	bool							Assign_Values		(CSG_Table *pTable);
 
-	bool							Load				(const CSG_String &FileName, int Format, SG_Char Separator);
-	virtual bool					Save				(const CSG_String &FileName, int Format = 0);
-	virtual bool					Save				(const CSG_String &FileName, int Format, SG_Char Separator);
+	bool							Load				(const CSG_String &File, int Format, SG_Char Separator);
+
+	virtual bool					Save				(const CSG_String &File, int Format, SG_Char Separator);
+	virtual bool					Save				(const char       *File, int Format, SG_Char Separator)	{ return( Save(CSG_String(File), Format, Separator) ); }
+	virtual bool					Save				(const wchar_t    *File, int Format, SG_Char Separator)	{ return( Save(CSG_String(File), Format, Separator) ); }
+
+	virtual bool					Save				(const CSG_String &File, int Format = 0);
+	virtual bool					Save				(const char       *File, int Format = 0)	{	return( Save(CSG_String(File), Format) );	}
+	virtual bool					Save				(const wchar_t    *File, int Format = 0)	{	return( Save(CSG_String(File), Format) );	}
+
 	bool							Serialize			(CSG_File &Stream, bool bSave);
 
 	//-----------------------------------------------------
