@@ -66,6 +66,8 @@
 
 #include "data_manager.h"
 
+#include <wx/string.h>
+
 
 ///////////////////////////////////////////////////////////
 //														 //
@@ -444,11 +446,9 @@ CSG_Parameters * CSG_Tool::Add_Parameters(const CSG_String &Identifier, const CS
 //---------------------------------------------------------
 CSG_Parameters * CSG_Tool::Get_Parameters(const CSG_String &Identifier)
 {
-	CSG_String	sIdentifier(Identifier);
-
 	for(int i=0; i<m_npParameters; i++)
 	{
-		if( !sIdentifier.Cmp(m_pParameters[i]->Get_Identifier()) )
+		if( m_pParameters[i]->Cmp_Identifier(Identifier) )
 		{
 			return( m_pParameters[i] );
 		}
@@ -591,13 +591,63 @@ void CSG_Tool::Process_Set_Text(const CSG_String &Text)
 }
 
 //---------------------------------------------------------
-bool CSG_Tool::Set_Progress(double Percent)
+void CSG_Tool::Process_Set_Text(const char    *Format, ...)
+{
+	wxString	_s;
+
+	va_list	argptr;
+
+	#ifdef _SAGA_LINUX
+	// workaround as we only use wide characters
+	// since wx 2.9.4 so interpret strings as multibyte
+	wxString	_Format(Format);	_Format.Replace("%s", "%ls");
+	va_start(argptr, _Format);
+	_s.PrintfV(_Format, argptr);
+	#else
+	va_start(argptr, Format);
+	_s.PrintfV(Format, argptr);
+	#endif
+
+	va_end(argptr);
+
+	CSG_String	s(&_s);
+
+	SG_UI_Process_Set_Text(s);
+}
+
+//---------------------------------------------------------
+void CSG_Tool::Process_Set_Text(const wchar_t *Format, ...)
+{
+	wxString	_s;
+
+	va_list	argptr;
+
+	#ifdef _SAGA_LINUX
+	// workaround as we only use wide characters
+	// since wx 2.9.4 so interpret strings as multibyte
+	wxString	_Format(Format);	_Format.Replace("%s", "%ls");
+	va_start(argptr, _Format);
+	_s.PrintfV(_Format, argptr);
+	#else
+	va_start(argptr, Format);
+	_s.PrintfV(Format, argptr);
+	#endif
+
+	va_end(argptr);
+
+	CSG_String	s(&_s);
+
+	SG_UI_Process_Set_Text(s);
+}
+
+//---------------------------------------------------------
+bool CSG_Tool::Set_Progress(double Percent)	const
 {
 	return( Set_Progress(Percent, 100.0) );
 }
 
 //---------------------------------------------------------
-bool CSG_Tool::Set_Progress(double Position, double Range)
+bool CSG_Tool::Set_Progress(double Position, double Range)	const
 {
 	return( m_bShow_Progress ? SG_UI_Process_Set_Progress(Position, Range) : Process_Get_Okay(false) );
 }
@@ -635,6 +685,56 @@ void CSG_Tool::Message_Add(const CSG_String &Text, bool bNewLine)
 	SG_UI_Msg_Add_Execution(Text, bNewLine);
 }
 
+//---------------------------------------------------------
+void CSG_Tool::Message_Fmt(const char *Format, ...)
+{
+	wxString	_s;
+
+	va_list	argptr;
+	
+#ifdef _SAGA_LINUX
+	// workaround as we only use wide characters
+	// since wx 2.9.4 so interpret strings as multibyte
+	wxString	_Format(Format);	_Format.Replace("%s", "%ls");
+	va_start(argptr, _Format);
+	_s.PrintfV(_Format, argptr);
+#else
+	va_start(argptr, Format);
+	_s.PrintfV(Format, argptr);
+#endif
+
+	va_end(argptr);
+
+	CSG_String	s(&_s);
+
+	SG_UI_Msg_Add_Execution(s, false);
+}
+
+//---------------------------------------------------------
+void CSG_Tool::Message_Fmt(const wchar_t *Format, ...)
+{
+	wxString	_s;
+
+	va_list	argptr;
+	
+#ifdef _SAGA_LINUX
+	// workaround as we only use wide characters
+	// since wx 2.9.4 so interpret strings as multibyte
+	wxString	_Format(Format);	_Format.Replace("%s", "%ls");
+	va_start(argptr, _Format);
+	_s.PrintfV(_Format, argptr);
+#else
+	va_start(argptr, Format);
+	_s.PrintfV(Format, argptr);
+#endif
+
+	va_end(argptr);
+
+	CSG_String	s(&_s);
+
+	SG_UI_Msg_Add_Execution(s, false);
+}
+
 //---------------------------------------------------------
 bool CSG_Tool::Error_Set(TSG_Tool_Error Error_ID)
 {
@@ -671,11 +771,9 @@ bool CSG_Tool::Error_Set(const CSG_String &Error_Text)
 }
 
 //---------------------------------------------------------
-#include <wx/string.h>
-
 bool CSG_Tool::Error_Fmt(const char *Format, ...)
 {
-	wxString	Error;
+	wxString	_s;
 
 	va_list	argptr;
 	
@@ -684,15 +782,15 @@ bool CSG_Tool::Error_Fmt(const char *Format, ...)
 	// since wx 2.9.4 so interpret strings as multibyte
 	wxString	_Format(Format);	_Format.Replace("%s", "%ls");
 	va_start(argptr, _Format);
-	Error.PrintfV(_Format, argptr);
+	_s.PrintfV(_Format, argptr);
 #else
 	va_start(argptr, Format);
-	Error.PrintfV(Format, argptr);
+	_s.PrintfV(Format, argptr);
 #endif
 
 	va_end(argptr);
 
-	CSG_String	s(&Error);
+	CSG_String	s(&_s);
 
 	return( Error_Set(s) );
 }
@@ -700,7 +798,7 @@ bool CSG_Tool::Error_Fmt(const char *Format, ...)
 //---------------------------------------------------------
 bool CSG_Tool::Error_Fmt(const wchar_t *Format, ...)
 {
-	wxString	Error;
+	wxString	_s;
 
 	va_list	argptr;
 	
@@ -709,15 +807,15 @@ bool CSG_Tool::Error_Fmt(const wchar_t *Format, ...)
 	// since wx 2.9.4 so interpret strings as multibyte
 	wxString	_Format(Format);	_Format.Replace("%s", "%ls");
 	va_start(argptr, _Format);
-	Error.PrintfV(_Format, argptr);
+	_s.PrintfV(_Format, argptr);
 #else
 	va_start(argptr, Format);
-	Error.PrintfV(Format, argptr);
+	_s.PrintfV(Format, argptr);
 #endif
 
 	va_end(argptr);
 
-	CSG_String	s(&Error);
+	CSG_String	s(&_s);
 
 	return( Error_Set(s) );
 }
@@ -818,16 +916,16 @@ bool CSG_Tool::DataObject_Set_Parameters(CSG_Data_Object *pDataObject, CSG_Param
 	return( SG_UI_DataObject_Params_Set(pDataObject, &Parameters) );
 }
 
-bool CSG_Tool::DataObject_Set_Parameters(CSG_Data_Object *pDataObject, CSG_Data_Object *pSource)
+bool CSG_Tool::DataObject_Set_Parameters(CSG_Data_Object *pDataObject, CSG_Data_Object *pCopy)
 {
-	if( pDataObject == pSource )
+	if( pDataObject == pCopy )
 	{
 		return( true );
 	}
 
 	CSG_Parameters	Parms;
 	
-	if( DataObject_Get_Parameters(pSource, Parms) )
+	if( DataObject_Get_Parameters(pCopy, Parms) )
 	{
 		if( 1 )
 		{
@@ -854,9 +952,14 @@ bool CSG_Tool::DataObject_Set_Parameter(CSG_Data_Object *pDataObject, CSG_Parame
 {
 	CSG_Parameters	P;
 
-	P._Add(pParameter);
+	return( P._Add(pParameter) != NULL && DataObject_Set_Parameters(pDataObject, P) );
+}
 
-	return( DataObject_Set_Parameters(pDataObject, P) );
+bool CSG_Tool::DataObject_Set_Parameter(CSG_Data_Object *pDataObject, CSG_Data_Object *pCopy, const CSG_String &ID)
+{
+	CSG_Parameter	*pParameter	= DataObject_Get_Parameter(pCopy, ID);
+
+	return( DataObject_Set_Parameter(pDataObject, pParameter) );
 }
 
 bool CSG_Tool::DataObject_Set_Parameter	(CSG_Data_Object *pDataObject, const CSG_String &ID, int            Value)
@@ -931,9 +1034,9 @@ bool CSG_Tool::DataObject_Set_Parameter	(CSG_Data_Object *pDataObject, const CSG
   * Direct 'set a value' access to this tool's default parameters list.
 */
 //---------------------------------------------------------
-bool CSG_Tool::Set_Parameter(const CSG_String &Identifier, CSG_Parameter *pSource)
+bool CSG_Tool::Set_Parameter(const CSG_String &Identifier, CSG_Parameter *pValue)
 {
-	return( Parameters.Set_Parameter(Identifier, pSource) );
+	return( Parameters.Set_Parameter(Identifier, pValue) );
 }
 
 //---------------------------------------------------------
@@ -971,7 +1074,27 @@ bool CSG_Tool::Set_Parameter(const CSG_String &Identifier, void *Value, int Type
   * Direct 'set a value' access to this tool's default parameters list.
 */
 //---------------------------------------------------------
-bool CSG_Tool::Set_Parameter(const CSG_String &Identifier, const SG_Char *Value, int Type)
+bool CSG_Tool::Set_Parameter(const CSG_String &Identifier, const CSG_String &Value, int Type)
+{
+	return( Parameters.Set_Parameter(Identifier, Value, Type) );
+}
+
+//---------------------------------------------------------
+/**
+  * Direct 'set a value' access to this tool's default parameters list.
+*/
+//---------------------------------------------------------
+bool CSG_Tool::Set_Parameter(const CSG_String &Identifier, const char *Value, int Type)
+{
+	return( Parameters.Set_Parameter(Identifier, Value, Type) );
+}
+
+//---------------------------------------------------------
+/**
+  * Direct 'set a value' access to this tool's default parameters list.
+*/
+//---------------------------------------------------------
+bool CSG_Tool::Set_Parameter(const CSG_String &Identifier, const wchar_t *Value, int Type)
 {
 	return( Parameters.Set_Parameter(Identifier, Value, Type) );
 }
@@ -1145,480 +1268,6 @@ bool CSG_Tool::DataObject_Set_History(CSG_Parameter *pParameter, CSG_MetaData *p
 }
 
 
-///////////////////////////////////////////////////////////
-//														 //
-//						Summary							 //
-//														 //
-///////////////////////////////////////////////////////////
-
-//---------------------------------------------------------
-void _Add_XML(CSG_MetaData *pParent, CSG_Parameter *pParameter, CSG_String ID = "")
-{
-	if( !ID.is_Empty() )	ID	+= "_";	ID	+= pParameter->Get_Identifier();
-
-	CSG_MetaData	*pItem	= pParent->Add_Child(SG_XML_PARAM);
-
-	pItem->Add_Property(SG_XML_PARAM_ATT_NAME , pParameter->Get_Name());
-	pItem->Add_Property(SG_XML_PARAM_ATT_CLASS,	pParameter->is_Input() ? "input" : pParameter->is_Output() ? "output" : "option");
-
-	pItem->Add_Child(SG_XML_PARAM_IDENT, ID);
-	pItem->Add_Child(SG_XML_PARAM_TYPE , pParameter->Get_Type_Name().Make_Lower());
-	pItem->Add_Child(SG_XML_PARAM_MAND , pParameter->is_Optional() ? SG_T("false") : SG_T("true"));
-	pItem->Add_Child(SG_XML_DESCRIPTION, pParameter->Get_Description());
-
-	switch( pParameter->Get_Type() )
-	{
-	//-----------------------------------------------------
-	case PARAMETER_TYPE_Choice:
-		{
-			CSG_MetaData	*pChild	= pItem->Add_Child(SG_XML_PARAM_LIST);
-
-			for(int i=0; i<pParameter->asChoice()->Get_Count(); i++)
-			{
-				pChild->Add_Child(SG_XML_PARAM_ITEM, pParameter->asChoice()->Get_Item(i));
-			}
-
-			if( !pParameter->asChoice()->Get_Default().is_Empty() )
-			{
-				pItem->Add_Child(SG_XML_PARAM_DEFAULT, pParameter->asChoice()->Get_Default());
-			}
-		}
-		break;
-
-	//-----------------------------------------------------
-	case PARAMETER_TYPE_Choices:
-		{
-			CSG_MetaData	*pChild	= pItem->Add_Child(SG_XML_PARAM_LIST);
-
-			for(int i=0; i<pParameter->asChoices()->Get_Item_Count(); i++)
-			{
-				pChild->Add_Child(SG_XML_PARAM_ITEM, pParameter->asChoices()->Get_Item(i));
-			}
-
-			if( !pParameter->asChoices()->Get_Default().is_Empty() )
-			{
-				pItem->Add_Child(SG_XML_PARAM_DEFAULT, pParameter->asChoices()->Get_Default());
-			}
-		}
-		break;
-
-	//-----------------------------------------------------
-	case PARAMETER_TYPE_FixedTable:
-		{
-			CSG_MetaData	*pChild	= pItem->Add_Child(SG_XML_PARAM_TABLE);
-
-			for(int i=0; i<pParameter->asTable()->Get_Field_Count(); i++)
-			{
-				CSG_MetaData	*pField	= pChild->Add_Child(SG_XML_PARAM_FIELD);
-
-				pField->Add_Property(SG_XML_PARAM_FIELD_ATT_NAME, pParameter->asTable()->Get_Field_Name(i));
-				pField->Add_Property(SG_XML_PARAM_FIELD_ATT_TYPE, SG_Data_Type_Get_Name(pParameter->asTable()->Get_Field_Type(i)));
-			}
-		}
-		break;
-
-	//-----------------------------------------------------
-	case PARAMETER_TYPE_Int:
-	case PARAMETER_TYPE_Double:
-	case PARAMETER_TYPE_Degree:
-		if( ((CSG_Parameter_Value *)pParameter->Get_Data())->has_Minimum() ) pItem->Add_Child(SG_XML_PARAM_MIN, ((CSG_Parameter_Value *)pParameter->Get_Data())->Get_Minimum());
-		if( ((CSG_Parameter_Value *)pParameter->Get_Data())->has_Maximum() ) pItem->Add_Child(SG_XML_PARAM_MAX, ((CSG_Parameter_Value *)pParameter->Get_Data())->Get_Maximum());
-		if( !pParameter->Get_Data()->Get_Default().is_Empty() )              pItem->Add_Child(SG_XML_PARAM_DEFAULT, pParameter->Get_Data()->Get_Default());
-		break;
-
-	//-----------------------------------------------------
-	case PARAMETER_TYPE_Bool:
-		pItem->Add_Child(SG_XML_PARAM_DEFAULT, pParameter->asBool());
-		break;
-
-	//-----------------------------------------------------
-	case PARAMETER_TYPE_Parameters:
-		{
-			for(int i=0; i<pParameter->asParameters()->Get_Count(); i++)
-			{
-				_Add_XML(pItem, pParameter->asParameters()->Get_Parameter(i), ID);
-			}
-		}
-	default:
-		break;
-	}
-}
-
-//---------------------------------------------------------
-CSG_String CSG_Tool::Get_Summary(bool bParameters, const CSG_String &Menu, const CSG_String &Description, int Format)
-{
-	#define SUMMARY_DO_ADD	(SG_UI_Get_Window_Main() ? Parameters(i)->do_UseInGUI() : Parameters(i)->do_UseInCMD())
-
-	int			i;
-	CSG_String	s;
-
-	//-----------------------------------------------------
-	switch( Format )
-	{
-	case SG_SUMMARY_FMT_XML:
-		{
-			CSG_MetaData	m;
-
-			m.Set_Name    (SG_XML_TOOL);
-			m.Add_Property(SG_XML_TOOL_ATT_NAME   , Get_Name       ());
-			m.Add_Property(SG_XML_TOOL_ATT_ID     , Get_ID         ());
-			m.Add_Property(SG_XML_TOOL_ATT_AUTHOR , Get_Author     ());
-			m.Add_Property(SG_XML_TOOL_ATT_VERSION, Get_Version    ());
-			m.Add_Child   (SG_XML_DESCRIPTION     , Get_Description());
-			m.Add_Child   (SG_XML_MENU            , Get_MenuPath   ());
-			m.Add_Child   (SG_XML_SPEC_ATT_GRID   , is_Grid        () ? "true" : "false");
-			m.Add_Child   (SG_XML_SPEC_ATT_INTERA , is_Interactive () ? "true" : "false");
-
-		//	CSG_MetaData	*pChild	= m.Add_Child(SG_XML_SPECIFICATION);
-		//	pChild->Add_Property(SG_XML_SPEC_ATT_GRID  , is_Grid        () ? "true" : "false");
-		//	pChild->Add_Property(SG_XML_SPEC_ATT_INTERA, is_Interactive () ? "true" : "false");
-
-			if( bParameters )
-			{
-				for(i=0; i<Parameters.Get_Count(); i++)
-				{
-					if( SUMMARY_DO_ADD && Parameters(i)->is_Input() )
- 					{
-						_Add_XML(&m, Parameters(i));
-					}
-				}
-
-				for(i=0; i<Parameters.Get_Count(); i++)
-				{
-					if( SUMMARY_DO_ADD && Parameters(i)->is_Output() )
- 					{
-						_Add_XML(&m, Parameters(i));
-					}
-				}
-
-				for(i=0; i<Parameters.Get_Count(); i++)
-				{
-					if( SUMMARY_DO_ADD && Parameters(i)->is_Option()
-					&&  Parameters(i)->Get_Type() != PARAMETER_TYPE_Node
-					&&  Parameters(i)->Get_Type() != PARAMETER_TYPE_Grid_System )
- 					{
-						_Add_XML(&m, Parameters(i));
-					}
-				}
-			}
-
-			s	= m.asText(1);
-		}
-		break;
-
-	//-----------------------------------------------------
-	case SG_SUMMARY_FMT_HTML:
-		{
-			#define SUMMARY_ADD_STR(label, value)	CSG_String::Format("<tr><td valign=\"top\"><b>%s</b></td><td valign=\"top\">%s</td></tr>", label, value)
-			#define SUMMARY_ADD_INT(label, value)	CSG_String::Format("<tr><td valign=\"top\"><b>%s</b></td><td valign=\"top\">%d</td></tr>", label, value)
-
-			s	+= CSG_String::Format("<h4>%s</h4><table border=\"0\">", _TL("Tool"));
-
-			s	+= SUMMARY_ADD_STR(_TL("Name"   ), Get_Name   ().c_str());
-			s	+= SUMMARY_ADD_STR(_TL("Author" ), Get_Author ().c_str());
-			s	+= SUMMARY_ADD_STR(_TL("Version"), Get_Version().c_str());
-			s	+= SUMMARY_ADD_STR(_TL("Library"), Get_Library().c_str());
-			s	+= SUMMARY_ADD_STR(_TL("ID"     ), Get_ID     ().c_str());
-
-			if( is_Interactive() && is_Grid() )
-			{
-				s	+= SUMMARY_ADD_STR(_TL("Specification"), CSG_String::Format("%s, %s", _TL("grid"), _TL("interactive")).c_str() );
-			}
-			else if( is_Interactive() )
-			{
-				s	+= SUMMARY_ADD_STR(_TL("Specification"), _TL("interactive"));
-			}
-			else if( is_Grid() )
-			{
-				s	+= SUMMARY_ADD_STR(_TL("Specification"), _TL("grid"));
-			}
-
-			if( Get_Type() == TOOL_TYPE_Chain )
-			{
-				s	+= SUMMARY_ADD_STR(_TL("File"), Get_File_Name().c_str() );
-			}
-
-			if( Menu.Length() > 0 )
-			{
-				CSG_String	sMenu(Menu);
-
-				sMenu.Replace("|", " <b>></b> ");
-
-				s	+= SUMMARY_ADD_STR(_TL("Menu"  ), sMenu.c_str());
-			}
-
-			s	+= "</table>";
-
-			#undef SUMMARY_ADD_STR
-			#undef SUMMARY_ADD_INT
-
-			//---------------------------------------------
-			s	+= CSG_String::Format("<hr><h4>%s</h4>", _TL("Description"));
-
-			s	+= !Description.is_Empty() ? Description : Get_Description();
-
-			//---------------------------------------------
-			if( Description.is_Empty() && Get_References().Get_Count() > 0 )
-			{
-				s	+= CSG_String::Format("<hr><h4>%s</h4><ul>", _TL("References"));
-
-				for(i=0; i<Get_References().Get_Count(); i++)
-				{
-					s	+= "<li>" + Get_References()[i] + "</li>";
-				}
-
-				s	+= "</ul>";
-			}
-
-			//---------------------------------------------
-			if( bParameters )
-			{
-				bool	bFirst, bOptionals	= false;
-
-				s	+= CSG_String::Format("<hr><h4>%s</h4>", _TL("Parameters"));
-				s	+= CSG_String::Format("<table border=\"1\" width=\"100%%\" valign=\"top\" cellpadding=\"5\" rules=\"all\"><tr><th>%s</th><th>%s</th><th>%s</th><th>%s</th><th>%s</th></tr>\n",
-						_TL("Name"), _TL("Type"), _TL("Identifier"), _TL("Description"), _TL("Constraints")
-					);
-
-				//-----------------------------------------
-				for(i=0, bFirst=true; i<Parameters.Get_Count(); i++)
-				{
-					CSG_Parameter	*pParameter	= Parameters(i);
-
-					if( SUMMARY_DO_ADD && pParameter->is_Input() )
-					{
-						if( bFirst )
-						{
-							bFirst	= false;
-							s	+= CSG_String::Format("<tr><th colspan=\"5\">%s</th></tr>", _TL("Input"));
-						}
-
-						s	+= CSG_String::Format("<tr><td>%s%s</td><td>%s</td><td>%s</td><td>%s</td><td>%s</td></tr>",
-							pParameter->Get_Name(),
-							pParameter->is_Optional() ? SG_T(" (*)") : SG_T(" "),
-							pParameter->Get_Description(PARAMETER_DESCRIPTION_TYPE).c_str(),
-							pParameter->Get_Identifier(),
-							pParameter->Get_Description(),
-							pParameter->Get_Description(PARAMETER_DESCRIPTION_PROPERTIES).c_str()
-						);
-					}
-				}
-
-				//-----------------------------------------
-				for(i=0, bFirst=true; i<Parameters.Get_Count(); i++)
-				{
-					CSG_Parameter	*pParameter	= Parameters(i);
-
-					if( SUMMARY_DO_ADD && pParameter->is_Output() )
-					{
-						if( bFirst )
-						{
-							bFirst	= false;
-							s	+= CSG_String::Format("<tr><th colspan=\"5\">%s</th></tr>", _TL("Output"));
-						}
-
-						s	+= CSG_String::Format("<tr><td>%s%s</td><td>%s</td><td>%s</td><td>%s</td><td>%s</td></tr>",
-							pParameter->Get_Name(),
-							pParameter->is_Optional() ? SG_T(" (*)") : SG_T(""),
-							pParameter->Get_Description(PARAMETER_DESCRIPTION_TYPE).c_str(),
-							pParameter->Get_Identifier(),
-							pParameter->Get_Description(),
-							pParameter->Get_Description(PARAMETER_DESCRIPTION_PROPERTIES).c_str()
-						);
-					}
-				}
-
-				//-----------------------------------------
-				for(i=0, bFirst=true; i<Parameters.Get_Count(); i++)
-				{
-					CSG_Parameter	*pParameter	= Parameters(i);
-
-					if( SUMMARY_DO_ADD && pParameter->is_Option() && pParameter->Get_Type() != PARAMETER_TYPE_Grid_System )
-					{
-						if( bFirst )
-						{
-							bFirst	= false;
-							s	+= CSG_String::Format("<tr><th colspan=\"5\">%s</th></tr>", _TL("Options"));
-						}
-
-						s	+= CSG_String::Format("<tr><td>%s</td><td>%s</td><td>%s</td><td>%s</td><td>%s</td></tr>",
-							pParameter->Get_Name(),
-							pParameter->Get_Description(PARAMETER_DESCRIPTION_TYPE).c_str(),
-							pParameter->Get_Identifier(),
-							pParameter->Get_Description(),
-							pParameter->Get_Description(PARAMETER_DESCRIPTION_PROPERTIES).c_str()
-						);
-					}
-					else if( pParameter->is_Optional() )
-					{
-						bOptionals	= true;
-					}
-				}
-
-				//-----------------------------------------
-				s	+= "</table>";
-
-				if( bOptionals )
-				{
-					s	+= CSG_String::Format("(*) <i>%s</i>", _TL("optional"));
-				}
-			}
-		}
-		break;
-
-	//-----------------------------------------------------
-	case SG_SUMMARY_FMT_FLAT: default:
-		{
-			#define SUMMARY_ADD_STR(label, value)	CSG_String::Format("%s:\t%s\n", label, value)
-			#define SUMMARY_ADD_INT(label, value)	CSG_String::Format("%s:\t%d\n", label, value)
-
-			s	+= SUMMARY_ADD_STR(_TL("Name"   ), Get_Name   ().c_str());
-			s	+= SUMMARY_ADD_STR(_TL("ID"     ), Get_ID     ().c_str());
-			s	+= SUMMARY_ADD_STR(_TL("Author" ), Get_Author ().c_str());
-			s	+= SUMMARY_ADD_STR(_TL("Version"), Get_Version().c_str());
-
-			if( is_Interactive() && is_Grid() )
-			{
-				s	+= SUMMARY_ADD_STR(_TL("Specification"), CSG_String::Format("%s, %s", _TL("grid"), _TL("interactive")).c_str() );
-			}
-			else if( is_Interactive() )
-			{
-				s	+= SUMMARY_ADD_STR(_TL("Specification"), _TL("interactive"));
-			}
-			else if( is_Grid() )
-			{
-				s	+= SUMMARY_ADD_STR(_TL("Specification"), _TL("grid"));
-			}
-
-			if( Get_Type() == TOOL_TYPE_Chain )
-			{
-				s	+= SUMMARY_ADD_STR(_TL("File"), Get_File_Name().c_str() );
-			}
-
-			if( Menu.Length() > 0 )
-			{
-				CSG_String	sMenu(Menu);
-
-				sMenu.Replace("|", " <b>></b> ");
-
-				s	+= SUMMARY_ADD_STR(_TL("Menu"  ), sMenu.c_str());
-			}
-
-			#undef SUMMARY_ADD_STR
-			#undef SUMMARY_ADD_INT
-
-			//---------------------------------------------
-			s	+= "\n____________________________\n";
-
-			s	+= CSG_String::Format("%s:\n", _TL("Description"));
-
-			s	+= !Description.is_Empty() ? Description : Get_Description();
-
-			//---------------------------------------------
-			if( Description.is_Empty() && Get_References().Get_Count() > 0 )
-			{
-				s	+= "\n____________________________\n";
-
-				s	+= CSG_String::Format("\n%s:\n", _TL("References"));
-
-				for(i=0; i<Get_References().Get_Count(); i++)
-				{
-					s	+= " - " + Get_References()[i] + "\n";
-				}
-			}
-
-			//---------------------------------------------
-			if( bParameters )
-			{
-				bool	bFirst, bOptionals	= false;
-
-				s	+= "\n";
-
-				//-----------------------------------------
-				for(i=0, bFirst=true; i<Parameters.Get_Count(); i++)
-				{
-					CSG_Parameter	*pParameter	= Parameters(i);
-
-					if( SUMMARY_DO_ADD && pParameter->is_Input() )
-					{
-						if( bFirst )
-						{
-							bFirst	= false;
-							s	+= "____________________________\n";
-							s	+= CSG_String::Format("%s:\n", _TL("Input"));
-						}
-
-						s	+= CSG_String::Format("_\n%s\n%s\n%s\n%s\n%s\n",
-							pParameter->Get_Name(),
-							pParameter->Get_Identifier(),
-							pParameter->Get_Description(PARAMETER_DESCRIPTION_TYPE).c_str(),
-							pParameter->Get_Description(),
-							pParameter->Get_Description(PARAMETER_DESCRIPTION_PROPERTIES).c_str()
-						);
-					}
-				}
-
-				//-----------------------------------------
-				for(i=0, bFirst=true; i<Parameters.Get_Count(); i++)
-				{
-					CSG_Parameter	*pParameter	= Parameters(i);
-
-					if( SUMMARY_DO_ADD && pParameter->is_Output() )
-					{
-						if( bFirst )
-						{
-							bFirst	= false;
-							s	+= "____________________________\n";
-							s	+= CSG_String::Format("%s:\n", _TL("Output"));
-						}
-
-						s	+= CSG_String::Format("_\n%s\n%s\n%s\n%s\n%s\n",
-							pParameter->Get_Name(),
-							pParameter->Get_Identifier(),
-							pParameter->Get_Description(PARAMETER_DESCRIPTION_TYPE).c_str(),
-							pParameter->Get_Description(),
-							pParameter->Get_Description(PARAMETER_DESCRIPTION_PROPERTIES).c_str()
-						);
-					}
-				}
-
-				//-----------------------------------------
-				for(i=0, bFirst=true; i<Parameters.Get_Count(); i++)
-				{
-					CSG_Parameter	*pParameter	= Parameters(i);
-
-					if( SUMMARY_DO_ADD && pParameter->is_Option() && pParameter->Get_Type() != PARAMETER_TYPE_Grid_System )
-					{
-						if( bFirst )
-						{
-							bFirst	= false;
-							s	+= "____________________________\n";
-							s	+= CSG_String::Format("%s:\n", _TL("Options"));
-						}
-
-						s	+= CSG_String::Format("_\n%s\n%s\n%s\n%s\n%s\n",
-							pParameter->Get_Name(),
-							pParameter->Get_Identifier(),
-							pParameter->Get_Description(PARAMETER_DESCRIPTION_TYPE).c_str(),
-							pParameter->Get_Description(),
-							pParameter->Get_Description(PARAMETER_DESCRIPTION_PROPERTIES).c_str()
-						);
-					}
-					else if( pParameter->is_Optional() )
-					{
-						bOptionals	= true;
-					}
-				}
-			}
-		}
-		break;
-	}
-
-	//-----------------------------------------------------
-	return( s );
-}
-
-
 ///////////////////////////////////////////////////////////
 //														 //
 //														 //
