@@ -75,63 +75,6 @@
 #include "parameters.h"
 
 
-///////////////////////////////////////////////////////////
-//														 //
-//		XML tags for mark-up of tool synopsis	 		 //
-//														 //
-///////////////////////////////////////////////////////////
-
-//---------------------------------------------------------
-#define SG_XML_SYSTEM				SG_T("system")
-#define SG_XML_SYSTEM_VER			SG_T("version")
-#define SG_XML_SYSTEM_MLP			SG_T("library-path")
-#define SG_XML_LIBRARY				SG_T("library")
-#define SG_XML_LIBRARY_PATH			SG_T("path")
-#define SG_XML_LIBRARY_NAME			SG_T("name")
-#define SG_XML_TOOL					SG_T("module")
-#define SG_XML_TOOL_ATT_NAME		SG_T("name")
-#define SG_XML_TOOL_ATT_ID			SG_T("id")
-#define SG_XML_TOOL_ATT_VERSION		SG_T("version")
-#define SG_XML_TOOL_ATT_AUTHOR		SG_T("author")
-#define SG_XML_SPECIFICATION		SG_T("specification")
-#define SG_XML_SPEC_ATT_GRID		SG_T("grid")
-#define SG_XML_SPEC_ATT_INTERA		SG_T("interactive")
-#define SG_XML_MENU					SG_T("menu")
-#define SG_XML_DESCRIPTION			SG_T("description")
-#define SG_XML_PARAM				SG_T("parameter")
-#define SG_XML_PARAM_ATT_NAME		SG_T("name")
-#define SG_XML_PARAM_ATT_CLASS		SG_T("class")
-#define SG_XML_PARAM_MAND			SG_T("mandatory")
-#define SG_XML_PARAM_TYPE			SG_T("type")
-#define SG_XML_PARAM_IDENT			SG_T("identifier")
-#define SG_XML_PARAM_DESC			SG_T("description")
-#define SG_XML_PARAM_PROP			SG_T("properties")
-#define SG_XML_PARAM_LIST			SG_T("list")
-#define SG_XML_PARAM_ITEM			SG_T("item")
-#define SG_XML_PARAM_TABLE			SG_T("table")
-#define SG_XML_PARAM_FIELD			SG_T("field")
-#define SG_XML_PARAM_FIELD_ATT_NAME	SG_T("name")
-#define SG_XML_PARAM_FIELD_ATT_TYPE	SG_T("type")
-#define SG_XML_PARAM_MIN			SG_T("min")
-#define SG_XML_PARAM_MAX			SG_T("max")
-#define SG_XML_PARAM_DEFAULT		SG_T("default")
-
-//---------------------------------------------------------
-#define SG_XML_ERROR				SG_T("error")
-#define SG_XML_ERROR_ATT_MSG		SG_T("message")
-#define SG_XML_ERROR_ATT_DESC		SG_T("description")
-#define SG_XML_WARNING				SG_T("warning")
-#define SG_XML_MESSAGE				SG_T("message")
-#define SG_XML_MESSAGE_PROC			SG_T("message-proc")
-#define SG_XML_MESSAGE_EXEC			SG_T("message-exec")
-#define SG_XML_PROGRESS				SG_T("progress")
-
-//---------------------------------------------------------
-#define SG_GET_XML_TAGGED_STR(value, tag)	CSG_String::Format(SG_T("<%s>%s</%s>"), tag, value, tag)
-#define SG_GET_XML_TAGGED_INT(value, tag)	CSG_String::Format(SG_T("<%s>%d</%s>"), tag, value, tag)
-#define SG_GET_XML_TAGGED_FLT(value, tag)	CSG_String::Format(SG_T("<%s>%f</%s>"), tag, value, tag)
-
-
 ///////////////////////////////////////////////////////////
 //														 //
 //														 //
@@ -195,7 +138,7 @@ public:
 
 	virtual void				Destroy						(void);
 
-	virtual TSG_Tool_Type		Get_Type					(void)	{	return( TOOL_TYPE_Base );	}
+	virtual TSG_Tool_Type		Get_Type					(void)	const	{	return( TOOL_TYPE_Base );	}
 
 	const CSG_String &			Get_ID						(void)	const	{	return( m_ID );	}
 
@@ -217,11 +160,13 @@ public:
 	CSG_Parameters *			Get_Parameters				(int i)	{	return( i >= 0 && i < m_npParameters ? m_pParameters[i] : NULL );	}
 	CSG_Parameters *			Get_Parameters				(const CSG_String &Identifier);
 
-	bool						Set_Parameter				(const CSG_String &Identifier, CSG_Parameter *pSource);
-	bool						Set_Parameter				(const CSG_String &Identifier, int            Value, int Type = PARAMETER_TYPE_Undefined);
-	bool						Set_Parameter				(const CSG_String &Identifier, double         Value, int Type = PARAMETER_TYPE_Undefined);
-	bool						Set_Parameter				(const CSG_String &Identifier, void          *Value, int Type = PARAMETER_TYPE_Undefined);
-	bool						Set_Parameter				(const CSG_String &Identifier, const SG_Char *Value, int Type = PARAMETER_TYPE_Undefined);
+	bool						Set_Parameter				(const CSG_String &Identifier, CSG_Parameter   *pValue);
+	bool						Set_Parameter				(const CSG_String &Identifier, int               Value, int Type = PARAMETER_TYPE_Undefined);
+	bool						Set_Parameter				(const CSG_String &Identifier, double            Value, int Type = PARAMETER_TYPE_Undefined);
+	bool						Set_Parameter				(const CSG_String &Identifier, void             *Value, int Type = PARAMETER_TYPE_Undefined);
+	bool						Set_Parameter				(const CSG_String &Identifier, const CSG_String &Value, int Type = PARAMETER_TYPE_Undefined);
+	bool						Set_Parameter				(const CSG_String &Identifier, const char       *Value, int Type = PARAMETER_TYPE_Undefined);
+	bool						Set_Parameter				(const CSG_String &Identifier, const wchar_t    *Value, int Type = PARAMETER_TYPE_Undefined);
 
 	bool						Update_Parameter_States		(void);
 
@@ -233,12 +178,12 @@ public:
 
 	virtual bool				do_Sync_Projections			(void)	{	return( true  );	}
 
-	virtual bool				needs_GUI					(void)	{	return( false );	}
+	virtual bool				needs_GUI					(void)	const	{	return( false );	}
 
-	virtual bool				is_Grid						(void)	{	return( false );	}
-	virtual bool				is_Interactive				(void)	{	return( false );	}
-	bool						is_Progress					(void)	{	return( SG_UI_Process_Get_Okay(false) );	}
-	bool						is_Executing				(void)	{	return( m_bExecutes );	}
+	virtual bool				is_Grid						(void)	const	{	return( false );	}
+	virtual bool				is_Interactive				(void)	const	{	return( false );	}
+	bool						is_Progress					(void)	const	{	return( SG_UI_Process_Get_Okay(false) );	}
+	bool						is_Executing				(void)	const	{	return( m_bExecutes );	}
 
 	void						Set_Show_Progress			(bool bOn = true);
 
@@ -279,17 +224,21 @@ protected:
 
 
 	//-----------------------------------------------------
-	virtual bool				Process_Get_Okay			(bool bBlink = false);
-	virtual void				Process_Set_Text			(const CSG_String &Text);
+	static bool					Process_Get_Okay			(bool bBlink = false);
+	static void					Process_Set_Text			(const CSG_String &Text);
+	static void					Process_Set_Text			(const char    *Format, ...);
+	static void					Process_Set_Text			(const wchar_t *Format, ...);
 
-	virtual bool				Set_Progress				(double Percent);
-	virtual bool				Set_Progress				(double Position, double Range);
+	virtual bool				Set_Progress				(double Percent)				const;
+	virtual bool				Set_Progress				(double Position, double Range)	const;
 
 	bool						Stop_Execution				(bool bDialog = true);
 
-	void						Message_Add					(const CSG_String &Text, bool bNewLine = true);
 	void						Message_Dlg					(const CSG_String &Text, const SG_Char *Caption = NULL);
 	bool						Message_Dlg_Confirm			(const CSG_String &Text, const SG_Char *Caption = NULL);
+	static void					Message_Add					(const CSG_String &Text, bool bNewLine = true);
+	static void					Message_Fmt					(const char    *Format, ...);
+	static void					Message_Fmt					(const wchar_t *Format, ...);
 
 	bool						Error_Set					(TSG_Tool_Error Error_ID = TOOL_ERROR_Unknown);
 	bool						Error_Set					(const CSG_String &Error_Text);
@@ -310,10 +259,11 @@ protected:
 
 	bool						DataObject_Get_Parameters	(CSG_Data_Object *pDataObject, CSG_Parameters &Parameters);
 	bool						DataObject_Set_Parameters	(CSG_Data_Object *pDataObject, CSG_Parameters &Parameters);
-	bool						DataObject_Set_Parameters	(CSG_Data_Object *pDataObject, CSG_Data_Object *pSource);
+	bool						DataObject_Set_Parameters	(CSG_Data_Object *pDataObject, CSG_Data_Object *pCopy);
 
 	CSG_Parameter *				DataObject_Get_Parameter	(CSG_Data_Object *pDataObject, const CSG_String &ID);
 	bool						DataObject_Set_Parameter	(CSG_Data_Object *pDataObject, CSG_Parameter *pParameter);
+	bool						DataObject_Set_Parameter	(CSG_Data_Object *pDataObject, CSG_Data_Object *pCopy, const CSG_String &ID);
 	bool						DataObject_Set_Parameter	(CSG_Data_Object *pDataObject, const CSG_String &ID, int            Value);
 	bool						DataObject_Set_Parameter	(CSG_Data_Object *pDataObject, const CSG_String &ID, double         Value);
 	bool						DataObject_Set_Parameter	(CSG_Data_Object *pDataObject, const CSG_String &ID, void          *Value);
@@ -367,48 +317,51 @@ public:
 	CSG_Tool_Grid(void);
 	virtual ~CSG_Tool_Grid(void);
 
-	virtual TSG_Tool_Type		Get_Type				(void)			{	return( TOOL_TYPE_Grid );	}
+	virtual TSG_Tool_Type		Get_Type				(void)	const	{	return( TOOL_TYPE_Grid );	}
 
-	CSG_Grid_System *			Get_System				(void)			{	return( Parameters.Get_Grid_System() );	}
+	const CSG_Grid_System &		Get_System				(void)	const	{	return( *Parameters.Get_Grid_System() );	}
+	bool						Set_System				(const CSG_Grid_System &System);
 
-	virtual bool				is_Grid					(void)			{	return( true );	}
+	virtual bool				is_Grid					(void)	const	{	return( true );	}
 
 
 protected:
 
-	virtual bool				Set_Progress_NCells		(sLong iCell);
-	virtual bool				Set_Progress			(int  iRow);
-	virtual bool				Set_Progress			(double Position, double Range);
+	virtual bool				Set_Progress_NCells		(sLong iCell)					const;
+	virtual bool				Set_Progress			(int    iRow)					const;
+	virtual bool				Set_Progress			(double Position, double Range)	const;
 
 	//-----------------------------------------------------
-	int							Get_NX					(void)						{	return( Get_System()->Get_NX() );				}
-	int							Get_NY					(void)						{	return( Get_System()->Get_NY() );				}
-	sLong						Get_NCells				(void)						{	return( Get_System()->Get_NCells() );			}
-	double						Get_Cellsize			(void)						{	return( Get_System()->Get_Cellsize() );			}
-	double						Get_Cellarea			(void)						{	return( Get_System()->Get_Cellarea() );			}
-	double						Get_XMin				(void)						{	return( Get_System()->Get_XMin() );				}
-	double						Get_YMin				(void)						{	return( Get_System()->Get_YMin() );				}
-	double						Get_XMax				(void)						{	return( Get_System()->Get_XMax() );				}
-	double						Get_YMax				(void)						{	return( Get_System()->Get_YMax() );				}
-	int							Get_xTo					(int Dir, int x = 0)		{	return( Get_System()->Get_xTo(Dir, x) );		}
-	int							Get_yTo					(int Dir, int y = 0)		{	return( Get_System()->Get_yTo(Dir, y) );		}
-	int							Get_xFrom				(int Dir, int x = 0)		{	return( Get_System()->Get_xFrom(Dir, x) );		}
-	int							Get_yFrom				(int Dir, int y = 0)		{	return( Get_System()->Get_yFrom(Dir, y) );		}
-	double						Get_Length				(int Dir)					{	return( Get_System()->Get_Length(Dir) );		}
-	double						Get_UnitLength			(int Dir)					{	return( Get_System()->Get_UnitLength(Dir) );	}
-	bool						is_InGrid				(int x, int y)				{	return(	Get_System()->is_InGrid(x, y) );		}
-	bool						is_InGrid				(int x, int y, int Rand)	{	return(	Get_System()->is_InGrid(x, y, Rand) );	}
+	int							Get_NX					(void)						const	{	return( Get_System().Get_NX      () );	}
+	int							Get_NY					(void)						const	{	return( Get_System().Get_NY      () );	}
+	sLong						Get_NCells				(void)						const	{	return( Get_System().Get_NCells  () );	}
+	double						Get_XMin				(void)						const	{	return( Get_System().Get_XMin    () );	}
+	double						Get_YMin				(void)						const	{	return( Get_System().Get_YMin    () );	}
+	double						Get_XMax				(void)						const	{	return( Get_System().Get_XMax    () );	}
+	double						Get_YMax				(void)						const	{	return( Get_System().Get_YMax    () );	}
+	double						Get_Cellsize			(void)						const	{	return( Get_System().Get_Cellsize() );	}
+	double						Get_Cellarea			(void)						const	{	return( Get_System().Get_Cellarea() );	}
+
+	double						Get_Length				(int i)						const	{	return( Get_System().Get_Length    (i)     );	}
+	double						Get_UnitLength			(int i)						const	{	return( Get_System().Get_UnitLength(i)     );	}
+	bool						is_InGrid				(int x, int y)				const	{	return(	Get_System().is_InGrid(x, y)       );	}
+	bool						is_InGrid				(int x, int y, int Rand)	const	{	return(	Get_System().is_InGrid(x, y, Rand) );	}
+
+	static int					Get_xTo					(int i, int x = 0)	{	return( CSG_Grid_System::Get_xTo  (i, x) );	}
+	static int					Get_yTo					(int i, int y = 0)	{	return( CSG_Grid_System::Get_yTo  (i, y) );	}
+	static int					Get_xFrom				(int i, int x = 0)	{	return( CSG_Grid_System::Get_xFrom(i, x) );	}
+	static int					Get_yFrom				(int i, int y = 0)	{	return( CSG_Grid_System::Get_yFrom(i, y) );	}
 
 	//-----------------------------------------------------
 	void						Lock_Create				(void);
 	void						Lock_Destroy			(void);
 
 	bool						is_Locked				(int x, int y)	{	return( Lock_Get(x, y) != 0 );	}
-	char						Lock_Get				(int x, int y)	{	return( m_pLock && x >= 0 && x < Get_System()->Get_NX() && y >= 0 && y < Get_System()->Get_NY() ? m_pLock->asChar(x, y) : 0 );	}
+	char						Lock_Get				(int x, int y)	{	return( m_pLock && x >= 0 && x < Get_NX() && y >= 0 && y < Get_NY() ? m_pLock->asChar(x, y) : 0 );	}
 
 	void						Lock_Set				(int x, int y, char Value = 1)
 	{
-		if( m_pLock && x >= 0 && x < Get_System()->Get_NX() && y >= 0 && y < Get_System()->Get_NY() )
+		if( m_pLock && x >= 0 && x < Get_NX() && y >= 0 && y < Get_NY() )
 		{
 			m_pLock->Set_Value(x, y, Value);
 		}
@@ -536,11 +489,11 @@ public:
 	CSG_Tool_Interactive(void);
 	virtual ~CSG_Tool_Interactive(void);
 
-	virtual TSG_Tool_Type		Get_Type				(void)	{	return( TOOL_TYPE_Interactive );	}
+	virtual TSG_Tool_Type		Get_Type				(void)	const	{	return( TOOL_TYPE_Interactive );	}
 
-	virtual bool				needs_GUI				(void)	{	return( true );	}
+	virtual bool				needs_GUI				(void)	const	{	return( true );	}
 
-	virtual bool				is_Interactive			(void)	{	return( true );	}
+	virtual bool				is_Interactive			(void)	const	{	return( true );	}
 
 };
 
@@ -562,11 +515,11 @@ public:
 	CSG_Tool_Grid_Interactive(void);
 	virtual ~CSG_Tool_Grid_Interactive(void);
 
-	virtual TSG_Tool_Type		Get_Type				(void)	{	return( TOOL_TYPE_Grid_Interactive );	}
+	virtual TSG_Tool_Type		Get_Type				(void)	const	{	return( TOOL_TYPE_Grid_Interactive );	}
 
-	virtual bool				needs_GUI				(void)	{	return( true );	}
+	virtual bool				needs_GUI				(void)	const	{	return( true );	}
 
-	virtual bool				is_Interactive			(void)	{	return( true );	}
+	virtual bool				is_Interactive			(void)	const	{	return( true );	}
 
 
 protected:
