@@ -375,7 +375,7 @@ int CSG_Tool_Chain::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parame
 	{
 		const CSG_MetaData	&Conditions	= m_Conditions[iParameter];
 
-		if( pParameters->Get_Parameter(Conditions.Get_Name()) )
+		if( (*pParameters)(Conditions.Get_Name()) )
 		{
 			bool	bEnable	= true;
 
@@ -384,7 +384,7 @@ int CSG_Tool_Chain::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parame
 				bEnable	= Check_Condition(Conditions[iCondition], pParameters);
 			}
 
-			pParameters->Get_Parameter(Conditions.Get_Name())->Set_Enabled(bEnable);
+			(*pParameters)(Conditions.Get_Name())->Set_Enabled(bEnable);
 		}
 	}
 
@@ -667,6 +667,34 @@ bool CSG_Tool_Chain::Data_Finalize(void)
 }
 
 
+///////////////////////////////////////////////////////////
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+bool CSG_Tool_Chain::Parameter_isCompatible(TSG_Parameter_Type A, TSG_Parameter_Type B)
+{
+	if( A == B )
+	{
+		return( true );
+	}
+
+	switch( A )
+	{
+	default:
+		return( false );
+
+	case PARAMETER_TYPE_Table:
+		return( B == PARAMETER_TYPE_Shapes
+			||  B == PARAMETER_TYPE_PointCloud
+			||  B == PARAMETER_TYPE_TIN );
+
+	case PARAMETER_TYPE_Shapes:
+		return( B == PARAMETER_TYPE_PointCloud );
+	}
+}
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 ///////////////////////////////////////////////////////////
@@ -699,18 +727,18 @@ bool CSG_Tool_Chain::Check_Condition(const CSG_MetaData &Condition, CSG_Paramete
 	//-----------------------------------------------------
 	if( !Type.CmpNoCase("exists"    ) )	// data object exists
 	{
-		CSG_Parameter	*pParameter	= pData->Get_Parameter(Variable);
+		CSG_Parameter	*pParameter	= (*pData)(Variable);
 
 		return( pParameter && ((pParameter->is_DataObject() && pParameter->asDataObject()) || (pParameter->is_DataObject_List() && pParameter->asList()->Get_Data_Count())) );
 	}
 
 	if( !Type.CmpNoCase("not_exists") )	// data object does not exist
 	{
-		return( pData->Get_Parameter(Variable) == NULL || pData->Get_Parameter(Variable)->asDataObject() == NULL );
+		return( (*pData)(Variable) == NULL || (*pData)(Variable)->asDataObject() == NULL );
 	}
 
 	//-----------------------------------------------------
-	CSG_Parameter	*pOption	= pData->Get_Parameter(Variable);
+	CSG_Parameter	*pOption	= (*pData)(Variable);
 
 	if( pOption == NULL )
 	{
@@ -800,14 +828,6 @@ bool CSG_Tool_Chain::Check_Condition(const CSG_MetaData &Condition, CSG_Paramete
 //---------------------------------------------------------
 bool CSG_Tool_Chain::ForEach(const CSG_MetaData &Commands)
 {
-	CSG_String	ListVarName;
-	
-	if( !Commands.Get_Property("input", ListVarName) )
-	{
-		return( false );
-	}
-
-	//-----------------------------------------------------
 	for(int i=0; i<Commands.Get_Children_Count(); i++)	// add internal target lists, if any..
 	{
 		if( Commands[i].Cmp_Name("output") || Commands[i].Cmp_Name("datalist") )
@@ -817,69 +837,177 @@ bool CSG_Tool_Chain::ForEach(const CSG_MetaData &Commands)
 	}
 
 	//-----------------------------------------------------
-	return( ForEach_Object(Commands, ListVarName)
-		||  ForEach_File  (Commands, ListVarName) );
+	bool	bIgnoreErrors	= IS_TRUE_PROPERTY(Commands, "ignore_errors");
+
+	CSG_String	VarName;
+
+	if( Commands.Get_Property("varname", VarName) )
+	{
+		return( ForEach_Iterator(Commands, VarName, bIgnoreErrors) );
+	}
+
+	if( Commands.Get_Property("input", VarName) )
+	{
+		return( ForEach_Object  (Commands, VarName, bIgnoreErrors)
+			||  ForEach_File    (Commands, VarName, bIgnoreErrors) );
+	}
+
+	Error_Set("foreach statement misses iterator or input list definition");
+
+	return( false );
 }
 
 //---------------------------------------------------------
-bool CSG_Tool_Chain::ForEach_Object(const CSG_MetaData &Commands, const CSG_String &ListVarName)
+bool CSG_Tool_Chain::ForEach_Iterator(const CSG_MetaData &Commands, const CSG_String &VarName, bool bIgnoreErrors)
 {
-	bool	bResult	= false;
+	CSG_Parameter	*pIterator	= Parameters(VarName);
 
-	CSG_Parameter	*pList	= m_Data(ListVarName);
-
-	if( pList )
+	if( pIterator )
 	{
-		bResult	= true;
+		Error_Set("foreach statement iterator variable name is already in use");
 
-		//-------------------------------------------------
-		if( pList->is_DataObject_List() )
+		return( false );
+	}
+
+	//-----------------------------------------------------
+	CSG_String	s;
+
+	double	begin	= Commands.Get_Property("begin", s) ? (Parameters(s) ? Parameters[s].asDouble() : s.asDouble()) : 0.0;
+	double	end		= Commands.Get_Property("end"  , s) ? (Parameters(s) ? Parameters[s].asDouble() : s.asDouble()) : 0.0;
+
+	if( begin >= end )
+	{
+		Error_Set("foreach iterator statement with invalid range (define begin < end)");
+
+		return( false );
+	}
+
+	double	step	= 1.0;
+
+	if( Commands.Get_Property("steps", s) )
+	{
+		double	steps	= Parameters(s) ? Parameters[s].asDouble() : s.asDouble();
+
+		if( steps > 0 )
 		{
-			for(int iObject=0; bResult && iObject<pList->asList()->Get_Data_Count(); iObject++)
+			step	= (end - begin) / steps;
+		}
+	}
+	else if( Commands.Get_Property("step", s) )
+	{
+		 step	= Parameters(s) ? Parameters[s].asDouble() : s.asDouble();
+	}
+
+	if( step <= 0.0 )
+	{
+		Error_Set("foreach iterator statement with invalid step size (define step > 0 or steps > 0)");
+
+		return( false );
+	}
+
+	Message_Fmt("\nfor i = %f to %f step %f (%d steps)", begin, end, step, (int)((end - begin) / step));
+
+	//-----------------------------------------------------
+	bool	bResult	= true;
+
+	pIterator	= Parameters.Add_Double("", VarName, "Iterator", "");
+
+	for(double i=begin; bResult && i<=end; i+=step)
+	{
+		Message_Fmt("\nfor step: %f", i);
+
+		pIterator->Set_Value(i);
+
+		for(int iTool=0; bResult && iTool<Commands.Get_Children_Count(); iTool++)
+		{
+			const CSG_MetaData	&Tool	= Commands[iTool];
+
+			if( Tool.Cmp_Name("tool") )
 			{
-				for(int iTool=0; bResult && iTool<Commands.Get_Children_Count(); iTool++)
+				bResult	= Tool_Run(Tool, bIgnoreErrors);
+
+				if( !bResult && bIgnoreErrors )
 				{
-					const CSG_MetaData	&Tool	= Commands[iTool];
-
-					if( Tool.Cmp_Name("tool") )
-					{
-						for(int j=0; j<Tool.Get_Children_Count(); j++)
-						{
-							if( Tool[j].Cmp_Name("input") && Tool[j].Get_Content().Find(ListVarName) == 0 )
-							{
-								Tool(j)->Set_Content(ListVarName + CSG_String::Format("[%d]", iObject));
-							}
-						}
-
-						bResult	= Tool_Run(Tool);
-					}
+					bResult	= true;
 				}
 			}
 		}
+	}
 
-		//-------------------------------------------------
-		else if( pList->Get_Type() == PARAMETER_TYPE_Grids )
+	Parameters.Del_Parameter(VarName);
+
+	return( bResult );
+}
+
+//---------------------------------------------------------
+bool CSG_Tool_Chain::ForEach_Object(const CSG_MetaData &Commands, const CSG_String &ListVarName, bool bIgnoreErrors)
+{
+	CSG_Parameter	*pList	= m_Data(ListVarName);
+
+	if( !pList )
+	{
+		return( false );
+	}
+
+	//-----------------------------------------------------
+	bool	bResult	= true;
+
+	if( pList->is_DataObject_List() )
+	{
+		for(int iObject=0; bResult && iObject<pList->asList()->Get_Data_Count(); iObject++)
 		{
-			for(int iObject=0; bResult && iObject<pList->asGrids()->Get_Grid_Count(); iObject++)
+			for(int iTool=0; bResult && iTool<Commands.Get_Children_Count(); iTool++)
 			{
-				for(int iTool=0; bResult && iTool<Commands.Get_Children_Count(); iTool++)
+				const CSG_MetaData	&Tool	= Commands[iTool];
+
+				if( Tool.Cmp_Name("tool") )
 				{
-					const CSG_MetaData	&Tool	= Commands[iTool];
-
-					if( Tool.Cmp_Name("tool") )
+					for(int j=0; j<Tool.Get_Children_Count(); j++)
 					{
-						for(int j=0; j<Tool.Get_Children_Count(); j++)
+						if( Tool[j].Cmp_Name("input") && Tool[j].Get_Content().Find(ListVarName) == 0 )
 						{
-							if( Tool[j].Cmp_Name("input") && Tool[j].Get_Content().Find(ListVarName) == 0 )
-							{
-								Tool(j)->Set_Content(ListVarName + CSG_String::Format("[%d]", iObject));
-							}
+							Tool(j)->Set_Content(ListVarName + CSG_String::Format("[%d]", iObject));
 						}
-
-						bResult	= Tool_Run(Tool);
 					}
+
+					bResult	= Tool_Run(Tool, bIgnoreErrors);
 				}
 			}
+
+			if( !bResult && bIgnoreErrors )
+			{
+				bResult	= true;
+			}
+		}
+	}
+
+	//-----------------------------------------------------
+	else if( pList->Get_Type() == PARAMETER_TYPE_Grids )
+	{
+		for(int iObject=0; bResult && iObject<pList->asGrids()->Get_Grid_Count(); iObject++)
+		{
+			for(int iTool=0; bResult && iTool<Commands.Get_Children_Count(); iTool++)
+			{
+				const CSG_MetaData	&Tool	= Commands[iTool];
+
+				if( Tool.Cmp_Name("tool") )
+				{
+					for(int j=0; j<Tool.Get_Children_Count(); j++)
+					{
+						if( Tool[j].Cmp_Name("input") && Tool[j].Get_Content().Find(ListVarName) == 0 )
+						{
+							Tool(j)->Set_Content(ListVarName + CSG_String::Format("[%d]", iObject));
+						}
+					}
+
+					bResult	= Tool_Run(Tool, bIgnoreErrors);
+				}
+			}
+
+			if( !bResult && bIgnoreErrors )
+			{
+				bResult	= true;
+			}
 		}
 	}
 
@@ -887,7 +1015,7 @@ bool CSG_Tool_Chain::ForEach_Object(const CSG_MetaData &Commands, const CSG_Stri
 }
 
 //---------------------------------------------------------
-bool CSG_Tool_Chain::ForEach_File(const CSG_MetaData &Commands, const CSG_String &ListVarName)
+bool CSG_Tool_Chain::ForEach_File(const CSG_MetaData &Commands, const CSG_String &ListVarName, bool bIgnoreErrors)
 {
 	CSG_Parameter	*pList	= Parameters(ListVarName);
 
@@ -924,13 +1052,18 @@ bool CSG_Tool_Chain::ForEach_File(const CSG_MetaData &Commands, const CSG_String
 					}
 				}
 
-				bResult	= Tool_Run(Tool);
+				bResult	= Tool_Run(Tool, bIgnoreErrors);
 
 				for(size_t i=0; i<Input.Get_Size(); i++)
 				{
 					Tool(Input[i])->Set_Content(ListVarName);
 					Tool(Input[i])->Set_Property("varname", "true");
 				}
+
+				if( !bResult && bIgnoreErrors )
+				{
+					bResult	= true;
+				}
 			}
 		}
 	}
@@ -944,7 +1077,7 @@ bool CSG_Tool_Chain::ForEach_File(const CSG_MetaData &Commands, const CSG_String
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-bool CSG_Tool_Chain::Tool_Run(const CSG_MetaData &Tool)
+bool CSG_Tool_Chain::Tool_Run(const CSG_MetaData &Tool, bool bShowError)
 {
 	//-----------------------------------------------------
 	if( Tool.Cmp_Name("comment") )
@@ -985,7 +1118,7 @@ bool CSG_Tool_Chain::Tool_Run(const CSG_MetaData &Tool)
 	//-----------------------------------------------------
 	if( !Tool.Cmp_Name("tool") || !Tool.Get_Property("library") || !(Tool.Get_Property("tool") || Tool.Get_Property("module")) )
 	{
-		Error_Set(_TL("invalid tool definition"));
+		if( bShowError ) Error_Set(_TL("invalid tool definition"));
 
 		return( false );
 	}
@@ -995,16 +1128,17 @@ bool CSG_Tool_Chain::Tool_Run(const CSG_MetaData &Tool)
 
 	CSG_Tool	*pTool;
 
-	if(	!(pTool = SG_Get_Tool_Library_Manager().Get_Tool(Tool.Get_Property("library"), Name)) )
+	if(	!(pTool = SG_Get_Tool_Library_Manager().Get_Tool(Tool.Get_Property("library"), Name.c_str())) )
 	{
-		Error_Fmt("%s [%s].[%s]", _TL("could not find tool"), Tool.Get_Property("library"), Name.c_str());
+		if( bShowError ) Error_Fmt("%s [%s].[%s]", _TL("could not find tool"), Tool.Get_Property("library"), Name.c_str());
 
 		return( false );
 	}
 
 	//-----------------------------------------------------
 	Process_Set_Text(pTool->Get_Name());
-	Message_Add(CSG_String::Format("\n%s: %s", _TL("Run Tool"), pTool->Get_Name().c_str()), false);
+
+	Message_Fmt("\n%s: %s", _TL("Run Tool"), pTool->Get_Name().c_str());
 
 	pTool->Settings_Push(&m_Data_Manager);
 
@@ -1012,15 +1146,15 @@ bool CSG_Tool_Chain::Tool_Run(const CSG_MetaData &Tool)
 
 	if( !pTool->On_Before_Execution() )
 	{
-		Error_Fmt("%s [%s].[%s]", _TL("before tool execution check failed"), pTool->Get_Library().c_str(), pTool->Get_Name().c_str());
+		if( bShowError ) Error_Fmt("%s [%s].[%s]", _TL("before tool execution check failed"), pTool->Get_Library().c_str(), pTool->Get_Name().c_str());
 	}
 	else if( !Tool_Initialize(Tool, pTool) )
 	{
-		Error_Fmt("%s [%s].[%s]", _TL("tool initialization failed"        ), pTool->Get_Library().c_str(), pTool->Get_Name().c_str());
+		if( bShowError ) Error_Fmt("%s [%s].[%s]", _TL("tool initialization failed"        ), pTool->Get_Library().c_str(), pTool->Get_Name().c_str());
 	}
 	else if( !(bResult = pTool->Execute()) )
 	{
-		Error_Fmt("%s [%s].[%s]", _TL("tool execution failed"             ), pTool->Get_Library().c_str(), pTool->Get_Name().c_str());
+	//	if( bShowError ) Error_Fmt("%s [%s].[%s]", _TL("tool execution failed"             ), pTool->Get_Library().c_str(), pTool->Get_Name().c_str());
 	}
 
 	if( bResult )
@@ -1063,35 +1197,75 @@ bool CSG_Tool_Chain::Tool_Check_Condition(const CSG_MetaData &Tool)
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-bool CSG_Tool_Chain::Tool_Get_Parameter(const CSG_MetaData &Parameter, CSG_Tool *pTool, CSG_Parameter **ppParameter, CSG_Parameter **ppParameters)
+bool CSG_Tool_Chain::Tool_Get_Parameter(CSG_String ID, CSG_Parameters *pParameters, CSG_Parameter **ppParameter, CSG_Parameter **ppOwner)
 {
-	CSG_String	ID	= Parameter.Get_Property("id");
+	CSG_Parameter	*pParameter	= (*pParameters)(ID.BeforeFirst('.'));
 
-	*ppParameters	= NULL;
-
-	CSG_Parameter	*pParameters	= pTool->Get_Parameters()->Get_Parameter(Parameter.Get_Property("parms"));
-
-	if( pParameters && pParameters->Get_Type() == PARAMETER_TYPE_Parameters && pParameters->asParameters()->Get_Parameter(ID) )
+	if( pParameter )
 	{
-		*ppParameters	= pParameters;
-		*ppParameter	= pParameters->asParameters()->Get_Parameter(ID);
+		switch( pParameter->Get_Type() )
+		{
+		default:
+			*ppParameter	= pParameter;
+
+			return( true );
+
+		case PARAMETER_TYPE_Parameters:
+			*ppOwner	= pParameter;
+
+			return( Tool_Get_Parameter(ID.AfterFirst('.'), pParameter->asParameters(), ppParameter, ppOwner) );
+
+		case PARAMETER_TYPE_Range:
+			ID	= ID.AfterFirst('.');
+
+			if( ID.CmpNoCase("minimum") )
+			{
+				*ppParameter	= pParameter->asRange()->Get_Min_Parameter();
+			}
+			else if( ID.CmpNoCase("maximum") )
+			{
+				*ppParameter	= pParameter->asRange()->Get_Max_Parameter();
+			}
+
+			return( true );
+		}
 	}
-	else if( pTool->Get_Parameters(Parameter.Get_Property("parms")) )
+
+	return( false );
+}
+
+//---------------------------------------------------------
+bool CSG_Tool_Chain::Tool_Get_Parameter(const CSG_MetaData &Parameter, CSG_Tool *pTool, CSG_Parameter **ppParameter, CSG_Parameter **ppOwner)
+{
+	CSG_String	ID(Parameter.Get_Property("parms"));
+
+	if( !ID.is_Empty() )
 	{
-		*ppParameter	= pTool->Get_Parameters(Parameter.Get_Property("parms"))->Get_Parameter(ID);
+		ID	+= '.';
+	}
+
+	ID	+= Parameter.Get_Property("id");
+
+	//-----------------------------------------------------
+	CSG_Parameter	*pOwner; if( !ppOwner ) { ppOwner = &pOwner; } *ppOwner = NULL;
+
+	CSG_Parameters	*pParameters	= pTool->Get_Parameters(ID.BeforeFirst('.'));
+
+	if( pParameters )
+	{
+		ID	= ID.AfterFirst('.');
 	}
 	else
 	{
-		*ppParameter	= pTool->Get_Parameters()->Get_Parameter(ID);
+		pParameters	= pTool->Get_Parameters();
 	}
 
-	return( *ppParameter != NULL );
+	return( Tool_Get_Parameter(ID, pParameters, ppParameter, ppOwner) );
 }
 
 //---------------------------------------------------------
 bool CSG_Tool_Chain::Tool_Initialize(const CSG_MetaData &Tool, CSG_Tool *pTool)
 {
-	//-----------------------------------------------------
 	int		i;
 
 	//-----------------------------------------------------
@@ -1099,15 +1273,16 @@ bool CSG_Tool_Chain::Tool_Initialize(const CSG_MetaData &Tool, CSG_Tool *pTool)
 	{
 		const CSG_MetaData	&Parameter	= Tool[i];
 
-		CSG_Parameter	*pParameter, *pOwner;
-
 		if( Parameter.Cmp_Name("comment") )
 		{
 			continue;
 		}
-		else if( !Tool_Get_Parameter(Parameter, pTool, &pParameter, &pOwner) )
+
+		CSG_Parameter	*pParameter, *pOwner;
+
+		if( !Tool_Get_Parameter(Parameter, pTool, &pParameter, &pOwner) )
 		{
-			Error_Set(CSG_String::Format("%s: %s", _TL("parameter not found"), Parameter.Get_Property("id")));
+			Error_Fmt("%s: %s", _TL("parameter not found"), Parameter.Get_Property("id"));
 
 			return( false );
 		}
@@ -1150,6 +1325,10 @@ bool CSG_Tool_Chain::Tool_Initialize(const CSG_MetaData &Tool, CSG_Tool *pTool)
 				{
 					bResult	= pParameter->Assign(pData);
 				}
+				else if( Parameter_isCompatible(pParameter->Get_Type(), pData->Get_Type()) )
+				{
+					bResult = pParameter->Set_Value(pData->asDataObject());
+				}
 				else if( pParameter->is_DataObject_List() && pData->is_DataObject() )
 				{
 					bResult	= pParameter->asList()->Add_Item(pData->asDataObject());
@@ -1166,7 +1345,7 @@ bool CSG_Tool_Chain::Tool_Initialize(const CSG_MetaData &Tool, CSG_Tool *pTool)
 
 			if( !bResult )
 			{
-				Error_Set(CSG_String::Format("%s: %s", _TL("set input"), Parameter.Get_Property("id")));
+				Error_Fmt("%s: %s", _TL("set input"), Parameter.Get_Property("id"));
 
 				return( false );
 			}
@@ -1203,13 +1382,14 @@ bool CSG_Tool_Chain::Tool_Initialize(const CSG_MetaData &Tool, CSG_Tool *pTool)
 	{
 		const CSG_MetaData	&Parameter	= Tool[i];
 
-		CSG_Parameter	*pParameter, *pOwner;
-
 		if( Parameter.Cmp_Name("comment") )
 		{
 			continue;
 		}
-		else if( !Tool_Get_Parameter(Parameter, pTool, &pParameter, &pOwner) )
+
+		CSG_Parameter	*pParameter;
+
+		if( !Tool_Get_Parameter(Parameter, pTool, &pParameter) )
 		{
 			return( false );
 		}
@@ -1269,11 +1449,12 @@ bool CSG_Tool_Chain::Tool_Finalize(const CSG_MetaData &Tool, CSG_Tool *pTool)
 
 		if( Parameter.Cmp_Name("output") )
 		{
-			CSG_String	ID	= Parameter.Get_Property("id");
+			CSG_String	ID      (Parameter.Get_Property("id"   ));
+			CSG_String	ID_parms(Parameter.Get_Property("parms"));
 
-			CSG_Parameter	*pParameter	= pTool->Get_Parameters(Parameter.Get_Property("parms"))
-				? pTool->Get_Parameters(Parameter.Get_Property("parms"))->Get_Parameter(ID)
-				: pTool->Get_Parameters()->Get_Parameter(ID);
+			CSG_Parameter	*pParameter	= pTool->Get_Parameters(ID_parms)
+				? (*pTool->Get_Parameters(ID_parms))(ID)
+				: (*pTool->Get_Parameters(        ))(ID);
 
 			if( !pParameter || !Data_Add(Parameter.Get_Content(), pParameter) )
 			{
@@ -1289,7 +1470,7 @@ bool CSG_Tool_Chain::Tool_Finalize(const CSG_MetaData &Tool, CSG_Tool *pTool)
 
 		for(int j=0; j<pParameters->Get_Count(); j++)
 		{
-			CSG_Parameter	*pParameter	= pParameters->Get_Parameter(j);
+			CSG_Parameter	*pParameter	= (*pParameters)(j);
 
 			if( pParameter->is_Output() )
 			{
