@@ -94,7 +94,7 @@ public:
 								CSG_Tool_Chain			(const CSG_String &File);
 	bool						Create					(const CSG_String &File);
 
-	virtual TSG_Tool_Type		Get_Type				(void)			{	return( TOOL_TYPE_Chain );	}
+	virtual TSG_Tool_Type		Get_Type				(void)	const	{	return( TOOL_TYPE_Chain );	}
 
 	bool						is_Okay					(void)	const	{	return( m_Chain.Get_Children_Count() > 0 );	}
 
@@ -131,24 +131,28 @@ private:
 	bool						Data_Initialize			(void);
 	bool						Data_Finalize			(void);
 
+	bool						Parameter_isCompatible	(TSG_Parameter_Type A, TSG_Parameter_Type B);
+
 	bool						Check_Condition			(const CSG_MetaData &Condition, CSG_Parameters *pData);
 
 	bool						ForEach					(const CSG_MetaData &Commands);
-	bool						ForEach_Object			(const CSG_MetaData &Commands, const CSG_String &ListVarName);
-	bool						ForEach_File			(const CSG_MetaData &Commands, const CSG_String &ListVarName);
+	bool						ForEach_Iterator		(const CSG_MetaData &Commands, const CSG_String &    VarName, bool bIgnoreErrors);
+	bool						ForEach_Object			(const CSG_MetaData &Commands, const CSG_String &ListVarName, bool bIgnoreErrors);
+	bool						ForEach_File			(const CSG_MetaData &Commands, const CSG_String &ListVarName, bool bIgnoreErrors);
 
-	bool						Tool_Run				(const CSG_MetaData &Tool);
+	bool						Tool_Run				(const CSG_MetaData &Tool, bool bShowError = true);
 	bool						Tool_Check_Condition	(const CSG_MetaData &Tool);
-	bool						Tool_Get_Parameter		(const CSG_MetaData &Parameter, CSG_Tool *pTool, CSG_Parameter **ppParameter, CSG_Parameter **ppParameters);
+	bool						Tool_Get_Parameter		(const CSG_String ID, CSG_Parameters *pParameters, CSG_Parameter **ppParameter, CSG_Parameter **ppOwner = NULL);
+	bool						Tool_Get_Parameter		(const CSG_MetaData &Parameter, CSG_Tool *pTool  , CSG_Parameter **ppParameter, CSG_Parameter **ppOwner = NULL);
 	bool						Tool_Initialize			(const CSG_MetaData &Tool, CSG_Tool *pTool);
 	bool						Tool_Finalize			(const CSG_MetaData &Tool, CSG_Tool *pTool);
 
 
 //---------------------------------------------------------
-public: 	static bool			Save_History_to_Model		(const CSG_MetaData &History, const CSG_String &File);
+public: 	static bool			Save_History_to_Model	(const CSG_MetaData &History, const CSG_String &File);
 
-private:	static bool			_Save_History_Add_Tool		(const CSG_MetaData &History, CSG_MetaData &Parms, CSG_MetaData &Tools, bool bAddOutput = false);
-private:	static bool			_Save_History_Add_Input		(const CSG_MetaData &History, CSG_MetaData &Parms, CSG_MetaData &Tool);
+private:	static bool			_Save_History_Add_Tool	(const CSG_MetaData &History, CSG_MetaData &Parms, CSG_MetaData &Tools, bool bAddOutput = false);
+private:	static bool			_Save_History_Add_Input	(const CSG_MetaData &History, CSG_MetaData &Parms, CSG_MetaData &Tool);
 
 };
 
