@@ -67,8 +67,6 @@
 #include <wx/filename.h>
 #include <wx/utils.h>
 
-#include "saga_api.h"
-
 #include "tool_chain.h"
 
 
@@ -86,15 +84,15 @@ CSG_Tool_Library::CSG_Tool_Library(void)
 }
 
 //---------------------------------------------------------
-CSG_Tool_Library::CSG_Tool_Library(const CSG_String &FileName)
+CSG_Tool_Library::CSG_Tool_Library(const CSG_String &File)
 {
-	m_pLibrary	= new wxDynamicLibrary(SG_File_Get_Path_Absolute(FileName).c_str(), wxDL_DEFAULT|wxDL_QUIET);
+	m_pLibrary	= new wxDynamicLibrary(SG_File_Get_Path_Absolute(File).c_str(), wxDL_DEFAULT|wxDL_QUIET);
 
 	if(	m_pLibrary->IsLoaded()
 	&&	m_pLibrary->HasSymbol(SYMBOL_TLB_Get_Interface)
 	&&	m_pLibrary->HasSymbol(SYMBOL_TLB_Initialize)
 	&&	m_pLibrary->HasSymbol(SYMBOL_TLB_Finalize)
-	&&	((TSG_PFNC_TLB_Initialize)m_pLibrary->GetSymbol(SYMBOL_TLB_Initialize))(FileName) )
+	&&	((TSG_PFNC_TLB_Initialize)m_pLibrary->GetSymbol(SYMBOL_TLB_Initialize))(File) )
 	{
 		m_pInterface	= ((TSG_PFNC_TLB_Get_Interface)m_pLibrary->GetSymbol(SYMBOL_TLB_Get_Interface))();
 
@@ -154,137 +152,6 @@ CSG_String CSG_Tool_Library::Get_Info(int Type) const
 	return( "" );
 }
 
-//---------------------------------------------------------
-#define SUMMARY_ADD_STR(label, value)	CSG_String::Format("<tr><td valign=\"top\"><b>%s</b></td><td valign=\"top\">%s</td></tr>", label, value)
-#define SUMMARY_ADD_INT(label, value)	CSG_String::Format("<tr><td valign=\"top\"><b>%s</b></td><td valign=\"top\">%d</td></tr>", label, value)
-
-//---------------------------------------------------------
-CSG_String CSG_Tool_Library::Get_Summary(int Format, bool bWithGUINeeded) const
-{
-	bool	bToolChains	= Get_File_Name().is_Empty();
-
-	int			i;
-	CSG_String	s;
-
-	switch( Format )
-	{
-	//-----------------------------------------------------
-	case SG_SUMMARY_FMT_FLAT:
-
-		if( !bToolChains )
-		{
-			s	+= CSG_String::Format("\n%s:\t", _TL("Library" )) + Get_Info(TLB_INFO_Name    );
-			s	+= CSG_String::Format("\n%s:\t", _TL("Category")) + Get_Info(TLB_INFO_Category);
-			s	+= CSG_String::Format("\n%s:\t", _TL("File"    )) + Get_File_Name();
-		}
-		else
-		{
-			s	+= CSG_String::Format("\n%s:\t", _TL("Tool Chains")) + Get_Info(TLB_INFO_Name);
-		}
-
-		s	+= CSG_String::Format("\n%s:\n", _TL("Description")) + Get_Info(TLB_INFO_Description);
-
-		s	+= CSG_String::Format("\n\n%s:\n", _TL("Tools"));
-
-		for(i=0; i<Get_Count(); i++)
-		{
-			if( Get_Tool(i) && (bWithGUINeeded || !Get_Tool(i)->needs_GUI()) )
-			{
-				s	+= " [" + Get_Tool(i)->Get_ID() + "]\t" + Get_Tool(i)->Get_Name() + "\n";
-			}
-		}
-
-		break;
-
-	//-----------------------------------------------------
-	case SG_SUMMARY_FMT_HTML: default:
-
-		s	+= CSG_String::Format("<h4>%s</h4>", _TL("Tool Library"));
-
-		s	+= "<table border=\"0\">";
-
-		s	+= SUMMARY_ADD_STR(_TL("Name"   ), Get_Info(TLB_INFO_Name   ).c_str());
-		s	+= SUMMARY_ADD_STR(_TL("Author" ), Get_Info(TLB_INFO_Author ).c_str());
-		s	+= SUMMARY_ADD_STR(_TL("Version"), Get_Info(TLB_INFO_Version).c_str());
-		s	+= SUMMARY_ADD_STR(_TL("ID"     ), Get_Library_Name        ().c_str());
-		s	+= SUMMARY_ADD_STR(_TL("File"   ), Get_File_Name           ().c_str());
-
-		s	+= "</table>";
-
-		//-------------------------------------------------
-		s	+= CSG_String::Format("<hr><h4>%s</h4>", _TL("Description"));
-
-		s	+= Get_Info(TLB_INFO_Description);
-
-		//-------------------------------------------------
-		s	+= CSG_String::Format("<hr><h4>%s</h4>", _TL("Tools"));
-
-		s	+= "<table border=\"0\">";
-
-		s	+= CSG_String::Format("<tr align=\"left\"><th>%s</th><th>%s</th></tr>", _TL("ID"), _TL("Name"));
-
-		for(i=0; i<Get_Count(); i++)
-		{
-			if( Get_Tool(i) && (bWithGUINeeded || !Get_Tool(i)->needs_GUI()) )
-			{
-				s	+= SUMMARY_ADD_STR(Get_Tool(i)->Get_ID().c_str(), Get_Tool(i)->Get_Name().c_str());
-			}
-		}
-
-		s	+= "</table>";
-
-		s.Replace("\n", "<br>");
-
-		break;
-
-	//-----------------------------------------------------
-	case SG_SUMMARY_FMT_XML:
-
-		s	+= "<?xml version='1.0' encoding='UTF-8' standalone='yes' ?>\n";
-		s	+= CSG_String::Format("<%s>\n"         , SG_XML_LIBRARY);
-		s	+= CSG_String::Format("\t<%s>%s</%s>\n", SG_XML_LIBRARY_PATH, Get_File_Name().c_str(), SG_XML_LIBRARY_PATH);
-		s	+= CSG_String::Format("\t<%s>%s</%s>\n", SG_XML_LIBRARY_NAME, Get_Name     ().c_str(), SG_XML_LIBRARY_NAME);
-
-		for(i=0; i<Get_Count(); i++)
-		{
-			if( Get_Tool(i) && (bWithGUINeeded || !Get_Tool(i)->needs_GUI()) )
-			{
-				s	+= CSG_String::Format("\t<%s %s=\"%s\" %s=\"%s\">\n", SG_XML_TOOL,
-					SG_XML_TOOL_ATT_ID  , Get_Tool(i)->Get_ID  ().c_str(),
-					SG_XML_TOOL_ATT_NAME, Get_Tool(i)->Get_Name().c_str()
-				);
-			}
-		}
-
-		s	+= CSG_String::Format("</%s>\n", SG_XML_LIBRARY);
-
-		break;
-	}
-
-	return( s );
-}
-
-//---------------------------------------------------------
-bool CSG_Tool_Library::Get_Summary(const CSG_String &Path)	const
-{
-	CSG_File	f;
-
-	if( f.Open(SG_File_Make_Path(Path, Get_Library_Name(), SG_T("html")), SG_FILE_W) )
-	{
-		f.Write(Get_Summary());
-	}
-
-	for(int j=0; j<Get_Count(); j++)
-	{
-		if( Get_Tool(j) && f.Open(SG_File_Make_Path(Path, Get_Library_Name() + "_" + Get_Tool(j)->Get_ID(), SG_T("html")), SG_FILE_W) )
-		{
-			f.Write(Get_Tool(j)->Get_Summary());
-		}
-	}
-
-	return( true );
-}
-
 
 ///////////////////////////////////////////////////////////
 //														 //
@@ -314,26 +181,15 @@ CSG_Tool * CSG_Tool_Library::Get_Tool(const CSG_String &Tool, TSG_Tool_Type Type
 	return( NULL );
 }
 
-//---------------------------------------------------------
-CSG_Tool_Grid * CSG_Tool_Library::Get_Tool_Grid(int Index) const
-{	return( (CSG_Tool_Grid *)Get_Tool(Index , TOOL_TYPE_Grid) );	}
+CSG_Tool * CSG_Tool_Library::Get_Tool(const char       *Name, TSG_Tool_Type Type)	const
+{
+	return( Get_Tool(CSG_String(Name), Type) );
+}
 
-CSG_Tool_Grid * CSG_Tool_Library::Get_Tool_Grid(const CSG_String &Tool) const
-{	return( (CSG_Tool_Grid *)Get_Tool(Tool, TOOL_TYPE_Grid) );	}
-
-//---------------------------------------------------------
-CSG_Tool_Interactive * CSG_Tool_Library::Get_Tool_Interactive(int Index) const
-{	return( (CSG_Tool_Interactive *)Get_Tool(Index , TOOL_TYPE_Interactive) );	}
-
-CSG_Tool_Interactive * CSG_Tool_Library::Get_Tool_Interactive(const CSG_String &Tool) const
-{	return( (CSG_Tool_Interactive *)Get_Tool(Tool, TOOL_TYPE_Interactive) );	}
-
-//---------------------------------------------------------
-CSG_Tool_Grid_Interactive * CSG_Tool_Library::Get_Tool_Grid_Interactive(int Index) const
-{	return( (CSG_Tool_Grid_Interactive *)Get_Tool(Index , TOOL_TYPE_Grid_Interactive) );	}
-
-CSG_Tool_Grid_Interactive * CSG_Tool_Library::Get_Tool_Grid_Interactive(const CSG_String &Tool) const
-{	return( (CSG_Tool_Grid_Interactive *)Get_Tool(Tool, TOOL_TYPE_Grid_Interactive) );	}
+CSG_Tool * CSG_Tool_Library::Get_Tool(const wchar_t    *Name, TSG_Tool_Type Type)	const
+{
+	return( Get_Tool(CSG_String(Name), Type) );
+}
 
 
 ///////////////////////////////////////////////////////////
@@ -396,21 +252,21 @@ CSG_Tool_Library_Manager::~CSG_Tool_Library_Manager(void)
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-CSG_Tool_Library * CSG_Tool_Library_Manager::Add_Library(const SG_Char *FileName)
+CSG_Tool_Library * CSG_Tool_Library_Manager::Add_Library(const CSG_String &File)
 {
 	//-----------------------------------------------------
-	if( !SG_File_Cmp_Extension(FileName, SG_T("mlb"  ))
-	&&	!SG_File_Cmp_Extension(FileName, SG_T("dll"  ))
-	&&	!SG_File_Cmp_Extension(FileName, SG_T("so"   ))
-	&&	!SG_File_Cmp_Extension(FileName, SG_T("dylib")) )
+	if( !SG_File_Cmp_Extension(File, "mlb"  )
+	&&	!SG_File_Cmp_Extension(File, "dll"  )
+	&&	!SG_File_Cmp_Extension(File, "so"   )
+	&&	!SG_File_Cmp_Extension(File, "dylib") )
 	{
-		return( _Add_Tool_Chain(FileName) );
+		return( _Add_Tool_Chain(File) );
 	}
 
 	//-----------------------------------------------------
-	SG_UI_Msg_Add(CSG_String::Format("%s: %s...", _TL("Load library"), FileName), true);
+	SG_UI_Msg_Add(CSG_String::Format("%s: %s...", _TL("Load library"), File.c_str()), true);
 
-	wxFileName	fn(FileName);
+	wxFileName	fn(File.c_str());
 
 	for(int i=0; i<Get_Count(); i++)
 	{
@@ -423,7 +279,7 @@ CSG_Tool_Library * CSG_Tool_Library_Manager::Add_Library(const SG_Char *FileName
 	}
 
 	//-----------------------------------------------------
-	CSG_Tool_Library	*pLibrary	= new CSG_Tool_Library(FileName);
+	CSG_Tool_Library	*pLibrary	= new CSG_Tool_Library(File);
 
 	if( pLibrary->is_Valid() )
 	{
@@ -442,13 +298,23 @@ CSG_Tool_Library * CSG_Tool_Library_Manager::Add_Library(const SG_Char *FileName
 	return( NULL );
 }
 
+CSG_Tool_Library * CSG_Tool_Library_Manager::Add_Library(const char       *File)
+{
+	return( Add_Library(CSG_String(File)) );
+}
+
+CSG_Tool_Library * CSG_Tool_Library_Manager::Add_Library(const wchar_t    *File)
+{
+	return( Add_Library(CSG_String(File)) );
+}
+
 //---------------------------------------------------------
-int CSG_Tool_Library_Manager::Add_Directory(const SG_Char *Directory, bool bOnlySubDirectories)
+int CSG_Tool_Library_Manager::Add_Directory(const CSG_String &Directory, bool bOnlySubDirectories)
 {
 	int		nOpened	= 0;
 	wxDir	Dir;
 
-	if( Dir.Open(Directory) )
+	if( Dir.Open(Directory.c_str()) )
 	{
 		wxString	FileName, DirName(Dir.GetName());
 
@@ -480,16 +346,26 @@ int CSG_Tool_Library_Manager::Add_Directory(const SG_Char *Directory, bool bOnly
 	return( nOpened );
 }
 
+int CSG_Tool_Library_Manager::Add_Directory(const char       *Directory, bool bOnlySubDirectories)
+{
+	return( Add_Directory(CSG_String(Directory), bOnlySubDirectories) );
+}
+
+int CSG_Tool_Library_Manager::Add_Directory(const wchar_t    *Directory, bool bOnlySubDirectories)
+{
+	return( Add_Directory(CSG_String(Directory), bOnlySubDirectories) );
+}
+
 
 ///////////////////////////////////////////////////////////
 //														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-CSG_Tool_Library * CSG_Tool_Library_Manager::_Add_Tool_Chain(const SG_Char *FileName)
+CSG_Tool_Library * CSG_Tool_Library_Manager::_Add_Tool_Chain(const CSG_String &File)
 {
 	//-----------------------------------------------------
-	if( !SG_File_Cmp_Extension(FileName, SG_T("xml" )) )
+	if( !SG_File_Cmp_Extension(File, "xml") )
 	{
 		return( NULL );
 	}
@@ -500,7 +376,7 @@ CSG_Tool_Library * CSG_Tool_Library_Manager::_Add_Tool_Chain(const SG_Char *File
 
 	//-----------------------------------------------------
 	{	// is tool chain already loaded ?
-		wxFileName	fn(FileName);
+		wxFileName	fn(File.c_str());
 
 		for(int iLibrary=0; !pTool && iLibrary<Get_Count(); iLibrary++)
 		{
@@ -520,12 +396,12 @@ CSG_Tool_Library * CSG_Tool_Library_Manager::_Add_Tool_Chain(const SG_Char *File
 		if( pTool )	// ...then try to reload !
 		{
 			SG_UI_ProgressAndMsg_Lock(true);
-			CSG_Tool_Chain	Tool(FileName);	// don't reset loaded tool in case reloading fails!!!
+			CSG_Tool_Chain	Tool(File);	// don't reset loaded tool in case reloading fails!!!
 			SG_UI_ProgressAndMsg_Lock(false);
 
 			if( Tool.is_Okay() )
 			{
-				pTool->Create(FileName);
+				pTool->Create(File);
 			}
 
 			return( pLibrary );
@@ -533,7 +409,7 @@ CSG_Tool_Library * CSG_Tool_Library_Manager::_Add_Tool_Chain(const SG_Char *File
 	}
 
 	//-----------------------------------------------------
-	pTool	= new CSG_Tool_Chain(FileName);
+	pTool	= new CSG_Tool_Chain(File);
 
 	if( !pTool || !pTool->is_Okay() )
 	{
@@ -557,7 +433,7 @@ CSG_Tool_Library * CSG_Tool_Library_Manager::_Add_Tool_Chain(const SG_Char *File
 		}
 	}
 
-	if( !pLibrary && (pLibrary = new CSG_Tool_Chains(pTool->Get_Library(), SG_File_Get_Path(FileName))) != NULL )
+	if( !pLibrary && (pLibrary = new CSG_Tool_Chains(pTool->Get_Library(), SG_File_Get_Path(File))) != NULL )
 	{
 		m_pLibraries	= (CSG_Tool_Library **)SG_Realloc(m_pLibraries, (m_nLibraries + 1) * sizeof(CSG_Tool_Library *));
 		m_pLibraries[m_nLibraries++]	= pLibrary;
@@ -565,7 +441,7 @@ CSG_Tool_Library * CSG_Tool_Library_Manager::_Add_Tool_Chain(const SG_Char *File
 
 	if( !pLibrary )	// this should never happen, but who knows...
 	{
-		SG_UI_Msg_Add_Error(CSG_String::Format("%s %s: %s", _TL("ERROR"), _TL("tool chain library"), FileName));
+		SG_UI_Msg_Add_Error(CSG_String::Format("%s %s: %s", _TL("ERROR"), _TL("tool chain library"), File.c_str()));
 
 		delete(pTool);
 
@@ -654,13 +530,13 @@ bool CSG_Tool_Library_Manager::Del_Library(int i)
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-CSG_Tool_Library * CSG_Tool_Library_Manager::Get_Library(const SG_Char *Name, bool bLibrary) const
+CSG_Tool_Library * CSG_Tool_Library_Manager::Get_Library(const CSG_String &Name, bool bLibrary)	const
 {
 	for(int i=0; i<Get_Count(); i++)
 	{
 		CSG_Tool_Library	*pLibrary	= Get_Library(i);
 
-		if( !SG_STR_CMP(Name, bLibrary ? pLibrary->Get_Library_Name() : pLibrary->Get_Name()) )
+		if( !Name.Cmp(bLibrary ? pLibrary->Get_Library_Name() : pLibrary->Get_Name()) )
 		{
 			return( pLibrary );
 		}
@@ -669,6 +545,16 @@ CSG_Tool_Library * CSG_Tool_Library_Manager::Get_Library(const SG_Char *Name, bo
 	return( NULL );
 }
 
+CSG_Tool_Library * CSG_Tool_Library_Manager::Get_Library(const char *Name, bool bLibrary)	const
+{
+	return( Get_Library(CSG_String(Name), bLibrary) );
+}
+
+CSG_Tool_Library * CSG_Tool_Library_Manager::Get_Library(const wchar_t *Name, bool bLibrary)	const
+{
+	return( Get_Library(CSG_String(Name), bLibrary) );
+}
+
 //---------------------------------------------------------
 bool CSG_Tool_Library_Manager::is_Loaded(CSG_Tool_Library *pLibrary) const
 {
@@ -694,8 +580,18 @@ CSG_Tool * CSG_Tool_Library_Manager::Get_Tool(const CSG_String &Library, int ID)
 	return( Get_Tool(Library, CSG_String::Format("%d", ID)) );
 }
 
+CSG_Tool * CSG_Tool_Library_Manager::Get_Tool(const char       *Library, int ID)	const
+{
+	return( Get_Tool(CSG_String(Library), ID) );
+}
+
+CSG_Tool * CSG_Tool_Library_Manager::Get_Tool(const wchar_t    *Library, int ID)	const
+{
+	return( Get_Tool(CSG_String(Library), ID) );
+}
+
 //---------------------------------------------------------
-CSG_Tool * CSG_Tool_Library_Manager::Get_Tool(const CSG_String &Library, const CSG_String &Tool)	const
+CSG_Tool * CSG_Tool_Library_Manager::Get_Tool(const CSG_String &Library, const CSG_String &Name)	const
 {
 	for(int i=0; i<Get_Count(); i++)
 	{
@@ -703,7 +599,7 @@ CSG_Tool * CSG_Tool_Library_Manager::Get_Tool(const CSG_String &Library, const C
 
 		if( pLibrary->Get_Library_Name().Cmp(Library) == 0 )
 		{
-			CSG_Tool	*pTool	= pLibrary->Get_Tool(Tool);
+			CSG_Tool	*pTool	= pLibrary->Get_Tool(Name);
 
 			if( pTool )
 			{
@@ -715,137 +611,14 @@ CSG_Tool * CSG_Tool_Library_Manager::Get_Tool(const CSG_String &Library, const C
 	return( NULL );
 }
 
-
-///////////////////////////////////////////////////////////
-//														 //
-///////////////////////////////////////////////////////////
-
-//---------------------------------------------------------
-CSG_String CSG_Tool_Library_Manager::Get_Summary(int Format)	const
+CSG_Tool * CSG_Tool_Library_Manager::Get_Tool(const char       *Library, const char       *Name)	const
 {
-	//-----------------------------------------------------
-	int			i, nTools;
-
-	CSG_Table	Libraries;
-
-	Libraries.Add_Field("LIB"  , SG_DATATYPE_String);
-	Libraries.Add_Field("TOOLS", SG_DATATYPE_Int   );
-	Libraries.Add_Field("NAME" , SG_DATATYPE_String);
-	Libraries.Add_Field("PATH" , SG_DATATYPE_String);
-	Libraries.Add_Field("CHAIN", SG_DATATYPE_Int   );
-
-	for(i=0, nTools=0; i<Get_Count(); i++)
-	{
-		if( Get_Library(i)->Get_Count() > 0 )
-		{
-			nTools	+= Get_Library(i)->Get_Count();
-
-			Libraries.Add_Record();
-
-			Libraries[i].Set_Value(0, Get_Library(i)->Get_Library_Name());
-			Libraries[i].Set_Value(1, Get_Library(i)->Get_Count());
-			Libraries[i].Set_Value(2, Get_Library(i)->Get_Name());
-			Libraries[i].Set_Value(3, SG_File_Get_Path(Get_Library(i)->Get_File_Name()));
-			Libraries[i].Set_Value(4, Get_Library(i)->Get_File_Name().is_Empty() ? 1 : 0);
-		}
-	}
-
-	Libraries.Set_Index(4, TABLE_INDEX_Ascending, 0, TABLE_INDEX_Ascending);
-
-	//-----------------------------------------------------
-	CSG_String	s;
-
-	switch( Format )
-	{
-	//-----------------------------------------------------
-	case SG_SUMMARY_FMT_FLAT:
-
-		s	+= CSG_String::Format("\n%d %s (%d %s):\n", Libraries.Get_Count(), _TL("loaded tool libraries"), nTools, _TL("tools"));
-
-		for(i=0; i<Libraries.Get_Count(); i++)
-		{
-			if( Libraries[i].asInt(4) == 0 )
-				s	+= CSG_String::Format(" - %s\n"  , Libraries[i].asString(0));
-			else
-				s	+= CSG_String::Format(" - %s *\n", Libraries[i].asString(0));
-		}
-
-		s	+= CSG_String::Format("\n\n*) %s\n", _TL("tool chain libraries"));
-
-		break;
-
-	//-----------------------------------------------------
-	case SG_SUMMARY_FMT_HTML: default:
-
-		s	+= CSG_String::Format("<h4>%s</h4>", _TL("Tool Libraries"));
-
-		s	+= "<table border=\"0\">";
-
-		s	+= SUMMARY_ADD_INT(_TL("Libraries"), Libraries.Get_Count());
-		s	+= SUMMARY_ADD_INT(_TL("Tools"    ), nTools);
-
-		s	+= "</table>";
-
-		s	+= CSG_String::Format("<hr><h4>%s</h4><table border=\"1\">", _TL("Libraries"));
-
-		s	+= CSG_String::Format("<tr align=\"left\"><th>%s</th><th>%s</th><th>%s</th><th>%s</th></tr>",
-				_TL("Library" ),
-				_TL("Tools"   ),
-				_TL("Name"    ),
-				_TL("Location")
-			);
-
-		for(i=0; i<Libraries.Get_Count(); i++)
-		{
-			s	+= CSG_String::Format("<tr><td>%s</td><td>%d</td><td>%s</td><td>%s</td></tr>",
-					Libraries[i].asString(0),
-					Libraries[i].asInt   (1),
-					Libraries[i].asString(2),
-					Libraries[i].asString(3)
-				);
-		}
-
-		s	+= "</table>";
-
-		break;
-
-	//-----------------------------------------------------
-	case SG_SUMMARY_FMT_XML:
-
-		s	+= "<?xml version='1.0' encoding='UTF-8' standalone='yes' ?>\n";
-		s	+= CSG_String::Format("\n<%s>", SG_XML_SYSTEM);
-		s	+= CSG_String::Format("\n<%s>%s</%s>", SG_XML_SYSTEM_VER, SAGA_VERSION, SG_XML_SYSTEM_VER);
-
-		for(int i=0; i<Libraries.Get_Count(); i++)
-		{
-			s	+= CSG_String::Format("\n\t<%s %s=\"%s\"/>", SG_XML_LIBRARY, SG_XML_LIBRARY_NAME, Libraries[i].asString(0));
-		}
-
-		s	+= CSG_String::Format("\n</%s>", SG_XML_SYSTEM);
-
-		break;
-	}
-
-	//-----------------------------------------------------
-	return( s );
+	return( Get_Tool(CSG_String(Library), CSG_String(Name)) );
 }
 
-//---------------------------------------------------------
-bool CSG_Tool_Library_Manager::Get_Summary(const CSG_String &Path)	const
+CSG_Tool * CSG_Tool_Library_Manager::Get_Tool(const wchar_t    *Library, const wchar_t    *Name)	const
 {
-	for(int i=0; i<Get_Count(); i++)
-	{
-		CSG_Tool_Library	*pLibrary	= Get_Library(i);
-
-		CSG_String	Directory	= SG_File_Make_Path(Path, pLibrary->Get_Library_Name());
-
-		if( SG_Dir_Create(Directory) )
-		{
-			pLibrary->Get_Summary(Directory);
-		}
-	}
-
-	return( true );
+	return( Get_Tool(CSG_String(Library), CSG_String(Name)) );
 }
 
 
