@@ -274,10 +274,10 @@ bool CWKSP_Project::_Copy_To_File(CWKSP_Data_Item *pItem, const wxString &Direct
 	switch( pItem->Get_Type() )	// default extensions
 	{
 	case WKSP_ITEM_Table     : Path.SetExt("txt"     ); break;
-	case WKSP_ITEM_Shapes    : Path.SetExt("shp"     ); break;
-	case WKSP_ITEM_TIN       : Path.SetExt("shp"     ); break;
+	case WKSP_ITEM_Shapes    : Path.SetExt(SG_Shapes_Get_File_Extension_Default().c_str()); break;
+	case WKSP_ITEM_TIN       : Path.SetExt(SG_Shapes_Get_File_Extension_Default().c_str()); break;
 	case WKSP_ITEM_PointCloud: Path.SetExt("sg-pts-z"); break;
-	case WKSP_ITEM_Grid      : Path.SetExt("sgrd"    ); break;
+	case WKSP_ITEM_Grid      : Path.SetExt(SG_Grid_Get_File_Extension_Default().c_str()); break;
 	case WKSP_ITEM_Grids     : Path.SetExt("sg-gds-z"); break;
 	default:	return( false );
 	}
@@ -1015,8 +1015,8 @@ bool CWKSP_Project::_Compatibility_Data(TSG_Data_Type Type, CSG_Parameters *pPar
 			if( (pParameter = pParameters->Get_Parameter("COLORS_TYPE")) != NULL )
 			{
 				if( pParameter->asInt() == 3 )
-				{	// 0:Single >> 1:LUT >> 2:Discrete >> 3:Graduated >> 4:Shade >> 5:Overlay >> 6:RGB
-					pParameter->Set_Value(6);	// RGB moved to position 6
+				{	// 0:Single >> 1:LUT >> 2:Discrete >> 3:Graduated >> 4:RGB Overlay >> 5:RGB Composite >> 6:Shade
+					pParameter->Set_Value(5);	// RGB moved to position 5
 				}
 			}
 		}
