@@ -188,6 +188,8 @@ enum ID_COMMANDS
 	ID_CMD_DATA_DEL_FILES,
 	ID_CMD_DATA_PROJECTION,
 	ID_CMD_DATA_METADATA,
+	ID_CMD_DATA_FORCE_UPDATE,
+	ID_CMD_DATA_CLASSIFY_IMPORT,
 	ID_CMD_DATA_LAST,
 
 	ID_CMD_GRID_FIRST,
