@@ -24,7 +24,8 @@
 // Geoscientific Analyses'. SAGA is free software; you   //
 // can redistribute it and/or modify it under the terms  //
 // of the GNU General Public License as published by the //
-// Free Software Foundation; version 2 of the License.   //
+// Free Software Foundation, either version 2 of the     //
+// License, or (at your option) any later version.       //
 //                                                       //
 // SAGA is distributed in the hope that it will be       //
 // useful, but WITHOUT ANY WARRANTY; without even the    //
@@ -33,10 +34,8 @@
 // License for more details.                             //
 //                                                       //
 // You should have received a copy of the GNU General    //
-// Public License along with this program; if not,       //
-// write to the Free Software Foundation, Inc.,          //
-// 51 Franklin Street, 5th Floor, Boston, MA 02110-1301, //
-// USA.                                                  //
+// Public License along with this program; if not, see   //
+// <http://www.gnu.org/licenses/>.                       //
 //                                                       //
 //-------------------------------------------------------//
 //                                                       //
@@ -174,6 +173,7 @@ enum ID_IMAGES
 	ID_IMG_TB_MAP_ZOOM_LAST,
 	ID_IMG_TB_MAP_ZOOM_NEXT,
 	ID_IMG_TB_MAP_ZOOM_SELECTION,
+	ID_IMG_TB_MAP_CROSSHAIR,
 	ID_IMG_TB_OPEN,
 	ID_IMG_TB_OPEN_GRID,
 	ID_IMG_TB_OPEN_TOOL,
@@ -193,9 +193,10 @@ enum ID_IMAGES
 	ID_IMG_TB_WKSP,
 
 	ID_IMG_WKSP_DATA_MANAGER,
-	ID_IMG_WKSP_GRID,
 	ID_IMG_WKSP_GRID_MANAGER,
 	ID_IMG_WKSP_GRID_SYSTEM,
+	ID_IMG_WKSP_GRID,
+	ID_IMG_WKSP_GRIDS,
 	ID_IMG_WKSP_MAP,
 	ID_IMG_WKSP_MAP_MANAGER,
 	ID_IMG_WKSP_MAP_GRATICULE,
