@@ -24,7 +24,8 @@
 // Geoscientific Analyses'. SAGA is free software; you   //
 // can redistribute it and/or modify it under the terms  //
 // of the GNU General Public License as published by the //
-// Free Software Foundation; version 2 of the License.   //
+// Free Software Foundation, either version 2 of the     //
+// License, or (at your option) any later version.       //
 //                                                       //
 // SAGA is distributed in the hope that it will be       //
 // useful, but WITHOUT ANY WARRANTY; without even the    //
@@ -33,10 +34,8 @@
 // License for more details.                             //
 //                                                       //
 // You should have received a copy of the GNU General    //
-// Public License along with this program; if not,       //
-// write to the Free Software Foundation, Inc.,          //
-// 51 Franklin Street, 5th Floor, Boston, MA 02110-1301, //
-// USA.                                                  //
+// Public License along with this program; if not, see   //
+// <http://www.gnu.org/licenses/>.                       //
 //                                                       //
 //-------------------------------------------------------//
 //                                                       //
@@ -134,16 +133,16 @@ CSAGA::~CSAGA(void)
 bool CSAGA::OnInit(void)
 {
 	//-----------------------------------------------------
-	g_pSAGA				= this;
+	g_pSAGA	= this;
 
-	SetVendorName		("SAGA-GIS.org");
-	SetAppName			("SAGA");
+	SetVendorName("www.saga-gis.org");
+	SetAppName   ("saga_gui");
 
 	wxInitAllImageHandlers();
 
-	wxFileName			App_Path(argv[0]);	App_Path.MakeAbsolute();
+	wxFileName	App_Path(argv[0]);	App_Path.MakeAbsolute();
 
-	m_App_Path			= App_Path.GetPath();
+	m_App_Path	= App_Path.GetPath();
 
 #if !defined(_DEBUG)
 	wxSetAssertHandler(NULL);		// disable all wx asserts in SAGA release builds
@@ -158,7 +157,6 @@ bool CSAGA::OnInit(void)
 	//setlocale(LC_NUMERIC, "C");
 	m_wxLocale.Init(wxLANGUAGE_ENGLISH);
 
-
 	_Init_Config();
 
 	//-----------------------------------------------------
@@ -168,25 +166,13 @@ bool CSAGA::OnInit(void)
 	m_Process_Frequency	= CONFIG_Read("/TOOLS", "PROCESS_UPDATE", lValue) ? lValue : 0;
 
 	//-----------------------------------------------------
-	wxSplashScreen	*pLogo;
+	bool	bLogo	= argc <= 1 && CONFIG_Read("/TOOLS", "START_LOGO", bLogo) ? bLogo : true;
 
-	long	iLogo		= CONFIG_Read("/TOOLS", "START_LOGO"    , iLogo ) ? iLogo : 1;
-
-	switch( iLogo )
-	{
-	default:
-		pLogo	= NULL;
-		break;
-
-	case 1:
-	case 3:
-		pLogo	= new wxSplashScreen(IMG_Get_Bitmap(ID_IMG_SAGA_SPLASH), wxSPLASH_CENTRE_ON_SCREEN|wxSPLASH_NO_TIMEOUT, 0, NULL, -1);
-		break;
-
-	case 2:
-		pLogo	= new wxSplashScreen(IMG_Get_Bitmap(ID_IMG_SAGA_SPLASH), wxSPLASH_CENTRE_ON_SCREEN|wxSPLASH_TIMEOUT, 20000, NULL, -1);
-		break;
-	}
+	wxSplashScreen	*pLogo	= !bLogo ? NULL :
+		new wxSplashScreen(IMG_Get_Bitmap(ID_IMG_SAGA_SPLASH),
+			wxSPLASH_CENTRE_ON_SCREEN|wxSPLASH_NO_TIMEOUT, 0, NULL, -1,
+			wxDefaultPosition, wxDefaultSize, wxBORDER_SIMPLE
+		);
 
 	wxYield();
 
@@ -252,7 +238,7 @@ bool CSAGA::OnInit(void)
 	SetTopWindow(new CSAGA_Frame());
 
 	//-----------------------------------------------------
-	if( pLogo && (iLogo == 1 || argc > 1) )
+	if( pLogo )
 	{
 		pLogo->Destroy();
 
