@@ -109,14 +109,14 @@ int Scatter_Plot_On_Parameter_Changed(CSG_Parameter *pParameter, int Flags)
 
 	if( Flags & PARAMETER_CHECK_ENABLE )
 	{
-		if( !SG_STR_CMP(pParameter->Get_Identifier(), "CMP_WITH") )
+		if( pParameter->Cmp_Identifier("CMP_WITH") )
 		{
 			pParameters->Get_Parameter("GRID")->Get_Parent()->Set_Enabled(pParameter->asInt() == 0);
 			pParameters->Set_Enabled("GRID"  , pParameter->asInt() == 0);
 			pParameters->Set_Enabled("POINTS", pParameter->asInt() == 1);
 		}
 
-		if( !SG_STR_CMP(pParameter->Get_Identifier(), "REG_SHOW") )
+		if( pParameter->Cmp_Identifier("REG_SHOW") )
 		{
 			pParameters->Set_Enabled("REG_TYPE" , pParameter->asBool());
 			pParameters->Set_Enabled("REG_COLOR", pParameter->asBool());
@@ -124,7 +124,7 @@ int Scatter_Plot_On_Parameter_Changed(CSG_Parameter *pParameter, int Flags)
 			pParameters->Set_Enabled("REG_INFO" , pParameter->asBool());
 		}
 
-		if( !SG_STR_CMP(pParameter->Get_Identifier(), "DISPLAY") )
+		if( pParameter->Cmp_Identifier("DISPLAY") )
 		{
 			pParameters->Set_Enabled("DENSITY_RES", pParameter->asInt() == 1);
 			pParameters->Set_Enabled("DENSITY_PAL", pParameter->asInt() == 1);
@@ -134,7 +134,7 @@ int Scatter_Plot_On_Parameter_Changed(CSG_Parameter *pParameter, int Flags)
 
 	if( Flags & PARAMETER_CHECK_VALUES )
 	{
-		if( !SG_STR_CMP(pParameter->Get_Identifier(), "CMP_WITH") )
+		if( pParameter->Cmp_Identifier("CMP_WITH") )
 		{
 			pParameters->Get_Parameter("OPTIONS")->asParameters()->
 				Get_Parameter("DISPLAY")->Set_Value(pParameter->asInt() == 0 ? 1 : 0);
@@ -449,7 +449,7 @@ void CVIEW_ScatterPlot::On_AsTable(wxCommandEvent &event)
 	{
 		CSG_Table	*pTable	= new CSG_Table;
 
-		pTable->Set_Name(CSG_String::Format("%s: [%s]-[%s]", _TL("Scatterplot"), m_sX.c_str(), m_sY.c_str()));
+		pTable->Set_Name("%s: [%s]-[%s]", _TL("Scatterplot"), m_sX.c_str(), m_sY.c_str());
 
 		pTable->Add_Field("ID", SG_DATATYPE_Int   );
 		pTable->Add_Field(m_sX, SG_DATATYPE_Double);
