@@ -137,13 +137,19 @@ void Add_Metadata2Parameters(const CSG_MetaData &M, CSG_Parameters &P, CSG_Param
 
 		for(int j=0; j<M[i].Get_Property_Count(); j++)
 		{
-			Properties	+= "\n" + M[i].Get_Property_Name(j) + ": " + M[i].Get_Property(i);
+			if( j > 0 )	Properties	+= "\n";
+
+			Properties	+= M[i].Get_Property_Name(j) + ": " + M[i].Get_Property(j);
 		}
 
 		if( M[i].Get_Children_Count() > 0 )
 		{
 			Add_Metadata2Parameters(M[i], P, P.Add_Node(pParent, SG_Get_String(P.Get_Count()), M[i].Get_Name(), Properties));
 		}
+		else if( M[i].Get_Content().is_Empty() )
+		{
+			P.Add_Info_String(pParent, SG_Get_String(P.Get_Count()), M[i].Get_Name(), Properties, Properties);
+		}
 		else
 		{
 			P.Add_Info_String(pParent, SG_Get_String(P.Get_Count()), M[i].Get_Name(), Properties, M[i].Get_Content());
@@ -382,8 +388,8 @@ void CWKSP_Data_Item::On_Parameters_Changed(void)
 	m_pObject->Set_Name       (m_Parameters("OBJECT_NAME")->asString());
 	m_pObject->Set_Description(m_Parameters("OBJECT_DESC")->asString());
 	m_pObject->Set_NoData_Value_Range(
-		m_Parameters("OBJECT_NODATA")->asRange()->Get_LoVal(),
-		m_Parameters("OBJECT_NODATA")->asRange()->Get_HiVal()
+		m_Parameters("OBJECT_NODATA")->asRange()->Get_Min(),
+		m_Parameters("OBJECT_NODATA")->asRange()->Get_Max()
 	);
 }
 
