@@ -216,6 +216,7 @@ wxMenu * CWKSP_Grid::Get_Menu(void)
 	pMenu->AppendSeparator();
 	CMD_Menu_Add_Item(pMenu, true , ID_CMD_GRID_HISTOGRAM);
 	CMD_Menu_Add_Item(pMenu, false, ID_CMD_GRID_SCATTERPLOT);
+	CMD_Menu_Add_Item(pMenu, false, ID_CMD_DATA_FORCE_UPDATE);
 
 	pMenu->AppendSeparator();
 	CMD_Menu_Add_Item(pMenu, false, ID_CMD_GRID_SET_LUT);
@@ -358,56 +359,6 @@ void CWKSP_Grid::On_Create_Parameters(void)
 	//-----------------------------------------------------
 	// Classification...
 
-	((CSG_Parameter_Choice *)m_Parameters("COLORS_TYPE")->Get_Data())->Set_Items(
-		CSG_String::Format("%s|%s|%s|%s|%s|%s|%s|",
-			_TL("Single Symbol"   ),	// CLASSIFY_UNIQUE
-			_TL("Classified"      ),	// CLASSIFY_LUT
-			_TL("Discrete Colors" ),	// CLASSIFY_METRIC
-			_TL("Graduated Colors"),	// CLASSIFY_GRADUATED
-			_TL("Shade"           ),	// CLASSIFY_SHADE
-			_TL("RGB Composite"   ),	// CLASSIFY_OVERLAY
-			_TL("RGB Coded Values")		// CLASSIFY_RGB
-		)
-	);
-
-	m_Parameters("COLORS_TYPE")->Set_Value(CLASSIFY_GRADUATED);
-
-	//-----------------------------------------------------
-	m_Parameters.Add_Choice("NODE_COLORS",
-		"STRETCH_DEFAULT"	, _TL("Histogram Stretch"),
-		_TL("Histogram stretch used when fitting to zoomed extent in a map window."),
-		CSG_String::Format("%s|%s|%s|",
-			_TL("Linear"),
-			_TL("Standard Deviation"),
-			_TL("Percentile")
-		), g_pData->Get_Parameter("GRID_STRETCH_DEFAULT")->asInt()
-	);
-
-	m_Parameters.Add_Double("STRETCH_DEFAULT",
-		"STRETCH_LINEAR"	, _TL("Linear Percent Stretch"),
-		_TL("Linear percent stretch allows you to trim extreme values from both ends of the histogram using the percentage specified here."),
-		5.0, 0.0, true, 50.0, true
-	);
-
-	m_Parameters.Add_Double("STRETCH_DEFAULT",
-		"STRETCH_STDDEV"	, _TL("Standard Deviation"),
-		_TL(""),
-		2.0, 0.0, true
-	);
-
-	m_Parameters.Add_Bool("STRETCH_STDDEV",
-		"STRETCH_INRANGE"	, _TL("Keep in Range"),
-		_TL("Prevents that minimum or maximum stretch value fall outside the data value range."),
-		true
-	);
-
-	m_Parameters.Add_Double("STRETCH_DEFAULT",
-		"STRETCH_PCTL"		, _TL("Percentile"),
-		_TL(""),
-		2.0, 0.0, true, 50.0, true
-	);
-
-	//-----------------------------------------------------
 	m_Parameters.Add_Node("NODE_COLORS", "NODE_SHADE"	, _TL("Shade"),
 		_TL("")
 	);
@@ -596,35 +547,50 @@ bool CWKSP_Grid::Update(CWKSP_Layer *pChanged)
 int CWKSP_Grid::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *pParameter, int Flags)
 {
 	//-----------------------------------------------------
-	if( Flags & PARAMETER_CHECK_VALUES )
+	if( pParameters->Cmp_Identifier("CLASSIFY") )
 	{
-		if(	!SG_STR_CMP(pParameter->Get_Identifier(), "OBJECT_Z_FACTOR")
-		||	!SG_STR_CMP(pParameter->Get_Identifier(), "OBJECT_Z_OFFSET") )
+		if( Flags & PARAMETER_CHECK_ENABLE )
 		{
-			double	newFactor	= pParameters->Get("OBJECT_Z_FACTOR")->asDouble(), oldFactor	= m_Parameters("OBJECT_Z_FACTOR")->asDouble();
-			double	newOffset	= pParameters->Get("OBJECT_Z_OFFSET")->asDouble(), oldOffset	= m_Parameters("OBJECT_Z_OFFSET")->asDouble();
-
-			if( newFactor != 0.0 && oldFactor != 0.0 )
+			if( pParameter->Cmp_Identifier("METHOD") )
 			{
-				CSG_Parameter_Range	*newRange	= pParameters->Get("METRIC_ZRANGE")->asRange();
-				CSG_Parameter_Range	*oldRange	= m_Parameters.Get("METRIC_ZRANGE")->asRange();
-
-				newRange->Set_LoVal(((oldRange->Get_LoVal() - oldOffset) / oldFactor) * newFactor + newOffset);
-				newRange->Set_HiVal(((oldRange->Get_HiVal() - oldOffset) / oldFactor) * newFactor + newOffset);
+				pParameters->Set_Enabled("COUNT"   , pParameter->asInt() != 0);
+				pParameters->Set_Enabled("COUNTMAX", pParameter->asInt() == 0);
 			}
 		}
 
-		if( !SG_STR_CMP(pParameter->Get_Identifier(), "STRETCH_DEFAULT")
-		||  !SG_STR_CMP(pParameter->Get_Identifier(), "STRETCH_LINEAR" )
-		||  !SG_STR_CMP(pParameter->Get_Identifier(), "STRETCH_STDDEV" )
-		||  !SG_STR_CMP(pParameter->Get_Identifier(), "STRETCH_INRANGE")
-		||  !SG_STR_CMP(pParameter->Get_Identifier(), "STRETCH_PCTL"   ) )
+		return( CWKSP_Layer::On_Parameter_Changed(pParameters, pParameter, Flags) );
+	}
+
+	//-----------------------------------------------------
+	if( Flags & PARAMETER_CHECK_VALUES )
+	{
+		if(	pParameter->Cmp_Identifier("OBJECT_Z_FACTOR")
+		||	pParameter->Cmp_Identifier("OBJECT_Z_OFFSET") )
+		{
+			double	newFactor	= (*pParameters)("OBJECT_Z_FACTOR")->asDouble(), oldFactor	= m_Parameters("OBJECT_Z_FACTOR")->asDouble();
+			double	newOffset	= (*pParameters)("OBJECT_Z_OFFSET")->asDouble(), oldOffset	= m_Parameters("OBJECT_Z_OFFSET")->asDouble();
+
+			if( newFactor != 0.0 && oldFactor != 0.0 )
+			{
+				CSG_Parameter_Range	*newRange	= (*pParameters)("METRIC_ZRANGE")->asRange();
+				CSG_Parameter_Range	*oldRange	=  m_Parameters ("METRIC_ZRANGE")->asRange();
+
+				newRange->Set_Min(((oldRange->Get_Min() - oldOffset) / oldFactor) * newFactor + newOffset);
+				newRange->Set_Max(((oldRange->Get_Max() - oldOffset) / oldFactor) * newFactor + newOffset);
+			}
+		}
+
+		if( pParameter->Cmp_Identifier("STRETCH_DEFAULT")
+		||  pParameter->Cmp_Identifier("STRETCH_LINEAR" )
+		||  pParameter->Cmp_Identifier("STRETCH_STDDEV" )
+		||  pParameter->Cmp_Identifier("STRETCH_INRANGE")
+		||  pParameter->Cmp_Identifier("STRETCH_PCTL"   ) )
 		{
 			double	Minimum, Maximum;
 
 			if( _Fit_Colors(*pParameters, Minimum, Maximum) )
 			{
-				pParameters->Get("METRIC_ZRANGE")->asRange()->Set_Range(Minimum, Maximum);
+				(*pParameters)("METRIC_ZRANGE")->asRange()->Set_Range(Minimum, Maximum);
 			}
 		}
 	}
@@ -632,7 +598,7 @@ int CWKSP_Grid::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter
 	//-----------------------------------------------------
 	if( Flags & PARAMETER_CHECK_ENABLE )
 	{
-		if(	!SG_STR_CMP(pParameter->Get_Identifier(), "DISPLAY_SHADING") )
+		if(	pParameter->Cmp_Identifier("DISPLAY_SHADING") )
 		{
 			pParameters->Set_Enabled("SHADING_AZIMUTH", pParameter->asInt() != 0);
 			pParameters->Set_Enabled("SHADING_HEIGHT" , pParameter->asInt() != 0);
@@ -641,7 +607,7 @@ int CWKSP_Grid::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter
 			pParameters->Set_Enabled("SHADING_MAX"    , pParameter->asInt() != 0);
 		}
 
-		if(	!SG_STR_CMP(pParameter->Get_Identifier(), "COLORS_TYPE") )
+		if(	pParameter->Cmp_Identifier("COLORS_TYPE") )
 		{
 			int		Value	= pParameter->asInt();
 
@@ -655,14 +621,14 @@ int CWKSP_Grid::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter
 			pParameters->Set_Enabled("DISPLAY_SHADING"   , Value != CLASSIFY_SHADE);
 		}
 
-		if( !SG_STR_CMP(pParameter->Get_Identifier(), "OVERLAY_MODE") )
+		if( pParameter->Cmp_Identifier("OVERLAY_MODE") )
 		{
-			pParameters->Get("OVERLAY_R")->Get_Parent()->Set_Enabled(pParameter->asInt() != 0);
-			pParameters->Get("OVERLAY_G")->Get_Parent()->Set_Enabled(pParameter->asInt() != 1);
-			pParameters->Get("OVERLAY_B")->Get_Parent()->Set_Enabled(pParameter->asInt() != 2);
+			(*pParameters)("OVERLAY_R")->Get_Parent()->Set_Enabled(pParameter->asInt() != 0);
+			(*pParameters)("OVERLAY_G")->Get_Parent()->Set_Enabled(pParameter->asInt() != 1);
+			(*pParameters)("OVERLAY_B")->Get_Parent()->Set_Enabled(pParameter->asInt() != 2);
 		}
 
-		if(	!SG_STR_CMP(pParameter->Get_Identifier(), "VALUES_SHOW") )
+		if(	pParameter->Cmp_Identifier("VALUES_SHOW") )
 		{
 			pParameters->Set_Enabled("VALUES_FONT"    , pParameter->asBool());
 			pParameters->Set_Enabled("VALUES_SIZE"    , pParameter->asBool());
@@ -670,12 +636,12 @@ int CWKSP_Grid::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter
 			pParameters->Set_Enabled("VALUES_EFFECT"  , pParameter->asBool());
 		}
 
-		if(	!SG_STR_CMP(pParameter->Get_Identifier(), "VALUES_EFFECT") )
+		if(	pParameter->Cmp_Identifier("VALUES_EFFECT") )
 		{
 			pParameters->Set_Enabled("VALUES_EFFECT_COLOR", pParameter->asInt() > 0);
 		}
 
-		if(	!SG_STR_CMP(pParameter->Get_Identifier(), "STRETCH_DEFAULT") )
+		if(	pParameter->Cmp_Identifier("STRETCH_DEFAULT") )
 		{
 			pParameters->Set_Enabled("STRETCH_LINEAR", pParameter->asInt() == 0);
 			pParameters->Set_Enabled("STRETCH_STDDEV", pParameter->asInt() == 1);
@@ -695,14 +661,16 @@ int CWKSP_Grid::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter
 void CWKSP_Grid::_LUT_Create(void)
 {
 	//-----------------------------------------------------
-	static CSG_Parameters	Parameters;
+	static CSG_Parameters	PStatic;
 
-	if( Parameters.Get_Count() == 0 )
+	if( PStatic.Get_Count() == 0 )
 	{
-		Parameters.Create(NULL, _TL("Classify"), _TL(""));
-		Parameters.Add_Colors("", "COLOR" , _TL("Colors"        ), _TL(""))->asColors()->Set_Count(11);
-		Parameters.Add_Choice("", "METHOD", _TL("Classification"), _TL(""),
-			CSG_String::Format("%s|%s|%s|%s|",
+		PStatic.Create(NULL, _TL("Classify"), _TL(""));
+		PStatic.Add_Colors("", "COLORS"  , _TL("Colors"                   ), _TL(""))->asColors()->Set_Count(11);
+		PStatic.Add_Int   ("", "COUNT"   , _TL("Number of Classes"        ), _TL(""),   10, 1, true);
+		PStatic.Add_Int   ("", "COUNTMAX", _TL("Maximum Number of Classes"), _TL(""), 1000, 1, true);
+		PStatic.Add_Choice("", "METHOD"  , _TL("Classification"           ), _TL(""),
+			CSG_String::Format("%s|%s|%s|%s",
 				_TL("unique values"),
 				_TL("equal intervals"),
 				_TL("quantiles"),
@@ -711,13 +679,26 @@ void CWKSP_Grid::_LUT_Create(void)
 		);
 	}
 
+	CSG_Parameters	Parameters(this, _TL("Classify"), _TL(""), SG_T("CLASSIFY"));
+
+	Parameters.Assign_Parameters(&PStatic);
+
+	Parameters.Set_Callback_On_Parameter_Changed(&Parameter_Callback);
+
 	if( !DLG_Parameters(&Parameters) )
 	{
 		return;
 	}
 
+	PStatic.Assign_Values(&Parameters);
+
 	//-----------------------------------------------------
-	CSG_Colors	Colors(*Parameters("COLOR")->asColors());
+	CSG_Colors	Colors(*Parameters("COLORS")->asColors());
+
+	if( Parameters("METHOD")->asInt() != 0 )
+	{
+		Colors.Set_Count(Parameters("COUNT")->asInt());
+	}
 
 	CSG_Table	Classes(m_Parameters("LUT")->asTable());
 
@@ -728,9 +709,9 @@ void CWKSP_Grid::_LUT_Create(void)
 	{
 		CSG_Unique_Number_Statistics	s;
 
-		#define MAX_CLASSES	1024
+		int	maxClasses	= Parameters("COUNTMAX")->asInt();
 
-		for(sLong iCell = 0; iCell<Get_Grid()->Get_NCells() && s.Get_Count()<MAX_CLASSES && PROGRESSBAR_Set_Position(iCell, Get_Grid()->Get_NCells()); iCell++)
+		for(sLong iCell = 0; iCell<Get_Grid()->Get_NCells() && s.Get_Count()<maxClasses && PROGRESSBAR_Set_Position(iCell, Get_Grid()->Get_NCells()); iCell++)
 		{
 			if( !Get_Grid()->is_NoData(iCell) )
 			{
