@@ -111,8 +111,6 @@ CWKSP_Shapes::~CWKSP_Shapes(void)
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -157,7 +155,7 @@ wxString CWKSP_Shapes::Get_Description(void)
 	DESC_ADD_INT(_TL("Number of Shapes"), Get_Shapes()->Get_Count());
 	DESC_ADD_SIZET(_TL("Selected"      ), Get_Shapes()->Get_Selection_Count());
 
-	s	+= wxT("</table>");
+	s	+= "</table>";
 
 	s	+= Get_TableInfo_asHTML(Get_Shapes());
 
@@ -201,6 +199,7 @@ wxMenu * CWKSP_Shapes::Get_Menu(void)
 
 	pMenu->AppendSeparator();
 	CMD_Menu_Add_Item(pMenu, false, ID_CMD_SHAPES_SET_LUT);
+	CMD_Menu_Add_Item(pMenu, false, ID_CMD_DATA_CLASSIFY_IMPORT);
 	CMD_Menu_Add_Item(pMenu, false, ID_CMD_WKSP_ITEM_SETTINGS_COPY);
 
 	pMenu->AppendSeparator();
@@ -219,8 +218,6 @@ wxMenu * CWKSP_Shapes::Get_Menu(void)
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -233,6 +230,7 @@ bool CWKSP_Shapes::On_Command(int Cmd_ID)
 
 	//-----------------------------------------------------
 	case ID_CMD_SHAPES_SET_LUT       :	_LUT_Create     ();	break;
+	case ID_CMD_DATA_CLASSIFY_IMPORT :  _LUT_Import     ();	break;
 	case ID_CMD_SHAPES_HISTOGRAM     :	Histogram_Toggle();	break;
 
 	//-----------------------------------------------------
@@ -345,8 +343,6 @@ bool CWKSP_Shapes::On_Command_UI(wxUpdateUIEvent &event)
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -355,11 +351,14 @@ void CWKSP_Shapes::On_Create_Parameters(void)
 	CWKSP_Layer::On_Create_Parameters();
 
 	//-----------------------------------------------------
-	// Classification...
+	// Display...
 
-	AttributeList_Add("NODE_LUT"   , "LUT_ATTRIB"   , _TL("Attribute"), _TL(""));
-	AttributeList_Add("NODE_METRIC", "METRIC_ATTRIB", _TL("Attribute"), _TL(""));
-	AttributeList_Add("NODE_METRIC", "METRIC_NORMAL", _TL("Normalize"), _TL(""));
+	m_Parameters.Add_Parameters("NODE_DISPLAY",
+		"DISPLAY_CHART"	, _TL("Chart"), _TL("")
+	);
+
+	//-----------------------------------------------------
+	// Classification...
 
 	m_Parameters.Add_Bool("NODE_COLORS",
 		"NODATA_SHOW"	, _TL("Show No-Data"), _TL(""), true
@@ -369,23 +368,13 @@ void CWKSP_Shapes::On_Create_Parameters(void)
 		"NODATA_COLOR"	, _TL("Color"), _TL(""), SG_COLOR_GREY_LIGHT
 	);
 
-	//-----------------------------------------------------
-	// Display...
-
-	m_Parameters.Add_Parameters("NODE_DISPLAY",
-		"DISPLAY_CHART"	, _TL("Chart"), _TL("")
-	);
-
-	m_Parameters.Add_Node("", "NODE_TABLE", _TL("Attributes Table"), _TL(""));
-	m_Parameters.Add_Parameter(g_pData->Get_Parameter("TABLE_FLT_STYLE"   ));
-	m_Parameters.Add_Parameter(g_pData->Get_Parameter("TABLE_FLT_DECIMALS"));
-
 	//-----------------------------------------------------
 	// Label...
 
-	AttributeList_Add("NODE_LABEL",
+	m_Parameters.Add_Choice("NODE_LABEL",
 		"LABEL_ATTRIB"	, _TL("Attribute"),
-		_TL("")
+		_TL(""),
+		_TL("<default>")
 	);
 
 	m_Parameters.Add_Font("LABEL_ATTRIB",
@@ -396,7 +385,7 @@ void CWKSP_Shapes::On_Create_Parameters(void)
 	m_Parameters.Add_Choice("LABEL_ATTRIB",
 		"LABEL_ATTRIB_PREC"	, _TL("Numerical Precision"),
 		_TL(""),
-		CSG_String::Format("%s|%s|%s|",
+		CSG_String::Format("%s|%s|%s",
 			_TL("fit to value"),
 			_TL("standard"),
 			SG_T("0|0.1|0.12|0.123|0.1234|0.12345|0.1234567|0.12345678|0.123456789|0.1234567890|0.12345678901|0.123456789012|0.1234567890123|0.12345678901234|0.123456789012345|0.1234567890123456|0.12345678901234567|0.123456789012345678|0.1234567890123456789|0.12345678901234567890")
@@ -415,7 +404,7 @@ void CWKSP_Shapes::On_Create_Parameters(void)
 	m_Parameters.Add_Choice("LABEL_ATTRIB",
 		"LABEL_ATTRIB_EFFECT"	, _TL("Boundary Effect"),
 		_TL(""),
-		CSG_String::Format("%s|%s|%s|%s|%s|%s|%s|%s|%s|%s|",
+		CSG_String::Format("%s|%s|%s|%s|%s|%s|%s|%s|%s|%s",
 			_TL("none"),
 			_TL("full frame"),
 			_TL("top"),
@@ -441,9 +430,10 @@ void CWKSP_Shapes::On_Create_Parameters(void)
 		1, 1, true
 	);
 
-	AttributeList_Add("LABEL_ATTRIB",
+	m_Parameters.Add_Choice("LABEL_ATTRIB",
 		"LABEL_ATTRIB_SIZE_BY"		, _TL("Size by Attribute"),
-		_TL("")
+		_TL(""),
+		_TL("<default>")
 	);
 
 	m_Parameters.Add_Double("LABEL_ATTRIB_SIZE_BY",
@@ -489,8 +479,6 @@ void CWKSP_Shapes::On_Create_Parameters(void)
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -559,23 +547,29 @@ void CWKSP_Shapes::On_Parameters_Changed(void)
 		m_fLabel	= -1;
 	}
 
-	m_Label_Prec		= m_Parameters("LABEL_ATTRIB_PREC"        )->asInt  () - 2;
-
 	m_Label_Eff_Color	= m_Parameters("LABEL_ATTRIB_EFFECT_COLOR")->asColor();
 	m_Label_Eff_Size	= m_Parameters("LABEL_ATTRIB_EFFECT_SIZE" )->asInt  ();
+	m_Label_Prec		= m_Parameters("LABEL_ATTRIB_PREC"        )->asInt  ();
+
+	switch( m_Label_Prec )
+	{
+	case  0:	m_Label_Prec  = -m_Parameters("TABLE_FLT_DECIMALS")->asInt(); break;
+	case  1:	m_Label_Prec  = -99; break;
+	default:	m_Label_Prec -=   2; break;
+	}
 
 	switch( m_Parameters("LABEL_ATTRIB_EFFECT")->asInt() )
 	{
-	default:	m_Label_Eff	= TEXTEFFECT_NONE;			break;
-	case 1:		m_Label_Eff	= TEXTEFFECT_FRAME;			break;
-	case 2:		m_Label_Eff	= TEXTEFFECT_TOP;			break;
-	case 3:		m_Label_Eff	= TEXTEFFECT_TOPLEFT;		break;
-	case 4:		m_Label_Eff	= TEXTEFFECT_LEFT;			break;
-	case 5:		m_Label_Eff	= TEXTEFFECT_BOTTOMLEFT;	break;
-	case 6:		m_Label_Eff	= TEXTEFFECT_BOTTOM;		break;
-	case 7:		m_Label_Eff	= TEXTEFFECT_BOTTOMRIGHT;	break;
-	case 8:		m_Label_Eff	= TEXTEFFECT_RIGHT;			break;
-	case 9:		m_Label_Eff	= TEXTEFFECT_TOPRIGHT;		break;
+	default:	m_Label_Eff = TEXTEFFECT_NONE       ;	break;
+	case  1:	m_Label_Eff = TEXTEFFECT_FRAME      ;	break;
+	case  2:	m_Label_Eff = TEXTEFFECT_TOP        ;	break;
+	case  3:	m_Label_Eff = TEXTEFFECT_TOPLEFT    ;	break;
+	case  4:	m_Label_Eff = TEXTEFFECT_LEFT       ;	break;
+	case  5:	m_Label_Eff = TEXTEFFECT_BOTTOMLEFT ;	break;
+	case  6:	m_Label_Eff = TEXTEFFECT_BOTTOM     ;	break;
+	case  7:	m_Label_Eff = TEXTEFFECT_BOTTOMRIGHT;	break;
+	case  8:	m_Label_Eff = TEXTEFFECT_RIGHT      ;	break;
+	case  9:	m_Label_Eff = TEXTEFFECT_TOPRIGHT   ;	break;
 	}
 
 	//-----------------------------------------------------
@@ -585,8 +579,6 @@ void CWKSP_Shapes::On_Parameters_Changed(void)
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -623,18 +615,32 @@ bool CWKSP_Shapes::Set_Metrics(int zField, int nField)
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
+
 //---------------------------------------------------------
 int CWKSP_Shapes::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *pParameter, int Flags)
 {
+	//-----------------------------------------------------
+	if( pParameters->Cmp_Identifier("CLASSIFY") )
+	{
+		if( Flags & PARAMETER_CHECK_ENABLE )
+		{
+			if( pParameter->Cmp_Identifier("METHOD") )
+			{
+				pParameters->Set_Enabled("COUNT"   , pParameter->asInt() != 0);
+				pParameters->Set_Enabled("COUNTMAX", pParameter->asInt() == 0);
+			}
+		}
+
+		return( CWKSP_Layer::On_Parameter_Changed(pParameters, pParameter, Flags) );
+	}
+
 	//-----------------------------------------------------
 	if( Flags & PARAMETER_CHECK_VALUES )
 	{
-		if(	!SG_STR_CMP(pParameter->Get_Identifier(), "COLORS_TYPE"  )
-		||	!SG_STR_CMP(pParameter->Get_Identifier(), "METRIC_ATTRIB")
-		||	!SG_STR_CMP(pParameter->Get_Identifier(), "METRIC_NORMAL") )
+		if(	pParameter->Cmp_Identifier("COLORS_TYPE"  )
+		||	pParameter->Cmp_Identifier("METRIC_ATTRIB")
+		||	pParameter->Cmp_Identifier("METRIC_NORMAL") )
 		{
 			Set_Metrics(
 				pParameters->Get_Parameter("METRIC_ATTRIB")->asInt(),
@@ -647,7 +653,7 @@ int CWKSP_Shapes::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Paramete
 			);
 		}
 
-		if(	!SG_STR_CMP(pParameter->Get_Identifier(), "LUT_ATTRIB")
+		if(	pParameter->Cmp_Identifier("LUT_ATTRIB")
 		&&  pParameter->asInt() >= 0 && pParameter->asInt() < Get_Shapes()->Get_Field_Count() )
 		{
 			TSG_Data_Type	Type	= SG_Data_Type_is_Numeric(Get_Shapes()->Get_Field_Type(pParameter->asInt()))
@@ -661,28 +667,28 @@ int CWKSP_Shapes::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Paramete
 	//-----------------------------------------------------
 	if( Flags & PARAMETER_CHECK_ENABLE )
 	{
-		if(	!SG_STR_CMP(pParameter->Get_Identifier(), "COLORS_TYPE") )
+		if(	pParameter->Cmp_Identifier("COLORS_TYPE") )
 		{
 			pParameters->Set_Enabled("NODATA_SHOW"  , pParameter->asInt() > 0);	// not 'single symbol'
 		}
 
-		if(	!SG_STR_CMP(pParameter->Get_Identifier(), "NODATA_SHOW") )
+		if(	pParameter->Cmp_Identifier("NODATA_SHOW") )
 		{
 			pParameters->Set_Enabled("NODATA_COLOR" , pParameter->asBool());
 		}
 
-		if(	!SG_STR_CMP(pParameter->Get_Identifier(), "METRIC_ATTRIB") )
+		if(	pParameter->Cmp_Identifier("METRIC_ATTRIB") )
 		{
 			pParameters->Set_Enabled("METRIC_NORMAL", pParameter->asInt() >= 0);
 		}
 
-		if(	!SG_STR_CMP(pParameter->Get_Identifier(), "OUTLINE") )
+		if(	pParameter->Cmp_Identifier("OUTLINE") )
 		{
 			pParameters->Set_Enabled("OUTLINE_COLOR", pParameter->asBool());
 			pParameters->Set_Enabled("OUTLINE_SIZE" , pParameter->asBool());
 		}
 
-		if(	!SG_STR_CMP(pParameter->Get_Identifier(), "LABEL_ATTRIB") )
+		if(	pParameter->Cmp_Identifier("LABEL_ATTRIB") )
 		{
 			bool	Value	= pParameter->asInt() < Get_Shapes()->Get_Field_Count();
 
@@ -693,8 +699,8 @@ int CWKSP_Shapes::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Paramete
 			pParameters->Set_Enabled("LABEL_ATTRIB_EFFECT"   , Value);
 		}
 
-		if( !SG_STR_CMP(pParameter->Get_Identifier(), "LABEL_ATTRIB_SIZE_TYPE")
-		||  !SG_STR_CMP(pParameter->Get_Identifier(), "LABEL_ATTRIB_SIZE_BY"  ) )
+		if( pParameter->Cmp_Identifier("LABEL_ATTRIB_SIZE_TYPE")
+		||  pParameter->Cmp_Identifier("LABEL_ATTRIB_SIZE_BY"  ) )
 		{
 			bool	Value	= pParameters->Get_Parameter("LABEL_ATTRIB_SIZE_TYPE")->asInt() != 0
 						||    pParameters->Get_Parameter("LABEL_ATTRIB_SIZE_BY"  )->asInt() < Get_Shapes()->Get_Field_Count();
@@ -702,19 +708,19 @@ int CWKSP_Shapes::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Paramete
 			pParameters->Set_Enabled("LABEL_ATTRIB_SIZE", Value);
 		}
 
-		if(	!SG_STR_CMP(pParameter->Get_Identifier(), "LABEL_ATTRIB_EFFECT") )
+		if(	pParameter->Cmp_Identifier("LABEL_ATTRIB_EFFECT") )
 		{
 			bool	Value	= pParameter->asInt() > 0;
 
 			pParameters->Set_Enabled("LABEL_ATTRIB_EFFECT_COLOR", Value);
 		}
 
-		if(	!SG_STR_CMP(pParameter->Get_Identifier(), "EDIT_SNAP_LIST") )
+		if(	pParameter->Cmp_Identifier("EDIT_SNAP_LIST") )
 		{
 			pParameters->Set_Enabled("EDIT_SNAP_DIST", pParameter->asList()->Get_Item_Count() > 0);
 		}
 
-		if(	!SG_STR_CMP(pParameters->Get_Identifier(), "DISPLAY_CHART") )
+		if(	pParameters->Cmp_Identifier("DISPLAY_CHART") )
 		{
 			CSG_String	s(pParameter->Get_Identifier());
 
@@ -740,8 +746,6 @@ void CWKSP_Shapes::On_Update_Views(void)
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -756,15 +760,17 @@ void CWKSP_Shapes::_LUT_Create(void)
 	}
 
 	//-----------------------------------------------------
-	static CSG_Parameters	Parameters;
+	static CSG_Parameters	PStatic;
 
-	if( Parameters.Get_Count() == 0 )
+	if( PStatic.Get_Count() == 0 )
 	{
-		Parameters.Create(NULL, _TL("Classify"), _TL(""));
-		Parameters.Add_Choice("", "FIELD" , _TL("Attribute"     ), _TL(""), "");
-		Parameters.Add_Colors("", "COLORS", _TL("Colors"        ), _TL(""))->asColors()->Set_Count(11);
-		Parameters.Add_Choice("", "METHOD", _TL("Classification"), _TL(""),
-			CSG_String::Format("%s|%s|%s|%s|",
+		PStatic.Create(NULL, _TL("Classify"), _TL(""), SG_T("CLASSIFY"));
+		PStatic.Add_Choice("", "FIELD"   , _TL("Attribute"                ), _TL(""), "");
+		PStatic.Add_Colors("", "COLORS"  , _TL("Colors"                   ), _TL(""));
+		PStatic.Add_Int   ("", "COUNT"   , _TL("Number of Classes"        ), _TL(""),   10, 1, true);
+		PStatic.Add_Int   ("", "COUNTMAX", _TL("Maximum Number of Classes"), _TL(""), 1000, 1, true);
+		PStatic.Add_Choice("", "METHOD"  , _TL("Classification"           ), _TL(""),
+			CSG_String::Format("%s|%s|%s|%s",
 				_TL("unique values"),
 				_TL("equal intervals"),
 				_TL("quantiles"),
@@ -773,38 +779,53 @@ void CWKSP_Shapes::_LUT_Create(void)
 		);
 	}
 
-	AttributeList_Set(Parameters("FIELD"), false);
+	AttributeList_Set(PStatic("FIELD"), false);
+
+	CSG_Parameters	Parameters(this, _TL("Classify"), _TL(""), SG_T("CLASSIFY"));
+
+	Parameters.Assign_Parameters(&PStatic);
+
+	Parameters.Set_Callback_On_Parameter_Changed(&Parameter_Callback);
 
 	if( !DLG_Parameters(&Parameters) )
 	{
 		return;
 	}
 
+	PStatic.Assign_Values(&Parameters);
+
 	//-----------------------------------------------------
 	DataObject_Changed();
 
 	int	Field	= Parameters("FIELD")->asInt();
 
+	int	Method	= SG_Data_Type_is_Numeric(Get_Shapes()->Get_Field_Type(Field)) ? Parameters("METHOD")->asInt() : 0;
+
 	CSG_Colors	Colors(*Parameters("COLORS")->asColors());
 
+	if( Method != 0 )
+	{
+		Colors.Set_Count(Parameters("COUNT")->asInt());
+	}
+
 	CSG_Table	Classes(m_Parameters("LUT")->asTable());
 
-	switch( SG_Data_Type_is_Numeric(Get_Shapes()->Get_Field_Type(Field)) ? Parameters("METHOD")->asInt() : 0 )
+	switch( Method )
 	{
 	//-----------------------------------------------------
 	case 0:	// unique values
 		{
 			TSG_Data_Type	Type	= SG_Data_Type_is_Numeric(Get_Shapes()->Get_Field_Type(Field))
-									? SG_DATATYPE_Double : SG_DATATYPE_String;
+				? SG_DATATYPE_Double : SG_DATATYPE_String;
 
 			Classes.Set_Field_Type(LUT_MIN, Type);
 			Classes.Set_Field_Type(LUT_MAX, Type);
 
 			CSG_Unique_String_Statistics	s;
 
-			#define MAX_CLASSES	1024
+			int	maxClasses	= Parameters("COUNTMAX")->asInt();
 
-			for(int iShape=0; iShape<Get_Shapes()->Get_Count() && s.Get_Count()<MAX_CLASSES; iShape++)
+			for(int iShape=0; iShape<Get_Shapes()->Get_Count() && s.Get_Count()<maxClasses; iShape++)
 			{
 				s	+= Get_Shapes()->Get_Shape(iShape)->asString(Field);
 			}
@@ -939,11 +960,34 @@ void CWKSP_Shapes::_LUT_Create(void)
 	}
 }
 
+//---------------------------------------------------------
+void CWKSP_Shapes::_LUT_Import(void)
+{
+	wxString	File, Filter;
+
+	Filter.Printf("%s (*.qml)|*.qml|%s|*.*", _TL("QGIS Layer Style File"), _TL("All Files"));
+
+	if( DLG_Open(File, _TL("Import Classification"), SG_T("QGIS Layer Style File (*.qml)|*.qml|All Files|*.*|")) )
+	{
+		CSG_Table	Classes;
+		CSG_String	Attribute;
+
+		if( QGIS_Styles_Import(&File, Classes, Attribute) )
+		{
+			m_Parameters.Set_Parameter("LUT_ATTRIB", Attribute);
+
+			m_Parameters("LUT")->asTable()->Assign(&Classes);
+
+			m_Parameters("COLORS_TYPE")->Set_Value(CLASSIFY_LUT);	// Lookup Table
+
+			Parameters_Changed();
+		}
+	}
+}
+
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -997,8 +1041,6 @@ double CWKSP_Shapes::Get_Value_StdDev (void)	{	return( m_Metrics.Get_StdDev () )
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1024,150 +1066,158 @@ wxString CWKSP_Shapes::Get_Name_Attribute(void)
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 void CWKSP_Shapes::On_Draw(CWKSP_Map_DC &dc_Map, int Flags)
 {
+	int		iShape;
+
 	//-----------------------------------------------------
-	if( Get_Extent().Intersects(dc_Map.m_rWorld) != INTERSECTION_None )
+	if( Get_Extent().Intersects(dc_Map.m_rWorld) == INTERSECTION_None )
 	{
-		int		iShape;
-
-		double	Transparency	= m_Parameters("DISPLAY_TRANSPARENCY")->asDouble() / 100.0;
-
-		CWKSP_Map_DC	*pDC	= Transparency > 0.0 ? new CWKSP_Map_DC(dc_Map.m_rWorld, dc_Map.m_rDC, dc_Map.m_Scale, SG_GET_RGB(254, 255, 255)) : NULL;
-		CWKSP_Map_DC	&dc		= pDC ? *pDC : dc_Map;
-
-		m_Sel_Color		= Get_Color_asWX(m_Parameters("SEL_COLOR" )->asInt());
-		m_Edit_Color	= Get_Color_asWX(m_Parameters("EDIT_COLOR")->asInt());
-
-		Draw_Initialize(dc);
-
-		//-------------------------------------------------
-		if( (Flags & LAYER_DRAW_FLAG_NOEDITS) == 0 && (m_Edit_pShape || Get_Shapes()->Get_Selection_Count() > 0) )
+		if( m_Edit_pShape )
 		{
-			for(iShape=0; iShape<Get_Shapes()->Get_Count(); iShape++)
-			{
-				if( !Get_Shapes()->Get_Shape(iShape)->is_Selected() )
-				{
-					_Draw_Shape(dc, Get_Shapes()->Get_Shape(iShape));
-				}
-			}
-
-			for(iShape=0; iShape<Get_Shapes()->Get_Selection_Count(); iShape++)
-			{
-				if( iShape != m_Edit_Index )
-				{
-					_Draw_Shape(dc, Get_Shapes()->Get_Selection(iShape), 2);
-				}
-			}
-
-			if( !m_Edit_pShape )
-			{
-				_Draw_Shape(dc, Get_Shapes()->Get_Selection(m_Edit_Index), 1);
-			}
-			else
-			{
-				Edit_Shape_Draw(dc);
-			}
-
-			if( m_Edit_Mode == EDIT_SHAPE_MODE_Split )
-			{
-				CSG_Shape	*pSplit	= m_Edit_Shapes.Get_Shape(1);
-
-				if( pSplit && pSplit->Get_Point_Count() > 1 )
-				{
-					for(int i=0; i<=1; i++)
-					{
-						dc_Map.dc.SetPen(wxPen(i == 0 ? *wxWHITE : *wxBLACK, i == 0 ? 3 : 1));
-
-						TSG_Point_Int	B, A	= dc_Map.World2DC(pSplit->Get_Point(0));
-
-						for(int iPoint=1; iPoint<pSplit->Get_Point_Count(); iPoint++)
-						{
-							B	= A;	A	= dc_Map.World2DC(pSplit->Get_Point(iPoint));
-
-							dc_Map.dc.DrawLine(A.x, A.y, B.x, B.y);
-						}
-					}
-				}
-			}
+			Edit_Shape_Draw(dc_Map);
 		}
 
-		//-------------------------------------------------
-		else
+		return;
+	}
+
+	//-----------------------------------------------------
+	if( (Flags & LAYER_DRAW_FLAG_THUMBNAIL) != 0 )
+	{
+		Draw_Initialize(dc_Map, Flags);
+
+		for(int iShape=0; iShape<Get_Shapes()->Get_Count(); iShape++)
+		{
+			_Draw_Shape(dc_Map, Get_Shapes()->Get_Shape(iShape));
+		}
+
+		return;
+	}
+
+	//-----------------------------------------------------
+	double	Transparency	= m_Parameters("DISPLAY_TRANSPARENCY")->asDouble() / 100.0;
+
+	CWKSP_Map_DC	*pDC	= Transparency > 0.0 ? new CWKSP_Map_DC(dc_Map.m_rWorld, dc_Map.m_rDC, dc_Map.m_Scale, SG_GET_RGB(254, 255, 255)) : NULL;
+	CWKSP_Map_DC	&dc		= pDC ? *pDC : dc_Map;
+
+	m_Sel_Color		= Get_Color_asWX(m_Parameters("SEL_COLOR" )->asInt());
+	m_Edit_Color	= Get_Color_asWX(m_Parameters("EDIT_COLOR")->asInt());
+
+	Draw_Initialize(dc, Flags);
+
+	//-----------------------------------------------------
+	if( (Flags & LAYER_DRAW_FLAG_NOEDITS) != 0 || !(m_Edit_pShape || Get_Shapes()->Get_Selection_Count()) )
+	{
+		for(iShape=0; iShape<Get_Shapes()->Get_Count(); iShape++)
+		{
+			_Draw_Shape(dc, Get_Shapes()->Get_Shape(iShape));
+		}
+
+		if( _Chart_is_Valid() )
 		{
 			for(iShape=0; iShape<Get_Shapes()->Get_Count(); iShape++)
+			{
+				_Draw_Chart(dc, Get_Shapes()->Get_Shape(iShape));
+			}
+		}
+	}
+	else	// selection and/or editing
+	{
+		for(iShape=0; iShape<Get_Shapes()->Get_Count(); iShape++)
+		{
+			if( !Get_Shapes()->Get_Shape(iShape)->is_Selected() )
 			{
 				_Draw_Shape(dc, Get_Shapes()->Get_Shape(iShape));
 			}
+		}
 
-			if( _Chart_is_Valid() )
+		for(iShape=0; iShape<Get_Shapes()->Get_Selection_Count(); iShape++)
+		{
+			if( iShape != m_Edit_Index )
 			{
-				for(iShape=0; iShape<Get_Shapes()->Get_Count(); iShape++)
-				{
-					_Draw_Chart(dc, Get_Shapes()->Get_Shape(iShape));
-				}
+				_Draw_Shape(dc, Get_Shapes()->Get_Selection(iShape), 2);
 			}
 		}
 
 		//-------------------------------------------------
-		if( (Flags & LAYER_DRAW_FLAG_NOLABELS) == 0 && m_fLabel >= 0 )
+		if( !m_Edit_pShape )
 		{
-			int		iSize	= m_Parameters("LABEL_ATTRIB_SIZE_BY"  )->asInt();
-			double	dSize	= m_Parameters("LABEL_ATTRIB_SIZE_TYPE")->asInt() == 1 ?
-				dc.m_World2DC * m_Parameters("LABEL_ATTRIB_SIZE")->asDouble() : 1.0;
+			_Draw_Shape(dc, Get_Shapes()->Get_Selection(m_Edit_Index), 1);
+		}
+		else
+		{
+			Edit_Shape_Draw(dc);
+		}
 
-			dc.dc.SetFont(Get_Font (m_Parameters("LABEL_ATTRIB_FONT")));
-			dc.dc.SetTextForeground(m_Parameters("LABEL_ATTRIB_FONT")->asColor());
+		if( m_Edit_Mode == EDIT_SHAPE_MODE_Split )
+		{
+			CSG_Shape	*pSplit	= m_Edit_Shapes.Get_Shape(1);
 
-			if( iSize < 0 || iSize >= Get_Shapes()->Get_Field_Count() )
+			if( pSplit && pSplit->Get_Point_Count() > 1 )
 			{
-				int	Size	= m_Parameters("LABEL_ATTRIB_SIZE_TYPE")->asInt() == 1 ? (int)(0.5 + dSize) : dc.dc.GetFont().GetPointSize();
+				for(int i=0; i<=1; i++)
+				{
+					dc_Map.dc.SetPen(wxPen(i == 0 ? *wxWHITE : *wxBLACK, i == 0 ? 3 : 1));
+
+					TSG_Point_Int	B, A	= dc_Map.World2DC(pSplit->Get_Point(0));
+
+					for(int iPoint=1; iPoint<pSplit->Get_Point_Count(); iPoint++)
+					{
+						B	= A;	A	= dc_Map.World2DC(pSplit->Get_Point(iPoint));
+
+						dc_Map.dc.DrawLine(A.x, A.y, B.x, B.y);
+					}
+				}
+			}
+		}
+	}
+
+	//-----------------------------------------------------
+	if( (Flags & LAYER_DRAW_FLAG_NOLABELS) == 0 && m_fLabel >= 0 )	// Labels
+	{
+		int		iSize	= m_Parameters("LABEL_ATTRIB_SIZE_BY"  )->asInt();
+		double	dSize	= m_Parameters("LABEL_ATTRIB_SIZE_TYPE")->asInt() == 1 ?
+			dc.m_World2DC * m_Parameters("LABEL_ATTRIB_SIZE")->asDouble() : 1.0;
+
+		dc.dc.SetFont(Get_Font (m_Parameters("LABEL_ATTRIB_FONT")));
+		dc.dc.SetTextForeground(m_Parameters("LABEL_ATTRIB_FONT")->asColor());
+
+		if( iSize >= 0 && iSize < Get_Shapes()->Get_Field_Count() )	// size by attribute
+		{
+			for(iShape=0; iShape<Get_Shapes()->Get_Count(); iShape++)
+			{
+				int	Size	= (int)(0.5 + dSize * Get_Shapes()->Get_Shape(iShape)->asDouble(iSize));
 
 				if( Size > 0 )
 				{
-					for(iShape=0; iShape<Get_Shapes()->Get_Count(); iShape++)
-					{
-						_Draw_Label(dc, Get_Shapes()->Get_Shape(iShape), Size);
-					}
+					_Draw_Label(dc, Get_Shapes()->Get_Shape(iShape), Size);
 				}
 			}
-			else if( iSize >= 0 )
+		}
+		else	// one size fits all
+		{
+			int	Size	= m_Parameters("LABEL_ATTRIB_SIZE_TYPE")->asInt() == 1 ? (int)(0.5 + dSize) : dc.dc.GetFont().GetPointSize();
+
+			if( Size > 0 )
 			{
 				for(iShape=0; iShape<Get_Shapes()->Get_Count(); iShape++)
 				{
-					int	Size	= (int)(0.5 + dSize * Get_Shapes()->Get_Shape(iShape)->asDouble(iSize));
-
-					if( Size > 0 )
-					{
-						_Draw_Label(dc, Get_Shapes()->Get_Shape(iShape), Size);
-					}
+					_Draw_Label(dc, Get_Shapes()->Get_Shape(iShape), Size);
 				}
 			}
 		}
-
-		//-------------------------------------------------
-		if( pDC )
-		{
-			dc_Map.Draw_DC(dc, Transparency);
-
-			delete(pDC);
-		}
 	}
 
 	//-----------------------------------------------------
-	else if( m_Edit_pShape )
+	if( pDC )	// Transparency ?
 	{
-		Edit_Shape_Draw(dc_Map);
-	}
+		dc_Map.Draw_DC(dc, Transparency);
 
-	//-----------------------------------------------------
-	dc_Map.dc.SetBrush(wxNullBrush);
-	dc_Map.dc.SetPen  (wxNullPen);
+		delete(pDC);
+	}
 }
 
 //---------------------------------------------------------
@@ -1229,16 +1279,8 @@ void CWKSP_Shapes::_Draw_Label(CWKSP_Map_DC &dc_Map, CSG_Shape *pShape, int Poin
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
-//---------------------------------------------------------
-CSG_Parameter * CWKSP_Shapes::AttributeList_Add(const CSG_String &ParentID, const CSG_String &Identifier, const CSG_String &Name, const CSG_String &Description)
-{
-	return( m_Parameters.Add_Choice(ParentID, Identifier, Name, Description, CSG_String(_TL("<default>")) + "|") );
-}
-
 //---------------------------------------------------------
 void CWKSP_Shapes::AttributeList_Set(CSG_Parameter *pFields, bool bAddNoField)
 {
@@ -1271,8 +1313,6 @@ void CWKSP_Shapes::AttributeList_Set(CSG_Parameter *pFields, bool bAddNoField)
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1356,8 +1396,6 @@ int CWKSP_Shapes::PenList_Get_Style(const CSG_String &Identifier)
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1402,8 +1440,6 @@ bool CWKSP_Shapes::Get_Class_Color(CSG_Shape *pShape, int &Color)
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1486,8 +1522,8 @@ bool CWKSP_Shapes::_Chart_Set_Options(void)
 
 			Fields	+= CSG_String::Format("%s|", _TL("<none>"));
 
-			pChart->Get("SIZE_FIELD")->asChoice()->Set_Items(Fields);
-			pChart->Get("SIZE_FIELD")->Set_Value(n);
+			(*pChart)("SIZE_FIELD")->asChoice()->Set_Items(Fields);
+			(*pChart)("SIZE_FIELD")->Set_Value(n);
 
 			return( true );
 		}
@@ -1504,28 +1540,28 @@ bool CWKSP_Shapes::_Chart_Get_Options(void)
 
 	CSG_Parameters	*pChart	= m_Parameters("DISPLAY_CHART")->asParameters();
 
-	if( pChart->Get_Parameter("FIELDS") )
+	if( (*pChart)("FIELDS") )
 	{
 		for(int i=0, n=0; i<Get_Shapes()->Get_Field_Count(); i++)
 		{
-			CSG_Parameter	*p	= pChart->Get_Parameter(CSG_String::Format("FIELD_%d", i));
+			CSG_Parameter	*p	= (*pChart)(CSG_String::Format("FIELD_%d", i));
 
 			if(	p )
 			{
-				if( pChart->Get_Parameter("SIZE_FIELD")->asInt() == n++ )
+				if( (*pChart)("SIZE_FIELD")->asInt() == n++ )
 					m_Chart_sField	= i;
 
-				if( p->asBool() && (p = pChart->Get_Parameter(CSG_String::Format("COLOR_%d", i))) != NULL )
+				if( p->asBool() && (p = (*pChart)(CSG_String::Format("COLOR_%d", i))) != NULL )
 					m_Chart.Add(i, p->asColor());
 			}
 		}
 
-		m_Chart_Type	= pChart->Get_Parameter("TYPE"        )->asInt();
-		m_Chart_sType	= pChart->Get_Parameter("SIZE_TYPE"   )->asInt();
+		m_Chart_Type	= (*pChart)("TYPE"        )->asInt();
+		m_Chart_sType	= (*pChart)("SIZE_TYPE"   )->asInt();
 		m_Chart_sSize	= m_Chart_sField < 0
-						? pChart->Get_Parameter("SIZE_DEFAULT")->asDouble()
-						: pChart->Get_Parameter("SIZE_RANGE"  )->asRange()->Get_LoVal();
-		m_Chart_sRange	= pChart->Get_Parameter("SIZE_RANGE"  )->asRange()->Get_HiVal() - m_Chart_sSize;
+						? (*pChart)("SIZE_DEFAULT")->asDouble()
+						: (*pChart)("SIZE_RANGE"  )->asRange()->Get_Min();
+		m_Chart_sRange	= (*pChart)("SIZE_RANGE"  )->asRange()->Get_Max() - m_Chart_sSize;
 
 		return( true );
 	}
