@@ -71,6 +71,17 @@
 #include "wksp_shapes_point.h"
 
 
+///////////////////////////////////////////////////////////
+//														 //
+//														 //
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+#define SYMBOL_TYPE_Image		13
+#define SYMBOL_TYPE_Beachball	14
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 //														 //
@@ -89,8 +100,6 @@ CWKSP_Shapes_Point::CWKSP_Shapes_Point(CSG_Shapes *pShapes)
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -124,7 +133,7 @@ void CWKSP_Shapes_Point::On_Create_Parameters(void)
 	m_Parameters.Add_Choice("NODE_DISPLAY",
 		"DISPLAY_SYMBOL_TYPE"	, _TL("Symbol Type"),
 		_TL(""),
-		CSG_String::Format("%s|%s|%s|%s|%s|%s|%s|%s|%s|%s|%s|%s|%s|%s|",
+		CSG_String::Format("%s|%s|%s|%s|%s|%s|%s|%s|%s|%s|%s|%s|%s|%s|%s|",
 			_TL("circle"),
 			_TL("square"),
 			_TL("rhombus"),
@@ -138,7 +147,8 @@ void CWKSP_Shapes_Point::On_Create_Parameters(void)
 			_TL("circle in rhombus"),
 			_TL("circle in triangle (up)"),
 			_TL("circle in triangle (down)"),
-			_TL("image")
+			_TL("image"),
+			_TL("beachball plot")
 		), 0
 	);
 
@@ -167,13 +177,18 @@ void CWKSP_Shapes_Point::On_Create_Parameters(void)
 		)
 	);
 
+	m_Parameters.Add_Choice("DISPLAY_SYMBOL_TYPE", "BEACHBALL_STRIKE", _TL("Strike"), _TL(""), _TL("<default>"));
+	m_Parameters.Add_Choice("DISPLAY_SYMBOL_TYPE", "BEACHBALL_DIP"   , _TL("Dip"   ), _TL(""), _TL("<default>"));
+	m_Parameters.Add_Choice("DISPLAY_SYMBOL_TYPE", "BEACHBALL_RAKE"  , _TL("Rake"  ), _TL(""), _TL("<default>"));
+
 
 	//-----------------------------------------------------
 	// Label...
 
-	AttributeList_Add("LABEL_ATTRIB",
+	m_Parameters.Add_Choice("LABEL_ATTRIB",
 		"LABEL_ANGLE_ATTRIB", _TL("Rotation by Attribute"),
-		_TL("")
+		_TL(""),
+		_TL("<default>")
 	);
 
 	m_Parameters.Add_Double("LABEL_ANGLE_ATTRIB",
@@ -215,9 +230,10 @@ void CWKSP_Shapes_Point::On_Create_Parameters(void)
 		), 0
 	);
 
-	AttributeList_Add("NODE_SIZE",
+	m_Parameters.Add_Choice("NODE_SIZE",
 		"SIZE_ATTRIB"		, _TL("Attribute"),
-		_TL("")
+		_TL(""),
+		_TL("<default>")
 	);
 
 	m_Parameters.Add_Choice("SIZE_ATTRIB",
@@ -255,8 +271,6 @@ void CWKSP_Shapes_Point::On_Create_Parameters(void)
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -264,8 +278,11 @@ void CWKSP_Shapes_Point::On_DataObject_Changed(void)
 {
 	CWKSP_Shapes::On_DataObject_Changed();
 
-	AttributeList_Set(m_Parameters("SIZE_ATTRIB"       ), true);
-	AttributeList_Set(m_Parameters("LABEL_ANGLE_ATTRIB"), true);
+	AttributeList_Set(m_Parameters("BEACHBALL_STRIKE"  ), false);
+	AttributeList_Set(m_Parameters("BEACHBALL_DIP"     ), false);
+	AttributeList_Set(m_Parameters("BEACHBALL_RAKE"    ), false);
+	AttributeList_Set(m_Parameters("SIZE_ATTRIB"       ),  true);
+	AttributeList_Set(m_Parameters("LABEL_ANGLE_ATTRIB"),  true);
 }
 
 //---------------------------------------------------------
@@ -276,10 +293,20 @@ void CWKSP_Shapes_Point::On_Parameters_Changed(void)
 	//-----------------------------------------------------
 	m_Symbol_Type	= m_Parameters("DISPLAY_SYMBOL_TYPE")->asInt();
 
-	if( !SG_File_Exists   (m_Parameters("DISPLAY_SYMBOL_IMAGE")->asString())
-	||	!m_Symbol.LoadFile(m_Parameters("DISPLAY_SYMBOL_IMAGE")->asString()) )
+	if( m_Symbol_Type == SYMBOL_TYPE_Image )
 	{
-		m_Symbol	= IMG_Get_Image(ID_IMG_DEFAULT);
+		if( !SG_File_Exists   (m_Parameters("DISPLAY_SYMBOL_IMAGE")->asString())
+		||	!m_Symbol.LoadFile(m_Parameters("DISPLAY_SYMBOL_IMAGE")->asString()) )
+		{
+			m_Symbol	= IMG_Get_Image(ID_IMG_DEFAULT);
+		}
+	}
+
+	if( m_Symbol_Type == SYMBOL_TYPE_Beachball )
+	{
+		m_Beachball[0]	= m_Parameters("BEACHBALL_STRIKE")->asInt();
+		m_Beachball[1]	= m_Parameters("BEACHBALL_DIP"   )->asInt();
+		m_Beachball[2]	= m_Parameters("BEACHBALL_RAKE"  )->asInt();
 	}
 
 	//-----------------------------------------------------
@@ -296,8 +323,8 @@ void CWKSP_Shapes_Point::On_Parameters_Changed(void)
 	}
 	else
 	{
-		m_Size		=  m_Parameters("SIZE_RANGE")->asRange()->Get_LoVal();
-		m_dSize		= (m_Parameters("SIZE_RANGE")->asRange()->Get_HiVal() - m_Size) / m_dSize;
+		m_Size		=  m_Parameters("SIZE_RANGE")->asRange()->Get_Min();
+		m_dSize		= (m_Parameters("SIZE_RANGE")->asRange()->Get_Max() - m_Size) / m_dSize;
 	}
 
 	//-----------------------------------------------------
@@ -331,8 +358,6 @@ void CWKSP_Shapes_Point::On_Parameters_Changed(void)
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -341,14 +366,14 @@ int CWKSP_Shapes_Point::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Pa
 	//-----------------------------------------------------
 	if( Flags & PARAMETER_CHECK_VALUES )
 	{
-		if(	!SG_STR_CMP(pParameter->Get_Identifier(), "COLORS_FONT") )
+		if(	pParameter->Cmp_Identifier("COLORS_FONT") )
 		{
 			Set_Metrics(
-				pParameters->Get_Parameter("METRIC_ATTRIB")->asInt(),
-				pParameters->Get_Parameter("METRIC_NORMAL")->asInt()
+				(*pParameters)("METRIC_ATTRIB")->asInt(),
+				(*pParameters)("METRIC_NORMAL")->asInt()
 			);
 
-			pParameters->Get_Parameter("METRIC_ZRANGE")->asRange()->Set_Range(
+			(*pParameters)("METRIC_ZRANGE")->asRange()->Set_Range(
 				m_Metrics.Get_Minimum(),
 				m_Metrics.Get_Maximum()
 			);
@@ -358,33 +383,40 @@ int CWKSP_Shapes_Point::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Pa
 	//-----------------------------------------------------
 	if( Flags & PARAMETER_CHECK_ENABLE )
 	{
-		if(	!SG_STR_CMP(pParameter->Get_Identifier(), "DISPLAY_SYMBOL_TYPE") )
+		if(	pParameter->Cmp_Identifier("DISPLAY_SYMBOL_TYPE") )
 		{
-			pParameters->Get_Parameter("DISPLAY_SYMBOL_IMAGE")->Set_Enabled(pParameter->asInt() == pParameter->asChoice()->Get_Count() - 1);
+			int		Value	= pParameter->asInt();
+
+			pParameters->Set_Enabled("DISPLAY_SYMBOL_IMAGE", Value == SYMBOL_TYPE_Image    );
+			pParameters->Set_Enabled("BEACHBALL_STRIKE"    , Value == SYMBOL_TYPE_Beachball);
+			pParameters->Set_Enabled("BEACHBALL_DIP"       , Value == SYMBOL_TYPE_Beachball);
+			pParameters->Set_Enabled("BEACHBALL_RAKE"      , Value == SYMBOL_TYPE_Beachball);
 		}
 
-		if(	!SG_STR_CMP(pParameter->Get_Identifier(), "LABEL_ATTRIB") )
+		if(	pParameter->Cmp_Identifier("LABEL_ATTRIB") )
 		{
 			bool	Value	= pParameter->asInt() < Get_Shapes()->Get_Field_Count();
 
-			pParameters->Get_Parameter("LABEL_ANGLE_ATTRIB")->Set_Enabled(Value);
-			pParameters->Get_Parameter("LABEL_ANGLE"       )->Set_Enabled(Value);
-			pParameters->Get_Parameter("LABEL_ALIGN_X"     )->Set_Enabled(Value);
-			pParameters->Get_Parameter("LABEL_ALIGN_Y"     )->Set_Enabled(Value);
+			pParameters->Set_Enabled("LABEL_ANGLE_ATTRIB"  , Value);
+			pParameters->Set_Enabled("LABEL_ANGLE"         , Value);
+			pParameters->Set_Enabled("LABEL_ALIGN_X"       , Value);
+			pParameters->Set_Enabled("LABEL_ALIGN_Y"       , Value);
 		}
 
-		if(	!SG_STR_CMP(pParameter->Get_Identifier(), "SIZE_ATTRIB") )
+		if(	pParameter->Cmp_Identifier("SIZE_ATTRIB") )
 		{
 			bool	Value	= pParameter->asInt() < Get_Shapes()->Get_Field_Count();
 
-			pParameters->Get_Parameter("SIZE_SCALE"  )->Set_Enabled(Value == true);
-			pParameters->Get_Parameter("SIZE_RANGE"  )->Set_Enabled(Value == true);
-			pParameters->Get_Parameter("SIZE_DEFAULT")->Set_Enabled(Value == false);
+			pParameters->Set_Enabled("SIZE_SCALE"          , Value ==  true);
+			pParameters->Set_Enabled("SIZE_RANGE"          , Value ==  true);
+			pParameters->Set_Enabled("SIZE_DEFAULT"        , Value == false);
 		}
 
-		if(	!SG_STR_CMP(pParameter->Get_Identifier(), "LABEL_ANGLE_ATTRIB") )
+		if(	pParameter->Cmp_Identifier("LABEL_ANGLE_ATTRIB") )
 		{
-			pParameters->Get_Parameter("LABEL_ANGLE")->Set_Enabled(pParameter->asInt() >= Get_Shapes()->Get_Field_Count());
+			bool	Value	= pParameter->asInt() >= Get_Shapes()->Get_Field_Count();
+
+			pParameters->Set_Enabled("LABEL_ANGLE"         , Value);
 		}
 	}
 
@@ -394,8 +426,6 @@ int CWKSP_Shapes_Point::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Pa
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -422,17 +452,26 @@ bool CWKSP_Shapes_Point::Get_Style_Size(int &min_Size, int &max_Size, double &mi
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-inline void CWKSP_Shapes_Point::Draw_Initialize(CWKSP_Map_DC &dc_Map)
+inline void CWKSP_Shapes_Point::Draw_Initialize(CWKSP_Map_DC &dc_Map, int Flags)
 {
 	dc_Map.dc.SetBrush(m_Brush);
 	dc_Map.dc.SetPen  (m_Pen  );
 
 	m_Sel_Color_Fill	= Get_Color_asWX(m_Parameters("SEL_COLOR_FILL")->asInt());
+
+	m_Symbol_Type	= m_Parameters("DISPLAY_SYMBOL_TYPE")->asInt();
+
+	if( (Flags & LAYER_DRAW_FLAG_THUMBNAIL) != 0 )
+	{
+		if( m_Symbol_Type == SYMBOL_TYPE_Image
+		||  m_Symbol_Type == SYMBOL_TYPE_Beachball )
+		{
+			m_Symbol_Type	= 0;
+		}
+	}
 }
 
 //---------------------------------------------------------
@@ -498,7 +537,23 @@ void CWKSP_Shapes_Point::Draw_Shape(CWKSP_Map_DC &dc_Map, CSG_Shape *pShape, int
 		{
 			TSG_Point_Int	p(dc_Map.World2DC(pShape->Get_Point(0)));
 
-			Draw_Symbol(dc_Map.dc, p.x, p.y, Size);
+			if( m_Symbol_Type == SYMBOL_TYPE_Beachball )
+			{
+				if( !pShape->is_NoData(m_Beachball[0])
+				&&  !pShape->is_NoData(m_Beachball[1])
+				&&  !pShape->is_NoData(m_Beachball[2])	)
+				{
+					_Beachball_Draw(dc_Map.dc, p.x, p.y, Size,
+						pShape->asDouble(m_Beachball[0]),
+						pShape->asDouble(m_Beachball[1]),
+						pShape->asDouble(m_Beachball[2])
+					);
+				}
+			}
+			else
+			{
+				Draw_Symbol(dc_Map.dc, p.x, p.y, Size);
+			}
 
 			if( Selection )
 			{
@@ -522,8 +577,6 @@ void CWKSP_Shapes_Point::Draw_Label(CWKSP_Map_DC &dc_Map, CSG_Shape *pShape, con
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -531,10 +584,12 @@ void CWKSP_Shapes_Point::Draw_Label(CWKSP_Map_DC &dc_Map, CSG_Shape *pShape, con
 	dc.DrawCircle(x, y, s);\
 }
 
+//---------------------------------------------------------
 #define DRAW_SQUARE			{	int		s	= (int)(0.7071067812 * size);\
 	dc.DrawRectangle(x - s, y - s, 2 * s, 2 * s);\
 }
 
+//---------------------------------------------------------
 #define DRAW_RHOMBUS		{	wxPoint	p[4];\
 	p[0].y	= p[2].y	= y;\
 	p[1].x	= p[3].x	= x;\
@@ -545,6 +600,7 @@ void CWKSP_Shapes_Point::Draw_Label(CWKSP_Map_DC &dc_Map, CSG_Shape *pShape, con
 	dc.DrawPolygon(4, p);\
 }
 
+//---------------------------------------------------------
 #define DRAW_TRIANGLE_UP	{	wxPoint	p[3];\
 	p[0].y	= p[1].y	= y + (size / 2);\
 	p[2].y				= y - (size - 1);\
@@ -554,6 +610,7 @@ void CWKSP_Shapes_Point::Draw_Label(CWKSP_Map_DC &dc_Map, CSG_Shape *pShape, con
 	dc.DrawPolygon(3, p);\
 }
 
+//---------------------------------------------------------
 #define DRAW_TRIANGLE_DOWN	{	wxPoint	p[3];\
 	p[0].y	= p[1].y	= y - (size / 2);\
 	p[2].y				= y + (size - 1);\
@@ -568,82 +625,26 @@ void CWKSP_Shapes_Point::Draw_Symbol(wxDC &dc, int x, int y, int size)
 {
 	switch( m_Symbol_Type )
 	{
-	default:
-	case 0:		// circle
-		DRAW_CIRCLE(1.0);
-		break;
+	default: DRAW_CIRCLE(1.0)                      ; break;	// circle
+	case  1: DRAW_SQUARE                           ; break;	// square
+	case  2: DRAW_RHOMBUS                          ; break;	// rhombus
+	case  3: DRAW_TRIANGLE_UP                      ; break;	// triangle up
+	case  4: DRAW_TRIANGLE_DOWN                    ; break;	// triangle down
+	case  5: DRAW_CIRCLE(1.0)  ; DRAW_SQUARE       ; break;	// square in circle
+	case  6: DRAW_CIRCLE(1.1)  ; DRAW_RHOMBUS      ; break;	// rhombus in circle
+	case  7: DRAW_CIRCLE(1.0)  ; DRAW_TRIANGLE_UP  ; break;	// triangle up in circle
+	case  8: DRAW_CIRCLE(1.0)  ; DRAW_TRIANGLE_DOWN; break;	// triangle down in circle
+	case  9: DRAW_SQUARE       ; DRAW_CIRCLE(0.7)  ; break;	// circle in square
+	case 10: DRAW_RHOMBUS      ; DRAW_CIRCLE(0.7)  ; break;	// circle in rhombus
+	case 11: DRAW_TRIANGLE_UP  ; DRAW_CIRCLE(0.5)  ; break;	// circle in triangle up
+	case 12: DRAW_TRIANGLE_DOWN; DRAW_CIRCLE(0.5)  ; break;	// circle in triangle down
 
-	case 1:		// square
-		DRAW_SQUARE;
-		break;
-
-	case 2:		// rhombus
-		DRAW_RHOMBUS;
-		break;
-
-	case 3:		// triangle up
-		DRAW_TRIANGLE_UP;
-		break;
-
-	case 4:		// triangle down
-		DRAW_TRIANGLE_DOWN;
-		break;
-
-	case 5:		// square in circle
-		DRAW_CIRCLE(1.0);
-		DRAW_SQUARE;
-		break;
-
-	case 6:		// rhombus in circle
-		DRAW_CIRCLE(1.1);
-		DRAW_RHOMBUS;
-		break;
-
-	case 7:		// triangle up in circle
-		DRAW_CIRCLE(1.0);
-		DRAW_TRIANGLE_UP;
-		break;
-
-	case 8:		// triangle down in circle
-		DRAW_CIRCLE(1.0);
-		DRAW_TRIANGLE_DOWN;
-		break;
-
-	case 9:		// circle in square
-		DRAW_SQUARE;
-		DRAW_CIRCLE(0.7);
-		break;
-
-	case 10:	// circle in rhombus
-		DRAW_RHOMBUS;
-		DRAW_CIRCLE(0.5 * sqrt(2.0));
-		break;
-
-	case 11:	// circle in triangle up
-		DRAW_TRIANGLE_UP;
-		DRAW_CIRCLE(0.5);
-		break;
-
-	case 12:	// circle in triangle down
-		DRAW_TRIANGLE_DOWN;
-		DRAW_CIRCLE(0.5);
-		break;
-
-	case 13:	// image
+	case 13:	// SYMBOL_TYPE_Image
 		{
 			double	d	= (double)m_Symbol.GetWidth() / (double)m_Symbol.GetHeight();
-			int		sx, sy;
 
-			if( d > 1.0 )
-			{
-				sx	= size;
-				sy	= (int)(0.5 + size / d);
-			}
-			else
-			{
-				sx	= (int)(0.5 + size * d);
-				sy	= size;
-			}
+			int	sx	= d >  1.0 ? size : (int)(0.5 + size * d);
+			int	sy	= d <= 1.0 ? size : (int)(0.5 + size / d);
 
 			if( sx > 0 && sy > 0 )
 			{
@@ -651,10 +652,161 @@ void CWKSP_Shapes_Point::Draw_Symbol(wxDC &dc, int x, int y, int size)
 			}
 		}
 		break;
+
+	case 14:	// SYMBOL_TYPE_Beachball
+		_Beachball_Draw(dc, x, y, size, 0.0, 25.0, 40.0);
+		break;
 	}	
 }
 
 
+///////////////////////////////////////////////////////////
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+void CWKSP_Shapes_Point::_Beachball_Draw(wxDC &dc, int x, int y, int size, double strike, double dip, double rake)
+{
+	const double	dArc	= 5.0;
+
+	strike	*= M_DEG_TO_RAD;
+	dip		*= M_DEG_TO_RAD;
+	rake	*= M_DEG_TO_RAD;
+
+	CSG_Shapes	Plot(SHAPE_TYPE_Polygon);
+
+	Plot.Add_Shape();	// 0, unit circle
+
+	for(double a=0.0; a<M_PI_360; a+=dArc*M_DEG_TO_RAD)
+	{
+		Plot.Get_Shape(0)->Add_Point(sin(a), cos(a));
+	}
+
+	CSG_Vector	N(3);
+
+	N[0] = 0; N[1] = 0; N[2] = 1;
+
+	SG_VectorR3_Rotate(N, 1, dip);
+	SG_VectorR3_Rotate(N, 2, strike);
+
+	_Beachball_Get_Plane(Plot.Add_Shape(), Plot.Get_Shape(0), N);	// 1, fault plane
+
+	N[0] = 0; N[1] = -1; N[2] = 0;
+
+	rake = fmod(rake, M_PI_360); if( rake < -M_PI_180 ) rake += M_PI_360; else if( rake > M_PI_180 ) rake -= M_PI_360;
+
+	SG_VectorR3_Rotate(N, 2, -rake);
+	SG_VectorR3_Rotate(N, 1, dip);
+	SG_VectorR3_Rotate(N, 2, strike);
+
+	_Beachball_Get_Plane(Plot.Add_Shape(), Plot.Get_Shape(0), N);	// 2, auxiliary plane
+
+	//-----------------------------------------------------
+	SG_Polygon_Intersection(Plot.Get_Shape(0), Plot.Get_Shape(1), Plot.Add_Shape());	// 3
+	SG_Polygon_Difference  (Plot.Get_Shape(0), Plot.Get_Shape(1), Plot.Add_Shape());	// 4
+
+	CSG_Shape_Polygon	*pPlot[2];
+
+	if( rake < 0.0 )
+	{
+		SG_Polygon_Difference  (Plot.Get_Shape(3), Plot.Get_Shape(2), pPlot[0] = (CSG_Shape_Polygon *)Plot.Add_Shape());
+		SG_Polygon_Intersection(Plot.Get_Shape(4), Plot.Get_Shape(2), pPlot[1] = (CSG_Shape_Polygon *)Plot.Add_Shape());
+	}
+	else
+	{
+		SG_Polygon_Intersection(Plot.Get_Shape(3), Plot.Get_Shape(2), pPlot[0] = (CSG_Shape_Polygon *)Plot.Add_Shape());
+		SG_Polygon_Difference  (Plot.Get_Shape(4), Plot.Get_Shape(2), pPlot[1] = (CSG_Shape_Polygon *)Plot.Add_Shape());
+	}
+
+	//-----------------------------------------------------
+	dc.DrawCircle(x, y, size);
+
+	wxBrush	b = dc.GetBrush(); dc.SetBrush(*wxWHITE_BRUSH);
+
+	for(int i=0; i<2; i++)
+	{
+		// SG_Polygon_Offset(pPlot[i], -0.01, dArc);
+		_Beachball_Get_Scaled(pPlot[i], x,  y, size);
+
+		if( pPlot[i]->Get_Area() > 1 )
+		{
+			wxPoint	*Points	= new wxPoint[pPlot[i]->Get_Point_Count(0)];
+
+			for(int iPoint=0; iPoint<pPlot[i]->Get_Point_Count(0); iPoint++)
+			{
+				TSG_Point	p		= pPlot[i]->Get_Point(iPoint, 0);
+				Points[iPoint].x	= (int)(p.x + 0.5);
+				Points[iPoint].y	= (int)(p.y + 0.5);
+			}
+
+			dc.DrawPolygon(pPlot[i]->Get_Point_Count(0), Points);
+
+			delete[](Points);
+		}
+	}
+
+	dc.SetBrush(b);
+}
+
+//---------------------------------------------------------
+void CWKSP_Shapes_Point::_Beachball_Get_Plane(CSG_Shape *pPlane, CSG_Shape *pCircle, const CSG_Vector &Normal)
+{
+	CSG_Vector	Ez(3);	Ez[2]	=  1.0;
+
+	double	Slope	= Normal.Get_Angle(Ez);
+	double	Azimuth	= M_PI_090 + atan2(Normal[1], Normal[0]);
+
+	if( Slope > M_PI_090 )
+	{
+		Azimuth	+= M_PI_180;
+		Slope	 = M_PI_090 - (Slope - M_PI_090);
+	}
+
+	TSG_Point	A, C;
+
+	A.x	= sin(Azimuth - M_PI_090);	// strike
+	A.y	= cos(Azimuth - M_PI_090);
+
+	if( Slope < M_PI_090 )
+	{
+		double	d	= -2. * tan(Slope / 2.);	// stereographic projection
+
+		C.x	= d * sin(Azimuth);
+		C.y	= d * cos(Azimuth);
+
+		pPlane->Add_Part(((CSG_Shape_Polygon *)pCircle)->Get_Part(0));
+
+		_Beachball_Get_Scaled(pPlane, C.x, C.y, SG_Get_Distance(A, C));
+	}
+	else
+	{
+		A.x	*= 1.1;	A.y	*= 1.1;
+
+		pPlane->Add_Point(-A.x, -A.y);
+		pPlane->Add_Point( A.x,  A.y);
+		pPlane->Add_Point( A.x - A.y,  A.y + A.x);
+		pPlane->Add_Point(-A.x - A.y, -A.y + A.x);
+	}
+}
+
+//---------------------------------------------------------
+void CWKSP_Shapes_Point::_Beachball_Get_Scaled(CSG_Shape *pShape, double x, double y, double size)
+{
+	for(int iPart=0; iPart<pShape->Get_Part_Count(); iPart++)
+	{
+		for(int iPoint=0; iPoint<pShape->Get_Point_Count(iPart); iPoint++)
+		{
+			TSG_Point	Point	= pShape->Get_Point(iPoint, iPart);
+
+			Point.x	= x + size * Point.x;
+			Point.y	= y - size * Point.y;
+
+			pShape->Set_Point(Point, iPoint, iPart);
+		}
+	}
+}
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 //														 //
