@@ -108,7 +108,7 @@ protected:
 
 	virtual int					On_Parameter_Changed	(CSG_Parameters *pParameters, CSG_Parameter *pParameter, int Flags);
 
-	virtual void				Draw_Initialize			(CWKSP_Map_DC &dc_Map);
+	virtual void				Draw_Initialize			(CWKSP_Map_DC &dc_Map, int Flags);
 	virtual void				Draw_Shape				(CWKSP_Map_DC &dc_Map, CSG_Shape *pShape, int Selection);
 	virtual void				Draw_Label				(CWKSP_Map_DC &dc_Map, CSG_Shape *pShape, const wxString &Label);
 
