@@ -121,7 +121,7 @@ private:
 	void							_Save_to_Script			(void);
 
 	CSG_String						_Get_XML				(bool bHeader);
-	void							_Get_XML				(CSG_MetaData &Tool, CSG_Parameters *pParameters);
+	void							_Get_XML				(CSG_MetaData &Tool, CSG_Parameters *pParameters, const CSG_String &Prefix = "");
 
 	CSG_String						_Get_CMD				(bool bHeader, int Type = -1);
 	void							_Get_CMD				(CSG_String &Command, CSG_Parameters *pParameters);
