@@ -165,14 +165,14 @@ CGrid_Levels_Interpolation::CGrid_Levels_Interpolation(void)
 //---------------------------------------------------------
 int CGrid_Levels_Interpolation::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
-	if( !SG_STR_CMP(pParameter->Get_Identifier(), SG_T("V_METHOD")) )
+	if( pParameter->Cmp_Identifier(SG_T("V_METHOD")) )
 	{
 		pParameters->Get_Parameter("LINEAR_SORTED")->Set_Enabled(pParameter->asInt() == 0);
 		pParameters->Get_Parameter("SPLINE_ALL"   )->Set_Enabled(pParameter->asInt() == 1);
 		pParameters->Get_Parameter("TREND_ORDER"  )->Set_Enabled(pParameter->asInt() >= 2);
 	}
 
-	if( !SG_STR_CMP(pParameter->Get_Identifier(), SG_T("X_SOURCE")) )
+	if( pParameter->Cmp_Identifier(SG_T("X_SOURCE")) )
 	{
 		pParameters->Get_Parameter("X_TABLE"      )->Set_Enabled(pParameter->asInt() == 0);
 		pParameters->Get_Parameter("X_GRIDS"      )->Set_Enabled(pParameter->asInt() == 1);
@@ -225,7 +225,7 @@ bool CGrid_Levels_Interpolation::Initialize(const CSG_Rect &Extent)
 		return( false );
 	}
 
-	if( !Extent.Intersects(Get_System()->Get_Extent(true)) )
+	if( !Extent.Intersects(Get_System().Get_Extent(true)) )
 	{
 		Error_Set(_TL("target area is distinct from levels area "));
 
@@ -275,7 +275,7 @@ bool CGrid_Levels_Interpolation::Initialize(const CSG_Rect &Extent)
 
 		for(i=0; i<=m_Trend_Order; i++)
 		{
-			m_Coeff[i].Create(*Get_System());
+			m_Coeff[i].Create(Get_System());
 		}
 
 		#pragma omp parallel for private(i)
