@@ -207,7 +207,7 @@ void CGrid_Geometric_Figures::Create_Plane(CSG_Grid *pGrid, double Direction)
 	double	xPos, yPos, z, dSin, dCos, Max;
 
 	//-----------------------------------------------------
-	pGrid->Set_Name(CSG_String::Format(_TL("Plane (%.2fDegree)"), Direction));
+	pGrid->Set_Name("%s (%.2f %s)", _TL("Plane"), Direction, _TL("Degree"));
 
 	Max		= sqrt(2.0) * pGrid->Get_Cellsize() * pGrid->Get_Cellsize() / 4.0;
 
