@@ -166,7 +166,7 @@ bool CFilter_Majority::On_Execute(void)
 	}
 	else
 	{
-		pResult->Set_Name(CSG_String::Format("%s [%s]", m_pInput->Get_Name(), _TL("Majority Filter")));
+		pResult->Set_Name("%s [%s]", m_pInput->Get_Name(), _TL("Majority Filter"));
 
 		pResult->Set_NoData_Value(m_pInput->Get_NoData_Value());
 
