@@ -190,10 +190,7 @@ bool CFilter_Morphology::On_Execute(void)
 	}
 	else
 	{
-		pResult->Set_Name(CSG_String::Format("%s [%s]",
-			Parameters("INPUT")->asGrid()->Get_Name(),
-			Parameters("METHOD")->asString()
-		));
+		pResult->Set_Name("%s [%s]", Parameters("INPUT")->asGrid()->Get_Name(), Parameters("METHOD")->asString());
 	}
 
 	m_Kernel.Destroy();
@@ -209,9 +206,9 @@ bool CFilter_Morphology::On_Execute(void)
 //---------------------------------------------------------
 bool CFilter_Morphology::Get_Extreme(bool bMinimum, CSG_Grid *pInput, CSG_Grid *pResult)
 {
-	if( !Get_System()->is_Equal(pResult->Get_System()) )
+	if( !Get_System().is_Equal(pResult->Get_System()) )
 	{
-		pResult->Create(*Get_System());
+		pResult->Create(Get_System());
 	}
 
 	for(int y=0; y<Get_NY() && Set_Progress(y); y++)
