@@ -58,120 +58,109 @@
 //														 //
 ///////////////////////////////////////////////////////////
 
-
+//---------------------------------------------------------
 #include "Filter_Multi_Dir_Lee.h"
 
 
+///////////////////////////////////////////////////////////
+//														 //
+//														 //
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
 double Filter_Directions[16][9][9]	=
-{
-	{
-		{0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0},
-		{0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0},
-		{0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0},
-		{0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5},
-		{1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0},
-		{0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5},
-		{0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0},
-		{0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0},
-		{0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0}
-	},
-
-	{
-		{0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0},
-		{0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0},
-		{0.5, 0.5, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0},
-		{1.0, 1.0, 0.5, 0.5, 0.5, 0.5, 0.0, 0.0, 0.0},
-		{0.5, 0.5, 1.0, 1.0, 1.0, 1.0, 1.0, 0.5, 0.5},
-		{0.0, 0.0, 0.0, 0.5, 0.5, 0.5, 0.5, 1.0, 1.0},
-		{0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.5, 0.5},
-		{0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0},
-		{0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0}
-	},
-
-	{
-		{0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0},
-		{0.5, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0},
-		{1.0, 1.0, 0.5, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0},
-		{0.5, 0.5, 1.0, 1.0, 0.5, 0.0, 0.0, 0.0, 0.0},
-		{0.0, 0.0, 0.5, 0.5, 1.0, 0.5, 0.5, 0.0, 0.0},
-		{0.0, 0.0, 0.0, 0.0, 0.5, 1.0, 1.0, 0.5, 0.5},
-		{0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.5, 1.0, 1.0},
-		{0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.5},
-		{0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0}
-	},
-
-	{
-		{0.5, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0},
-		{1.0, 0.5, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0},
-		{0.5, 1.0, 1.0, 0.5, 0.0, 0.0, 0.0, 0.0, 0.0},
-		{0.0, 0.5, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0, 0.0},
-		{0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0},
-		{0.0, 0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.5, 0.0},
-		{0.0, 0.0, 0.0, 0.0, 0.0, 0.5, 1.0, 1.0, 0.5},
-		{0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.5, 1.0},
-		{0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.5}
-	},
-
-	{
-		{1.0, 0.5, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0},
-		{0.5, 1.0, 0.5, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0},
-		{0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0, 0.0, 0.0},
-		{0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0, 0.0},
-		{0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0},
-		{0.0, 0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0},
-		{0.0, 0.0, 0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0},
-		{0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.5, 1.0, 0.5},
-		{0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.5, 1.0}
-	},
-
-	{
-		{0.5, 1.0, 0.5, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0},
-		{0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0, 0.0, 0.0},
-		{0.0, 0.0, 0.5, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0},
-		{0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0, 0.0},
-		{0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0},
-		{0.0, 0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0},
-		{0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.5, 0.0, 0.0},
-		{0.0, 0.0, 0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0},
-		{0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.5, 1.0, 0.5}
-	},
-
-	{
-		{0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0, 0.0, 0.0},
-		{0.0, 0.0, 1.0, 0.5, 0.0, 0.0, 0.0, 0.0, 0.0},
-		{0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0, 0.0},
-		{0.0, 0.0, 0.0, 1.0, 0.5, 0.0, 0.0, 0.0, 0.0},
-		{0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0},
-		{0.0, 0.0, 0.0, 0.0, 0.5, 1.0, 0.0, 0.0, 0.0},
-		{0.0, 0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0},
-		{0.0, 0.0, 0.0, 0.0, 0.0, 0.5, 1.0, 0.0, 0.0},
-		{0.0, 0.0, 0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0}
-	},
-
-	{
-		{0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0, 0.0},
-		{0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0, 0.0},
-		{0.0, 0.0, 0.0, 1.0, 0.5, 0.0, 0.0, 0.0, 0.0},
-		{0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0},
-		{0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0},
-		{0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0},
-		{0.0, 0.0, 0.0, 0.0, 0.5, 1.0, 0.0, 0.0, 0.0},
-		{0.0, 0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0},
-		{0.0, 0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0}
-	},
-
-	{
-		{0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0},
-		{0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0},
-		{0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0},
-		{0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0},
-		{0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0},
-		{0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0},
-		{0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0},
-		{0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0},
-		{0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0}
-	}
-};
+{ {
+	{0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0},
+	{0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0},
+	{0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0},
+	{0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5},
+	{1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0},
+	{0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5},
+	{0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0},
+	{0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0},
+	{0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0}
+}, {
+	{0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0},
+	{0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0},
+	{0.5, 0.5, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0},
+	{1.0, 1.0, 0.5, 0.5, 0.5, 0.5, 0.0, 0.0, 0.0},
+	{0.5, 0.5, 1.0, 1.0, 1.0, 1.0, 1.0, 0.5, 0.5},
+	{0.0, 0.0, 0.0, 0.5, 0.5, 0.5, 0.5, 1.0, 1.0},
+	{0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.5, 0.5},
+	{0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0},
+	{0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0}
+}, {
+	{0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0},
+	{0.5, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0},
+	{1.0, 1.0, 0.5, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0},
+	{0.5, 0.5, 1.0, 1.0, 0.5, 0.0, 0.0, 0.0, 0.0},
+	{0.0, 0.0, 0.5, 0.5, 1.0, 0.5, 0.5, 0.0, 0.0},
+	{0.0, 0.0, 0.0, 0.0, 0.5, 1.0, 1.0, 0.5, 0.5},
+	{0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.5, 1.0, 1.0},
+	{0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.5},
+	{0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0}
+}, {
+	{0.5, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0},
+	{1.0, 0.5, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0},
+	{0.5, 1.0, 1.0, 0.5, 0.0, 0.0, 0.0, 0.0, 0.0},
+	{0.0, 0.5, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0, 0.0},
+	{0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0},
+	{0.0, 0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.5, 0.0},
+	{0.0, 0.0, 0.0, 0.0, 0.0, 0.5, 1.0, 1.0, 0.5},
+	{0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.5, 1.0},
+	{0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.5}
+}, {
+	{1.0, 0.5, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0},
+	{0.5, 1.0, 0.5, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0},
+	{0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0, 0.0, 0.0},
+	{0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0, 0.0},
+	{0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0},
+	{0.0, 0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0},
+	{0.0, 0.0, 0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0},
+	{0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.5, 1.0, 0.5},
+	{0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.5, 1.0}
+}, {
+	{0.5, 1.0, 0.5, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0},
+	{0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0, 0.0, 0.0},
+	{0.0, 0.0, 0.5, 1.0, 0.0, 0.0, 0.0, 0.0, 0.0},
+	{0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0, 0.0},
+	{0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0},
+	{0.0, 0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0},
+	{0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.5, 0.0, 0.0},
+	{0.0, 0.0, 0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0},
+	{0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.5, 1.0, 0.5}
+}, {
+	{0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0, 0.0, 0.0},
+	{0.0, 0.0, 1.0, 0.5, 0.0, 0.0, 0.0, 0.0, 0.0},
+	{0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0, 0.0},
+	{0.0, 0.0, 0.0, 1.0, 0.5, 0.0, 0.0, 0.0, 0.0},
+	{0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0},
+	{0.0, 0.0, 0.0, 0.0, 0.5, 1.0, 0.0, 0.0, 0.0},
+	{0.0, 0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0},
+	{0.0, 0.0, 0.0, 0.0, 0.0, 0.5, 1.0, 0.0, 0.0},
+	{0.0, 0.0, 0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0}
+}, {
+	{0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0, 0.0},
+	{0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0, 0.0},
+	{0.0, 0.0, 0.0, 1.0, 0.5, 0.0, 0.0, 0.0, 0.0},
+	{0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0},
+	{0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0},
+	{0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0},
+	{0.0, 0.0, 0.0, 0.0, 0.5, 1.0, 0.0, 0.0, 0.0},
+	{0.0, 0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0},
+	{0.0, 0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0}
+}, {
+	{0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0},
+	{0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0},
+	{0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0},
+	{0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0},
+	{0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0},
+	{0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0},
+	{0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0},
+	{0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0},
+	{0.0, 0.0, 0.0, 0.5, 1.0, 0.5, 0.0, 0.0, 0.0}
+} };
 
 
 ///////////////////////////////////////////////////////////
@@ -184,78 +173,82 @@ double Filter_Directions[16][9][9]	=
 CFilter_Multi_Dir_Lee::CFilter_Multi_Dir_Lee(void)
 {
 	//-----------------------------------------------------
-	Set_Name(_TL("Multi Direction Lee Filter"));
+	Set_Name		(_TL("Multi Direction Lee Filter"));
 
-	Set_Author(_TL("Copyrights (c) 2003 by Andre Ringeler"));
+	Set_Author		("A.Ringeler (c) 2003");
 
 	Set_Description	(_TW(
 		"The tool searches for the minimum variance within 16 directions "
 		"and applies a Lee Filter in the direction of minimum variance. The "
 		"filter is edge-preserving and can be used to remove speckle noise "
 		"from SAR images or to smooth DTMs. Applied to DTMs, this filter "
-		"will preserve slope breaks and narrow valleys.\n\n"
-		"For more details, please refer to:\n"
-		"Lee, J.S. (1980): Digital image enhancement and noise filtering by use of local statistics. "
-        "IEEE Transactions on Pattern Analysis and Machine Intelligence, PAMI-2: 165-168\n\n"
-        "Lee, J.S., Papathanassiou, K.P., Ainsworth, T.L., Grunes, M.R., Reigber, A. (1998): A "
-        "New Technique for Noise Filtering of SAR Interferometric Phase Images. IEEE "
-        "Transactions on Geosciences and Remote Sensing 36(5): 1456-1465.\n\n"
-        "Selige, T., Böhner, J., Ringeler, A. (2006): Processing of SRTM X-SAR Data to correct interferometric "
-        "elevation models for land surface process applications. In: Böhner, J., McCloy, K.R., Strobl, J. [Eds.]: "
-        "SAGA - Analysis and Modelling Applications. Göttinger Geographische Abhandlungen, Vol. 115: 97-104 "
-        "<a href=\"http://downloads.sourceforge.net/saga-gis/gga115_09.pdf\">&lt;PDF&gt;</a>\n"
-        "\n\n"
-		)
+		"will preserve slope breaks and narrow valleys.\n"
+		"For more details, please refer to the references. "
+	));
+
+	Add_Reference("Lee, J.S.", "1980",
+		"Digital image enhancement and noise filtering by use of local statistics",
+        "IEEE Transactions on Pattern Analysis and Machine Intelligence, PAMI-2: 165-168."
 	);
 
+	Add_Reference("Lee, J.S., Papathanassiou, K.P., Ainsworth, T.L., Grunes, M.R., Reigber, A.", "1998",
+		"A New Technique for Noise Filtering of SAR Interferometric Phase Images",
+		"IEEE Transactions on Geosciences and Remote Sensing 36(5): 1456-1465."
+	);
+
+	Add_Reference("Selige, T., Böhner, J., Ringeler, A.", "2006",
+		"Processing of SRTM X-SAR Data to correct interferometric elevation models for land surface process applications",
+		"In: Böhner, J., McCloy, K.R., Strobl, J. [Eds.]: SAGA - Analysis and Modelling Applications. Göttinger Geographische Abhandlungen, Vol. 115: 97-104.",
+        SG_T("http://downloads.sourceforge.net/saga-gis/gga115_09.pdf")
+	);
 
 	//-----------------------------------------------------
 	Parameters.Add_Grid(
-		NULL, "INPUT"		, _TL("Grid"),
+		"", "INPUT"		, _TL("Grid"),
 		_TL(""),
 		PARAMETER_INPUT
 	);
 
 	Parameters.Add_Grid(
-		NULL, "RESULT"		, _TL("Filtered Grid"),
+		"", "RESULT"	, _TL("Filtered Grid"),
 		_TL(""),
 		PARAMETER_OUTPUT
 	);
 
 	Parameters.Add_Grid(
-		NULL, "STDDEV"		, _TL("Minimum Standard Deviation"),
+		"", "STDDEV"	, _TL("Minimum Standard Deviation"),
 		_TL(""),
 		PARAMETER_OUTPUT_OPTIONAL
 	);
 
 	Parameters.Add_Grid(
-		NULL, "DIR"			, _TL("Direction of Minimum Standard Deviation"),
+		"", "DIR"		, _TL("Direction of Minimum Standard Deviation"),
 		_TL(""),
 		PARAMETER_OUTPUT_OPTIONAL
 	);
 
 	Parameters.Add_Value(
-		NULL, "NOISE_ABS"	, _TL("Estimated Noise (absolute)"),
+		"", "NOISE_ABS"	, _TL("Estimated Noise (absolute)"),
 		_TL("Estimated noise in units of input data"),
 		PARAMETER_TYPE_Double, 1.0
 	);
 
-	Parameters.Add_Value(
-		NULL, "NOISE_REL"	, _TL("Estimated Noise (relative)"),
+	Parameters.Add_Double(
+		"", "NOISE_REL"	, _TL("Estimated Noise (relative)"),
 		_TL("Estimated noise relative to mean standard deviation"),
-		PARAMETER_TYPE_Double, 1.0
+		1.0
 	);
 
-	Parameters.Add_Value(
-		NULL, "WEIGHTED"	, _TL("Weighted"),
+	Parameters.Add_Bool(
+		"", "WEIGHTED"	, _TL("Weighted"),
 		_TL(""),
-		PARAMETER_TYPE_Bool, true
+		true
 	);
 
 	Parameters.Add_Choice(
-		NULL, "METHOD"		, _TL("Method"),
+		"", "METHOD"	, _TL("Method"),
 		_TL(""),
-		CSG_String::Format(SG_T("%s|%s|%s|"),
+		CSG_String::Format("%s|%s|%s",
 			_TL("noise variance given as absolute value"),
 			_TL("noise variance given relative to mean standard deviation"),
 			_TL("original calculation (Ringeler)")
@@ -278,131 +271,108 @@ CFilter_Multi_Dir_Lee::CFilter_Multi_Dir_Lee(void)
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 bool CFilter_Multi_Dir_Lee::On_Execute(void)
 {
-	bool	bResult	= false, bWeighted;
+	m_pInput		= Parameters("INPUT" )->asGrid();
+	m_pFiltered		= Parameters("RESULT")->asGrid();
+	m_pStdDev		= Parameters("STDDEV")->asGrid();
+	m_pDirection	= Parameters("DIR"   )->asGrid();
 
-	m_pInput		= Parameters("INPUT")		->asGrid();
-	m_pFiltered		= Parameters("RESULT")		->asGrid();
-	m_pStdDev		= Parameters("STDDEV")		->asGrid();
-	m_pDirection	= Parameters("DIR")			->asGrid();
-	bWeighted		= Parameters("WEIGHTED")	->asBool();
+	if( m_pFiltered  ) m_pFiltered ->Set_Name("%s [%s]", m_pInput->Get_Name(), _TL("Lee Filter"));
+	if( m_pStdDev    ) m_pStdDev   ->Set_Name("%s [%s]", m_pInput->Get_Name(), _TL("Lee Filter - Standard Deviation"));
+	if( m_pDirection ) m_pDirection->Set_Name("%s [%s]", m_pInput->Get_Name(), _TL("Lee Filter - Direction"));
 
 	switch( Parameters("METHOD")->asInt() )
 	{
-	case 0:	bResult	= Get_Filter(bWeighted, true);	break;
-	case 1:	bResult	= Get_Filter(bWeighted, false);	break;
-	case 2:	bResult	= Get_Filter_Ringeler();		break;
+	default: return( Get_Filter( true) );
+	case  1: return( Get_Filter(false) );
+
+	case  2: return( Get_Filter_Ringeler() );	// obsolete?!
 	}
-
-	m_pFiltered->Set_Name(CSG_String::Format(SG_T("%s [%s]"), m_pInput->Get_Name(), _TL("Lee Filter")));
-
-	if( m_pStdDev )
-	{
-		m_pStdDev		->Set_Name(CSG_String::Format(SG_T("%s [%s]"), m_pInput->Get_Name(), _TL("Lee Filter - Standard Deviation")));
-	}
-
-	if( m_pDirection )
-	{
-		m_pDirection	->Set_Name(CSG_String::Format(SG_T("%s [%s]"), m_pInput->Get_Name(), _TL("Lee Filter - Direction")));
-	}
-
-	return( bResult );
 }
 
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-bool CFilter_Multi_Dir_Lee::Get_Filter(bool bWeighted, bool bAbsolute)
+bool CFilter_Multi_Dir_Lee::Get_Filter(bool bAbsolute)
 {
-	int		x, y, ix, iy, k, kx, ky, Best_Direction;
-	double	Count, Mean, StdDev, Variance, Best_Mean, Best_StdDev, Noise, Noise2;
+	bool	bWeighted	= Parameters("WEIGHTED")->asBool();
 
-	if( bAbsolute )
+	double	Noise	= Parameters("NOISE_ABS")->asDouble();
+
+	CSG_Grid	Temp;
+
+	if( !bAbsolute && m_pStdDev == NULL )
 	{
-		Noise	= Parameters("NOISE_ABS")->asDouble();
-		Noise2	= Noise*Noise;
-	}
-	else if( m_pStdDev == NULL )
-	{
-		Parameters("STDDEV")->Set_Value(m_pStdDev = SG_Create_Grid(*Get_System(), SG_DATATYPE_Float));
+		m_pStdDev	= &Temp; Temp.Create(Get_System());
 	}
 
 	//-----------------------------------------------------
-	for(y=0; y<Get_NY() && Set_Progress(y); y++)
+	for(int y=0; y<Get_NY() && Set_Progress(y); y++)
 	{
-		for(x=0; x<Get_NX(); x++)
+		#pragma omp parallel for
+		for(int x=0; x<Get_NX(); x++)
 		{
 			if( m_pInput->is_NoData(x, y) )
 			{
-				m_pFiltered	->Set_NoData(x, y);
-				if( m_pStdDev )		m_pStdDev		->Set_NoData(x, y);
-				if( m_pDirection )	m_pDirection	->Set_NoData(x, y);
+				if( m_pFiltered  ) m_pFiltered ->Set_NoData(x, y);
+				if( m_pStdDev    ) m_pStdDev   ->Set_NoData(x, y);
+				if( m_pDirection ) m_pDirection->Set_NoData(x, y);
 			}
 			else
 			{
-				//-----------------------------------------
-				for(k=0; k<16; k++)
-				{
-					Variance	= Mean	= Count	= 0;
+				int		Dir;
+				double	Mean, StdDev;
 
-					for(ky=0, iy=y-4; ky<9; iy++, ky++)
+				for(int k=0; k<16; k++)
+				{
+					CSG_Simple_Statistics	s;
+
+					for(int ky=0, iy=y-4; ky<9; iy++, ky++)
 					{
-						for(kx=0, ix=x-4; kx<9; ix++, kx++)
+						for(int kx=0, ix=x-4; kx<9; ix++, kx++)
 						{
 							if( m_pInput->is_InGrid(ix, iy) && Filter_Directions[k][ky][kx] > 0.0 )
 							{
-								double	w	 = bWeighted ? Filter_Directions[k][ky][kx] : 1.0;
-								double	z	 = m_pInput->asDouble(ix, iy);
-								Mean		+= w * z;
-								Variance	+= w * z*z;
-								Count		+= w;
+								s.Add_Value(m_pInput->asDouble(ix, iy), bWeighted ? Filter_Directions[k][ky][kx] : 1.0);
 							}
 						}
 					}
 
-					Mean		= Mean     / Count;
-					Variance	= Variance / Count - Mean*Mean;
-					StdDev		= sqrt(Variance);
-
-					if( k == 0 || StdDev < Best_StdDev )
+					if( k == 0 || StdDev > s.Get_StdDev() )
 					{
-						Best_StdDev		= StdDev;
-						Best_Mean		= Mean;
-						Best_Direction	= k;
+						Dir		= k;
+						Mean	= s.Get_Mean  ();
+						StdDev	= s.Get_StdDev();
 					}
 				}
 
 				//-----------------------------------------
-				if( bAbsolute && Best_StdDev > Noise )
+				if( bAbsolute && StdDev > Noise )
 				{
-					double	b	= Best_StdDev*Best_StdDev;
+					double	b	= StdDev*StdDev;
 
-					b	= (b - Noise2) / b;
+					b	= (b - Noise*Noise) / b;
 
-					m_pFiltered->Set_Value(x, y, m_pInput->asDouble(x, y) * b + (1.0 - b) * Best_Mean);
+					m_pFiltered->Set_Value(x, y, m_pInput->asDouble(x, y) * b + (1.0 - b) * Mean);
 				}
-				else if( Best_StdDev > 0.0 )
+				else if( StdDev > 0.0 )
 				{
-					m_pFiltered->Set_Value(x, y, Best_Mean);
+					m_pFiltered->Set_Value(x, y, Mean);
 				}
 				else
 				{
 					m_pFiltered->Set_Value(x, y, m_pInput->asDouble(x, y));
 				}
 
-				if( m_pStdDev )		m_pStdDev		->Set_Value(x, y, Best_StdDev);
-				if( m_pDirection )	m_pDirection	->Set_Value(x, y, Best_Direction);
+				if( m_pStdDev    ) m_pStdDev   ->Set_Value(x, y, StdDev);
+				if( m_pDirection ) m_pDirection->Set_Value(x, y, Dir   );
 			}
 		}
 	}
@@ -411,19 +381,19 @@ bool CFilter_Multi_Dir_Lee::Get_Filter(bool bWeighted, bool bAbsolute)
 	if( !bAbsolute )
 	{
 		Noise	= Parameters("NOISE_REL")->asDouble() * m_pStdDev->Get_Mean();
-		Noise2	= Noise*Noise;
 
-		for(y=0; y<Get_NY() && Set_Progress(y); y++)
+		#pragma omp parallel for
+		for(sLong i=0; i<Get_NCells(); i++)
 		{
-			for(x=0; x<Get_NX(); x++)
+			if( !m_pInput->is_NoData(i) )
 			{
-				if( !m_pInput->is_NoData(x, y) && (Best_StdDev = m_pStdDev->asDouble(x, y)) > Noise )
+				double	b	= m_pStdDev->asDouble(i);
+			
+				if( b > Noise )
 				{
-					double	b	= Best_StdDev*Best_StdDev;
+					b	= (b*b - Noise*Noise) / b*b;
 
-					b	= (b - Noise2) / b;
-
-					m_pFiltered->Set_Value(x, y, m_pInput->asDouble(x, y) * b + (1.0 - b) * m_pFiltered->asDouble(x, y));
+					m_pFiltered->Set_Value(i, m_pInput->asDouble(i) * b + (1. - b) * m_pFiltered->asDouble(i));
 				}
 			}
 		}
