@@ -105,12 +105,12 @@ CGridding_Spline_Base::CGridding_Spline_Base(bool bGridPoints)
 //---------------------------------------------------------
 int CGridding_Spline_Base::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
-	if( !SG_STR_CMP(pParameter->Get_Identifier(), "SHAPES") )
+	if( pParameter->Cmp_Identifier("SHAPES") )
 	{
 		m_Grid_Target.Set_User_Defined(pParameters, pParameter->asShapes());
 	}
 
-	if( !SG_STR_CMP(pParameter->Get_Identifier(), "GRID") && pParameter->asGrid() )
+	if( pParameter->Cmp_Identifier("GRID") && pParameter->asGrid() )
 	{
 		m_Grid_Target.Set_User_Defined(pParameters, pParameter->asGrid()->Get_System());
 	}
@@ -163,7 +163,7 @@ bool CGridding_Spline_Base::_Get_Grid(void)
 			return( false );
 		}
 
-		m_pGrid->Set_Name(CSG_String::Format("%s [%s]", pPoints->Get_Name(), Get_Name().c_str()));
+		m_pGrid->Set_Name("%s [%s]", pPoints->Get_Name(), Get_Name().c_str());
 	}
 
 	//-----------------------------------------------------
@@ -176,7 +176,7 @@ bool CGridding_Spline_Base::_Get_Grid(void)
 			return( false );
 		}
 
-		m_pGrid->Set_Name(CSG_String::Format("%s.%s [%s]", pPoints->Get_Name(), Parameters("FIELD")->asString(), Get_Name().c_str()));
+		m_pGrid->Set_Name("%s.%s [%s]", pPoints->Get_Name(), Parameters("FIELD")->asString(), Get_Name().c_str());
 	}
 
 	//-----------------------------------------------------
