@@ -105,7 +105,7 @@ CMBASpline_for_Categories::CMBASpline_for_Categories(void)
 //---------------------------------------------------------
 int CMBASpline_for_Categories::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
-	if( !SG_STR_CMP(pParameter->Get_Identifier(), "POINTS") )
+	if( pParameter->Cmp_Identifier("POINTS") )
 	{
 		m_Grid_Target.Set_User_Defined(pParameters, pParameter->asShapes());
 	}
@@ -185,8 +185,8 @@ bool CMBASpline_for_Categories::On_Execute(void)
 	}
 
 	//-----------------------------------------------------
-	pGrid->Set_Name(CSG_String::Format("%s"     , Points.Get_Field_Name(0)));
-	pProp->Set_Name(CSG_String::Format("%s [%s]", Points.Get_Field_Name(0), _TL("Propability")));
+	pGrid->Set_Name("%s"     , Points.Get_Field_Name(0));
+	pProp->Set_Name("%s [%s]", Points.Get_Field_Name(0), _TL("Propability"));
 
 	pProp->Assign(0.0);
 	pProp->Set_NoData_Value(0.0);
@@ -196,7 +196,7 @@ bool CMBASpline_for_Categories::On_Execute(void)
 	//-----------------------------------------------------
 	for(int i=0; i<nCategories; i++)
 	{
-		Process_Set_Text(CSG_String::Format("%s: %s", _TL("processing"), Points.Get_Field_Name(1 + i)));
+		Process_Set_Text("%s: %s", _TL("processing"), Points.Get_Field_Name(1 + i));
 
 		SG_UI_Progress_Lock(true);
 
