@@ -85,25 +85,25 @@ CSG_Grid_System Fit_Extent(const CSG_Grid_System &System, const CSG_Rect &Extent
 }
 
 //---------------------------------------------------------
-void Fit_Extent(CSG_Parameters *pParameters, CSG_Parameter *pParameter, CSG_Grid_System *pSystem)
+void Fit_Extent(CSG_Parameters *pParameters, CSG_Parameter *pParameter, const CSG_Grid_System &_System)
 {
-	if( pSystem && pSystem->is_Valid() )
+	if( _System.is_Valid() )
 	{
-		CSG_Grid_System	System(Fit_Extent(*pSystem, CSG_Rect(
+		CSG_Grid_System	System(Fit_Extent(_System, CSG_Rect(
 			pParameters->Get_Parameter("XMIN")->asDouble(),
 			pParameters->Get_Parameter("YMIN")->asDouble(),
 			pParameters->Get_Parameter("XMAX")->asDouble(),
 			pParameters->Get_Parameter("YMAX")->asDouble()
 		)));
 
-		if( !SG_STR_CMP(pParameter->Get_Identifier(), "NX") )
+		if( pParameter->Cmp_Identifier("NX") )
 		{
 			System.Assign(System.Get_Cellsize(), System.Get_XMin(), System.Get_YMin(),
 				pParameters->Get_Parameter("NX")->asInt(), System.Get_NY()
 			);
 		}
 
-		if( !SG_STR_CMP(pParameter->Get_Identifier(), "NY") )
+		if( pParameter->Cmp_Identifier("NY") )
 		{
 			System.Assign(System.Get_Cellsize(), System.Get_XMin(), System.Get_YMin(),
 				System.Get_NX(), pParameters->Get_Parameter("NY")->asInt()
@@ -179,7 +179,7 @@ CGrid_Clip_Interactive::CGrid_Clip_Interactive(void)
 //---------------------------------------------------------
 int CGrid_Clip_Interactive::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
-	if( is_Executing() && !SG_STR_CMP(pParameters->Get_Identifier(), "EXTENT") )
+	if( is_Executing() && pParameters->Cmp_Identifier("EXTENT") )
 	{
 		Fit_Extent(pParameters, pParameter, Get_System());
 	}
@@ -229,19 +229,19 @@ bool CGrid_Clip_Interactive::On_Execute_Position(CSG_Point ptWorld, TSG_Tool_Int
 			m_bDown		= false;
 			ptWorld		= ptWorld;
 
-			CSG_Grid_System	System	= Fit_Extent(*Get_System(), CSG_Rect(
+			CSG_Grid_System	System	= Fit_Extent(Get_System(), CSG_Rect(
 				m_ptDown.Get_X(), m_ptDown.Get_Y(), ptWorld.Get_X(), ptWorld.Get_Y()
 			));
 
 			CSG_Parameters	*pParameters	= Get_Parameters("EXTENT");
 
 			pParameters->Set_Callback(false);
-			pParameters->Get("XMIN")->Set_Value(System.Get_XMin());
-			pParameters->Get("XMAX")->Set_Value(System.Get_XMax());
-			pParameters->Get("YMIN")->Set_Value(System.Get_YMin());
-			pParameters->Get("YMAX")->Set_Value(System.Get_YMax());
-			pParameters->Get("NX"  )->Set_Value(System.Get_NX  ());
-			pParameters->Get("NY"  )->Set_Value(System.Get_NY  ());
+			(*pParameters)("XMIN")->Set_Value(System.Get_XMin());
+			(*pParameters)("XMAX")->Set_Value(System.Get_XMax());
+			(*pParameters)("YMIN")->Set_Value(System.Get_YMin());
+			(*pParameters)("YMAX")->Set_Value(System.Get_YMax());
+			(*pParameters)("NX"  )->Set_Value(System.Get_NX  ());
+			(*pParameters)("NY"  )->Set_Value(System.Get_NY  ());
 			pParameters->Set_Callback(true);
 
 			if( !Dlg_Parameters(pParameters, _TL("Clip to Extent")) )
@@ -249,11 +249,11 @@ bool CGrid_Clip_Interactive::On_Execute_Position(CSG_Point ptWorld, TSG_Tool_Int
 				return( false );
 			}
 
-			System	= Fit_Extent(*Get_System(), CSG_Rect(
-				pParameters->Get("XMIN")->asDouble(),
-				pParameters->Get("YMIN")->asDouble(),
-				pParameters->Get("XMAX")->asDouble(),
-				pParameters->Get("YMAX")->asDouble()
+			System	= Fit_Extent(Get_System(), CSG_Rect(
+				(*pParameters)("XMIN")->asDouble(),
+				(*pParameters)("YMIN")->asDouble(),
+				(*pParameters)("XMAX")->asDouble(),
+				(*pParameters)("YMAX")->asDouble()
 			));
 
 			if( !System.is_Valid() )
@@ -362,7 +362,7 @@ CGrid_Clip::CGrid_Clip(void)
 	Parameters.Add_Choice("",
 		"EXTENT"	, _TL("Extent"),
 		_TL(""),
-		CSG_String::Format("%s|%s|%s|%s|",
+		CSG_String::Format("%s|%s|%s|%s",
 			_TL("user defined"),
 			_TL("grid system"),
 			_TL("shapes extent"),
@@ -382,11 +382,17 @@ CGrid_Clip::CGrid_Clip(void)
 	);
 
 	Parameters.Add_Shapes("EXTENT",
-		"POLYGONS"	, _TL("Polygon"),
+		"POLYGONS"	, _TL("Polygons"),
 		_TL(""),
 		PARAMETER_INPUT, SHAPE_TYPE_Polygon
 	);
 
+	Parameters.Add_Bool("POLYGONS",
+		"INTERIOR"	, _TL("Interior"),
+		_TL("Clip those cells that are covered by the polygons instead of those that are not."),
+		false
+	);
+
 	Parameters.Add_Double("EXTENT", "XMIN", _TL("Left"   ), _TL(""));
 	Parameters.Add_Double("EXTENT", "XMAX", _TL("Right"  ), _TL(""));
 	Parameters.Add_Double("EXTENT", "YMIN", _TL("Bottom" ), _TL(""));
@@ -409,17 +415,20 @@ CGrid_Clip::CGrid_Clip(void)
 //---------------------------------------------------------
 int CGrid_Clip::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
-	CSG_Grid_System	*pSystem	= pParameters->Get_Parameter("PARAMETERS_GRID_SYSTEM")->asGrid_System();
+//	CSG_Grid_System	*pSystem	= pParameters->Get_Parameter("PARAMETERS_GRID_SYSTEM")->asGrid_System();
+//	if( pParameter->Cmp_Identifier("PARAMETERS_GRID_SYSTEM") && pSystem && pSystem->is_Valid() )
 
-	if( !SG_STR_CMP(pParameter->Get_Identifier(), "PARAMETERS_GRID_SYSTEM") && pSystem && pSystem->is_Valid() )
+	CSG_Grid_System	*pSystem	= pParameters->Get_Grid_System();
+
+	if( pParameter->asGrid_System() == pSystem && pSystem && pSystem->is_Valid() )
 	{
-		pParameters->Get("XMIN")->Set_Value(pSystem->Get_XMin());
-		pParameters->Get("XMAX")->Set_Value(pSystem->Get_XMax());
-		pParameters->Get("YMIN")->Set_Value(pSystem->Get_YMin());
-		pParameters->Get("YMAX")->Set_Value(pSystem->Get_YMax());
+		pParameters->Set_Parameter("XMIN", pSystem->Get_XMin());
+		pParameters->Set_Parameter("XMAX", pSystem->Get_XMax());
+		pParameters->Set_Parameter("YMIN", pSystem->Get_YMin());
+		pParameters->Set_Parameter("YMAX", pSystem->Get_YMax());
 	}
 
-	Fit_Extent(pParameters, pParameter, pSystem);
+	Fit_Extent(pParameters, pParameter, *pSystem);
 
 	return( CSG_Tool_Grid::On_Parameter_Changed(pParameters, pParameter) );
 }
@@ -427,7 +436,7 @@ int CGrid_Clip::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter
 //---------------------------------------------------------
 int CGrid_Clip::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
-	if( !SG_STR_CMP(pParameter->Get_Identifier(), "EXTENT") )
+	if( pParameter->Cmp_Identifier("EXTENT") )
 	{
 		pParameters->Set_Enabled("XMIN"      , pParameter->asInt() == 0);
 		pParameters->Set_Enabled("XMAX"      , pParameter->asInt() == 0);
@@ -469,11 +478,14 @@ bool CGrid_Clip::On_Execute(void)
 		break;
 
 	case 2:	// shapes extent
-		Extent.Assign(Parameters("SHAPES"  )->asShapes()->Get_Extent());
+		Extent.Assign(Parameters("SHAPES")->asShapes()->Get_Extent());
 		break;
 
 	case 3:	// polygon
-		Extent.Assign(Parameters("POLYGONS")->asShapes()->Get_Extent());
+		Extent.Assign(Parameters("INTERIOR")->asBool()
+			? Get_System().Get_Extent()
+			: Parameters("POLYGONS")->asShapes()->Get_Extent()
+		);
 		break;
 	}
 
@@ -483,7 +495,7 @@ bool CGrid_Clip::On_Execute(void)
 	}
 
 	//--------------------------------------------------------
-	CSG_Grid_System	System	= Fit_Extent(*Get_System(), Extent);
+	CSG_Grid_System	System	= Fit_Extent(Get_System(), Extent);
 
 	if( !System.is_Valid() )
 	{
@@ -604,6 +616,13 @@ bool CGrid_Clip::Get_Mask(CSG_Grid &Mask, CSG_Grid_System &System, CSG_Shapes *p
 
 	Mask.Set_NoData_Value(0);
 
+	bool	bInterior	= Parameters("INTERIOR")->asBool();
+
+	if( bInterior )
+	{
+		Mask.Assign(1.);
+	}
+
 	//-----------------------------------------------------
 	for(int i=0; i<pPolygons->Get_Count() && Set_Progress(i, pPolygons->Get_Count()); i++)
 	{
@@ -668,7 +687,7 @@ bool CGrid_Clip::Get_Mask(CSG_Grid &Mask, CSG_Grid_System &System, CSG_Shapes *p
 
 					if( Fill )
 					{
-						Mask.Set_Value(x, y, 1);
+						Mask.Set_Value(x, y, bInterior ? 0 : 1);
 					}
 				}
 
