@@ -173,7 +173,7 @@ bool CGrid_Gaps_Spline_Fill::On_Execute(void)
 	{
 		m_pGrid->Assign(Parameters("GRID")->asGrid());
 
-		m_pGrid->Set_Name(CSG_String::Format(SG_T("%s [%s]"), Parameters("GRID")->asGrid()->Get_Name(), _TL("no gaps")));
+		m_pGrid->Set_Name(SG_T("%s [%s]"), Parameters("GRID")->asGrid()->Get_Name(), _TL("no gaps"));
 	}
 
 	if( m_nGapCells_Max == 0 )
@@ -187,7 +187,7 @@ bool CGrid_Gaps_Spline_Fill::On_Execute(void)
 	}
 
 	//-----------------------------------------------------
-	m_Gaps.Create(*Get_System(), SG_DATATYPE_Int);
+	m_Gaps.Create(Get_System(), SG_DATATYPE_Int);
 	m_Gaps.Assign(0.0);
 	m_nGaps	= 0;
 
