@@ -143,7 +143,7 @@ CGrid_Value_Replace::CGrid_Value_Replace(void)
 //---------------------------------------------------------
 int CGrid_Value_Replace::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
-	if( !SG_STR_CMP(pParameter->Get_Identifier(), "METHOD") )
+	if( pParameter->Cmp_Identifier("METHOD") )
 	{
 		pParameters->Set_Enabled("IDENTITY", pParameter->asInt() == 0);
 		pParameters->Set_Enabled("RANGE"   , pParameter->asInt() == 1);
@@ -174,7 +174,7 @@ bool CGrid_Value_Replace::On_Execute(void)
 
 		DataObject_Set_Parameters(pGrid, Parameters("INPUT")->asGrid());
 
-		pGrid->Set_Name(CSG_String::Format("%s [%s]", Parameters("INPUT")->asGrid()->Get_Name(), _TL("Changed")));
+		pGrid->Set_Name("%s [%s]", Parameters("INPUT")->asGrid()->Get_Name(), _TL("Changed"));
 	}
 
 	//-----------------------------------------------------
