@@ -105,7 +105,12 @@ protected:
 	int							Get_Feature_Count		(void)	{	return( m_pFeatures->Get_Grid_Count() );	}
 	int							Get_Class_Count			(void)	{	return( m_Classes   .Get_Count     () );	}
 
-	virtual Ptr<StatModel>		Get_Model				(void)	= 0;
+	bool						Check_Model_File		(const CSG_String &File);
+
+	virtual const char *		Get_Model_ID			(void)	const	= 0;
+
+	virtual Ptr<StatModel>		Get_Model				(const CSG_String &File)	= 0;
+	virtual Ptr<StatModel>		Get_Model				(void)						= 0;
 	virtual Ptr<TrainData>		Get_Training			(const CSG_Matrix &Data);
 
 	virtual double				Get_Probability			(const Ptr<StatModel> &Model, const Mat &Sample)	{	return( 0.0 );	}
@@ -148,6 +153,9 @@ public:
 
 protected:
 
+	virtual const char *		Get_Model_ID			(void)	const	{	return( "nbayes" );	}
+
+	virtual Ptr<StatModel>		Get_Model				(const CSG_String &File);
 	virtual Ptr<StatModel>		Get_Model				(void);
 
 	virtual double				Get_Probability			(const Ptr<StatModel> &Model, const Mat &Sample);
@@ -170,6 +178,9 @@ protected:
 
 	virtual int					On_Parameters_Enable	(CSG_Parameters *pParameters, CSG_Parameter *pParameter);
 
+	virtual const char *		Get_Model_ID			(void)	const	{	return( "knn" );	}
+
+	virtual Ptr<StatModel>		Get_Model				(const CSG_String &File);
 	virtual Ptr<StatModel>		Get_Model				(void);
 
 };
@@ -190,6 +201,9 @@ protected:
 
 	virtual int					On_Parameters_Enable	(CSG_Parameters *pParameters, CSG_Parameter *pParameter);
 
+	virtual const char *		Get_Model_ID			(void)	const	{	return( "svm" );	}
+
+	virtual Ptr<StatModel>		Get_Model				(const CSG_String &File);
 	virtual Ptr<StatModel>		Get_Model				(void);
 
 };
@@ -208,8 +222,12 @@ public:
 
 protected:
 
+	virtual const char *		Get_Model_ID			(void)	const	{	return( "dtree" );	}
+
+	virtual Ptr<StatModel>		Get_Model				(const CSG_String &File);
 	virtual Ptr<StatModel>		Get_Model				(void);
 
+	virtual Ptr<DTrees>			Get_Trees				(const CSG_String &File);
 	virtual Ptr<DTrees>			Get_Trees				(void);
 
 };
@@ -223,6 +241,9 @@ public:
 
 protected:
 
+	virtual const char *		Get_Model_ID			(void)	const	{	return( "boost" );	}
+
+	virtual Ptr<DTrees>			Get_Trees				(const CSG_String &File);
 	virtual Ptr<DTrees>			Get_Trees				(void);
 
 };
@@ -236,6 +257,9 @@ public:
 
 protected:
 
+	virtual const char *		Get_Model_ID			(void)	const	{	return( "rtrees" );	}
+
+	virtual Ptr<DTrees>			Get_Trees				(const CSG_String &File);
 	virtual Ptr<DTrees>			Get_Trees				(void);
 
 };
@@ -256,6 +280,9 @@ protected:
 
 	virtual int					On_Parameters_Enable	(CSG_Parameters *pParameters, CSG_Parameter *pParameter);
 
+	virtual const char *		Get_Model_ID			(void)	const	{	return( "ann" );	}
+
+	virtual Ptr<StatModel>		Get_Model				(const CSG_String &File);
 	virtual Ptr<StatModel>		Get_Model				(void);
 
 	virtual Ptr<TrainData>		Get_Training			(const CSG_Matrix &Data);
