@@ -192,17 +192,17 @@ bool CWatershed_Segmentation::On_Execute(void)
 	//-----------------------------------------------------
 	m_pSeeds->Create(SHAPE_TYPE_Point, CSG_String::Format(SG_T("%s [%s]"), m_pGrid->Get_Name(), _TL("Seeds")));
 
-	m_pSeeds->Add_Field(SG_T("XCELL")	, SG_DATATYPE_Int);		// SEED_X
-	m_pSeeds->Add_Field(SG_T("YCELL")	, SG_DATATYPE_Int);		// SEED_Y
-	m_pSeeds->Add_Field(SG_T("VALUE")	, SG_DATATYPE_Double);	// SEED_Z
-	m_pSeeds->Add_Field(SG_T("ID")		, SG_DATATYPE_Int);		// SEED_ID
-	m_pSeeds->Add_Field(SG_T("ID_JOIN")	, SG_DATATYPE_Int);		// SEED_JOIN
+	m_pSeeds->Add_Field("XCELL"  , SG_DATATYPE_Int   );	// SEED_X
+	m_pSeeds->Add_Field("YCELL"  , SG_DATATYPE_Int   );	// SEED_Y
+	m_pSeeds->Add_Field("VALUE"  , SG_DATATYPE_Double);	// SEED_Z
+	m_pSeeds->Add_Field("ID"     , SG_DATATYPE_Int   );	// SEED_ID
+	m_pSeeds->Add_Field("ID_JOIN", SG_DATATYPE_Int   );	// SEED_JOIN
 
 	//-----------------------------------------------------
-	m_pSegments->Set_Name(CSG_String::Format(SG_T("%s [%s]"), m_pGrid->Get_Name(), _TL("Segments")));
+	m_pSegments->Set_Name("%s [%s]", m_pGrid->Get_Name(), _TL("Segments"));
 	m_pSegments->Set_NoData_Value(-999999.0);
 
-	m_Dir.Create(*Get_System(), SG_DATATYPE_Char);
+	m_Dir.Create(Get_System(), SG_DATATYPE_Char);
 
 	//-----------------------------------------------------
 	if( !Get_Seeds() )
@@ -297,7 +297,7 @@ bool CWatershed_Segmentation::Get_Seeds(void)
 
 					CSG_Shape	*pSeed	= m_pSeeds->Add_Shape();
 
-					pSeed->Set_Point(Get_System()->Get_Grid_to_World(x, y), 0);
+					pSeed->Set_Point(Get_System().Get_Grid_to_World(x, y), 0);
 
 					pSeed->Set_Value(SEED_X		, x);
 					pSeed->Set_Value(SEED_Y		, y);
