@@ -91,7 +91,7 @@ CLandsat_Scene_Import::CLandsat_Scene_Import(void)
 
 	//-----------------------------------------------------
 	Parameters.Add_FilePath("",
-		"METAFILE"	, _TL("Metadata File"),
+		"METAFILE"		, _TL("Metadata File"),
 		_TL(""),
 		CSG_String::Format("%s|*.met;*.txt|%s (*.met)|*.met|%s (*.txt)|*.txt|%s|*.*",
 			_TL("Recognized Files"),
@@ -102,43 +102,71 @@ CLandsat_Scene_Import::CLandsat_Scene_Import(void)
 	);
 
 	Parameters.Add_Grid_List("",
-		"BANDS"		, _TL("Bands"),
+		"BANDS"			, _TL("Bands"),
 		_TL(""),
 		PARAMETER_OUTPUT
 	);
 
 	Parameters.Add_Table("",
-		"BAND_INFO"	, _TL("Band Info"),
+		"BAND_INFO"		, _TL("Band Info"),
 		_TL(""),
 		PARAMETER_OUTPUT_OPTIONAL
 	);
 
 	Parameters.Add_Bool("",
-		"MULTI2GRIDS", _TL("Multispectral Bands as Grid Collection"),
+		"MULTI2GRIDS"	, _TL("Multispectral Bands as Grid Collection"),
 		_TL(""),
 		true
 	);
 
 	Parameters.Add_Bool("",
-		"SKIP_PAN"	, _TL("Skip Panchromatic Band"),
+		"SKIP_PAN"		, _TL("Skip Panchromatic Band"),
 		_TL(""),
 		true
 	);
 
-	Parameters.Add_Choice(NULL,
-		"PROJECTION", _TL("Coordinate System"),
+	Parameters.Add_Choice("",
+		"CALIBRATION"	, _TL("Radiometric Calibration"),
 		_TL(""),
-		CSG_String::Format("%s|%s|%s|",
+		CSG_String::Format("%s|%s|%s",
+			_TL("none"),
+			_TL("radiance"),
+			_TL("reflectance")
+		), 0
+	);
+
+	Parameters.Add_Choice("CALIBRATION",
+		"DATA_TYPE"		, _TL("Output Data Type"),
+		_TL(""),
+		CSG_String::Format("%s|%s",
+			_TL("integers with scaling"),
+			_TL("floating point numbers")
+		), 0
+	);
+
+	Parameters.Add_Choice("CALIBRATION",
+		"TEMP_UNIT"		, _TL("Temperature Unit"),
+		_TL(""),
+		CSG_String::Format("%s|%s",
+			_TL("Kelvin"),
+			_TL("Celsius")
+		), 0
+	);
+
+	Parameters.Add_Choice("",
+		"PROJECTION"	, _TL("Coordinate System"),
+		_TL(""),
+		CSG_String::Format("%s|%s|%s",
 			_TL("UTM North"),
 			_TL("UTM South"),
 			_TL("Geographic Coordinates")
 		), 0
 	);
 
-	Parameters.Add_Choice(Parameters("PROJECTION"),
-		"RESAMPLING", _TL("Resampling"),
+	Parameters.Add_Choice("PROJECTION",
+		"RESAMPLING"	, _TL("Resampling"),
 		_TL(""),
-		CSG_String::Format("%s|%s|%s|%s|",
+		CSG_String::Format("%s|%s|%s|%s",
 			_TL("Nearest Neighbour"),
 			_TL("Bilinear Interpolation"),
 			_TL("Bicubic Spline Interpolation"),
@@ -155,7 +183,7 @@ CLandsat_Scene_Import::CLandsat_Scene_Import(void)
 //---------------------------------------------------------
 int CLandsat_Scene_Import::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
-	if( !SG_STR_CMP(pParameter->Get_Identifier(), "METAFILE") )
+	if( pParameter->Cmp_Identifier("METAFILE") )
 	{
 		CSG_MetaData	Metadata;
 
@@ -171,7 +199,13 @@ int CLandsat_Scene_Import::On_Parameters_Enable(CSG_Parameters *pParameters, CSG
 		}
 	}
 
-	if( !SG_STR_CMP(pParameter->Get_Identifier(), "PROJECTION") )
+	if( pParameter->Cmp_Identifier("CALIBRATION") )
+	{
+		pParameters->Set_Enabled("DATA_TYPE", pParameter->asInt() != 0);
+		pParameters->Set_Enabled("TEMP_UNIT", pParameter->asInt() == 2);
+	}
+
+	if( pParameter->Cmp_Identifier("PROJECTION") )
 	{
 		pParameters->Set_Enabled("RESAMPLING", pParameter->asInt() == 2);
 	}
@@ -223,12 +257,21 @@ bool CLandsat_Scene_Import::On_Execute(void)
 	}
 
 	//-----------------------------------------------------
-	Parameters("BANDS")->asGridList()->Del_Items();
-
 	CSG_String	Path	= SG_File_Get_Path(Parameters("METAFILE")->asString());
 
 	bool	bSkipPan	= Parameters("SKIP_PAN"   )->asBool();
 	bool	bMultiGrids	= Parameters("MULTI2GRIDS")->asBool();
+	int		Calibration	= Parameters("CALIBRATION")->asInt ();
+
+	double	SunHeight	= -1;
+
+	if( Info_Scene("SUN_ELEVATION") )
+	{
+		SunHeight	= Info_Scene["SUN_ELEVATION"].Get_Content().asDouble();
+	}
+
+	//-----------------------------------------------------
+	Parameters("BANDS")->asGridList()->Del_Items();
 
 	CSG_Grids	*pBands	= NULL;
 
@@ -239,16 +282,35 @@ bool CLandsat_Scene_Import::On_Execute(void)
 			continue;
 		}
 
-		Process_Set_Text(CSG_String::Format("%s: %s", _TL("loading"), File_Bands[i].c_str()));
+		Process_Set_Text("%s: %s", _TL("loading"), File_Bands[i].c_str());
 
 		CSG_Grid	*pBand	= Load_Band(SG_File_Make_Path(Path, File_Bands[i], ""));
 
 		if( pBand )
 		{
+			switch( Calibration )
+			{
+			case  1:
+				{
+					Get_Radiance   (pBand, Info_Bands[i]);
+				}
+				break;
+
+			case  2: if( is_Thermal(Sensor, i) )
+				{
+					Get_Temperature(pBand, Info_Bands[i]);
+				}
+				else
+				{
+					Get_Reflectance(pBand, Info_Bands[i], SunHeight);
+				}
+				break;
+			}
+
 			pBand->Get_MetaData().Add_Child(Info_Scene)->Set_Name("LANDSAT");
 			pBand->Set_Description(Info_Scene.asText());
 
-			if( bMultiGrids && is_Multispectral(Sensor, i) )
+			if( bMultiGrids && is_Multispectral(Sensor, i) && !is_Cirrus(Sensor, i) )
 			{
 				if( pBands == NULL )
 				{
@@ -316,6 +378,18 @@ bool CLandsat_Scene_Import::is_Multispectral(int Sensor, int Band)
 	return( false );
 }
 
+//---------------------------------------------------------
+bool CLandsat_Scene_Import::is_Cirrus(int Sensor, int Band)
+{
+	return( (Sensor == SENSOR_OLI_TIRS && Band == 8) );
+}
+
+//---------------------------------------------------------
+bool CLandsat_Scene_Import::is_Thermal(int Sensor, int Band)
+{
+	return( !is_Panchromatic(Sensor, Band) && !is_Multispectral(Sensor, Band) );
+}
+
 
 ///////////////////////////////////////////////////////////
 //														 //
@@ -377,7 +451,7 @@ bool CLandsat_Scene_Import::Load_Metadata(const CSG_String &Line, CSG_String &Ke
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-enum
+enum EMetadata_Version
 {
 	VERSION_MET	= 0,
 	VERSION_MTL_1,
@@ -432,7 +506,7 @@ struct SBand_Keys
 };
 
 //---------------------------------------------------------
-enum
+enum EBand_Head
 {
 	BAND_HEAD_ID	= 0,
 	BAND_HEAD_NR,
@@ -793,7 +867,7 @@ CSG_Grid * CLandsat_Scene_Import::Load_Band(const CSG_String &File)
 
 		if(	pTool )
 		{
-			Message_Add(CSG_String::Format("\n%s (%s: %s)\n", _TL("re-projection to geographic coordinates"), _TL("original"), pBand->Get_Projection().Get_Name().c_str()), false);
+			Message_Fmt("\n%s (%s: %s)\n", _TL("re-projection to geographic coordinates"), _TL("original"), pBand->Get_Projection().Get_Name().c_str());
 
 			pTool->Settings_Push(NULL);
 
@@ -817,6 +891,190 @@ CSG_Grid * CLandsat_Scene_Import::Load_Band(const CSG_String &File)
 }
 
 
+///////////////////////////////////////////////////////////
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+bool CLandsat_Scene_Import::Get_Float(CSG_Grid *pBand, CSG_Grid &DN)
+{
+	pBand->Create(DN.Get_System(), SG_DATATYPE_Float);
+	pBand->Get_Projection().Create(DN.Get_Projection());
+	pBand->Set_Name        (DN.Get_Name());
+	pBand->Set_Description (DN.Get_Description());
+	pBand->Set_NoData_Value(-1.0);
+
+	return( true );
+}
+
+//---------------------------------------------------------
+bool CLandsat_Scene_Import::Get_Radiance(CSG_Grid *pBand, const CSG_Table_Record &Info_Band)
+{
+	//-----------------------------------------------------
+	double	Offset, Scale, DNmin;
+
+	if( Info_Band.asString("REFLECTANCE_ADD") && Info_Band.asString("REFLECTANCE_MUL") )
+	{
+		DNmin	=  0.0;
+		Offset	=  Info_Band.asDouble("REFLECTANCE_ADD");
+		Scale	=  Info_Band.asDouble("REFLECTANCE_MUL");
+	}
+	else if( Info_Band.asString("L_MIN") && Info_Band.asString("L_MAX") && Info_Band.asString("QCAL_MIN") && Info_Band.asString("QCAL_MAX") )
+	{
+		DNmin	=  Info_Band.asDouble("QCAL_MIN");
+		Offset	=  Info_Band.asDouble("L_MIN");
+		Scale	= (Info_Band.asDouble("L_MAX") - Offset) / (Info_Band.asDouble("QCAL_MAX") - DNmin);
+	}
+	else
+	{
+		SG_UI_Msg_Add_Error(CSG_String::Format("%s: %s", pBand->Get_Name(), _TL("failed to derive radiances")));
+
+		return( false );
+	}
+
+	//-----------------------------------------------------
+	CSG_Grid	DN(*pBand);
+
+	if( Parameters("DATA_TYPE")->asInt() == 1 )
+	{
+		Get_Float(pBand, DN);
+	}
+	else
+	{
+		double	MaxVal	= (pBand->Get_Type() == SG_DATATYPE_Byte ? 256 : 256*256) - 1;
+		pBand->Set_NoData_Value(MaxVal--);
+		pBand->Set_Scaling(1000.0 / MaxVal, 0.0);
+	}
+
+	pBand->Set_Unit("W/(m2*sr*um");
+
+	//-----------------------------------------------------
+	#pragma omp parallel for
+	for(sLong i=0; i<pBand->Get_NCells(); i++)
+	{
+		if( DN.is_NoData(i) )
+		{
+			pBand->Set_NoData(i);
+		}
+		else
+		{
+			pBand->Set_Value(i, Offset + Scale * (DN.asDouble(i) - DNmin));
+		}
+	}
+
+	//-----------------------------------------------------
+	return( true );
+}
+
+//---------------------------------------------------------
+bool CLandsat_Scene_Import::Get_Reflectance(CSG_Grid *pBand, const CSG_Table_Record &Info_Band, double SunHeight)
+{
+	//-----------------------------------------------------
+	double	Offset, Scale;
+
+	if( Info_Band.asString("REFLECTANCE_ADD") && Info_Band.asString("REFLECTANCE_MUL") )
+	{
+		Offset	= Info_Band.asDouble("REFLECTANCE_ADD");
+		Scale	= Info_Band.asDouble("REFLECTANCE_MUL");
+	}
+	else
+	{
+		SG_UI_Msg_Add_Error(CSG_String::Format("%s: %s", pBand->Get_Name(), _TL("failed to derive reflectances")));
+
+		return( false );
+	}
+
+	SunHeight	= sin(SunHeight * M_DEG_TO_RAD);
+
+	//-----------------------------------------------------
+	CSG_Grid	DN(*pBand);
+
+	if( Parameters("DATA_TYPE")->asInt() == 1 )
+	{
+		Get_Float(pBand, DN);
+	}
+	else
+	{
+		double	MaxVal	= (pBand->Get_Type() == SG_DATATYPE_Byte ? 256 : 256*256) - 1;
+		pBand->Set_NoData_Value(MaxVal--);
+		pBand->Set_Scaling(100.0 / MaxVal, 0.0);	// 0 to 100 percent
+	}
+
+	pBand->Set_Unit("Percent");
+
+	//-----------------------------------------------------
+	#pragma omp parallel for
+	for(sLong i=0; i<pBand->Get_NCells(); i++)
+	{
+		if( DN.is_NoData(i) )
+		{
+			pBand->Set_NoData(i);
+		}
+		else
+		{
+			pBand->Set_Value(i, 100.0 * (Offset + Scale * DN.asDouble(i)) / SunHeight);
+		}
+	}
+
+	//-----------------------------------------------------
+	return( true );
+}
+
+//---------------------------------------------------------
+bool CLandsat_Scene_Import::Get_Temperature(CSG_Grid *pBand, const CSG_Table_Record &Info_Band)
+{
+	if( !Info_Band.asString("RADIANCE_ADD") || !Info_Band.asString("RADIANCE_MUL") || !Info_Band.asString("THERMAL_K1") || !Info_Band.asString("THERMAL_K2") )
+	{
+		SG_UI_Msg_Add_Error(CSG_String::Format("%s: %s", pBand->Get_Name(), _TL("failed to derive temperatures")));
+
+		return( false );
+	}
+
+	double	Offset	= Info_Band.asDouble("RADIANCE_ADD");
+	double	Scale	= Info_Band.asDouble("RADIANCE_MUL");
+
+	double	k1		= Info_Band.asDouble("THERMAL_K1");
+	double	k2		= Info_Band.asDouble("THERMAL_K2");
+
+	//-----------------------------------------------------
+	CSG_Grid	DN(*pBand);
+
+	int	Unit	= Parameters("TEMP_UNIT")->asInt();
+
+	if( Parameters("DATA_TYPE")->asInt() == 1 )
+	{
+		Get_Float(pBand, DN);
+	}
+	else
+	{
+		double	MaxVal	= (pBand->Get_Type() == SG_DATATYPE_Byte ? 256 : 256*256) - 1;
+		pBand->Set_NoData_Value(MaxVal--);
+		pBand->Set_Scaling(100.0 / MaxVal, (Unit == 0 ? 273.15 : 0.0) - 40.0);	// -40C to 60C
+	}
+
+	pBand->Set_Unit(Unit == 0 ? "Kelvin" : "Celsius");
+
+	//-----------------------------------------------------
+	#pragma omp parallel for
+	for(sLong i=0; i<pBand->Get_NCells(); i++)
+	{
+		if( DN.is_NoData(i) )
+		{
+			pBand->Set_NoData(i);
+		}
+		else
+		{
+			double	r	= Offset + Scale * DN.asDouble(i);
+
+			pBand->Set_Value(i, k2 / log(1.0 + (k1 / r)) - (Unit == 0 ? 0.0 : 273.15));
+		}
+	}
+
+	//-----------------------------------------------------
+	return( true );
+}
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 //														 //
