@@ -233,8 +233,8 @@ bool CViGrA_FFT::On_Execute(void)
 	//-----------------------------------------------------
 	Copy_ComplexGrid_VIGRA_to_SAGA(*pReal, *pImag, Output, false);
 
-	pReal->Set_Name(CSG_String::Format(SG_T("%s [FFT - %s]"), pInput->Get_Name(), _TL("Real")));
-	pImag->Set_Name(CSG_String::Format(SG_T("%s [FFT - %s]"), pInput->Get_Name(), _TL("Imaginary")));
+	pReal->Set_Name("%s [FFT - %s]", pInput->Get_Name(), _TL("Real"     ));
+	pImag->Set_Name("%s [FFT - %s]", pInput->Get_Name(), _TL("Imaginary"));
 
 	return( true );
 }
@@ -319,7 +319,7 @@ bool CViGrA_FFT_Inverse::On_Execute(void)
 
 	Copy_ComplexGrid_VIGRA_to_SAGA(*pReal, Output, false);
 
-	pReal->Set_Name(CSG_String::Format(SG_T("%s [FFT - %s]"), Get_Name().c_str(), _TL("Real")));
+	pReal->Set_Name("%s [FFT - %s]", Get_Name().c_str(), _TL("Real"));
 
 	return( true );
 }
@@ -381,7 +381,7 @@ bool CViGrA_FFT_Real::On_Execute(void)
 	//-----------------------------------------------------
 	Copy_Grid_VIGRA_to_SAGA(*pOutput, Output, false);
 
-	pOutput->Set_Name(CSG_String::Format(SG_T("%s [%s - %s]"), Get_Name().c_str(), pInput->Get_Name()));
+	pOutput->Set_Name("%s [%s - %s]", Get_Name().c_str(), pInput->Get_Name());
 
 	return( true );
 
@@ -474,7 +474,7 @@ CViGrA_FFT_Filter::CViGrA_FFT_Filter(void)
 //---------------------------------------------------------
 int CViGrA_FFT_Filter::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
-	if( !SG_STR_CMP(pParameter->Get_Identifier(), "FILTER") )
+	if( pParameter->Cmp_Identifier("FILTER") )
 	{
 		pParameters->Get_Parameter("SCALE")->Set_Enabled(pParameter->asInt() == 0);
 		pParameters->Get_Parameter("POWER")->Set_Enabled(pParameter->asInt() == 1);
@@ -501,8 +501,8 @@ bool CViGrA_FFT_Filter::On_Execute(void)
 	Scale		= Parameters("SCALE" )->asDouble();
 	Power		= Parameters("POWER" )->asDouble();
 	Filter		= Parameters("FILTER")->asInt();
-	Range_Min	= Parameters("RANGE" )->asRange()->Get_LoVal();
-	Range_Max	= Parameters("RANGE" )->asRange()->Get_HiVal();
+	Range_Min	= Parameters("RANGE" )->asRange()->Get_Min();
+	Range_Max	= Parameters("RANGE" )->asRange()->Get_Max();
 
 	//-----------------------------------------------------
 	vigra::FImage			Input, Filter_Raw(Get_NX(), Get_NY()), Filter_(Get_NX(), Get_NY());
@@ -549,7 +549,7 @@ bool CViGrA_FFT_Filter::On_Execute(void)
 	//-----------------------------------------------------
 	Copy_ComplexGrid_VIGRA_to_SAGA(*pOutput, Output, false);
 
-	pOutput->Set_Name(CSG_String::Format(SG_T("%s [FFT %s]"), pInput->Get_Name(), _TL("Filter")));
+	pOutput->Set_Name("%s [FFT %s]", pInput->Get_Name(), _TL("Filter"));
 
 	return( true );
 }
