@@ -148,7 +148,7 @@ bool CViGrA_Morphology::On_Execute(void)
 	//-----------------------------------------------------
 	if( bRescale )
 	{
-		Rescaled.Create(*Get_System(), SG_DATATYPE_Byte);
+		Rescaled.Create(Get_System(), SG_DATATYPE_Byte);
 
 		for(sLong i=0; i<Get_NCells() && Set_Progress_NCells(i); i++)
 		{
@@ -185,7 +185,7 @@ bool CViGrA_Morphology::On_Execute(void)
 	//-----------------------------------------------------
 	Copy_Grid_VIGRA_to_SAGA(*pOutput, Output, false);
 
-	pOutput->Set_Name(CSG_String::Format("%s [%s]", pInput->Get_Name(), Get_Name().c_str()));
+	pOutput->Set_Name("%s [%s]", pInput->Get_Name(), Get_Name().c_str());
 
 	return( true );
 }
