@@ -415,7 +415,7 @@ CViGrA_Random_Forest::CViGrA_Random_Forest(void)
 //---------------------------------------------------------
 int CViGrA_Random_Forest::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
-	if( !SG_STR_CMP(pParameter->Get_Identifier(), "RF_IMPORT") )
+	if( pParameter->Cmp_Identifier("RF_IMPORT") )
 	{
 		bool	bTraining	= !SG_File_Exists(pParameter->asString());
 
@@ -424,12 +424,12 @@ int CViGrA_Random_Forest::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_
 		pParameters->Set_Enabled("IMPORTANCES", bTraining);
 	}
 
-	if( !SG_STR_CMP(pParameter->Get_Identifier(), "DO_MRMR") )
+	if( pParameter->Cmp_Identifier("DO_MRMR") )
 	{
-		pParameters->Get("DO_MRMR")->Set_Children_Enabled(pParameter->asBool());
+		(*pParameters)("DO_MRMR")->Set_Children_Enabled(pParameter->asBool());
 	}
 
-	if( pParameters->Get("DO_MRMR")->asBool() )
+	if( (*pParameters)("DO_MRMR")->asBool() )
 	{
 		CSG_mRMR::Parameters_Enable(pParameters, pParameter);
 	}
@@ -459,7 +459,7 @@ bool CViGrA_Random_Forest::On_Execute(void)
 	{
 		if( pFeatures->Get_Grid(i)->Get_Range() <= 0.0 )
 		{
-			Message_Add(CSG_String::Format("%s: %s", _TL("grid has been dropped"), pFeatures->Get_Grid(i)->Get_Name()));
+			Message_Fmt("\n%s: %s", _TL("grid has been dropped"), pFeatures->Get_Grid(i)->Get_Name());
 		}
 		else
 		{
@@ -675,9 +675,9 @@ bool CViGrA_Random_Forest::Get_Training(CSG_Matrix &Data, CSG_Table &Classes)
 			{
 				bSelected[j = Selector.Get_Index(i) - 1]	= 1;
 
-				Message_Add(CSG_String::Format(SG_T("\n%02d. %s (%s: %f)"),
+				Message_Fmt("\n%02d. %s (%s: %f)",
 					i + 1, m_pFeatures[j]->Get_Name(), _TL("Score"), Selector.Get_Score(i)
-				), false);
+				);
 			}
 
 			Message_Add("\n", false);
@@ -709,16 +709,16 @@ int CViGrA_Random_Forest::Get_Training(CSG_Matrix &Data, int ID, CSG_Shape_Polyg
 {
 	int	Count	= 0;
 
-	int	xMin	= Get_System()->Get_xWorld_to_Grid(pArea->Get_Extent().Get_XMin());	if( xMin <  0        ) xMin = 0;
-	int	xMax	= Get_System()->Get_xWorld_to_Grid(pArea->Get_Extent().Get_XMax());	if( xMax >= Get_NX() ) xMax = Get_NX() - 1;
-	int	yMin	= Get_System()->Get_yWorld_to_Grid(pArea->Get_Extent().Get_YMin());	if( yMin <  0        ) yMin = 0;
-	int	yMax	= Get_System()->Get_yWorld_to_Grid(pArea->Get_Extent().Get_YMax());	if( yMax >= Get_NY() ) yMax = Get_NY() - 1;
+	int	xMin	= Get_System().Get_xWorld_to_Grid(pArea->Get_Extent().Get_XMin());	if( xMin <  0        ) xMin = 0;
+	int	xMax	= Get_System().Get_xWorld_to_Grid(pArea->Get_Extent().Get_XMax());	if( xMax >= Get_NX() ) xMax = Get_NX() - 1;
+	int	yMin	= Get_System().Get_yWorld_to_Grid(pArea->Get_Extent().Get_YMin());	if( yMin <  0        ) yMin = 0;
+	int	yMax	= Get_System().Get_yWorld_to_Grid(pArea->Get_Extent().Get_YMax());	if( yMax >= Get_NY() ) yMax = Get_NY() - 1;
 
 	for(int y=yMin; y<=yMax; y++)
 	{
 		for(int x=xMin; x<=xMax; x++)
 		{
-			if( pArea->Contains(Get_System()->Get_Grid_to_World(x, y)) )
+			if( pArea->Contains(Get_System().Get_Grid_to_World(x, y)) )
 			{
 				CSG_Vector	z(1 + m_nFeatures);
 
@@ -838,12 +838,12 @@ CSG_Parameter_Grid_List * CViGrA_Random_Forest::Get_Propability_Grids(CSG_Table
 			}
 			else
 			{
-				pGrids->Add_Item(pGrid = SG_Get_Data_Manager().Add_Grid(*Get_System()));
+				pGrids->Add_Item(pGrid = SG_Get_Data_Manager().Add_Grid(Get_System()));
 
 				DataObject_Set_Colors(pGrid, 11, SG_COLORS_WHITE_GREEN);
 			}
 
-			pGrid->Set_Name(CSG_String::Format(SG_T("%s [%s]"), Classes[i].asString(CLASS_NAME), _TL("Probability")));
+			pGrid->Set_Name("%s [%s]", Classes[i].asString(CLASS_NAME), _TL("Probability"));
 		}
 
 		return( pGrids );
@@ -923,7 +923,7 @@ CViGrA_RF_Presence::CViGrA_RF_Presence(void)
 //---------------------------------------------------------
 int CViGrA_RF_Presence::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
-	if( !SG_STR_CMP(pParameter->Get_Identifier(), "RF_IMPORT") )
+	if( pParameter->Cmp_Identifier("RF_IMPORT") )
 	{
 		bool	bTraining	= !SG_File_Exists(pParameter->asString());
 
@@ -931,12 +931,12 @@ int CViGrA_RF_Presence::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Pa
 		pParameters->Set_Enabled("PRESENCE"  , bTraining);
 	}
 
-	if( !SG_STR_CMP(pParameter->Get_Identifier(), "DO_MRMR") )
+	if( pParameter->Cmp_Identifier("DO_MRMR") )
 	{
-		pParameters->Get("DO_MRMR")->Set_Children_Enabled(pParameter->asBool());
+		(*pParameters)("DO_MRMR")->Set_Children_Enabled(pParameter->asBool());
 	}
 
-	if( pParameters->Get("DO_MRMR")->asBool() )
+	if( (*pParameters)("DO_MRMR")->asBool() )
 	{
 		CSG_mRMR::Parameters_Enable(pParameters, pParameter);
 	}
@@ -964,7 +964,7 @@ bool CViGrA_RF_Presence::On_Execute(void)
 	{
 		if( pFeatures->Get_Grid(i)->Get_Range() <= 0.0 )
 		{
-			Message_Add(CSG_String::Format(SG_T("%s: %s"), _TL("grid has been dropped"), pFeatures->Get_Grid(i)->Get_Name()));
+			Message_Fmt("\n%s: %s", _TL("grid has been dropped"), pFeatures->Get_Grid(i)->Get_Name());
 		}
 		else
 		{
@@ -1077,8 +1077,8 @@ bool CViGrA_RF_Presence::Get_Training(CSG_Matrix &Data)
 	{
 		TSG_Point	p	= pPresence->Get_Shape(iPoint)->Get_Point(0);
 
-		int	x	= Get_System()->Get_xWorld_to_Grid(p.x);
-		int	y	= Get_System()->Get_yWorld_to_Grid(p.y);
+		int	x	= Get_System().Get_xWorld_to_Grid(p.x);
+		int	y	= Get_System().Get_yWorld_to_Grid(p.y);
 
 		Get_Training(Data, x, y, 1);
 	}
@@ -1113,9 +1113,9 @@ bool CViGrA_RF_Presence::Get_Training(CSG_Matrix &Data)
 			{
 				bSelected[j = Selector.Get_Index(i) - 1]	= 1;
 
-				Message_Add(CSG_String::Format(SG_T("\n%02d. %s (%s: %f)"),
+				Message_Fmt("\n%02d. %s (%s: %f)",
 					i + 1, m_pFeatures[j]->Get_Name(), _TL("Score"), Selector.Get_Score(i)
-				), false);
+				);
 			}
 
 			Message_Add("\n", false);
@@ -1233,7 +1233,7 @@ CViGrA_RF_Table::CViGrA_RF_Table(void)
 //---------------------------------------------------------
 int CViGrA_RF_Table::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
-	if( !SG_STR_CMP(pParameter->Get_Identifier(), "RF_IMPORT") )
+	if( pParameter->Cmp_Identifier("RF_IMPORT") )
 	{
 		bool	bTraining	= !SG_File_Exists(pParameter->asString());
 
