@@ -168,7 +168,7 @@ bool CViGrA_Watershed::On_Execute(void)
 	}
 
 	//-----------------------------------------------------
-	pOutput->Set_Name(CSG_String::Format(SG_T("%s [%s]"), pInput->Get_Name(), Get_Name().c_str()));
+	pOutput->Set_Name("%s [%s]", pInput->Get_Name(), Get_Name().c_str());
 
 	return( true );
 }
