@@ -374,6 +374,28 @@ bool CSG_GDAL_DataSet::Open_Read(const CSG_String &File_Name, const CSG_Grid_Sys
 	return( _Set_Transformation() );
 }
 
+//---------------------------------------------------------
+CSG_Strings CSG_GDAL_DataSet::Get_SubDataSets(bool bDescription) const
+{
+	CSG_MetaData	MetaData;	Get_MetaData(MetaData, "SUBDATASETS");
+
+	CSG_Strings	SubDataSets;
+
+	const SG_Char	*Type	= bDescription ? SG_T("DESC") : SG_T("NAME");
+
+	for(int i=0; i==SubDataSets.Get_Count(); i++)
+	{
+		CSG_MetaData	*pSubDataSet	= MetaData(CSG_String::Format("SUBDATASET_%d_%s", i + 1, Type));
+
+		if( pSubDataSet )
+		{
+			SubDataSets	+= pSubDataSet->Get_Content();
+		}
+	}
+
+	return( SubDataSets );
+}
+
 //---------------------------------------------------------
 bool CSG_GDAL_DataSet::_Set_Transformation(void)
 {
@@ -590,9 +612,9 @@ CSG_String CSG_GDAL_DataSet::Get_File_Name(void)	const
 //---------------------------------------------------------
 const char * CSG_GDAL_DataSet::Get_MetaData_Item(const char *pszName, const char *pszDomain)	const
 {
-	const char	*s	= GDALGetMetadataItem(m_pDataSet, pszName, pszDomain);
+	const char	*Item	= GDALGetMetadataItem(m_pDataSet, pszName, pszDomain);
 
-	return( s ? s : "" );
+	return( Item ? Item : "" );
 }
 
 //---------------------------------------------------------
@@ -693,11 +715,11 @@ CSG_String CSG_GDAL_DataSet::Get_Name(int i)	const
 		{
 			if( (s = GDALGetMetadataItem(pBand, "GRIB_COMMENT", 0)) != NULL && *s )
 			{
-				Name	= s;
+				Name	= s;	CSG_DateTime	d;
 
 				if( (s = GDALGetMetadataItem(pBand, "GRIB_ELEMENT"   , 0)) != NULL && *s )	{	Name += "["; Name += s; Name += "]";	}
 				if( (s = GDALGetMetadataItem(pBand, "GRIB_SHORT_NAME", 0)) != NULL && *s )	{	Name += "["; Name += s; Name += "]";	}
-				if( (s = GDALGetMetadataItem(pBand, "GRIB_VALID_TIME", 0)) != NULL && *s )	{	Name += CSG_String::Format("[%s]", CSG_Time_Converter::Get_String(atoi(s), SG_TIME_FMT_Seconds_Unix).c_str());	}
+				if( (s = GDALGetMetadataItem(pBand, "GRIB_VALID_TIME", 0)) != NULL && *s )	{	d.Set_Unix_Time(atoi(s)); Name += "[" + d.Format_ISOCombined() + "]";	}
 			}
 		}
 
