@@ -187,12 +187,12 @@ CGDAL_Import::CGDAL_Import(void)
 //---------------------------------------------------------
 int CGDAL_Import::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
-	if(	!SG_STR_CMP(pParameter->Get_Identifier(), "TRANSFORM") )
+	if(	pParameter->Cmp_Identifier("TRANSFORM") )
 	{
 		pParameters->Set_Enabled("RESAMPLING" , pParameter->asBool());
 	}
 
-	if(	!SG_STR_CMP(pParameter->Get_Identifier(), "SELECT") )
+	if(	pParameter->Cmp_Identifier("SELECT") )
 	{
 		pParameters->Set_Enabled("SELECT_SORT", pParameter->asBool());
 	}
@@ -207,7 +207,7 @@ int CGDAL_Import::On_Selection_Changed(CSG_Parameter *pParameter, int Flags)
 	{
 		if( Flags & PARAMETER_CHECK_ENABLE )
 		{
-			if( !SG_STR_CMP(pParameter->Get_Identifier(), "ALL") )
+			if( pParameter->Cmp_Identifier("ALL") )
 			{
 				pParameter->Get_Owner()->Set_Enabled("BANDS", pParameter->asBool() == false);
 			}
@@ -239,7 +239,7 @@ bool CGDAL_Import::On_Execute(void)
 
 	for(int i=0; i<Files.Get_Count(); i++)
 	{
-		Message_Add(CSG_String::Format("\n%s: %s", _TL("loading"), Files[i].c_str()), false);
+		Message_Fmt("\n%s: %s", _TL("loading"), Files[i].c_str());
 
 		if( Load(Files[i]) == false )
 		{
@@ -355,17 +355,17 @@ bool CGDAL_Import::Load(const CSG_String &File)
 
 	//-----------------------------------------------------
 	Message_Add("\n", false);
-	Message_Add(CSG_String::Format("\n%s: %s", _TL("Driver" ), DataSet.Get_DriverID().c_str()), false);
-	Message_Add(CSG_String::Format("\n%s: %d", _TL("Bands"  ), DataSet.Get_Count   ()        ), false);
-	Message_Add(CSG_String::Format("\n%s: %d", _TL("Rows"   ), DataSet.Get_NX      ()        ), false);
-	Message_Add(CSG_String::Format("\n%s: %d", _TL("Columns"), DataSet.Get_NY      ()        ), false);
+	Message_Fmt("\n%s: %s", _TL("Driver" ), DataSet.Get_DriverID().c_str());
+	Message_Fmt("\n%s: %d", _TL("Bands"  ), DataSet.Get_Count   ()        );
+	Message_Fmt("\n%s: %d", _TL("Rows"   ), DataSet.Get_NX      ()        );
+	Message_Fmt("\n%s: %d", _TL("Columns"), DataSet.Get_NY      ()        );
 	Message_Add("\n", false);
 
 	if( DataSet.Needs_Transformation() )
 	{
-		Message_Add(CSG_String::Format("\n%s:", _TL("Transformation")                               ), false);
-		Message_Add(CSG_String::Format("\n  x' = %.6f + x * %.6f + y * %.6f", A[0], B[0][0], B[0][1]), false);
-		Message_Add(CSG_String::Format("\n  y' = %.6f + x * %.6f + y * %.6f", A[1], B[1][0], B[1][1]), false);
+		Message_Fmt("\n%s:", _TL("Transformation")                               );
+		Message_Fmt("\n  x' = %.6f + x * %.6f + y * %.6f", A[0], B[0][0], B[0][1]);
+		Message_Fmt("\n  y' = %.6f + x * %.6f + y * %.6f", A[1], B[1][0], B[1][1]);
 		Message_Add("\n", false);
 	}
 
@@ -378,7 +378,7 @@ bool CGDAL_Import::Load(const CSG_String &File)
 		{
 			CSG_String	Message	= "%s: " + SG_File_Get_Name(File, false);	if( DataSet.Get_Count() > 1 )	Message	+= CSG_String::Format(" [%d/%d]", i + 1, DataSet.Get_Count());
 
-			Process_Set_Text(CSG_String::Format(Message.c_str(), _TL("loading")));
+			Process_Set_Text(Message.c_str(), _TL("loading"));
 
 			CSG_Grid	*pGrid	= DataSet.Read(Bands[i].Get_Index());
 
@@ -386,7 +386,7 @@ bool CGDAL_Import::Load(const CSG_String &File)
 			{
 				if( bTransform )
 				{
-					Process_Set_Text(CSG_String::Format(Message.c_str(), _TL("translation")));
+					Process_Set_Text(Message.c_str(), _TL("translation"));
 
 					DataSet.Get_Transformation(&pGrid, Resampling, true);
 				}
