@@ -142,29 +142,29 @@ CGDAL_Import_NetCDF::CGDAL_Import_NetCDF(void)
 //---------------------------------------------------------
 int CGDAL_Import_NetCDF::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
-	if(	!SG_STR_CMP(pParameter->Get_Identifier(), "SAVE_FILE") )
+	if(	pParameter->Cmp_Identifier("SAVE_FILE") )
 	{
-		pParameters->Set_Enabled("SAVE_PATH" ,  pParameter->asBool());
+		pParameters->Set_Enabled("SAVE_PATH" , pParameter->asBool() == true);
 	}
 
-	if(	!SG_STR_CMP(pParameter->Get_Identifier(), "VARS_ALL" ) && pParameters->Get("VARS") )
+	if(	pParameter->Cmp_Identifier("VARS_ALL" ) )
 	{
-		pParameters->Set_Enabled("VARS"      , !pParameter->asBool());
+		pParameters->Set_Enabled("VARS"      , pParameter->asBool() == false);
 	}
 
-	if(	!SG_STR_CMP(pParameter->Get_Identifier(), "TIME_ALL" ) && pParameters->Get("TIME") )
+	if(	pParameter->Cmp_Identifier("TIME_ALL" ) )
 	{
-		pParameters->Set_Enabled("TIME"      , !pParameter->asBool());
+		pParameters->Set_Enabled("TIME"      , pParameter->asBool() == false);
 	}
 
-	if(	!SG_STR_CMP(pParameter->Get_Identifier(), "LEVEL_ALL") && pParameters->Get("LEVEL") )
+	if(	pParameter->Cmp_Identifier("LEVEL_ALL") )
 	{
-		pParameters->Set_Enabled("LEVEL"     , !pParameter->asBool());
+		pParameters->Set_Enabled("LEVEL"     , pParameter->asBool() == false);
 	}
 
-	if(	!SG_STR_CMP(pParameter->Get_Identifier(), "TRANSFORM") )
+	if(	pParameter->Cmp_Identifier("TRANSFORM") )
 	{
-		pParameters->Set_Enabled("RESAMPLING",  pParameter->asBool());
+		pParameters->Set_Enabled("RESAMPLING", pParameter->asBool() == true);
 	}
 
 	return( CSG_Tool::On_Parameters_Enable(pParameters, pParameter) );
@@ -210,11 +210,16 @@ const char * CGDAL_Import_NetCDF::Get_Level(CSG_GDAL_DataSet &DataSet, int iBand
 //---------------------------------------------------------
 CSG_String CGDAL_Import_NetCDF::Get_Time_String(const CSG_String &Time, int Format)
 {
+	CSG_DateTime	Date;
+
 	switch( Format )
 	{
-	case  0:	return( CSG_Time_Converter::Get_String(Time.asInt(), SG_TIME_FMT_Hours_AD) );
+	case  0:
+		Date.Set_Hours_AD(Time.asInt());
+		return( Date.Format_ISOCombined() );
 
-	default:	return( Time );
+	default:
+		return( Time );
 	}
 }
 
@@ -252,46 +257,32 @@ bool CGDAL_Import_NetCDF::On_Execute(void)
 
 	if( DataSet.Get_DriverID().Cmp("netCDF") )
 	{
-		Message_Add(CSG_String::Format("\n%s: %s [%s]\n", _TL("Warning"), _TL("Driver"), DataSet.Get_DriverID().c_str()), false);
+		Message_Fmt("\n%s: %s [%s]\n", _TL("Warning"), _TL("Driver"), DataSet.Get_DriverID().c_str());
 	}
 
 	//-----------------------------------------------------
-	CSG_MetaData	MetaData;
+	CSG_Strings	SubDataSets	= DataSet.Get_SubDataSets(false);
 
-	if( DataSet.Get_Count() <= 0 && DataSet.Get_MetaData(MetaData, "SUBDATASETS") )
+	if( SubDataSets.Get_Count() > 0 )
 	{
-		Message_Add(CSG_String::Format("\n====\n%s\n%s\n", DataSet.Get_Name().c_str(), MetaData.asText().c_str()), false);
+		CSG_Strings	Descriptions	= DataSet.Get_SubDataSets(true);
 
-		int	i, n;
-
-		for(i=0, n=0; i==n; i++)
+		for(int i=0; i<SubDataSets.Get_Count() && Process_Get_Okay(); i++)
 		{
-			CSG_MetaData	*pEntry	= MetaData.Get_Child(CSG_String::Format("SUBDATASET_%d_NAME", i + 1));
-
-			if( pEntry && DataSet.Open_Read(pEntry->Get_Content()) )
+			if( DataSet.Open_Read(SubDataSets[i]) )
 			{
-				CSG_String	Name	= pEntry->Get_Content();
+				CSG_String	Name	= SubDataSets[i];
 
 				if( Name.Find("://") >= 0 )
 				{
 					Name	= Name.Right(Name.Length() - Name.Find("://") - 3);
 				}
 
-				CSG_String	Desc;
-
-				if( (pEntry = MetaData.Get_Child(CSG_String::Format("SUBDATASET_%d_DESC", i + 1))) != NULL )
-				{
-					Desc	= pEntry->Get_Content();
-				}
-
-				if( Load(DataSet, Name, Desc) )
-				{
-					n++;
-				}
+				Load(DataSet, Name, Descriptions[i]);
 			}
 		}
 
-		return( n > 0 );
+		return( true );
 	}
 
 	return( Load(DataSet, SG_File_Get_Name(Parameters("FILE")->asString(), false), "") );
@@ -310,10 +301,10 @@ bool CGDAL_Import_NetCDF::Load(CSG_GDAL_DataSet &DataSet, const CSG_String &Name
 
 	DataSet.Get_MetaData(MetaData);
 
-	Message_Add(CSG_String::Format("\n____\n%s\n%s\n%s\n",
+	Message_Fmt("\n____\n%s\n%s\n%s\n",
 		Name.c_str(),
 		Description.c_str(),
-		MetaData.asText().c_str()), false
+		MetaData.asText().c_str()
 	);
 
 	//-----------------------------------------------------
@@ -349,9 +340,9 @@ bool CGDAL_Import_NetCDF::Load(CSG_GDAL_DataSet &DataSet, const CSG_String &Name
 		{
 			const char	*s;
 
-			if( !!(s = Get_Variable(DataSet, i)) && !pVars ->Get(s) ) pVars ->Add_Bool("", s, s, _TL(""), false);
-			if( !!(s = Get_Time    (DataSet, i)) && !pTime ->Get(s) ) pTime ->Add_Bool("", s, Get_Time_String(s, tFmt), _TL(""), false);
-			if( !!(s = Get_Level   (DataSet, i)) && !pLevel->Get(s) ) pLevel->Add_Bool("", s, s, _TL(""), false);
+			if( !!(s = Get_Variable(DataSet, i)) && !(*pVars )(s) ) pVars ->Add_Bool("", s, s, _TL(""), false);
+			if( !!(s = Get_Time    (DataSet, i)) && !(*pTime )(s) ) pTime ->Add_Bool("", s, Get_Time_String(s, tFmt), _TL(""), false);
+			if( !!(s = Get_Level   (DataSet, i)) && !(*pLevel)(s) ) pLevel->Add_Bool("", s, s, _TL(""), false);
 		}
 
 		P("VARS_ALL" )->Set_Enabled(pVars ->Get_Count() > 1);
@@ -400,7 +391,7 @@ bool CGDAL_Import_NetCDF::Load(CSG_GDAL_DataSet &DataSet, const CSG_String &Name
 			{
 				if( bTransform )
 				{
-					Process_Set_Text(CSG_String::Format("%s [%d/%d]", _TL("band transformation"), i + 1, DataSet.Get_Count()));
+					Process_Set_Text("%s [%d/%d]", _TL("band transformation"), i + 1, DataSet.Get_Count());
 
 					DataSet.Get_Transformation(&pGrid, Resampling, true);
 				}
