@@ -99,19 +99,19 @@ CGrid_to_KML::CGrid_to_KML(void)
 	Parameters.Add_FilePath("",
 		"FILE"		, _TL("Image File"),
 		_TL(""),
-		CSG_String::Format("%s|%s|%s|%s|%s|%s|%s|%s|%s|%s",
-			_TL("Portable Network Graphics (*.png)"           ), SG_T("*.png"),
-			_TL("JPEG - JFIF Compliant (*.jpg, *.jif, *.jpeg)"), SG_T("*.jpg;*.jif;*.jpeg"),
-			_TL("Tagged Image File Format (*.tif, *.tiff)"    ), SG_T("*.tif;*.tiff"),
-			_TL("Windows or OS/2 Bitmap (*.bmp)"              ), SG_T("*.bmp"),
-			_TL("Zsoft Paintbrush (*.pcx)"                    ), SG_T("*.pcx")
+		CSG_String::Format("%s (*.png)|*.png|%s (*.jpg, *.jif, *.jpeg)|*.jpg;*.jif;*.jpeg|%s (*.tif, *.tiff)|*.tif;*.tiff|%s (*.bmp)|*.bmp|%s (*.pcx)|*.pcx",
+			_TL("Portable Network Graphics"),
+			_TL("JPEG - JFIF Compliant"    ),
+			_TL("Tagged Image File Format" ),
+			_TL("Windows or OS/2 Bitmap"   ),
+			_TL("Zsoft Paintbrush"         )
 		), NULL, true
 	);
 
 	Parameters.Add_Choice("",
 		"OUTPUT"	, _TL("Output"),
 		_TL(""),
-		CSG_String::Format("%s|%s|%s|",
+		CSG_String::Format("%s|%s|%s",
 			_TL("kml and image files"),
 			_TL("kmz, kml and image files"),
 			_TL("kmz file")
@@ -221,7 +221,7 @@ CGrid_to_KML::CGrid_to_KML(void)
 //---------------------------------------------------------
 int CGrid_to_KML::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
-	if(	!SG_STR_CMP(pParameter->Get_Identifier(), "COLOURING") )
+	if(	pParameter->Cmp_Identifier("COLOURING") )
 	{
 		pParameters->Set_Enabled("COL_PALETTE", pParameter->asInt() <= 2);
 		pParameters->Set_Enabled("STDDEV"     , pParameter->asInt() == 0);
@@ -229,12 +229,12 @@ int CGrid_to_KML::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Paramete
 		pParameters->Set_Enabled("LUT"        , pParameter->asInt() == 3);
 	}
 
-	if(	!SG_STR_CMP(pParameter->Get_Identifier(), "SHADE") && pParameters->Get_Parameter("SHADE_BRIGHT") )
+	if(	pParameter->Cmp_Identifier("SHADE") && pParameters->Get_Parameter("SHADE_BRIGHT") )
 	{
 		pParameters->Set_Enabled("SHADE_BRIGHT", pParameter->asPointer() != NULL);
 	}
 
-	if(	!SG_STR_CMP(pParameter->Get_Identifier(), "GRID") || !SG_STR_CMP(pParameter->Get_Identifier(), "COLOURING") )
+	if(	pParameter->Cmp_Identifier("GRID") || pParameter->Cmp_Identifier("COLOURING") )
 	{
 		CSG_Grid	*pGrid	= pParameters->Get_Parameter("GRID")->asGrid();
 
@@ -288,7 +288,7 @@ bool CGrid_to_KML::On_Execute(void)
 	}
 	else if( pGrid->Get_Projection().Get_Type() != SG_PROJ_TYPE_CS_Geographic )
 	{
-		Message_Add(CSG_String::Format("\n%s (%s: %s)\n", _TL("re-projection to geographic coordinates"), _TL("original"), pGrid->Get_Projection().Get_Name().c_str()), false);
+		Message_Fmt("\n%s (%s: %s)\n", _TL("re-projection to geographic coordinates"), _TL("original"), pGrid->Get_Projection().Get_Name().c_str());
 
 		if(	(pTool = SG_Get_Tool_Library_Manager().Get_Tool("pj_proj4", 4)) == NULL )	// Coordinate Transformation (Grid)
 		{
@@ -297,7 +297,7 @@ bool CGrid_to_KML::On_Execute(void)
 
 		pTool->Settings_Push();
 
-		if( pTool->Set_Parameter("CRS_PROJ4" , SG_T("+proj=longlat +ellps=WGS84 +datum=WGS84"))
+		if( pTool->Set_Parameter("CRS_PROJ4" , "+proj=longlat +ellps=WGS84 +datum=WGS84")
 		&&  pTool->Set_Parameter("RESAMPLING", Method < 4 && Parameters("RESAMPLING")->asBool() ? 4 : 0)
 		&&  pTool->Set_Parameter("SOURCE"    , pGrid)
 		&&  pTool->Execute() )
@@ -320,7 +320,7 @@ bool CGrid_to_KML::On_Execute(void)
 
 		if( !bDelete )
 		{
-			Message_Add(CSG_String::Format("\n%s: %s\n", _TL("re-projection"), _TL("failed")), false);
+			Message_Fmt("\n%s: %s\n", _TL("re-projection"), _TL("failed"));
 
 			return( false );
 		}
@@ -504,7 +504,7 @@ bool CGrid_from_KML::On_Execute(void)
 
 	if( !KML.Load(&File) )
 	{
-		Error_Fmt("%s [%s]", _TL("failed to load file"), File.wc_str());
+		Error_Fmt("%s [%s]", _TL("failed to load file"), File.wx_str());
 
 		return( false );
 	}
@@ -582,11 +582,11 @@ bool CGrid_from_KML::Load_Overlay(const SG_Char *Dir, const CSG_MetaData &KML)
 	}
 
 	CSG_Data_Manager	Data;
-	CSG_String			FullPath = fn.GetFullPath().wc_str();
+	CSG_String			FullPath = fn.GetFullPath().wx_str();
 
 	if( !Data.Add(FullPath) || !Data.Get_Grid_System(0) || !Data.Get_Grid_System(0)->Get(0) )
 	{
-		Error_Fmt("%s: %s", _TL("failed to load KML ground overlay icon"), fn.GetFullPath().wc_str());
+		Error_Fmt("%s: %s", _TL("failed to load KML ground overlay icon"), fn.GetFullPath().wx_str());
 	}
 
 	//-----------------------------------------------------
@@ -614,7 +614,7 @@ bool CGrid_from_KML::Load_Overlay(const SG_Char *Dir, const CSG_MetaData &KML)
 	m_pGrids->Add_Item(pGrid);
 
 	DataObject_Add(pGrid);
-	DataObject_Set_Parameter(pGrid, "COLORS_TYPE", 6);	// Color Classification Type: RGB
+	DataObject_Set_Parameter(pGrid, "COLORS_TYPE", 5);	// Color Classification Type: RGB Coded Values
 
 	//-----------------------------------------------------
 	return( true );
