@@ -243,7 +243,7 @@ bool CPC_Transform::On_Execute(void)
 
 	pOut->Create(pIn);
 
-	pOut->Set_Name(CSG_String::Format(SG_T("%s [%s]"), pIn->Get_Name(), _TL("Transformed")));
+	pOut->Set_Name("%s [%s]", pIn->Get_Name(), _TL("Transformed"));
 
 
 	//-----------------------------------------------------
