@@ -173,7 +173,7 @@ CPROJ4_Base::CPROJ4_Base(int Interface, bool bInputList)
 int CPROJ4_Base::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
 	if( !m_bInputList && m_Interface == PROJ4_INTERFACE_SIMPLE
-	&&	!SG_STR_CMP(pParameter->Get_Identifier(), SG_T("SOURCE"))
+	&&	pParameter->Cmp_Identifier(SG_T("SOURCE"))
 	&&	pParameter->asDataObject() && pParameter->asDataObject()->Get_Projection().Get_Proj4().Length() > 0 )
 	{
 		pParameters->Get_Parameter("SOURCE_PROJ")->Set_Value(pParameter->asDataObject()->Get_Projection().Get_Proj4());
@@ -209,8 +209,8 @@ bool CPROJ4_Base::On_Execute(void)
 			Error_Set(CSG_String::Format(SG_T("%s:\n%s"), _TL("projection initialization failure"), SG_STR_MBTOSG(pj_strerrno(pj_errno))));
 		}
 
-		Message_Add(CSG_String::Format(SG_T("\n%s: %s\n"), _TL("Source"), sSrc.c_str()), false);
-		Message_Add(CSG_String::Format(SG_T("\n%s: %s\n"), _TL("Target"), sDst.c_str()), false);
+		Message_Fmt("\n%s: %s", _TL("Source"), sSrc.c_str());
+		Message_Fmt("\n%s: %s", _TL("Target"), sDst.c_str());
 
 		//-------------------------------------------------
 		if(	m_pPrjSrc && m_pPrjDst )
