@@ -142,7 +142,7 @@ bool CCRS_Transform_PointCloud::On_Execute_Transformation(void)
 			CSG_PointCloud	*pSource	= pSources->Get_PointCloud(i);
 			CSG_PointCloud	*pTarget	= SG_Create_PointCloud(pSource);
 
-			pTarget->Set_Name(CSG_String::Format(SG_T("%s_transformed"), pSource->Get_Name()));
+			pTarget->Set_Name("%s [%s]", pSource->Get_Name(), _TL("projected"));
 
 			if( Transform(pSource, pTarget) )
 			{
@@ -171,7 +171,7 @@ bool CCRS_Transform_PointCloud::On_Execute_Transformation(void)
 			{
 				pSource->Assign(pTarget);
 
-				pSource->Set_Name(CSG_String::Format(SG_T("%s_transformed"), sName.c_str()));
+				pSource->Set_Name("%s [%s]", sName.c_str(), _TL("projected"));
 
 				return( true );
 			}
@@ -186,7 +186,7 @@ bool CCRS_Transform_PointCloud::On_Execute_Transformation(void)
 		{
 			pTarget->Create(pSource);
 
-			pTarget->Set_Name(CSG_String::Format(SG_T("%s_transformed"), pSource->Get_Name()));
+			pTarget->Set_Name("%s [%s]", pSource->Get_Name(), _TL("projected"));
 		}
 
 		return( Transform(pSource, pTarget) );
@@ -213,7 +213,7 @@ bool CCRS_Transform_PointCloud::Transform(CSG_PointCloud *pSource, CSG_PointClou
 
 	int		nDropped	= 0;
 
-	Process_Set_Text(CSG_String::Format(SG_T("%s: %s"), _TL("Processing"), pSource->Get_Name()));
+	Process_Set_Text("%s: %s", _TL("Processing"), pSource->Get_Name());
 
 	for(int iPoint=0; iPoint<pSource->Get_Point_Count() && Set_Progress(iPoint, pSource->Get_Point_Count()); iPoint++)
 	{
@@ -236,7 +236,7 @@ bool CCRS_Transform_PointCloud::Transform(CSG_PointCloud *pSource, CSG_PointClou
 
 	if( nDropped > 0 )
 	{
-		Message_Add(CSG_String::Format(SG_T("%s: %d %s"), pTarget->Get_Name(), nDropped, _TL("points have been dropped")));
+		Message_Fmt("\n%s: %d %s", pTarget->Get_Name(), nDropped, _TL("points have been dropped"));
 	}
 
 	pTarget->Get_Projection() = m_Projector.Get_Target();
