@@ -154,7 +154,7 @@ CGrid_Statistics_AddTo_Polygon::CGrid_Statistics_AddTo_Polygon(void)
 //---------------------------------------------------------
 int CGrid_Statistics_AddTo_Polygon::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
-	if( !SG_STR_CMP(pParameter->Get_Identifier(), "METHOD") )
+	if( pParameter->Cmp_Identifier("METHOD") )
 	{
 		pParameters->Set_Enabled("PARALLELIZED", pParameter->asInt() != 0 && SG_OMP_Get_Max_Num_Threads() > 1);
 	}
@@ -168,7 +168,7 @@ int CGrid_Statistics_AddTo_Polygon::On_Parameters_Enable(CSG_Parameters *pParame
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-#define GET_FIELD_NAME(VAR)	Naming == 0 ? CSG_String::Format("G%02d_%s", iGrid + 1, VAR) : CSG_String::Format("%s [%s]", pGrids->Get_Grid(iGrid)->Get_Name(), VAR)
+#define GET_FIELD_NAME(VAR)	Naming == 0 ? CSG_String::Format("G%02d_%s", iGrid + 1, VAR) : CSG_String::Format("%s (%s)", pGrids->Get_Grid(iGrid)->Get_Name(), VAR)
 
 //---------------------------------------------------------
 bool CGrid_Statistics_AddTo_Polygon::On_Execute(void)
@@ -193,7 +193,7 @@ bool CGrid_Statistics_AddTo_Polygon::On_Execute(void)
 		return( false );
 	}
 
-	if( !Get_System()->Get_Extent().Intersects(pPolygons->Get_Extent()) )
+	if( !Get_System().Get_Extent().Intersects(pPolygons->Get_Extent()) )
 	{
 		Error_Set(_TL("no spatial intersection between grid(s) and polygon layer"));
 
@@ -244,7 +244,7 @@ bool CGrid_Statistics_AddTo_Polygon::On_Execute(void)
 	{
 		pPolygons	= Parameters("RESULT")->asShapes();
 		pPolygons	->Assign(Parameters("POLYGONS")->asShapes());
-		pPolygons	->Set_Name(CSG_String::Format("%s [%s]", Parameters("POLYGONS")->asShapes()->Get_Name(), _TL("Grid Statistics")));
+		pPolygons	->Set_Name("%s [%s]", Parameters("POLYGONS")->asShapes()->Get_Name(), _TL("Grid Statistics"));
 	}
 
 	CSG_Simple_Statistics	*Statistics	= new CSG_Simple_Statistics[pPolygons->Get_Count()];
@@ -252,7 +252,7 @@ bool CGrid_Statistics_AddTo_Polygon::On_Execute(void)
 	//-----------------------------------------------------
 	for(int iGrid=0; iGrid<pGrids->Get_Grid_Count() && Process_Get_Okay(); iGrid++)
 	{
-		Process_Set_Text(CSG_String::Format("[%d/%d] %s", 1 + iGrid, pGrids->Get_Grid_Count(), pGrids->Get_Grid(iGrid)->Get_Name()));
+		Process_Set_Text("[%d/%d] %s", 1 + iGrid, pGrids->Get_Grid_Count(), pGrids->Get_Grid(iGrid)->Get_Name());
 
 		if( (Method == 0 && Get_Simple (pGrids->Get_Grid(iGrid), pPolygons, Statistics, Quantile > 0 || fGINI > 0, Index))
 		||  (Method != 0 && Get_Precise(pGrids->Get_Grid(iGrid), pPolygons, Statistics, Quantile > 0 || fGINI > 0, bParallelized)) )
@@ -377,22 +377,22 @@ bool CGrid_Statistics_AddTo_Polygon::Get_Precise(CSG_Grid *pGrid, CSG_Shape_Poly
 	//-----------------------------------------------------
 	Statistics.Create(bHoldValues);
 
-	int	ax	= Get_System()->Get_xWorld_to_Grid(pPolygon->Get_Extent().Get_XMin()) - 1;	if( ax < 0         )	ax	= 0;
-	int	bx	= Get_System()->Get_xWorld_to_Grid(pPolygon->Get_Extent().Get_XMax()) + 1;	if( bx >= Get_NX() )	bx	= Get_NX() - 1;
-	int	ay	= Get_System()->Get_yWorld_to_Grid(pPolygon->Get_Extent().Get_YMin()) - 1;	if( ay < 0         )	ay	= 0;
-	int	by	= Get_System()->Get_yWorld_to_Grid(pPolygon->Get_Extent().Get_YMax()) + 1;	if( by >= Get_NY() )	by	= Get_NY() - 1;
+	int	ax	= Get_System().Get_xWorld_to_Grid(pPolygon->Get_Extent().Get_XMin()) - 1;	if( ax < 0         )	ax	= 0;
+	int	bx	= Get_System().Get_xWorld_to_Grid(pPolygon->Get_Extent().Get_XMax()) + 1;	if( bx >= Get_NX() )	bx	= Get_NX() - 1;
+	int	ay	= Get_System().Get_yWorld_to_Grid(pPolygon->Get_Extent().Get_YMin()) - 1;	if( ay < 0         )	ay	= 0;
+	int	by	= Get_System().Get_yWorld_to_Grid(pPolygon->Get_Extent().Get_YMax()) + 1;	if( by >= Get_NY() )	by	= Get_NY() - 1;
 
 	TSG_Point	Center;
 	TSG_Rect	Cell;
 
 	//-----------------------------------------------------
-	Center.y	= Get_System()->Get_yGrid_to_World(ay);
+	Center.y	= Get_System().Get_yGrid_to_World(ay);
 	Cell.yMin	= Center.y - 0.5 * Get_Cellsize();
 	Cell.yMax	= Cell.yMin + Get_Cellsize();
 		
 	for(int y=ay; y<=by; y++, Center.y+=Get_Cellsize(), Cell.yMin+=Get_Cellsize(), Cell.yMax+=Get_Cellsize())
 	{
-		Center.x	= Get_System()->Get_xGrid_to_World(ax);
+		Center.x	= Get_System().Get_xGrid_to_World(ax);
 		Cell.xMin	= Center.x - 0.5 * Get_Cellsize();
 		Cell.xMax	= Cell.xMin + Get_Cellsize();
 
@@ -487,7 +487,7 @@ bool CGrid_Statistics_AddTo_Polygon::Get_Simple_Index(CSG_Shapes *pPolygons, CSG
 	CSG_Shape	*pPolygon;
 
 	//-----------------------------------------------------
-	Index.Create(*Get_System(), pPolygons->Get_Count() < 32767 ? SG_DATATYPE_Short : SG_DATATYPE_Int);
+	Index.Create(Get_System(), pPolygons->Get_Count() < 32767 ? SG_DATATYPE_Short : SG_DATATYPE_Int);
 	Index.Assign(-1.0);
 
 	bCrossing	= (bool *)SG_Malloc(Get_NX() * sizeof(bool));
@@ -498,8 +498,8 @@ bool CGrid_Statistics_AddTo_Polygon::Get_Simple_Index(CSG_Shapes *pPolygons, CSG
 		pPolygon	= pPolygons->Get_Shape(iShape);
 		Extent		= pPolygon->Get_Extent().m_rect;
 
-		xStart		= Get_System()->Get_xWorld_to_Grid(Extent.xMin) - 1;	if( xStart < 0 )		xStart	= 0;
-		xStop		= Get_System()->Get_xWorld_to_Grid(Extent.xMax) + 1;	if( xStop >= Get_NX() )	xStop	= Get_NX() - 1;
+		xStart		= Get_System().Get_xWorld_to_Grid(Extent.xMin) - 1;	if( xStart < 0 )		xStart	= 0;
+		xStop		= Get_System().Get_xWorld_to_Grid(Extent.xMax) + 1;	if( xStop >= Get_NX() )	xStop	= Get_NX() - 1;
 
 		pLeft.x		= Get_XMin() - 1.0;
 		pRight.x	= Get_XMax() + 1.0;
