@@ -165,7 +165,7 @@ bool CGrid_Statistics_For_Points::On_Execute(void)
 		return( false );
 	}
 
-	if( !Get_System()->Get_Extent().Intersects(pPoints->Get_Extent()) )
+	if( !Get_System().Get_Extent().Intersects(pPoints->Get_Extent()) )
 	{
 		Error_Set(_TL("no spatial intersection between grid(s) and points layer"));
 
@@ -206,12 +206,12 @@ bool CGrid_Statistics_For_Points::On_Execute(void)
 	{
 		pPoints	= Parameters("RESULT")->asShapes();
 		pPoints	->Assign(Parameters("POINTS")->asShapes());
-		pPoints	->Set_Name(CSG_String::Format("%s [%s]", Parameters("POINTS")->asShapes()->Get_Name(), _TL("Grid Statistics")));
+		pPoints	->Set_Name("%s [%s]", Parameters("POINTS")->asShapes()->Get_Name(), _TL("Grid Statistics"));
 	}
 
 	//-----------------------------------------------------
 	{
-		#define GET_FIELD_NAME(VAR)	Naming == 0 ? CSG_String::Format(SG_T("G%02d_%s"), iGrid + 1, VAR) : CSG_String::Format(SG_T("%s [%s]"), pGrids->Get_Grid(iGrid)->Get_Name(), VAR)
+		#define GET_FIELD_NAME(VAR)	Naming == 0 ? CSG_String::Format(SG_T("G%02d_%s"), iGrid + 1, VAR) : CSG_String::Format(SG_T("%s (%s)"), pGrids->Get_Grid(iGrid)->Get_Name(), VAR)
 
 		int	Naming	= Parameters("NAMING")->asInt();
 
@@ -310,8 +310,8 @@ bool CGrid_Statistics_For_Points::On_Execute(void)
 //---------------------------------------------------------
 bool CGrid_Statistics_For_Points::Get_Statistics(const TSG_Point &Point, CSG_Grid *pGrid, CSG_Simple_Statistics &Statistics)
 {
-	int	x	= Get_System()->Get_xWorld_to_Grid(Point.x);
-	int	y	= Get_System()->Get_yWorld_to_Grid(Point.y);
+	int	x	= Get_System().Get_xWorld_to_Grid(Point.x);
+	int	y	= Get_System().Get_yWorld_to_Grid(Point.y);
 
 	for(int i=0; i<m_Kernel.Get_Count(); i++)
 	{
