@@ -181,11 +181,11 @@ bool CSnap_Points_to_Grid::On_Execute(void)
 		Parameters("RESULT")->Set_Value(pPoints	= pInput);
 	}
 
-	pPoints->Set_Name(CSG_String::Format(SG_T("%s [%s: %s]"), pInput->Get_Name(), _TL("snapped"), pGrid->Get_Name()));
+	pPoints->Set_Name("%s [%s: %s]", pInput->Get_Name(), _TL("snapped"), pGrid->Get_Name());
 
 	if( pMoves )
 	{
-		pMoves->Create(SHAPE_TYPE_Line, CSG_String::Format(SG_T("%s [%s: %s]"), pInput->Get_Name(), _TL("snap move"), pGrid->Get_Name()), pPoints);
+		pMoves->Create(SHAPE_TYPE_Line, CSG_String::Format("%s [%s: %s]", pInput->Get_Name(), _TL("snap move"), pGrid->Get_Name()), pPoints);
 	}
 
 	//-----------------------------------------------------
@@ -199,8 +199,8 @@ bool CSnap_Points_to_Grid::On_Execute(void)
 		CSG_Shape	*pPoint		= pPoints->Get_Shape(iPoint);
 		TSG_Point	Point		= pPoint->Get_Point(0);
 
-		int		x		= Get_System()->Get_xWorld_to_Grid(Point.x);
-		int		y		= Get_System()->Get_yWorld_to_Grid(Point.y);
+		int		x		= Get_System().Get_xWorld_to_Grid(Point.x);
+		int		y		= Get_System().Get_yWorld_to_Grid(Point.y);
 		int		iMax	= -1;
 		double	dMax;
 
