@@ -97,11 +97,11 @@ CTransformShapes::CTransformShapes(void)
 //---------------------------------------------------------
 int CTransformShapes::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
-	if( !SG_STR_CMP(pParameter->Get_Identifier(), "SHAPES") && pParameter->asShapes() != NULL )
+	if( pParameter->Cmp_Identifier("SHAPES") && pParameter->asShapes() != NULL )
 	{
-		pParameters->Get("ANCHORX")->Set_Value(pParameter->asShapes()->Get_Extent().Get_Center().Get_X());
-		pParameters->Get("ANCHORY")->Set_Value(pParameter->asShapes()->Get_Extent().Get_Center().Get_Y());
-		pParameters->Get("ANCHORZ")->Set_Value((pParameter->asShapes()->Get_ZMin() + pParameter->asShapes()->Get_ZMax()) / 2.0);
+		pParameters->Set_Parameter("ANCHORX",  pParameter->asShapes()->Get_Extent().Get_Center().Get_X());
+		pParameters->Set_Parameter("ANCHORY",  pParameter->asShapes()->Get_Extent().Get_Center().Get_Y());
+		pParameters->Set_Parameter("ANCHORZ", (pParameter->asShapes()->Get_ZMin() + pParameter->asShapes()->Get_ZMax()) / 2.0);
 	}
 
 	return( CSG_Tool::On_Parameters_Enable(pParameters, pParameter) );
@@ -110,7 +110,7 @@ int CTransformShapes::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Para
 //---------------------------------------------------------
 int CTransformShapes::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
-	if( !SG_STR_CMP(pParameter->Get_Identifier(), "SHAPES") && pParameter->asShapes() != NULL )
+	if( pParameter->Cmp_Identifier("SHAPES") && pParameter->asShapes() != NULL )
 	{
 		pParameters->Set_Enabled("MOVEZ"  , pParameter->asShapes()->Get_Vertex_Type() != SG_VERTEX_TYPE_XY);
 		pParameters->Set_Enabled("SCALEZ" , pParameter->asShapes()->Get_Vertex_Type() != SG_VERTEX_TYPE_XY);
@@ -139,7 +139,7 @@ bool CTransformShapes::On_Execute(void)
 
 		DataObject_Set_Parameters(pShapes, Parameters("SHAPES")->asShapes());
 
-		pShapes->Set_Name(CSG_String::Format("%s [%s]", pShapes->Get_Name(), _TL("Transformed")));
+		pShapes->Set_Name("%s [%s]", pShapes->Get_Name(), _TL("Transformed"));
 	}
 	else
 	{
