@@ -71,7 +71,7 @@ CShapes_Split::CShapes_Split(void)
 {
 	Set_Name		(_TL("Split Shapes Layer"));
 
-	Set_Author		(SG_T("(c) 2006 by O.Conrad"));
+	Set_Author		("O.Conrad (c) 2006");
 
 	Set_Description	(_TW(
 		""
@@ -79,94 +79,88 @@ CShapes_Split::CShapes_Split(void)
 
 	//-----------------------------------------------------
 	Parameters.Add_Shapes(
-		NULL	, "SHAPES"		, _TL("Shapes"),
+		"", "SHAPES", _TL("Shapes"),
 		_TL(""),
 		PARAMETER_INPUT
 	);
 
 	Parameters.Add_Shapes_List(
-		NULL	, "CUTS"		, _TL("Tiles"),
+		"", "CUTS"	, _TL("Tiles"),
 		_TL(""),
 		PARAMETER_OUTPUT_OPTIONAL
 	);
 
 	Parameters.Add_Shapes(
-		NULL	, "EXTENT"		, _TL("Extent"),
+		"", "EXTENT", _TL("Extent"),
 		_TL(""),
 		PARAMETER_OUTPUT_OPTIONAL, SHAPE_TYPE_Polygon
 	);
 
-	Parameters.Add_Value(
-		NULL	, "NX"			, _TL("Number of horizontal tiles"),
+	Parameters.Add_Int(
+		"", "NX"	, _TL("Number of horizontal tiles"),
 		_TL(""),
-		PARAMETER_TYPE_Int, 2, 1, true
+		2, 1, true
 	);
 
-	Parameters.Add_Value(
-		NULL	, "NY"			, _TL("Number of vertical tiles"),
+	Parameters.Add_Int(
+		"", "NY"	, _TL("Number of vertical tiles"),
 		_TL(""),
-		PARAMETER_TYPE_Int, 2, 1, true
+		2, 1, true
 	);
 
 	Parameters.Add_Choice(
-		NULL	, "METHOD"		, _TL("Method"),
+		"", "METHOD", _TL("Method"),
 		_TL(""),
 		Cut_Methods_Str(), 0
 	);
 }
 
-//---------------------------------------------------------
-CShapes_Split::~CShapes_Split(void)
-{}
-
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 bool CShapes_Split::On_Execute(void)
 {
-	int			x, y, nx, ny, Method;
-	CSG_Shapes	*pShapes, *pCut, *pExtent;
-
 	//-----------------------------------------------------
-	pShapes	= Parameters("SHAPES")	->asShapes();
-	pExtent	= Parameters("EXTENT")	->asShapes();
-	nx		= Parameters("NX")		->asInt();
-	ny		= Parameters("NY")		->asInt();
-	Method	= Parameters("METHOD")	->asInt();
+	CSG_Shapes	*pShapes	= Parameters("SHAPES")->asShapes();
+	CSG_Shapes	*pExtent	= Parameters("EXTENT")->asShapes();
+
+	int	Method	= Parameters("METHOD")->asInt();
+
+	int	nx	= Parameters("NX")->asInt();
+	int	ny	= Parameters("NY")->asInt();
 
 	Parameters("CUTS")->asShapesList()->Del_Items();
 
 	//-----------------------------------------------------
 	if( pShapes->is_Valid() )
 	{
-		double		dx, dy;
-		TSG_Rect	r;
+		double	dx	= pShapes->Get_Extent().Get_XRange() / nx;
+		double	dy	= pShapes->Get_Extent().Get_YRange() / ny;
 
-		dx	= pShapes->Get_Extent().Get_XRange() / nx;
-		dy	= pShapes->Get_Extent().Get_YRange() / ny;
-
-		for(y=0; y<ny && Process_Get_Okay(false); y++)
+		for(int y=0; y<ny && Process_Get_Okay(false); y++)
 		{
+			TSG_Rect	r;
+
 			r.yMin	= pShapes->Get_Extent().Get_YMin() + y * dy;
 			r.yMax	= r.yMin + dy;
 
-			for(x=0; x<nx && Process_Get_Okay(false); x++)
+			for(int x=0; x<nx && Process_Get_Okay(false); x++)
 			{
 				r.xMin	= pShapes->Get_Extent().Get_XMin() + x * dx;
 				r.xMax	= r.xMin + dx;
 
 				Cut_Set_Extent(r, pExtent, y == 0 && x == 0);
 
-				Process_Set_Text(CSG_String::Format(SG_T("%d/%d"), y * nx + (x + 1), nx * ny));
+				Process_Set_Text("%d/%d", y * nx + (x + 1), nx * ny);
 
-				if( (pCut = Cut_Shapes(r, Method, pShapes)) != NULL )
+				CSG_Shapes	*pCut	= Cut_Shapes(r, Method, pShapes);
+
+				if( pCut )
 				{
-					pCut->Set_Name(CSG_String::Format(SG_T("%s [%d][%d]"), pShapes->Get_Name(), 1 + x, 1 + y));
+					pCut->Set_Name("%s [%d][%d]", pShapes->Get_Name(), 1 + x, 1 + y);
 
 					Parameters("CUTS")->asShapesList()->Add_Item(pCut);
 				}
@@ -176,6 +170,7 @@ bool CShapes_Split::On_Execute(void)
 		return( true );
 	}
 
+	//-----------------------------------------------------
 	return( false );
 }
 
