@@ -199,12 +199,12 @@ CKinWav_D8::CKinWav_D8(void)
 //---------------------------------------------------------
 int CKinWav_D8::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
-	if( !SG_STR_CMP(pParameter->Get_Identifier(), "GAUGES_FLOW") )
+	if( pParameter->Cmp_Identifier("GAUGES_FLOW") )
 	{
 		pParameters->Set_Enabled("GAUGES", pParameter->asTable() != NULL);
 	}
 
-	if( !SG_STR_CMP(pParameter->Get_Identifier(), "P_DISTRIB") )
+	if( pParameter->Cmp_Identifier("P_DISTRIB") )
 	{
 		pParameters->Set_Enabled("P_THRESHOLD", pParameter->asInt() == 1);
 	}
@@ -233,7 +233,7 @@ bool CKinWav_D8::On_Execute(void)
 
 	for(double Time=0.0; Time<=Time_Span && Set_Progress(Time, Time_Span); Time+=m_dTime)
 	{
-		Process_Set_Text(CSG_String::Format("%s [h]: %0.2f (%0.2f)", _TL("Simulation Time"), Time, Time_Span));
+		Process_Set_Text("%s [h]: %0.2f (%0.2f)", _TL("Simulation Time"), Time, Time_Span);
 
 		Set_Flow(Time);
 
@@ -436,14 +436,14 @@ bool CKinWav_D8::Initialize(void)
 	}
 
 	//-----------------------------------------------------
-	m_Flow_t0.Create(*Get_System(), SG_DATATYPE_Float);
-	m_Length .Create(*Get_System(), SG_DATATYPE_Float);
-	m_Alpha  .Create(*Get_System(), SG_DATATYPE_Float);
+	m_Flow_t0.Create(Get_System(), SG_DATATYPE_Float);
+	m_Length .Create(Get_System(), SG_DATATYPE_Float);
+	m_Alpha  .Create(Get_System(), SG_DATATYPE_Float);
 
 	switch( m_Routing )
 	{
 	default:
-		m_dFlow	= new CSG_Grid(*Get_System(), SG_DATATYPE_Char);
+		m_dFlow	= new CSG_Grid(Get_System(), SG_DATATYPE_Char);
 		break;
 
 	case  1:
@@ -451,7 +451,7 @@ bool CKinWav_D8::Initialize(void)
 
 		for(int i=0; i<8; i++)
 		{
-			m_dFlow[i].Create(*Get_System(), SG_DATATYPE_Float);
+			m_dFlow[i].Create(Get_System(), SG_DATATYPE_Float);
 		}
 		break;
 	}
@@ -637,7 +637,7 @@ bool CKinWav_D8::Gauges_Initialise(void)
 					{
 						CSG_Shape	*pGauge	= m_pGauges->Add_Shape();
 
-						pGauge->Add_Point(Get_System()->Get_Grid_to_World(x, y));
+						pGauge->Add_Point(Get_System().Get_Grid_to_World(x, y));
 						pGauge->Set_Value(0, m_pGauges->Get_Count() + 1);
 					}
 				}
