@@ -1,6 +1,3 @@
-/**********************************************************
- * Version $Id: grid_pca.h 1921 2014-01-09 10:24:11Z oconrad $
- *********************************************************/
 
 ///////////////////////////////////////////////////////////
 //                                                       //
@@ -48,18 +45,12 @@
 //                                                       //
 ///////////////////////////////////////////////////////////
 
-///////////////////////////////////////////////////////////
-//                                                       //
-//                                                       //
-//                                                       //
-///////////////////////////////////////////////////////////
-
 //---------------------------------------------------------
 #ifndef HEADER_INCLUDED__grid_pca_H
 #define HEADER_INCLUDED__grid_pca_H
 
 //---------------------------------------------------------
-#include "MLB_Interface.h"
+#include <saga_api/saga_api.h>
 
 
 ///////////////////////////////////////////////////////////
@@ -101,6 +92,7 @@ private:
 
 };
 
+
 ///////////////////////////////////////////////////////////
 //                                                       //
 ///////////////////////////////////////////////////////////
