@@ -200,12 +200,12 @@ CGrid_Multi_Grid_Regression::CGrid_Multi_Grid_Regression(void)
 //---------------------------------------------------------
 int CGrid_Multi_Grid_Regression::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
-	if(	!SG_STR_CMP(pParameter->Get_Identifier(), "CROSSVAL") )
+	if(	pParameter->Cmp_Identifier("CROSSVAL") )
 	{
 		pParameters->Set_Enabled("CROSSVAL_K", pParameter->asInt() == 3);	// k-fold
 	}
 
-	if(	!SG_STR_CMP(pParameter->Get_Identifier(), "METHOD") )
+	if(	pParameter->Cmp_Identifier("METHOD") )
 	{
 		pParameters->Set_Enabled("P_VALUE", pParameter->asInt() > 0);
 	}
@@ -273,12 +273,12 @@ bool CGrid_Multi_Grid_Regression::On_Execute(void)
 
 	if( CrossVal > 0 && m_Regression.Get_CrossValidation(CrossVal) )
 	{
-		Message_Add(CSG_String::Format(SG_T("\n%s:\n"      ), _TL("Cross Validation")), false);
-		Message_Add(CSG_String::Format(SG_T("\t%s:\t%s\n"  ), _TL("Type"   ), Parameters("CROSSVAL")->asString() ), false);
-		Message_Add(CSG_String::Format(SG_T("\t%s:\t%d\n"  ), _TL("Samples"), m_Regression.Get_CV_nSamples()     ), false);
-		Message_Add(CSG_String::Format(SG_T("\t%s:\t%f\n"  ), _TL("RMSE"   ), m_Regression.Get_CV_RMSE()         ), false);
-		Message_Add(CSG_String::Format(SG_T("\t%s:\t%.2f\n"), _TL("NRMSE"  ), m_Regression.Get_CV_NRMSE() * 100.0), false);
-		Message_Add(CSG_String::Format(SG_T("\t%s:\t%.2f\n"), _TL("R2"     ), m_Regression.Get_CV_R2()    * 100.0), false);
+		Message_Fmt("\n%s:", _TL("Cross Validation"));
+		Message_Fmt("\n\t%s:\t%s"  , _TL("Type"   ), Parameters("CROSSVAL")->asString() );
+		Message_Fmt("\n\t%s:\t%d"  , _TL("Samples"), m_Regression.Get_CV_nSamples()     );
+		Message_Fmt("\n\t%s:\t%f"  , _TL("RMSE"   ), m_Regression.Get_CV_RMSE()         );
+		Message_Fmt("\n\t%s:\t%.2f", _TL("NRMSE"  ), m_Regression.Get_CV_NRMSE() * 100.0);
+		Message_Fmt("\n\t%s:\t%.2f", _TL("R2"     ), m_Regression.Get_CV_R2()    * 100.0);
 	}
 
 	//-----------------------------------------------------
@@ -437,7 +437,7 @@ bool CGrid_Multi_Grid_Regression::Set_Regression(CSG_Parameter_Grid_List *pGrids
 
 	if( pDependent && pResiduals )
 	{
-		pResiduals->Set_Name(CSG_String::Format(SG_T("%s [%s]"), Name.c_str(), _TL("Residuals")));
+		pResiduals->Set_Name("%s [%s]", Name.c_str(), _TL("Residuals"));
 	}
 	else
 	{
@@ -471,12 +471,12 @@ bool CGrid_Multi_Grid_Regression::Set_Regression(CSG_Parameter_Grid_List *pGrids
 			{
 				if( bCoord_X )
 				{
-					z	+= m_Regression.Get_RCoeff(iGrid++) * Get_System()->Get_xGrid_to_World(x);
+					z	+= m_Regression.Get_RCoeff(iGrid++) * Get_System().Get_xGrid_to_World(x);
 				}
 
 				if( bCoord_Y )
 				{
-					z	+= m_Regression.Get_RCoeff(iGrid++) * Get_System()->Get_yGrid_to_World(y);
+					z	+= m_Regression.Get_RCoeff(iGrid++) * Get_System().Get_yGrid_to_World(y);
 				}
 
 				pRegression->Set_Value (x, y, z);
