@@ -151,7 +151,7 @@ void CTable_Regression_Multiple_Base::Initialise(void)
 //---------------------------------------------------------
 int CTable_Regression_Multiple_Base::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
-	if( !SG_STR_CMP(pParameter->Get_Identifier(), SG_T("TABLE")) )
+	if( pParameter->Cmp_Identifier(SG_T("TABLE")) )
 	{
 		CSG_Table		*pTable			= pParameter->asTable();
 		CSG_Parameters	*pPredictors	= pParameters->Get_Parameter("PREDICTORS")->asParameters();
@@ -176,12 +176,12 @@ int CTable_Regression_Multiple_Base::On_Parameter_Changed(CSG_Parameters *pParam
 //---------------------------------------------------------
 int CTable_Regression_Multiple_Base::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
-	if(	!SG_STR_CMP(pParameter->Get_Identifier(), SG_T("METHOD")) )
+	if(	pParameter->Cmp_Identifier(SG_T("METHOD")) )
 	{
 		pParameters->Set_Enabled("P_VALUE", pParameter->asInt() > 0);
 	}
 
-	if(	!SG_STR_CMP(pParameter->Get_Identifier(), SG_T("CROSSVAL")) )
+	if(	pParameter->Cmp_Identifier(SG_T("CROSSVAL")) )
 	{
 		pParameters->Get_Parameter("CROSSVAL_K")->Set_Enabled(pParameter->asInt() == 3);	// k-fold
 	}
@@ -309,12 +309,12 @@ bool CTable_Regression_Multiple_Base::On_Execute(void)
 
 	if( CrossVal > 0 && Regression.Get_CrossValidation(CrossVal) )
 	{
-		Message_Add(CSG_String::Format(SG_T("\n%s:\n"      ), _TL("Cross Validation")), false);
-		Message_Add(CSG_String::Format(SG_T("\t%s:\t%s\n"  ), _TL("Type"   ), Parameters("CROSSVAL")->asString()), false);
-		Message_Add(CSG_String::Format(SG_T("\t%s:\t%d\n"  ), _TL("Samples"), Regression.Get_CV_nSamples()      ), false);
-		Message_Add(CSG_String::Format(SG_T("\t%s:\t%f\n"  ), _TL("RMSE"   ), Regression.Get_CV_RMSE()          ), false);
-		Message_Add(CSG_String::Format(SG_T("\t%s:\t%.2f\n"), _TL("NRMSE"  ), Regression.Get_CV_NRMSE()  * 100.0), false);
-		Message_Add(CSG_String::Format(SG_T("\t%s:\t%.2f\n"), _TL("R2"     ), Regression.Get_CV_R2()     * 100.0), false);
+		Message_Fmt("\n%s:", _TL("Cross Validation"));
+		Message_Fmt("\n\t%s:\t%s"  , _TL("Type"   ), Parameters("CROSSVAL")->asString());
+		Message_Fmt("\n\t%s:\t%d"  , _TL("Samples"), Regression.Get_CV_nSamples()      );
+		Message_Fmt("\n\t%s:\t%f"  , _TL("RMSE"   ), Regression.Get_CV_RMSE()          );
+		Message_Fmt("\n\t%s:\t%.2f", _TL("NRMSE"  ), Regression.Get_CV_NRMSE()  * 100.0);
+		Message_Fmt("\n\t%s:\t%.2f", _TL("R2"     ), Regression.Get_CV_R2()     * 100.0);
 	}
 
 	//-----------------------------------------------------
@@ -351,7 +351,7 @@ bool CTable_Regression_Multiple_Base::On_Execute(void)
 			pResults->Create(*pTable);
 		}
 
-		pResults->Set_Name(CSG_String::Format(SG_T("%s [%s]"), pTable->Get_Name(), _TL("Regression")));
+		pResults->Set_Name("%s [%s]", pTable->Get_Name(), _TL("Regression"));
 
 		pTable	= pResults;
 	}
