@@ -141,7 +141,7 @@ CTable_Text_Replacer::CTable_Text_Replacer(void)
 //---------------------------------------------------------
 int CTable_Text_Replacer::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
-	if( !SG_STR_CMP(pParameter->Get_Identifier(), "TABLE") )
+	if( pParameter->Cmp_Identifier("TABLE") )
 	{
 		CSG_Data_Object	*pObject	= pParameter->asDataObject();
 
@@ -193,7 +193,7 @@ bool CTable_Text_Replacer::On_Execute(void)
 
 	if( pTable != Parameters("TABLE")->asTable() )
 	{
-		pTable->Set_Name(CSG_String::Format(SG_T("%s [%s]"), pTable->Get_Name(), _TL("Replacements")));
+		pTable->Set_Name("%s [%s]", pTable->Get_Name(), _TL("Replacements"));
 	}
 
 	//-----------------------------------------------------
@@ -220,7 +220,7 @@ bool CTable_Text_Replacer::On_Execute(void)
 	}
 
 	//-----------------------------------------------------
-	Message_Add(CSG_String::Format(SG_T("%s: %d"), _TL("number of replacements"), nChanges));
+	Message_Fmt("\n%s: %d", _TL("number of replacements"), nChanges);
 
 	if( pTable == Parameters("TABLE")->asTable() )
 	{
