@@ -142,12 +142,12 @@ void CFlow::Set_Point(int x, int y)
 //---------------------------------------------------------
 int CFlow::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
-	if( !SG_STR_CMP(pParameter->Get_Identifier(), "VAL_INPUT") )
+	if( pParameter->Cmp_Identifier("VAL_INPUT") )
 	{
 		pParameters->Set_Enabled("VAL_MEAN"   , pParameter->asGrid() != NULL);
 	}
 
-	if( !SG_STR_CMP(pParameter->Get_Identifier(), "ACCU_MATERIAL") )
+	if( pParameter->Cmp_Identifier("ACCU_MATERIAL") )
 	{
 		pParameters->Set_Enabled("ACCU_TARGET", pParameter->asGrid() != NULL);
 		pParameters->Set_Enabled("ACCU_TOTAL" , pParameter->asGrid() != NULL);
@@ -181,7 +181,7 @@ bool CFlow::On_Execute(void)
 	if( (m_pVal_Input	= Parameters("VAL_INPUT"    )->asGrid()) != NULL
 	&&  (m_pVal_Mean	= Parameters("VAL_MEAN"     )->asGrid()) != NULL )
 	{
-		m_pVal_Mean->Set_Name(CSG_String::Format("%s [%s]", m_pVal_Input->Get_Name(), _TL("Mean over Catchment")));
+		m_pVal_Mean->Set_Name("%s [%s]", m_pVal_Input->Get_Name(), _TL("Mean over Catchment"));
 		m_pVal_Mean->Set_Unit(m_pVal_Input->Get_Unit());
 	}
 	else
@@ -301,7 +301,7 @@ void CFlow::_Finalize(void)
 
 			if( m_pFlow && bCellsToArea )
 			{
-				m_pFlow->Set_Value(n, Flow * Get_System()->Get_Cellarea());
+				m_pFlow->Set_Value(n, Flow * Get_Cellarea());
 			}
 
 			if( Flow > 0.0 )
